@font-face {
    font-family: 思源宋體SemiBold;
    src: url('../素材/NotoSerifSC-SemiBold.otf');
}
@keyframes a {
    0% {
        opacity: 0;
    }
    100% {
        opacity: 1;
    }
}
:root {
    --x: 0px;
    --y: 0px;
}
body {
    font-family: 思源宋體SemiBold !important;
    font-size: 1.6vw;
    text-shadow: 0px 0px 5px #FFF;
    overflow: hidden;
    animation: a 2s;
}

a.synth {
    padding: 1vw 1.5vw;
}

#bb {
    filter: drop-shadow(var(--x) var(--y) 0.8vw rgba(0, 0, 0, 0.6));
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    margin: 0;
    padding: 0;
    z-index: -1;
}

#bg2 {
    -webkit-mask-image: url('虛僞的假面.png');
    -webkit-mask-size: cover;
    filter: hue-rotate(var(--s));
    background: url('../../../../黑科技/synthetic_css/紙背景花紋模糊.jpg');
    background-size: cover;
    width: 100%;
    height: 100%;
}

.主 {
    font-size: 250%;
    line-height: 150%;
    margin-left: 50%;
    margin-top: 10%;
    
}

.主>div {
    margin: 8%;
}
