!function(e){var t={};function n(r){if(t[r])return t[r].exports;var i=t[r]={i:r,l:!1,exports:{}};return e[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var i in e)n.d(r,i,function(t){return e[t]}.bind(null,i));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="./dist/",n(n.s=32)}([function(e,t,n){var r;
/*!
 * jQuery JavaScript Library v3.4.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2019-05-01T21:04Z
 */!function(t,n){"use strict";"object"==typeof e.exports?e.exports=t.document?n(t,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return n(e)}:n(t)}("undefined"!=typeof window?window:this,(function(n,i){"use strict";var o=[],a=n.document,s=Object.getPrototypeOf,u=o.slice,c=o.concat,l=o.push,f=o.indexOf,h={},p=h.toString,d=h.hasOwnProperty,v=d.toString,g=v.call(Object),y={},m=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType},b=function(e){return null!=e&&e===e.window},_={type:!0,src:!0,nonce:!0,noModule:!0};function w(e,t,n){var r,i,o=(n=n||a).createElement("script");if(o.text=e,t)for(r in _)(i=t[r]||t.getAttribute&&t.getAttribute(r))&&o.setAttribute(r,i);n.head.appendChild(o).parentNode.removeChild(o)}function x(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?h[p.call(e)]||"object":typeof e}var T=function(e,t){return new T.fn.init(e,t)},C=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;function E(e){var t=!!e&&"length"in e&&e.length,n=x(e);return!m(e)&&!b(e)&&("array"===n||0===t||"number"==typeof t&&t>0&&t-1 in e)}T.fn=T.prototype={jquery:"3.4.1",constructor:T,length:0,toArray:function(){return u.call(this)},get:function(e){return null==e?u.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=T.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return T.each(this,e)},map:function(e){return this.pushStack(T.map(this,(function(t,n){return e.call(t,n,t)})))},slice:function(){return this.pushStack(u.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(e){var t=this.length,n=+e+(e<0?t:0);return this.pushStack(n>=0&&n<t?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:l,sort:o.sort,splice:o.splice},T.extend=T.fn.extend=function(){var e,t,n,r,i,o,a=arguments[0]||{},s=1,u=arguments.length,c=!1;for("boolean"==typeof a&&(c=a,a=arguments[s]||{},s++),"object"==typeof a||m(a)||(a={}),s===u&&(a=this,s--);s<u;s++)if(null!=(e=arguments[s]))for(t in e)r=e[t],"__proto__"!==t&&a!==r&&(c&&r&&(T.isPlainObject(r)||(i=Array.isArray(r)))?(n=a[t],o=i&&!Array.isArray(n)?[]:i||T.isPlainObject(n)?n:{},i=!1,a[t]=T.extend(c,o,r)):void 0!==r&&(a[t]=r));return a},T.extend({expando:"jQuery"+("3.4.1"+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,n;return!(!e||"[object Object]"!==p.call(e))&&(!(t=s(e))||"function"==typeof(n=d.call(t,"constructor")&&t.constructor)&&v.call(n)===g)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t){w(e,{nonce:t&&t.nonce})},each:function(e,t){var n,r=0;if(E(e))for(n=e.length;r<n&&!1!==t.call(e[r],r,e[r]);r++);else for(r in e)if(!1===t.call(e[r],r,e[r]))break;return e},trim:function(e){return null==e?"":(e+"").replace(C,"")},makeArray:function(e,t){var n=t||[];return null!=e&&(E(Object(e))?T.merge(n,"string"==typeof e?[e]:e):l.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:f.call(t,e,n)},merge:function(e,t){for(var n=+t.length,r=0,i=e.length;r<n;r++)e[i++]=t[r];return e.length=i,e},grep:function(e,t,n){for(var r=[],i=0,o=e.length,a=!n;i<o;i++)!t(e[i],i)!==a&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=0,a=[];if(E(e))for(r=e.length;o<r;o++)null!=(i=t(e[o],o,n))&&a.push(i);else for(o in e)null!=(i=t(e[o],o,n))&&a.push(i);return c.apply([],a)},guid:1,support:y}),"function"==typeof Symbol&&(T.fn[Symbol.iterator]=o[Symbol.iterator]),T.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),(function(e,t){h["[object "+t+"]"]=t.toLowerCase()}));var k=
/*!
 * Sizzle CSS Selector Engine v2.3.4
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://js.foundation/
 *
 * Date: 2019-04-08
 */
function(e){var t,n,r,i,o,a,s,u,c,l,f,h,p,d,v,g,y,m,b,_="sizzle"+1*new Date,w=e.document,x=0,T=0,C=ue(),E=ue(),k=ue(),S=ue(),A=function(e,t){return e===t&&(f=!0),0},O={}.hasOwnProperty,D=[],P=D.pop,N=D.push,j=D.push,L=D.slice,I=function(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1},M="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",R="[\\x20\\t\\r\\n\\f]",B="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",$="\\["+R+"*("+B+")(?:"+R+"*([*^$|!~]?=)"+R+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+B+"))|)"+R+"*\\]",q=":("+B+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+$+")*)|.*)\\)|)",F=new RegExp(R+"+","g"),H=new RegExp("^"+R+"+|((?:^|[^\\\\])(?:\\\\.)*)"+R+"+$","g"),U=new RegExp("^"+R+"*,"+R+"*"),W=new RegExp("^"+R+"*([>+~]|"+R+")"+R+"*"),z=new RegExp(R+"|>"),K=new RegExp(q),V=new RegExp("^"+B+"$"),X={ID:new RegExp("^#("+B+")"),CLASS:new RegExp("^\\.("+B+")"),TAG:new RegExp("^("+B+"|[*])"),ATTR:new RegExp("^"+$),PSEUDO:new RegExp("^"+q),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+R+"*(even|odd|(([+-]|)(\\d*)n|)"+R+"*(?:([+-]|)"+R+"*(\\d+)|))"+R+"*\\)|)","i"),bool:new RegExp("^(?:"+M+")$","i"),needsContext:new RegExp("^"+R+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+R+"*((?:-\\d)?\\d*)"+R+"*\\)|)(?=[^-]|$)","i")},Y=/HTML$/i,G=/^(?:input|select|textarea|button)$/i,J=/^h\d$/i,Z=/^[^{]+\{\s*\[native \w/,Q=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ee=/[+~]/,te=new RegExp("\\\\([\\da-f]{1,6}"+R+"?|("+R+")|.)","ig"),ne=function(e,t,n){var r="0x"+t-65536;return r!=r||n?t:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},re=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ie=function(e,t){return t?"\0"===e?"�":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e},oe=function(){h()},ae=_e((function(e){return!0===e.disabled&&"fieldset"===e.nodeName.toLowerCase()}),{dir:"parentNode",next:"legend"});try{j.apply(D=L.call(w.childNodes),w.childNodes),D[w.childNodes.length].nodeType}catch(e){j={apply:D.length?function(e,t){N.apply(e,L.call(t))}:function(e,t){for(var n=e.length,r=0;e[n++]=t[r++];);e.length=n-1}}}function se(e,t,r,i){var o,s,c,l,f,d,y,m=t&&t.ownerDocument,x=t?t.nodeType:9;if(r=r||[],"string"!=typeof e||!e||1!==x&&9!==x&&11!==x)return r;if(!i&&((t?t.ownerDocument||t:w)!==p&&h(t),t=t||p,v)){if(11!==x&&(f=Q.exec(e)))if(o=f[1]){if(9===x){if(!(c=t.getElementById(o)))return r;if(c.id===o)return r.push(c),r}else if(m&&(c=m.getElementById(o))&&b(t,c)&&c.id===o)return r.push(c),r}else{if(f[2])return j.apply(r,t.getElementsByTagName(e)),r;if((o=f[3])&&n.getElementsByClassName&&t.getElementsByClassName)return j.apply(r,t.getElementsByClassName(o)),r}if(n.qsa&&!S[e+" "]&&(!g||!g.test(e))&&(1!==x||"object"!==t.nodeName.toLowerCase())){if(y=e,m=t,1===x&&z.test(e)){for((l=t.getAttribute("id"))?l=l.replace(re,ie):t.setAttribute("id",l=_),s=(d=a(e)).length;s--;)d[s]="#"+l+" "+be(d[s]);y=d.join(","),m=ee.test(e)&&ye(t.parentNode)||t}try{return j.apply(r,m.querySelectorAll(y)),r}catch(t){S(e,!0)}finally{l===_&&t.removeAttribute("id")}}}return u(e.replace(H,"$1"),t,r,i)}function ue(){var e=[];return function t(n,i){return e.push(n+" ")>r.cacheLength&&delete t[e.shift()],t[n+" "]=i}}function ce(e){return e[_]=!0,e}function le(e){var t=p.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function fe(e,t){for(var n=e.split("|"),i=n.length;i--;)r.attrHandle[n[i]]=t}function he(e,t){var n=t&&e,r=n&&1===e.nodeType&&1===t.nodeType&&e.sourceIndex-t.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===t)return-1;return e?1:-1}function pe(e){return function(t){return"input"===t.nodeName.toLowerCase()&&t.type===e}}function de(e){return function(t){var n=t.nodeName.toLowerCase();return("input"===n||"button"===n)&&t.type===e}}function ve(e){return function(t){return"form"in t?t.parentNode&&!1===t.disabled?"label"in t?"label"in t.parentNode?t.parentNode.disabled===e:t.disabled===e:t.isDisabled===e||t.isDisabled!==!e&&ae(t)===e:t.disabled===e:"label"in t&&t.disabled===e}}function ge(e){return ce((function(t){return t=+t,ce((function(n,r){for(var i,o=e([],n.length,t),a=o.length;a--;)n[i=o[a]]&&(n[i]=!(r[i]=n[i]))}))}))}function ye(e){return e&&void 0!==e.getElementsByTagName&&e}for(t in n=se.support={},o=se.isXML=function(e){var t=e.namespaceURI,n=(e.ownerDocument||e).documentElement;return!Y.test(t||n&&n.nodeName||"HTML")},h=se.setDocument=function(e){var t,i,a=e?e.ownerDocument||e:w;return a!==p&&9===a.nodeType&&a.documentElement?(d=(p=a).documentElement,v=!o(p),w!==p&&(i=p.defaultView)&&i.top!==i&&(i.addEventListener?i.addEventListener("unload",oe,!1):i.attachEvent&&i.attachEvent("onunload",oe)),n.attributes=le((function(e){return e.className="i",!e.getAttribute("className")})),n.getElementsByTagName=le((function(e){return e.appendChild(p.createComment("")),!e.getElementsByTagName("*").length})),n.getElementsByClassName=Z.test(p.getElementsByClassName),n.getById=le((function(e){return d.appendChild(e).id=_,!p.getElementsByName||!p.getElementsByName(_).length})),n.getById?(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){return e.getAttribute("id")===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&v){var n=t.getElementById(e);return n?[n]:[]}}):(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){var n=void 0!==e.getAttributeNode&&e.getAttributeNode("id");return n&&n.value===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&v){var n,r,i,o=t.getElementById(e);if(o){if((n=o.getAttributeNode("id"))&&n.value===e)return[o];for(i=t.getElementsByName(e),r=0;o=i[r++];)if((n=o.getAttributeNode("id"))&&n.value===e)return[o]}return[]}}),r.find.TAG=n.getElementsByTagName?function(e,t){return void 0!==t.getElementsByTagName?t.getElementsByTagName(e):n.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,r=[],i=0,o=t.getElementsByTagName(e);if("*"===e){for(;n=o[i++];)1===n.nodeType&&r.push(n);return r}return o},r.find.CLASS=n.getElementsByClassName&&function(e,t){if(void 0!==t.getElementsByClassName&&v)return t.getElementsByClassName(e)},y=[],g=[],(n.qsa=Z.test(p.querySelectorAll))&&(le((function(e){d.appendChild(e).innerHTML="<a id='"+_+"'></a><select id='"+_+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&g.push("[*^$]="+R+"*(?:''|\"\")"),e.querySelectorAll("[selected]").length||g.push("\\["+R+"*(?:value|"+M+")"),e.querySelectorAll("[id~="+_+"-]").length||g.push("~="),e.querySelectorAll(":checked").length||g.push(":checked"),e.querySelectorAll("a#"+_+"+*").length||g.push(".#.+[+~]")})),le((function(e){e.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var t=p.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&g.push("name"+R+"*[*^$|!~]?="),2!==e.querySelectorAll(":enabled").length&&g.push(":enabled",":disabled"),d.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&g.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),g.push(",.*:")}))),(n.matchesSelector=Z.test(m=d.matches||d.webkitMatchesSelector||d.mozMatchesSelector||d.oMatchesSelector||d.msMatchesSelector))&&le((function(e){n.disconnectedMatch=m.call(e,"*"),m.call(e,"[s!='']:x"),y.push("!=",q)})),g=g.length&&new RegExp(g.join("|")),y=y.length&&new RegExp(y.join("|")),t=Z.test(d.compareDocumentPosition),b=t||Z.test(d.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):e.compareDocumentPosition&&16&e.compareDocumentPosition(r)))}:function(e,t){if(t)for(;t=t.parentNode;)if(t===e)return!0;return!1},A=t?function(e,t){if(e===t)return f=!0,0;var r=!e.compareDocumentPosition-!t.compareDocumentPosition;return r||(1&(r=(e.ownerDocument||e)===(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!n.sortDetached&&t.compareDocumentPosition(e)===r?e===p||e.ownerDocument===w&&b(w,e)?-1:t===p||t.ownerDocument===w&&b(w,t)?1:l?I(l,e)-I(l,t):0:4&r?-1:1)}:function(e,t){if(e===t)return f=!0,0;var n,r=0,i=e.parentNode,o=t.parentNode,a=[e],s=[t];if(!i||!o)return e===p?-1:t===p?1:i?-1:o?1:l?I(l,e)-I(l,t):0;if(i===o)return he(e,t);for(n=e;n=n.parentNode;)a.unshift(n);for(n=t;n=n.parentNode;)s.unshift(n);for(;a[r]===s[r];)r++;return r?he(a[r],s[r]):a[r]===w?-1:s[r]===w?1:0},p):p},se.matches=function(e,t){return se(e,null,null,t)},se.matchesSelector=function(e,t){if((e.ownerDocument||e)!==p&&h(e),n.matchesSelector&&v&&!S[t+" "]&&(!y||!y.test(t))&&(!g||!g.test(t)))try{var r=m.call(e,t);if(r||n.disconnectedMatch||e.document&&11!==e.document.nodeType)return r}catch(e){S(t,!0)}return se(t,p,null,[e]).length>0},se.contains=function(e,t){return(e.ownerDocument||e)!==p&&h(e),b(e,t)},se.attr=function(e,t){(e.ownerDocument||e)!==p&&h(e);var i=r.attrHandle[t.toLowerCase()],o=i&&O.call(r.attrHandle,t.toLowerCase())?i(e,t,!v):void 0;return void 0!==o?o:n.attributes||!v?e.getAttribute(t):(o=e.getAttributeNode(t))&&o.specified?o.value:null},se.escape=function(e){return(e+"").replace(re,ie)},se.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},se.uniqueSort=function(e){var t,r=[],i=0,o=0;if(f=!n.detectDuplicates,l=!n.sortStable&&e.slice(0),e.sort(A),f){for(;t=e[o++];)t===e[o]&&(i=r.push(o));for(;i--;)e.splice(r[i],1)}return l=null,e},i=se.getText=function(e){var t,n="",r=0,o=e.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=i(e)}else if(3===o||4===o)return e.nodeValue}else for(;t=e[r++];)n+=i(t);return n},(r=se.selectors={cacheLength:50,createPseudo:ce,match:X,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(te,ne),e[3]=(e[3]||e[4]||e[5]||"").replace(te,ne),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||se.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&se.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return X.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&K.test(n)&&(t=a(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(te,ne).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=C[e+" "];return t||(t=new RegExp("(^|"+R+")"+e+"("+R+"|$)"))&&C(e,(function(e){return t.test("string"==typeof e.className&&e.className||void 0!==e.getAttribute&&e.getAttribute("class")||"")}))},ATTR:function(e,t,n){return function(r){var i=se.attr(r,e);return null==i?"!="===t:!t||(i+="","="===t?i===n:"!="===t?i!==n:"^="===t?n&&0===i.indexOf(n):"*="===t?n&&i.indexOf(n)>-1:"$="===t?n&&i.slice(-n.length)===n:"~="===t?(" "+i.replace(F," ")+" ").indexOf(n)>-1:"|="===t&&(i===n||i.slice(0,n.length+1)===n+"-"))}},CHILD:function(e,t,n,r,i){var o="nth"!==e.slice(0,3),a="last"!==e.slice(-4),s="of-type"===t;return 1===r&&0===i?function(e){return!!e.parentNode}:function(t,n,u){var c,l,f,h,p,d,v=o!==a?"nextSibling":"previousSibling",g=t.parentNode,y=s&&t.nodeName.toLowerCase(),m=!u&&!s,b=!1;if(g){if(o){for(;v;){for(h=t;h=h[v];)if(s?h.nodeName.toLowerCase()===y:1===h.nodeType)return!1;d=v="only"===e&&!d&&"nextSibling"}return!0}if(d=[a?g.firstChild:g.lastChild],a&&m){for(b=(p=(c=(l=(f=(h=g)[_]||(h[_]={}))[h.uniqueID]||(f[h.uniqueID]={}))[e]||[])[0]===x&&c[1])&&c[2],h=p&&g.childNodes[p];h=++p&&h&&h[v]||(b=p=0)||d.pop();)if(1===h.nodeType&&++b&&h===t){l[e]=[x,p,b];break}}else if(m&&(b=p=(c=(l=(f=(h=t)[_]||(h[_]={}))[h.uniqueID]||(f[h.uniqueID]={}))[e]||[])[0]===x&&c[1]),!1===b)for(;(h=++p&&h&&h[v]||(b=p=0)||d.pop())&&((s?h.nodeName.toLowerCase()!==y:1!==h.nodeType)||!++b||(m&&((l=(f=h[_]||(h[_]={}))[h.uniqueID]||(f[h.uniqueID]={}))[e]=[x,b]),h!==t)););return(b-=i)===r||b%r==0&&b/r>=0}}},PSEUDO:function(e,t){var n,i=r.pseudos[e]||r.setFilters[e.toLowerCase()]||se.error("unsupported pseudo: "+e);return i[_]?i(t):i.length>1?(n=[e,e,"",t],r.setFilters.hasOwnProperty(e.toLowerCase())?ce((function(e,n){for(var r,o=i(e,t),a=o.length;a--;)e[r=I(e,o[a])]=!(n[r]=o[a])})):function(e){return i(e,0,n)}):i}},pseudos:{not:ce((function(e){var t=[],n=[],r=s(e.replace(H,"$1"));return r[_]?ce((function(e,t,n,i){for(var o,a=r(e,null,i,[]),s=e.length;s--;)(o=a[s])&&(e[s]=!(t[s]=o))})):function(e,i,o){return t[0]=e,r(t,null,o,n),t[0]=null,!n.pop()}})),has:ce((function(e){return function(t){return se(e,t).length>0}})),contains:ce((function(e){return e=e.replace(te,ne),function(t){return(t.textContent||i(t)).indexOf(e)>-1}})),lang:ce((function(e){return V.test(e||"")||se.error("unsupported lang: "+e),e=e.replace(te,ne).toLowerCase(),function(t){var n;do{if(n=v?t.lang:t.getAttribute("xml:lang")||t.getAttribute("lang"))return(n=n.toLowerCase())===e||0===n.indexOf(e+"-")}while((t=t.parentNode)&&1===t.nodeType);return!1}})),target:function(t){var n=e.location&&e.location.hash;return n&&n.slice(1)===t.id},root:function(e){return e===d},focus:function(e){return e===p.activeElement&&(!p.hasFocus||p.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:ve(!1),disabled:ve(!0),checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!r.pseudos.empty(e)},header:function(e){return J.test(e.nodeName)},input:function(e){return G.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:ge((function(){return[0]})),last:ge((function(e,t){return[t-1]})),eq:ge((function(e,t,n){return[n<0?n+t:n]})),even:ge((function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e})),odd:ge((function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e})),lt:ge((function(e,t,n){for(var r=n<0?n+t:n>t?t:n;--r>=0;)e.push(r);return e})),gt:ge((function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e}))}}).pseudos.nth=r.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})r.pseudos[t]=pe(t);for(t in{submit:!0,reset:!0})r.pseudos[t]=de(t);function me(){}function be(e){for(var t=0,n=e.length,r="";t<n;t++)r+=e[t].value;return r}function _e(e,t,n){var r=t.dir,i=t.next,o=i||r,a=n&&"parentNode"===o,s=T++;return t.first?function(t,n,i){for(;t=t[r];)if(1===t.nodeType||a)return e(t,n,i);return!1}:function(t,n,u){var c,l,f,h=[x,s];if(u){for(;t=t[r];)if((1===t.nodeType||a)&&e(t,n,u))return!0}else for(;t=t[r];)if(1===t.nodeType||a)if(l=(f=t[_]||(t[_]={}))[t.uniqueID]||(f[t.uniqueID]={}),i&&i===t.nodeName.toLowerCase())t=t[r]||t;else{if((c=l[o])&&c[0]===x&&c[1]===s)return h[2]=c[2];if(l[o]=h,h[2]=e(t,n,u))return!0}return!1}}function we(e){return e.length>1?function(t,n,r){for(var i=e.length;i--;)if(!e[i](t,n,r))return!1;return!0}:e[0]}function xe(e,t,n,r,i){for(var o,a=[],s=0,u=e.length,c=null!=t;s<u;s++)(o=e[s])&&(n&&!n(o,r,i)||(a.push(o),c&&t.push(s)));return a}function Te(e,t,n,r,i,o){return r&&!r[_]&&(r=Te(r)),i&&!i[_]&&(i=Te(i,o)),ce((function(o,a,s,u){var c,l,f,h=[],p=[],d=a.length,v=o||function(e,t,n){for(var r=0,i=t.length;r<i;r++)se(e,t[r],n);return n}(t||"*",s.nodeType?[s]:s,[]),g=!e||!o&&t?v:xe(v,h,e,s,u),y=n?i||(o?e:d||r)?[]:a:g;if(n&&n(g,y,s,u),r)for(c=xe(y,p),r(c,[],s,u),l=c.length;l--;)(f=c[l])&&(y[p[l]]=!(g[p[l]]=f));if(o){if(i||e){if(i){for(c=[],l=y.length;l--;)(f=y[l])&&c.push(g[l]=f);i(null,y=[],c,u)}for(l=y.length;l--;)(f=y[l])&&(c=i?I(o,f):h[l])>-1&&(o[c]=!(a[c]=f))}}else y=xe(y===a?y.splice(d,y.length):y),i?i(null,a,y,u):j.apply(a,y)}))}function Ce(e){for(var t,n,i,o=e.length,a=r.relative[e[0].type],s=a||r.relative[" "],u=a?1:0,l=_e((function(e){return e===t}),s,!0),f=_e((function(e){return I(t,e)>-1}),s,!0),h=[function(e,n,r){var i=!a&&(r||n!==c)||((t=n).nodeType?l(e,n,r):f(e,n,r));return t=null,i}];u<o;u++)if(n=r.relative[e[u].type])h=[_e(we(h),n)];else{if((n=r.filter[e[u].type].apply(null,e[u].matches))[_]){for(i=++u;i<o&&!r.relative[e[i].type];i++);return Te(u>1&&we(h),u>1&&be(e.slice(0,u-1).concat({value:" "===e[u-2].type?"*":""})).replace(H,"$1"),n,u<i&&Ce(e.slice(u,i)),i<o&&Ce(e=e.slice(i)),i<o&&be(e))}h.push(n)}return we(h)}return me.prototype=r.filters=r.pseudos,r.setFilters=new me,a=se.tokenize=function(e,t){var n,i,o,a,s,u,c,l=E[e+" "];if(l)return t?0:l.slice(0);for(s=e,u=[],c=r.preFilter;s;){for(a in n&&!(i=U.exec(s))||(i&&(s=s.slice(i[0].length)||s),u.push(o=[])),n=!1,(i=W.exec(s))&&(n=i.shift(),o.push({value:n,type:i[0].replace(H," ")}),s=s.slice(n.length)),r.filter)!(i=X[a].exec(s))||c[a]&&!(i=c[a](i))||(n=i.shift(),o.push({value:n,type:a,matches:i}),s=s.slice(n.length));if(!n)break}return t?s.length:s?se.error(e):E(e,u).slice(0)},s=se.compile=function(e,t){var n,i=[],o=[],s=k[e+" "];if(!s){for(t||(t=a(e)),n=t.length;n--;)(s=Ce(t[n]))[_]?i.push(s):o.push(s);(s=k(e,function(e,t){var n=t.length>0,i=e.length>0,o=function(o,a,s,u,l){var f,d,g,y=0,m="0",b=o&&[],_=[],w=c,T=o||i&&r.find.TAG("*",l),C=x+=null==w?1:Math.random()||.1,E=T.length;for(l&&(c=a===p||a||l);m!==E&&null!=(f=T[m]);m++){if(i&&f){for(d=0,a||f.ownerDocument===p||(h(f),s=!v);g=e[d++];)if(g(f,a||p,s)){u.push(f);break}l&&(x=C)}n&&((f=!g&&f)&&y--,o&&b.push(f))}if(y+=m,n&&m!==y){for(d=0;g=t[d++];)g(b,_,a,s);if(o){if(y>0)for(;m--;)b[m]||_[m]||(_[m]=P.call(u));_=xe(_)}j.apply(u,_),l&&!o&&_.length>0&&y+t.length>1&&se.uniqueSort(u)}return l&&(x=C,c=w),b};return n?ce(o):o}(o,i))).selector=e}return s},u=se.select=function(e,t,n,i){var o,u,c,l,f,h="function"==typeof e&&e,p=!i&&a(e=h.selector||e);if(n=n||[],1===p.length){if((u=p[0]=p[0].slice(0)).length>2&&"ID"===(c=u[0]).type&&9===t.nodeType&&v&&r.relative[u[1].type]){if(!(t=(r.find.ID(c.matches[0].replace(te,ne),t)||[])[0]))return n;h&&(t=t.parentNode),e=e.slice(u.shift().value.length)}for(o=X.needsContext.test(e)?0:u.length;o--&&(c=u[o],!r.relative[l=c.type]);)if((f=r.find[l])&&(i=f(c.matches[0].replace(te,ne),ee.test(u[0].type)&&ye(t.parentNode)||t))){if(u.splice(o,1),!(e=i.length&&be(u)))return j.apply(n,i),n;break}}return(h||s(e,p))(i,t,!v,n,!t||ee.test(e)&&ye(t.parentNode)||t),n},n.sortStable=_.split("").sort(A).join("")===_,n.detectDuplicates=!!f,h(),n.sortDetached=le((function(e){return 1&e.compareDocumentPosition(p.createElement("fieldset"))})),le((function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")}))||fe("type|href|height|width",(function(e,t,n){if(!n)return e.getAttribute(t,"type"===t.toLowerCase()?1:2)})),n.attributes&&le((function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")}))||fe("value",(function(e,t,n){if(!n&&"input"===e.nodeName.toLowerCase())return e.defaultValue})),le((function(e){return null==e.getAttribute("disabled")}))||fe(M,(function(e,t,n){var r;if(!n)return!0===e[t]?t.toLowerCase():(r=e.getAttributeNode(t))&&r.specified?r.value:null})),se}(n);T.find=k,T.expr=k.selectors,T.expr[":"]=T.expr.pseudos,T.uniqueSort=T.unique=k.uniqueSort,T.text=k.getText,T.isXMLDoc=k.isXML,T.contains=k.contains,T.escapeSelector=k.escape;var S=function(e,t,n){for(var r=[],i=void 0!==n;(e=e[t])&&9!==e.nodeType;)if(1===e.nodeType){if(i&&T(e).is(n))break;r.push(e)}return r},A=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},O=T.expr.match.needsContext;function D(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}var P=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function N(e,t,n){return m(t)?T.grep(e,(function(e,r){return!!t.call(e,r,e)!==n})):t.nodeType?T.grep(e,(function(e){return e===t!==n})):"string"!=typeof t?T.grep(e,(function(e){return f.call(t,e)>-1!==n})):T.filter(t,e,n)}T.filter=function(e,t,n){var r=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===r.nodeType?T.find.matchesSelector(r,e)?[r]:[]:T.find.matches(e,T.grep(t,(function(e){return 1===e.nodeType})))},T.fn.extend({find:function(e){var t,n,r=this.length,i=this;if("string"!=typeof e)return this.pushStack(T(e).filter((function(){for(t=0;t<r;t++)if(T.contains(i[t],this))return!0})));for(n=this.pushStack([]),t=0;t<r;t++)T.find(e,i[t],n);return r>1?T.uniqueSort(n):n},filter:function(e){return this.pushStack(N(this,e||[],!1))},not:function(e){return this.pushStack(N(this,e||[],!0))},is:function(e){return!!N(this,"string"==typeof e&&O.test(e)?T(e):e||[],!1).length}});var j,L=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(T.fn.init=function(e,t,n){var r,i;if(!e)return this;if(n=n||j,"string"==typeof e){if(!(r="<"===e[0]&&">"===e[e.length-1]&&e.length>=3?[null,e,null]:L.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1]){if(t=t instanceof T?t[0]:t,T.merge(this,T.parseHTML(r[1],t&&t.nodeType?t.ownerDocument||t:a,!0)),P.test(r[1])&&T.isPlainObject(t))for(r in t)m(this[r])?this[r](t[r]):this.attr(r,t[r]);return this}return(i=a.getElementById(r[2]))&&(this[0]=i,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):m(e)?void 0!==n.ready?n.ready(e):e(T):T.makeArray(e,this)}).prototype=T.fn,j=T(a);var I=/^(?:parents|prev(?:Until|All))/,M={children:!0,contents:!0,next:!0,prev:!0};function R(e,t){for(;(e=e[t])&&1!==e.nodeType;);return e}T.fn.extend({has:function(e){var t=T(e,this),n=t.length;return this.filter((function(){for(var e=0;e<n;e++)if(T.contains(this,t[e]))return!0}))},closest:function(e,t){var n,r=0,i=this.length,o=[],a="string"!=typeof e&&T(e);if(!O.test(e))for(;r<i;r++)for(n=this[r];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&T.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(o.length>1?T.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?f.call(T(e),this[0]):f.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(T.uniqueSort(T.merge(this.get(),T(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),T.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return S(e,"parentNode")},parentsUntil:function(e,t,n){return S(e,"parentNode",n)},next:function(e){return R(e,"nextSibling")},prev:function(e){return R(e,"previousSibling")},nextAll:function(e){return S(e,"nextSibling")},prevAll:function(e){return S(e,"previousSibling")},nextUntil:function(e,t,n){return S(e,"nextSibling",n)},prevUntil:function(e,t,n){return S(e,"previousSibling",n)},siblings:function(e){return A((e.parentNode||{}).firstChild,e)},children:function(e){return A(e.firstChild)},contents:function(e){return void 0!==e.contentDocument?e.contentDocument:(D(e,"template")&&(e=e.content||e),T.merge([],e.childNodes))}},(function(e,t){T.fn[e]=function(n,r){var i=T.map(this,t,n);return"Until"!==e.slice(-5)&&(r=n),r&&"string"==typeof r&&(i=T.filter(r,i)),this.length>1&&(M[e]||T.uniqueSort(i),I.test(e)&&i.reverse()),this.pushStack(i)}}));var B=/[^\x20\t\r\n\f]+/g;function $(e){return e}function q(e){throw e}function F(e,t,n,r){var i;try{e&&m(i=e.promise)?i.call(e).done(t).fail(n):e&&m(i=e.then)?i.call(e,t,n):t.apply(void 0,[e].slice(r))}catch(e){n.apply(void 0,[e])}}T.Callbacks=function(e){e="string"==typeof e?function(e){var t={};return T.each(e.match(B)||[],(function(e,n){t[n]=!0})),t}(e):T.extend({},e);var t,n,r,i,o=[],a=[],s=-1,u=function(){for(i=i||e.once,r=t=!0;a.length;s=-1)for(n=a.shift();++s<o.length;)!1===o[s].apply(n[0],n[1])&&e.stopOnFalse&&(s=o.length,n=!1);e.memory||(n=!1),t=!1,i&&(o=n?[]:"")},c={add:function(){return o&&(n&&!t&&(s=o.length-1,a.push(n)),function t(n){T.each(n,(function(n,r){m(r)?e.unique&&c.has(r)||o.push(r):r&&r.length&&"string"!==x(r)&&t(r)}))}(arguments),n&&!t&&u()),this},remove:function(){return T.each(arguments,(function(e,t){for(var n;(n=T.inArray(t,o,n))>-1;)o.splice(n,1),n<=s&&s--})),this},has:function(e){return e?T.inArray(e,o)>-1:o.length>0},empty:function(){return o&&(o=[]),this},disable:function(){return i=a=[],o=n="",this},disabled:function(){return!o},lock:function(){return i=a=[],n||t||(o=n=""),this},locked:function(){return!!i},fireWith:function(e,n){return i||(n=[e,(n=n||[]).slice?n.slice():n],a.push(n),t||u()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!r}};return c},T.extend({Deferred:function(e){var t=[["notify","progress",T.Callbacks("memory"),T.Callbacks("memory"),2],["resolve","done",T.Callbacks("once memory"),T.Callbacks("once memory"),0,"resolved"],["reject","fail",T.Callbacks("once memory"),T.Callbacks("once memory"),1,"rejected"]],r="pending",i={state:function(){return r},always:function(){return o.done(arguments).fail(arguments),this},catch:function(e){return i.then(null,e)},pipe:function(){var e=arguments;return T.Deferred((function(n){T.each(t,(function(t,r){var i=m(e[r[4]])&&e[r[4]];o[r[1]]((function(){var e=i&&i.apply(this,arguments);e&&m(e.promise)?e.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,i?[e]:arguments)}))})),e=null})).promise()},then:function(e,r,i){var o=0;function a(e,t,r,i){return function(){var s=this,u=arguments,c=function(){var n,c;if(!(e<o)){if((n=r.apply(s,u))===t.promise())throw new TypeError("Thenable self-resolution");c=n&&("object"==typeof n||"function"==typeof n)&&n.then,m(c)?i?c.call(n,a(o,t,$,i),a(o,t,q,i)):(o++,c.call(n,a(o,t,$,i),a(o,t,q,i),a(o,t,$,t.notifyWith))):(r!==$&&(s=void 0,u=[n]),(i||t.resolveWith)(s,u))}},l=i?c:function(){try{c()}catch(n){T.Deferred.exceptionHook&&T.Deferred.exceptionHook(n,l.stackTrace),e+1>=o&&(r!==q&&(s=void 0,u=[n]),t.rejectWith(s,u))}};e?l():(T.Deferred.getStackHook&&(l.stackTrace=T.Deferred.getStackHook()),n.setTimeout(l))}}return T.Deferred((function(n){t[0][3].add(a(0,n,m(i)?i:$,n.notifyWith)),t[1][3].add(a(0,n,m(e)?e:$)),t[2][3].add(a(0,n,m(r)?r:q))})).promise()},promise:function(e){return null!=e?T.extend(e,i):i}},o={};return T.each(t,(function(e,n){var a=n[2],s=n[5];i[n[1]]=a.add,s&&a.add((function(){r=s}),t[3-e][2].disable,t[3-e][3].disable,t[0][2].lock,t[0][3].lock),a.add(n[3].fire),o[n[0]]=function(){return o[n[0]+"With"](this===o?void 0:this,arguments),this},o[n[0]+"With"]=a.fireWith})),i.promise(o),e&&e.call(o,o),o},when:function(e){var t=arguments.length,n=t,r=Array(n),i=u.call(arguments),o=T.Deferred(),a=function(e){return function(n){r[e]=this,i[e]=arguments.length>1?u.call(arguments):n,--t||o.resolveWith(r,i)}};if(t<=1&&(F(e,o.done(a(n)).resolve,o.reject,!t),"pending"===o.state()||m(i[n]&&i[n].then)))return o.then();for(;n--;)F(i[n],a(n),o.reject);return o.promise()}});var H=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;T.Deferred.exceptionHook=function(e,t){n.console&&n.console.warn&&e&&H.test(e.name)&&n.console.warn("jQuery.Deferred exception: "+e.message,e.stack,t)},T.readyException=function(e){n.setTimeout((function(){throw e}))};var U=T.Deferred();function W(){a.removeEventListener("DOMContentLoaded",W),n.removeEventListener("load",W),T.ready()}T.fn.ready=function(e){return U.then(e).catch((function(e){T.readyException(e)})),this},T.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--T.readyWait:T.isReady)||(T.isReady=!0,!0!==e&&--T.readyWait>0||U.resolveWith(a,[T]))}}),T.ready.then=U.then,"complete"===a.readyState||"loading"!==a.readyState&&!a.documentElement.doScroll?n.setTimeout(T.ready):(a.addEventListener("DOMContentLoaded",W),n.addEventListener("load",W));var z=function(e,t,n,r,i,o,a){var s=0,u=e.length,c=null==n;if("object"===x(n))for(s in i=!0,n)z(e,t,s,n[s],!0,o,a);else if(void 0!==r&&(i=!0,m(r)||(a=!0),c&&(a?(t.call(e,r),t=null):(c=t,t=function(e,t,n){return c.call(T(e),n)})),t))for(;s<u;s++)t(e[s],n,a?r:r.call(e[s],s,t(e[s],n)));return i?e:c?t.call(e):u?t(e[0],n):o},K=/^-ms-/,V=/-([a-z])/g;function X(e,t){return t.toUpperCase()}function Y(e){return e.replace(K,"ms-").replace(V,X)}var G=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function J(){this.expando=T.expando+J.uid++}J.uid=1,J.prototype={cache:function(e){var t=e[this.expando];return t||(t={},G(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var r,i=this.cache(e);if("string"==typeof t)i[Y(t)]=n;else for(r in t)i[Y(r)]=t[r];return i},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][Y(t)]},access:function(e,t,n){return void 0===t||t&&"string"==typeof t&&void 0===n?this.get(e,t):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,r=e[this.expando];if(void 0!==r){if(void 0!==t){n=(t=Array.isArray(t)?t.map(Y):(t=Y(t))in r?[t]:t.match(B)||[]).length;for(;n--;)delete r[t[n]]}(void 0===t||T.isEmptyObject(r))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!T.isEmptyObject(t)}};var Z=new J,Q=new J,ee=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,te=/[A-Z]/g;function ne(e,t,n){var r;if(void 0===n&&1===e.nodeType)if(r="data-"+t.replace(te,"-$&").toLowerCase(),"string"==typeof(n=e.getAttribute(r))){try{n=function(e){return"true"===e||"false"!==e&&("null"===e?null:e===+e+""?+e:ee.test(e)?JSON.parse(e):e)}(n)}catch(e){}Q.set(e,t,n)}else n=void 0;return n}T.extend({hasData:function(e){return Q.hasData(e)||Z.hasData(e)},data:function(e,t,n){return Q.access(e,t,n)},removeData:function(e,t){Q.remove(e,t)},_data:function(e,t,n){return Z.access(e,t,n)},_removeData:function(e,t){Z.remove(e,t)}}),T.fn.extend({data:function(e,t){var n,r,i,o=this[0],a=o&&o.attributes;if(void 0===e){if(this.length&&(i=Q.get(o),1===o.nodeType&&!Z.get(o,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&0===(r=a[n].name).indexOf("data-")&&(r=Y(r.slice(5)),ne(o,r,i[r]));Z.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof e?this.each((function(){Q.set(this,e)})):z(this,(function(t){var n;if(o&&void 0===t)return void 0!==(n=Q.get(o,e))||void 0!==(n=ne(o,e))?n:void 0;this.each((function(){Q.set(this,e,t)}))}),null,t,arguments.length>1,null,!0)},removeData:function(e){return this.each((function(){Q.remove(this,e)}))}}),T.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=Z.get(e,t),n&&(!r||Array.isArray(n)?r=Z.access(e,t,T.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=T.queue(e,t),r=n.length,i=n.shift(),o=T._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,(function(){T.dequeue(e,t)}),o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return Z.get(e,n)||Z.access(e,n,{empty:T.Callbacks("once memory").add((function(){Z.remove(e,[t+"queue",n])}))})}}),T.fn.extend({queue:function(e,t){var n=2;return"string"!=typeof e&&(t=e,e="fx",n--),arguments.length<n?T.queue(this[0],e):void 0===t?this:this.each((function(){var n=T.queue(this,e,t);T._queueHooks(this,e),"fx"===e&&"inprogress"!==n[0]&&T.dequeue(this,e)}))},dequeue:function(e){return this.each((function(){T.dequeue(this,e)}))},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=T.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";a--;)(n=Z.get(o[a],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(t)}});var re=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ie=new RegExp("^(?:([+-])=|)("+re+")([a-z%]*)$","i"),oe=["Top","Right","Bottom","Left"],ae=a.documentElement,se=function(e){return T.contains(e.ownerDocument,e)},ue={composed:!0};ae.getRootNode&&(se=function(e){return T.contains(e.ownerDocument,e)||e.getRootNode(ue)===e.ownerDocument});var ce=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&se(e)&&"none"===T.css(e,"display")},le=function(e,t,n,r){var i,o,a={};for(o in t)a[o]=e.style[o],e.style[o]=t[o];for(o in i=n.apply(e,r||[]),t)e.style[o]=a[o];return i};function fe(e,t,n,r){var i,o,a=20,s=r?function(){return r.cur()}:function(){return T.css(e,t,"")},u=s(),c=n&&n[3]||(T.cssNumber[t]?"":"px"),l=e.nodeType&&(T.cssNumber[t]||"px"!==c&&+u)&&ie.exec(T.css(e,t));if(l&&l[3]!==c){for(u/=2,c=c||l[3],l=+u||1;a--;)T.style(e,t,l+c),(1-o)*(1-(o=s()/u||.5))<=0&&(a=0),l/=o;l*=2,T.style(e,t,l+c),n=n||[]}return n&&(l=+l||+u||0,i=n[1]?l+(n[1]+1)*n[2]:+n[2],r&&(r.unit=c,r.start=l,r.end=i)),i}var he={};function pe(e){var t,n=e.ownerDocument,r=e.nodeName,i=he[r];return i||(t=n.body.appendChild(n.createElement(r)),i=T.css(t,"display"),t.parentNode.removeChild(t),"none"===i&&(i="block"),he[r]=i,i)}function de(e,t){for(var n,r,i=[],o=0,a=e.length;o<a;o++)(r=e[o]).style&&(n=r.style.display,t?("none"===n&&(i[o]=Z.get(r,"display")||null,i[o]||(r.style.display="")),""===r.style.display&&ce(r)&&(i[o]=pe(r))):"none"!==n&&(i[o]="none",Z.set(r,"display",n)));for(o=0;o<a;o++)null!=i[o]&&(e[o].style.display=i[o]);return e}T.fn.extend({show:function(){return de(this,!0)},hide:function(){return de(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each((function(){ce(this)?T(this).show():T(this).hide()}))}});var ve=/^(?:checkbox|radio)$/i,ge=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,ye=/^$|^module$|\/(?:java|ecma)script/i,me={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function be(e,t){var n;return n=void 0!==e.getElementsByTagName?e.getElementsByTagName(t||"*"):void 0!==e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&D(e,t)?T.merge([e],n):n}function _e(e,t){for(var n=0,r=e.length;n<r;n++)Z.set(e[n],"globalEval",!t||Z.get(t[n],"globalEval"))}me.optgroup=me.option,me.tbody=me.tfoot=me.colgroup=me.caption=me.thead,me.th=me.td;var we,xe,Te=/<|&#?\w+;/;function Ce(e,t,n,r,i){for(var o,a,s,u,c,l,f=t.createDocumentFragment(),h=[],p=0,d=e.length;p<d;p++)if((o=e[p])||0===o)if("object"===x(o))T.merge(h,o.nodeType?[o]:o);else if(Te.test(o)){for(a=a||f.appendChild(t.createElement("div")),s=(ge.exec(o)||["",""])[1].toLowerCase(),u=me[s]||me._default,a.innerHTML=u[1]+T.htmlPrefilter(o)+u[2],l=u[0];l--;)a=a.lastChild;T.merge(h,a.childNodes),(a=f.firstChild).textContent=""}else h.push(t.createTextNode(o));for(f.textContent="",p=0;o=h[p++];)if(r&&T.inArray(o,r)>-1)i&&i.push(o);else if(c=se(o),a=be(f.appendChild(o),"script"),c&&_e(a),n)for(l=0;o=a[l++];)ye.test(o.type||"")&&n.push(o);return f}we=a.createDocumentFragment().appendChild(a.createElement("div")),(xe=a.createElement("input")).setAttribute("type","radio"),xe.setAttribute("checked","checked"),xe.setAttribute("name","t"),we.appendChild(xe),y.checkClone=we.cloneNode(!0).cloneNode(!0).lastChild.checked,we.innerHTML="<textarea>x</textarea>",y.noCloneChecked=!!we.cloneNode(!0).lastChild.defaultValue;var Ee=/^key/,ke=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Se=/^([^.]*)(?:\.(.+)|)/;function Ae(){return!0}function Oe(){return!1}function De(e,t){return e===function(){try{return a.activeElement}catch(e){}}()==("focus"===t)}function Pe(e,t,n,r,i,o){var a,s;if("object"==typeof t){for(s in"string"!=typeof n&&(r=r||n,n=void 0),t)Pe(e,s,n,r,t[s],o);return e}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=Oe;else if(!i)return e;return 1===o&&(a=i,(i=function(e){return T().off(e),a.apply(this,arguments)}).guid=a.guid||(a.guid=T.guid++)),e.each((function(){T.event.add(this,t,i,r,n)}))}function Ne(e,t,n){n?(Z.set(e,t,!1),T.event.add(e,t,{namespace:!1,handler:function(e){var r,i,o=Z.get(this,t);if(1&e.isTrigger&&this[t]){if(o.length)(T.event.special[t]||{}).delegateType&&e.stopPropagation();else if(o=u.call(arguments),Z.set(this,t,o),r=n(this,t),this[t](),o!==(i=Z.get(this,t))||r?Z.set(this,t,!1):i={},o!==i)return e.stopImmediatePropagation(),e.preventDefault(),i.value}else o.length&&(Z.set(this,t,{value:T.event.trigger(T.extend(o[0],T.Event.prototype),o.slice(1),this)}),e.stopImmediatePropagation())}})):void 0===Z.get(e,t)&&T.event.add(e,t,Ae)}T.event={global:{},add:function(e,t,n,r,i){var o,a,s,u,c,l,f,h,p,d,v,g=Z.get(e);if(g)for(n.handler&&(n=(o=n).handler,i=o.selector),i&&T.find.matchesSelector(ae,i),n.guid||(n.guid=T.guid++),(u=g.events)||(u=g.events={}),(a=g.handle)||(a=g.handle=function(t){return void 0!==T&&T.event.triggered!==t.type?T.event.dispatch.apply(e,arguments):void 0}),c=(t=(t||"").match(B)||[""]).length;c--;)p=v=(s=Se.exec(t[c])||[])[1],d=(s[2]||"").split(".").sort(),p&&(f=T.event.special[p]||{},p=(i?f.delegateType:f.bindType)||p,f=T.event.special[p]||{},l=T.extend({type:p,origType:v,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&T.expr.match.needsContext.test(i),namespace:d.join(".")},o),(h=u[p])||((h=u[p]=[]).delegateCount=0,f.setup&&!1!==f.setup.call(e,r,d,a)||e.addEventListener&&e.addEventListener(p,a)),f.add&&(f.add.call(e,l),l.handler.guid||(l.handler.guid=n.guid)),i?h.splice(h.delegateCount++,0,l):h.push(l),T.event.global[p]=!0)},remove:function(e,t,n,r,i){var o,a,s,u,c,l,f,h,p,d,v,g=Z.hasData(e)&&Z.get(e);if(g&&(u=g.events)){for(c=(t=(t||"").match(B)||[""]).length;c--;)if(p=v=(s=Se.exec(t[c])||[])[1],d=(s[2]||"").split(".").sort(),p){for(f=T.event.special[p]||{},h=u[p=(r?f.delegateType:f.bindType)||p]||[],s=s[2]&&new RegExp("(^|\\.)"+d.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=h.length;o--;)l=h[o],!i&&v!==l.origType||n&&n.guid!==l.guid||s&&!s.test(l.namespace)||r&&r!==l.selector&&("**"!==r||!l.selector)||(h.splice(o,1),l.selector&&h.delegateCount--,f.remove&&f.remove.call(e,l));a&&!h.length&&(f.teardown&&!1!==f.teardown.call(e,d,g.handle)||T.removeEvent(e,p,g.handle),delete u[p])}else for(p in u)T.event.remove(e,p+t[c],n,r,!0);T.isEmptyObject(u)&&Z.remove(e,"handle events")}},dispatch:function(e){var t,n,r,i,o,a,s=T.event.fix(e),u=new Array(arguments.length),c=(Z.get(this,"events")||{})[s.type]||[],l=T.event.special[s.type]||{};for(u[0]=s,t=1;t<arguments.length;t++)u[t]=arguments[t];if(s.delegateTarget=this,!l.preDispatch||!1!==l.preDispatch.call(this,s)){for(a=T.event.handlers.call(this,s,c),t=0;(i=a[t++])&&!s.isPropagationStopped();)for(s.currentTarget=i.elem,n=0;(o=i.handlers[n++])&&!s.isImmediatePropagationStopped();)s.rnamespace&&!1!==o.namespace&&!s.rnamespace.test(o.namespace)||(s.handleObj=o,s.data=o.data,void 0!==(r=((T.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,u))&&!1===(s.result=r)&&(s.preventDefault(),s.stopPropagation()));return l.postDispatch&&l.postDispatch.call(this,s),s.result}},handlers:function(e,t){var n,r,i,o,a,s=[],u=t.delegateCount,c=e.target;if(u&&c.nodeType&&!("click"===e.type&&e.button>=1))for(;c!==this;c=c.parentNode||this)if(1===c.nodeType&&("click"!==e.type||!0!==c.disabled)){for(o=[],a={},n=0;n<u;n++)void 0===a[i=(r=t[n]).selector+" "]&&(a[i]=r.needsContext?T(i,this).index(c)>-1:T.find(i,this,null,[c]).length),a[i]&&o.push(r);o.length&&s.push({elem:c,handlers:o})}return c=this,u<t.length&&s.push({elem:c,handlers:t.slice(u)}),s},addProp:function(e,t){Object.defineProperty(T.Event.prototype,e,{enumerable:!0,configurable:!0,get:m(t)?function(){if(this.originalEvent)return t(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[e]},set:function(t){Object.defineProperty(this,e,{enumerable:!0,configurable:!0,writable:!0,value:t})}})},fix:function(e){return e[T.expando]?e:new T.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return ve.test(t.type)&&t.click&&D(t,"input")&&Ne(t,"click",Ae),!1},trigger:function(e){var t=this||e;return ve.test(t.type)&&t.click&&D(t,"input")&&Ne(t,"click"),!0},_default:function(e){var t=e.target;return ve.test(t.type)&&t.click&&D(t,"input")&&Z.get(t,"click")||D(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},T.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},T.Event=function(e,t){if(!(this instanceof T.Event))return new T.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?Ae:Oe,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&T.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[T.expando]=!0},T.Event.prototype={constructor:T.Event,isDefaultPrevented:Oe,isPropagationStopped:Oe,isImmediatePropagationStopped:Oe,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=Ae,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=Ae,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=Ae,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},T.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(e){var t=e.button;return null==e.which&&Ee.test(e.type)?null!=e.charCode?e.charCode:e.keyCode:!e.which&&void 0!==t&&ke.test(e.type)?1&t?1:2&t?3:4&t?2:0:e.which}},T.event.addProp),T.each({focus:"focusin",blur:"focusout"},(function(e,t){T.event.special[e]={setup:function(){return Ne(this,e,De),!1},trigger:function(){return Ne(this,e),!0},delegateType:t}})),T.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},(function(e,t){T.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,o=e.handleObj;return i&&(i===r||T.contains(r,i))||(e.type=o.origType,n=o.handler.apply(this,arguments),e.type=t),n}}})),T.fn.extend({on:function(e,t,n,r){return Pe(this,e,t,n,r)},one:function(e,t,n,r){return Pe(this,e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,T(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=Oe),this.each((function(){T.event.remove(this,e,n,t)}))}});var je=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,Le=/<script|<style|<link/i,Ie=/checked\s*(?:[^=]|=\s*.checked.)/i,Me=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function Re(e,t){return D(e,"table")&&D(11!==t.nodeType?t:t.firstChild,"tr")&&T(e).children("tbody")[0]||e}function Be(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function $e(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function qe(e,t){var n,r,i,o,a,s,u,c;if(1===t.nodeType){if(Z.hasData(e)&&(o=Z.access(e),a=Z.set(t,o),c=o.events))for(i in delete a.handle,a.events={},c)for(n=0,r=c[i].length;n<r;n++)T.event.add(t,i,c[i][n]);Q.hasData(e)&&(s=Q.access(e),u=T.extend({},s),Q.set(t,u))}}function Fe(e,t){var n=t.nodeName.toLowerCase();"input"===n&&ve.test(e.type)?t.checked=e.checked:"input"!==n&&"textarea"!==n||(t.defaultValue=e.defaultValue)}function He(e,t,n,r){t=c.apply([],t);var i,o,a,s,u,l,f=0,h=e.length,p=h-1,d=t[0],v=m(d);if(v||h>1&&"string"==typeof d&&!y.checkClone&&Ie.test(d))return e.each((function(i){var o=e.eq(i);v&&(t[0]=d.call(this,i,o.html())),He(o,t,n,r)}));if(h&&(o=(i=Ce(t,e[0].ownerDocument,!1,e,r)).firstChild,1===i.childNodes.length&&(i=o),o||r)){for(s=(a=T.map(be(i,"script"),Be)).length;f<h;f++)u=i,f!==p&&(u=T.clone(u,!0,!0),s&&T.merge(a,be(u,"script"))),n.call(e[f],u,f);if(s)for(l=a[a.length-1].ownerDocument,T.map(a,$e),f=0;f<s;f++)u=a[f],ye.test(u.type||"")&&!Z.access(u,"globalEval")&&T.contains(l,u)&&(u.src&&"module"!==(u.type||"").toLowerCase()?T._evalUrl&&!u.noModule&&T._evalUrl(u.src,{nonce:u.nonce||u.getAttribute("nonce")}):w(u.textContent.replace(Me,""),u,l))}return e}function Ue(e,t,n){for(var r,i=t?T.filter(t,e):e,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||T.cleanData(be(r)),r.parentNode&&(n&&se(r)&&_e(be(r,"script")),r.parentNode.removeChild(r));return e}T.extend({htmlPrefilter:function(e){return e.replace(je,"<$1></$2>")},clone:function(e,t,n){var r,i,o,a,s=e.cloneNode(!0),u=se(e);if(!(y.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||T.isXMLDoc(e)))for(a=be(s),r=0,i=(o=be(e)).length;r<i;r++)Fe(o[r],a[r]);if(t)if(n)for(o=o||be(e),a=a||be(s),r=0,i=o.length;r<i;r++)qe(o[r],a[r]);else qe(e,s);return(a=be(s,"script")).length>0&&_e(a,!u&&be(e,"script")),s},cleanData:function(e){for(var t,n,r,i=T.event.special,o=0;void 0!==(n=e[o]);o++)if(G(n)){if(t=n[Z.expando]){if(t.events)for(r in t.events)i[r]?T.event.remove(n,r):T.removeEvent(n,r,t.handle);n[Z.expando]=void 0}n[Q.expando]&&(n[Q.expando]=void 0)}}}),T.fn.extend({detach:function(e){return Ue(this,e,!0)},remove:function(e){return Ue(this,e)},text:function(e){return z(this,(function(e){return void 0===e?T.text(this):this.empty().each((function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)}))}),null,e,arguments.length)},append:function(){return He(this,arguments,(function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||Re(this,e).appendChild(e)}))},prepend:function(){return He(this,arguments,(function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=Re(this,e);t.insertBefore(e,t.firstChild)}}))},before:function(){return He(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this)}))},after:function(){return He(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)}))},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(T.cleanData(be(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map((function(){return T.clone(this,e,t)}))},html:function(e){return z(this,(function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!Le.test(e)&&!me[(ge.exec(e)||["",""])[1].toLowerCase()]){e=T.htmlPrefilter(e);try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(T.cleanData(be(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)}),null,e,arguments.length)},replaceWith:function(){var e=[];return He(this,arguments,(function(t){var n=this.parentNode;T.inArray(this,e)<0&&(T.cleanData(be(this)),n&&n.replaceChild(t,this))}),e)}}),T.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},(function(e,t){T.fn[e]=function(e){for(var n,r=[],i=T(e),o=i.length-1,a=0;a<=o;a++)n=a===o?this:this.clone(!0),T(i[a])[t](n),l.apply(r,n.get());return this.pushStack(r)}}));var We=new RegExp("^("+re+")(?!px)[a-z%]+$","i"),ze=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=n),t.getComputedStyle(e)},Ke=new RegExp(oe.join("|"),"i");function Ve(e,t,n){var r,i,o,a,s=e.style;return(n=n||ze(e))&&(""!==(a=n.getPropertyValue(t)||n[t])||se(e)||(a=T.style(e,t)),!y.pixelBoxStyles()&&We.test(a)&&Ke.test(t)&&(r=s.width,i=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=i,s.maxWidth=o)),void 0!==a?a+"":a}function Xe(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function e(){if(l){c.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",l.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",ae.appendChild(c).appendChild(l);var e=n.getComputedStyle(l);r="1%"!==e.top,u=12===t(e.marginLeft),l.style.right="60%",s=36===t(e.right),i=36===t(e.width),l.style.position="absolute",o=12===t(l.offsetWidth/3),ae.removeChild(c),l=null}}function t(e){return Math.round(parseFloat(e))}var r,i,o,s,u,c=a.createElement("div"),l=a.createElement("div");l.style&&(l.style.backgroundClip="content-box",l.cloneNode(!0).style.backgroundClip="",y.clearCloneStyle="content-box"===l.style.backgroundClip,T.extend(y,{boxSizingReliable:function(){return e(),i},pixelBoxStyles:function(){return e(),s},pixelPosition:function(){return e(),r},reliableMarginLeft:function(){return e(),u},scrollboxSize:function(){return e(),o}}))}();var Ye=["Webkit","Moz","ms"],Ge=a.createElement("div").style,Je={};function Ze(e){var t=T.cssProps[e]||Je[e];return t||(e in Ge?e:Je[e]=function(e){for(var t=e[0].toUpperCase()+e.slice(1),n=Ye.length;n--;)if((e=Ye[n]+t)in Ge)return e}(e)||e)}var Qe=/^(none|table(?!-c[ea]).+)/,et=/^--/,tt={position:"absolute",visibility:"hidden",display:"block"},nt={letterSpacing:"0",fontWeight:"400"};function rt(e,t,n){var r=ie.exec(t);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):t}function it(e,t,n,r,i,o){var a="width"===t?1:0,s=0,u=0;if(n===(r?"border":"content"))return 0;for(;a<4;a+=2)"margin"===n&&(u+=T.css(e,n+oe[a],!0,i)),r?("content"===n&&(u-=T.css(e,"padding"+oe[a],!0,i)),"margin"!==n&&(u-=T.css(e,"border"+oe[a]+"Width",!0,i))):(u+=T.css(e,"padding"+oe[a],!0,i),"padding"!==n?u+=T.css(e,"border"+oe[a]+"Width",!0,i):s+=T.css(e,"border"+oe[a]+"Width",!0,i));return!r&&o>=0&&(u+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-o-u-s-.5))||0),u}function ot(e,t,n){var r=ze(e),i=(!y.boxSizingReliable()||n)&&"border-box"===T.css(e,"boxSizing",!1,r),o=i,a=Ve(e,t,r),s="offset"+t[0].toUpperCase()+t.slice(1);if(We.test(a)){if(!n)return a;a="auto"}return(!y.boxSizingReliable()&&i||"auto"===a||!parseFloat(a)&&"inline"===T.css(e,"display",!1,r))&&e.getClientRects().length&&(i="border-box"===T.css(e,"boxSizing",!1,r),(o=s in e)&&(a=e[s])),(a=parseFloat(a)||0)+it(e,t,n||(i?"border":"content"),o,r,a)+"px"}function at(e,t,n,r,i){return new at.prototype.init(e,t,n,r,i)}T.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=Ve(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,a,s=Y(t),u=et.test(t),c=e.style;if(u||(t=Ze(s)),a=T.cssHooks[t]||T.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(e,!1,r))?i:c[t];"string"===(o=typeof n)&&(i=ie.exec(n))&&i[1]&&(n=fe(e,t,i),o="number"),null!=n&&n==n&&("number"!==o||u||(n+=i&&i[3]||(T.cssNumber[s]?"":"px")),y.clearCloneStyle||""!==n||0!==t.indexOf("background")||(c[t]="inherit"),a&&"set"in a&&void 0===(n=a.set(e,n,r))||(u?c.setProperty(t,n):c[t]=n))}},css:function(e,t,n,r){var i,o,a,s=Y(t);return et.test(t)||(t=Ze(s)),(a=T.cssHooks[t]||T.cssHooks[s])&&"get"in a&&(i=a.get(e,!0,n)),void 0===i&&(i=Ve(e,t,r)),"normal"===i&&t in nt&&(i=nt[t]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),T.each(["height","width"],(function(e,t){T.cssHooks[t]={get:function(e,n,r){if(n)return!Qe.test(T.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?ot(e,t,r):le(e,tt,(function(){return ot(e,t,r)}))},set:function(e,n,r){var i,o=ze(e),a=!y.scrollboxSize()&&"absolute"===o.position,s=(a||r)&&"border-box"===T.css(e,"boxSizing",!1,o),u=r?it(e,t,r,s,o):0;return s&&a&&(u-=Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-parseFloat(o[t])-it(e,t,"border",!1,o)-.5)),u&&(i=ie.exec(n))&&"px"!==(i[3]||"px")&&(e.style[t]=n,n=T.css(e,t)),rt(0,n,u)}}})),T.cssHooks.marginLeft=Xe(y.reliableMarginLeft,(function(e,t){if(t)return(parseFloat(Ve(e,"marginLeft"))||e.getBoundingClientRect().left-le(e,{marginLeft:0},(function(){return e.getBoundingClientRect().left})))+"px"})),T.each({margin:"",padding:"",border:"Width"},(function(e,t){T.cssHooks[e+t]={expand:function(n){for(var r=0,i={},o="string"==typeof n?n.split(" "):[n];r<4;r++)i[e+oe[r]+t]=o[r]||o[r-2]||o[0];return i}},"margin"!==e&&(T.cssHooks[e+t].set=rt)})),T.fn.extend({css:function(e,t){return z(this,(function(e,t,n){var r,i,o={},a=0;if(Array.isArray(t)){for(r=ze(e),i=t.length;a<i;a++)o[t[a]]=T.css(e,t[a],!1,r);return o}return void 0!==n?T.style(e,t,n):T.css(e,t)}),e,t,arguments.length>1)}}),T.Tween=at,at.prototype={constructor:at,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||T.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(T.cssNumber[n]?"":"px")},cur:function(){var e=at.propHooks[this.prop];return e&&e.get?e.get(this):at.propHooks._default.get(this)},run:function(e){var t,n=at.propHooks[this.prop];return this.options.duration?this.pos=t=T.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):at.propHooks._default.set(this),this}},at.prototype.init.prototype=at.prototype,at.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=T.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){T.fx.step[e.prop]?T.fx.step[e.prop](e):1!==e.elem.nodeType||!T.cssHooks[e.prop]&&null==e.elem.style[Ze(e.prop)]?e.elem[e.prop]=e.now:T.style(e.elem,e.prop,e.now+e.unit)}}},at.propHooks.scrollTop=at.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},T.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},T.fx=at.prototype.init,T.fx.step={};var st,ut,ct=/^(?:toggle|show|hide)$/,lt=/queueHooks$/;function ft(){ut&&(!1===a.hidden&&n.requestAnimationFrame?n.requestAnimationFrame(ft):n.setTimeout(ft,T.fx.interval),T.fx.tick())}function ht(){return n.setTimeout((function(){st=void 0})),st=Date.now()}function pt(e,t){var n,r=0,i={height:e};for(t=t?1:0;r<4;r+=2-t)i["margin"+(n=oe[r])]=i["padding"+n]=e;return t&&(i.opacity=i.width=e),i}function dt(e,t,n){for(var r,i=(vt.tweeners[t]||[]).concat(vt.tweeners["*"]),o=0,a=i.length;o<a;o++)if(r=i[o].call(n,t,e))return r}function vt(e,t,n){var r,i,o=0,a=vt.prefilters.length,s=T.Deferred().always((function(){delete u.elem})),u=function(){if(i)return!1;for(var t=st||ht(),n=Math.max(0,c.startTime+c.duration-t),r=1-(n/c.duration||0),o=0,a=c.tweens.length;o<a;o++)c.tweens[o].run(r);return s.notifyWith(e,[c,r,n]),r<1&&a?n:(a||s.notifyWith(e,[c,1,0]),s.resolveWith(e,[c]),!1)},c=s.promise({elem:e,props:T.extend({},t),opts:T.extend(!0,{specialEasing:{},easing:T.easing._default},n),originalProperties:t,originalOptions:n,startTime:st||ht(),duration:n.duration,tweens:[],createTween:function(t,n){var r=T.Tween(e,c.opts,t,n,c.opts.specialEasing[t]||c.opts.easing);return c.tweens.push(r),r},stop:function(t){var n=0,r=t?c.tweens.length:0;if(i)return this;for(i=!0;n<r;n++)c.tweens[n].run(1);return t?(s.notifyWith(e,[c,1,0]),s.resolveWith(e,[c,t])):s.rejectWith(e,[c,t]),this}}),l=c.props;for(!function(e,t){var n,r,i,o,a;for(n in e)if(i=t[r=Y(n)],o=e[n],Array.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(a=T.cssHooks[r])&&"expand"in a)for(n in o=a.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(l,c.opts.specialEasing);o<a;o++)if(r=vt.prefilters[o].call(c,e,l,c.opts))return m(r.stop)&&(T._queueHooks(c.elem,c.opts.queue).stop=r.stop.bind(r)),r;return T.map(l,dt,c),m(c.opts.start)&&c.opts.start.call(e,c),c.progress(c.opts.progress).done(c.opts.done,c.opts.complete).fail(c.opts.fail).always(c.opts.always),T.fx.timer(T.extend(u,{elem:e,anim:c,queue:c.opts.queue})),c}T.Animation=T.extend(vt,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return fe(n.elem,e,ie.exec(t),n),n}]},tweener:function(e,t){m(e)?(t=e,e=["*"]):e=e.match(B);for(var n,r=0,i=e.length;r<i;r++)n=e[r],vt.tweeners[n]=vt.tweeners[n]||[],vt.tweeners[n].unshift(t)},prefilters:[function(e,t,n){var r,i,o,a,s,u,c,l,f="width"in t||"height"in t,h=this,p={},d=e.style,v=e.nodeType&&ce(e),g=Z.get(e,"fxshow");for(r in n.queue||(null==(a=T._queueHooks(e,"fx")).unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,h.always((function(){h.always((function(){a.unqueued--,T.queue(e,"fx").length||a.empty.fire()}))}))),t)if(i=t[r],ct.test(i)){if(delete t[r],o=o||"toggle"===i,i===(v?"hide":"show")){if("show"!==i||!g||void 0===g[r])continue;v=!0}p[r]=g&&g[r]||T.style(e,r)}if((u=!T.isEmptyObject(t))||!T.isEmptyObject(p))for(r in f&&1===e.nodeType&&(n.overflow=[d.overflow,d.overflowX,d.overflowY],null==(c=g&&g.display)&&(c=Z.get(e,"display")),"none"===(l=T.css(e,"display"))&&(c?l=c:(de([e],!0),c=e.style.display||c,l=T.css(e,"display"),de([e]))),("inline"===l||"inline-block"===l&&null!=c)&&"none"===T.css(e,"float")&&(u||(h.done((function(){d.display=c})),null==c&&(l=d.display,c="none"===l?"":l)),d.display="inline-block")),n.overflow&&(d.overflow="hidden",h.always((function(){d.overflow=n.overflow[0],d.overflowX=n.overflow[1],d.overflowY=n.overflow[2]}))),u=!1,p)u||(g?"hidden"in g&&(v=g.hidden):g=Z.access(e,"fxshow",{display:c}),o&&(g.hidden=!v),v&&de([e],!0),h.done((function(){for(r in v||de([e]),Z.remove(e,"fxshow"),p)T.style(e,r,p[r])}))),u=dt(v?g[r]:0,r,h),r in g||(g[r]=u.start,v&&(u.end=u.start,u.start=0))}],prefilter:function(e,t){t?vt.prefilters.unshift(e):vt.prefilters.push(e)}}),T.speed=function(e,t,n){var r=e&&"object"==typeof e?T.extend({},e):{complete:n||!n&&t||m(e)&&e,duration:e,easing:n&&t||t&&!m(t)&&t};return T.fx.off?r.duration=0:"number"!=typeof r.duration&&(r.duration in T.fx.speeds?r.duration=T.fx.speeds[r.duration]:r.duration=T.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){m(r.old)&&r.old.call(this),r.queue&&T.dequeue(this,r.queue)},r},T.fn.extend({fadeTo:function(e,t,n,r){return this.filter(ce).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=T.isEmptyObject(e),o=T.speed(t,n,r),a=function(){var t=vt(this,T.extend({},e),o);(i||Z.get(this,"finish"))&&t.stop(!0)};return a.finish=a,i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(e,t,n){var r=function(e){var t=e.stop;delete e.stop,t(n)};return"string"!=typeof e&&(n=t,t=e,e=void 0),t&&!1!==e&&this.queue(e||"fx",[]),this.each((function(){var t=!0,i=null!=e&&e+"queueHooks",o=T.timers,a=Z.get(this);if(i)a[i]&&a[i].stop&&r(a[i]);else for(i in a)a[i]&&a[i].stop&&lt.test(i)&&r(a[i]);for(i=o.length;i--;)o[i].elem!==this||null!=e&&o[i].queue!==e||(o[i].anim.stop(n),t=!1,o.splice(i,1));!t&&n||T.dequeue(this,e)}))},finish:function(e){return!1!==e&&(e=e||"fx"),this.each((function(){var t,n=Z.get(this),r=n[e+"queue"],i=n[e+"queueHooks"],o=T.timers,a=r?r.length:0;for(n.finish=!0,T.queue(this,e,[]),i&&i.stop&&i.stop.call(this,!0),t=o.length;t--;)o[t].elem===this&&o[t].queue===e&&(o[t].anim.stop(!0),o.splice(t,1));for(t=0;t<a;t++)r[t]&&r[t].finish&&r[t].finish.call(this);delete n.finish}))}}),T.each(["toggle","show","hide"],(function(e,t){var n=T.fn[t];T.fn[t]=function(e,r,i){return null==e||"boolean"==typeof e?n.apply(this,arguments):this.animate(pt(t,!0),e,r,i)}})),T.each({slideDown:pt("show"),slideUp:pt("hide"),slideToggle:pt("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},(function(e,t){T.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}})),T.timers=[],T.fx.tick=function(){var e,t=0,n=T.timers;for(st=Date.now();t<n.length;t++)(e=n[t])()||n[t]!==e||n.splice(t--,1);n.length||T.fx.stop(),st=void 0},T.fx.timer=function(e){T.timers.push(e),T.fx.start()},T.fx.interval=13,T.fx.start=function(){ut||(ut=!0,ft())},T.fx.stop=function(){ut=null},T.fx.speeds={slow:600,fast:200,_default:400},T.fn.delay=function(e,t){return e=T.fx&&T.fx.speeds[e]||e,t=t||"fx",this.queue(t,(function(t,r){var i=n.setTimeout(t,e);r.stop=function(){n.clearTimeout(i)}}))},function(){var e=a.createElement("input"),t=a.createElement("select").appendChild(a.createElement("option"));e.type="checkbox",y.checkOn=""!==e.value,y.optSelected=t.selected,(e=a.createElement("input")).value="t",e.type="radio",y.radioValue="t"===e.value}();var gt,yt=T.expr.attrHandle;T.fn.extend({attr:function(e,t){return z(this,T.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each((function(){T.removeAttr(this,e)}))}}),T.extend({attr:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return void 0===e.getAttribute?T.prop(e,t,n):(1===o&&T.isXMLDoc(e)||(i=T.attrHooks[t.toLowerCase()]||(T.expr.match.bool.test(t)?gt:void 0)),void 0!==n?null===n?void T.removeAttr(e,t):i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:(e.setAttribute(t,n+""),n):i&&"get"in i&&null!==(r=i.get(e,t))?r:null==(r=T.find.attr(e,t))?void 0:r)},attrHooks:{type:{set:function(e,t){if(!y.radioValue&&"radio"===t&&D(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,r=0,i=t&&t.match(B);if(i&&1===e.nodeType)for(;n=i[r++];)e.removeAttribute(n)}}),gt={set:function(e,t,n){return!1===t?T.removeAttr(e,n):e.setAttribute(n,n),n}},T.each(T.expr.match.bool.source.match(/\w+/g),(function(e,t){var n=yt[t]||T.find.attr;yt[t]=function(e,t,r){var i,o,a=t.toLowerCase();return r||(o=yt[a],yt[a]=i,i=null!=n(e,t,r)?a:null,yt[a]=o),i}}));var mt=/^(?:input|select|textarea|button)$/i,bt=/^(?:a|area)$/i;function _t(e){return(e.match(B)||[]).join(" ")}function wt(e){return e.getAttribute&&e.getAttribute("class")||""}function xt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(B)||[]}T.fn.extend({prop:function(e,t){return z(this,T.prop,e,t,arguments.length>1)},removeProp:function(e){return this.each((function(){delete this[T.propFix[e]||e]}))}}),T.extend({prop:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&T.isXMLDoc(e)||(t=T.propFix[t]||t,i=T.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=T.find.attr(e,"tabindex");return t?parseInt(t,10):mt.test(e.nodeName)||bt.test(e.nodeName)&&e.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),y.optSelected||(T.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),T.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],(function(){T.propFix[this.toLowerCase()]=this})),T.fn.extend({addClass:function(e){var t,n,r,i,o,a,s,u=0;if(m(e))return this.each((function(t){T(this).addClass(e.call(this,t,wt(this)))}));if((t=xt(e)).length)for(;n=this[u++];)if(i=wt(n),r=1===n.nodeType&&" "+_t(i)+" "){for(a=0;o=t[a++];)r.indexOf(" "+o+" ")<0&&(r+=o+" ");i!==(s=_t(r))&&n.setAttribute("class",s)}return this},removeClass:function(e){var t,n,r,i,o,a,s,u=0;if(m(e))return this.each((function(t){T(this).removeClass(e.call(this,t,wt(this)))}));if(!arguments.length)return this.attr("class","");if((t=xt(e)).length)for(;n=this[u++];)if(i=wt(n),r=1===n.nodeType&&" "+_t(i)+" "){for(a=0;o=t[a++];)for(;r.indexOf(" "+o+" ")>-1;)r=r.replace(" "+o+" "," ");i!==(s=_t(r))&&n.setAttribute("class",s)}return this},toggleClass:function(e,t){var n=typeof e,r="string"===n||Array.isArray(e);return"boolean"==typeof t&&r?t?this.addClass(e):this.removeClass(e):m(e)?this.each((function(n){T(this).toggleClass(e.call(this,n,wt(this),t),t)})):this.each((function(){var t,i,o,a;if(r)for(i=0,o=T(this),a=xt(e);t=a[i++];)o.hasClass(t)?o.removeClass(t):o.addClass(t);else void 0!==e&&"boolean"!==n||((t=wt(this))&&Z.set(this,"__className__",t),this.setAttribute&&this.setAttribute("class",t||!1===e?"":Z.get(this,"__className__")||""))}))},hasClass:function(e){var t,n,r=0;for(t=" "+e+" ";n=this[r++];)if(1===n.nodeType&&(" "+_t(wt(n))+" ").indexOf(t)>-1)return!0;return!1}});var Tt=/\r/g;T.fn.extend({val:function(e){var t,n,r,i=this[0];return arguments.length?(r=m(e),this.each((function(n){var i;1===this.nodeType&&(null==(i=r?e.call(this,n,T(this).val()):e)?i="":"number"==typeof i?i+="":Array.isArray(i)&&(i=T.map(i,(function(e){return null==e?"":e+""}))),(t=T.valHooks[this.type]||T.valHooks[this.nodeName.toLowerCase()])&&"set"in t&&void 0!==t.set(this,i,"value")||(this.value=i))}))):i?(t=T.valHooks[i.type]||T.valHooks[i.nodeName.toLowerCase()])&&"get"in t&&void 0!==(n=t.get(i,"value"))?n:"string"==typeof(n=i.value)?n.replace(Tt,""):null==n?"":n:void 0}}),T.extend({valHooks:{option:{get:function(e){var t=T.find.attr(e,"value");return null!=t?t:_t(T.text(e))}},select:{get:function(e){var t,n,r,i=e.options,o=e.selectedIndex,a="select-one"===e.type,s=a?null:[],u=a?o+1:i.length;for(r=o<0?u:a?o:0;r<u;r++)if(((n=i[r]).selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!D(n.parentNode,"optgroup"))){if(t=T(n).val(),a)return t;s.push(t)}return s},set:function(e,t){for(var n,r,i=e.options,o=T.makeArray(t),a=i.length;a--;)((r=i[a]).selected=T.inArray(T.valHooks.option.get(r),o)>-1)&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),T.each(["radio","checkbox"],(function(){T.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=T.inArray(T(e).val(),t)>-1}},y.checkOn||(T.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})})),y.focusin="onfocusin"in n;var Ct=/^(?:focusinfocus|focusoutblur)$/,Et=function(e){e.stopPropagation()};T.extend(T.event,{trigger:function(e,t,r,i){var o,s,u,c,l,f,h,p,v=[r||a],g=d.call(e,"type")?e.type:e,y=d.call(e,"namespace")?e.namespace.split("."):[];if(s=p=u=r=r||a,3!==r.nodeType&&8!==r.nodeType&&!Ct.test(g+T.event.triggered)&&(g.indexOf(".")>-1&&(y=g.split("."),g=y.shift(),y.sort()),l=g.indexOf(":")<0&&"on"+g,(e=e[T.expando]?e:new T.Event(g,"object"==typeof e&&e)).isTrigger=i?2:3,e.namespace=y.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+y.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=r),t=null==t?[e]:T.makeArray(t,[e]),h=T.event.special[g]||{},i||!h.trigger||!1!==h.trigger.apply(r,t))){if(!i&&!h.noBubble&&!b(r)){for(c=h.delegateType||g,Ct.test(c+g)||(s=s.parentNode);s;s=s.parentNode)v.push(s),u=s;u===(r.ownerDocument||a)&&v.push(u.defaultView||u.parentWindow||n)}for(o=0;(s=v[o++])&&!e.isPropagationStopped();)p=s,e.type=o>1?c:h.bindType||g,(f=(Z.get(s,"events")||{})[e.type]&&Z.get(s,"handle"))&&f.apply(s,t),(f=l&&s[l])&&f.apply&&G(s)&&(e.result=f.apply(s,t),!1===e.result&&e.preventDefault());return e.type=g,i||e.isDefaultPrevented()||h._default&&!1!==h._default.apply(v.pop(),t)||!G(r)||l&&m(r[g])&&!b(r)&&((u=r[l])&&(r[l]=null),T.event.triggered=g,e.isPropagationStopped()&&p.addEventListener(g,Et),r[g](),e.isPropagationStopped()&&p.removeEventListener(g,Et),T.event.triggered=void 0,u&&(r[l]=u)),e.result}},simulate:function(e,t,n){var r=T.extend(new T.Event,n,{type:e,isSimulated:!0});T.event.trigger(r,null,t)}}),T.fn.extend({trigger:function(e,t){return this.each((function(){T.event.trigger(e,t,this)}))},triggerHandler:function(e,t){var n=this[0];if(n)return T.event.trigger(e,t,n,!0)}}),y.focusin||T.each({focus:"focusin",blur:"focusout"},(function(e,t){var n=function(e){T.event.simulate(t,e.target,T.event.fix(e))};T.event.special[t]={setup:function(){var r=this.ownerDocument||this,i=Z.access(r,t);i||r.addEventListener(e,n,!0),Z.access(r,t,(i||0)+1)},teardown:function(){var r=this.ownerDocument||this,i=Z.access(r,t)-1;i?Z.access(r,t,i):(r.removeEventListener(e,n,!0),Z.remove(r,t))}}}));var kt=n.location,St=Date.now(),At=/\?/;T.parseXML=function(e){var t;if(!e||"string"!=typeof e)return null;try{t=(new n.DOMParser).parseFromString(e,"text/xml")}catch(e){t=void 0}return t&&!t.getElementsByTagName("parsererror").length||T.error("Invalid XML: "+e),t};var Ot=/\[\]$/,Dt=/\r?\n/g,Pt=/^(?:submit|button|image|reset|file)$/i,Nt=/^(?:input|select|textarea|keygen)/i;function jt(e,t,n,r){var i;if(Array.isArray(t))T.each(t,(function(t,i){n||Ot.test(e)?r(e,i):jt(e+"["+("object"==typeof i&&null!=i?t:"")+"]",i,n,r)}));else if(n||"object"!==x(t))r(e,t);else for(i in t)jt(e+"["+i+"]",t[i],n,r)}T.param=function(e,t){var n,r=[],i=function(e,t){var n=m(t)?t():t;r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==n?"":n)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!T.isPlainObject(e))T.each(e,(function(){i(this.name,this.value)}));else for(n in e)jt(n,e[n],t,i);return r.join("&")},T.fn.extend({serialize:function(){return T.param(this.serializeArray())},serializeArray:function(){return this.map((function(){var e=T.prop(this,"elements");return e?T.makeArray(e):this})).filter((function(){var e=this.type;return this.name&&!T(this).is(":disabled")&&Nt.test(this.nodeName)&&!Pt.test(e)&&(this.checked||!ve.test(e))})).map((function(e,t){var n=T(this).val();return null==n?null:Array.isArray(n)?T.map(n,(function(e){return{name:t.name,value:e.replace(Dt,"\r\n")}})):{name:t.name,value:n.replace(Dt,"\r\n")}})).get()}});var Lt=/%20/g,It=/#.*$/,Mt=/([?&])_=[^&]*/,Rt=/^(.*?):[ \t]*([^\r\n]*)$/gm,Bt=/^(?:GET|HEAD)$/,$t=/^\/\//,qt={},Ft={},Ht="*/".concat("*"),Ut=a.createElement("a");function Wt(e){return function(t,n){"string"!=typeof t&&(n=t,t="*");var r,i=0,o=t.toLowerCase().match(B)||[];if(m(n))for(;r=o[i++];)"+"===r[0]?(r=r.slice(1)||"*",(e[r]=e[r]||[]).unshift(n)):(e[r]=e[r]||[]).push(n)}}function zt(e,t,n,r){var i={},o=e===Ft;function a(s){var u;return i[s]=!0,T.each(e[s]||[],(function(e,s){var c=s(t,n,r);return"string"!=typeof c||o||i[c]?o?!(u=c):void 0:(t.dataTypes.unshift(c),a(c),!1)})),u}return a(t.dataTypes[0])||!i["*"]&&a("*")}function Kt(e,t){var n,r,i=T.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);return r&&T.extend(!0,e,r),e}Ut.href=kt.href,T.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:kt.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(kt.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Ht,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":T.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?Kt(Kt(e,T.ajaxSettings),t):Kt(T.ajaxSettings,e)},ajaxPrefilter:Wt(qt),ajaxTransport:Wt(Ft),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var r,i,o,s,u,c,l,f,h,p,d=T.ajaxSetup({},t),v=d.context||d,g=d.context&&(v.nodeType||v.jquery)?T(v):T.event,y=T.Deferred(),m=T.Callbacks("once memory"),b=d.statusCode||{},_={},w={},x="canceled",C={readyState:0,getResponseHeader:function(e){var t;if(l){if(!s)for(s={};t=Rt.exec(o);)s[t[1].toLowerCase()+" "]=(s[t[1].toLowerCase()+" "]||[]).concat(t[2]);t=s[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return l?o:null},setRequestHeader:function(e,t){return null==l&&(e=w[e.toLowerCase()]=w[e.toLowerCase()]||e,_[e]=t),this},overrideMimeType:function(e){return null==l&&(d.mimeType=e),this},statusCode:function(e){var t;if(e)if(l)C.always(e[C.status]);else for(t in e)b[t]=[b[t],e[t]];return this},abort:function(e){var t=e||x;return r&&r.abort(t),E(0,t),this}};if(y.promise(C),d.url=((e||d.url||kt.href)+"").replace($t,kt.protocol+"//"),d.type=t.method||t.type||d.method||d.type,d.dataTypes=(d.dataType||"*").toLowerCase().match(B)||[""],null==d.crossDomain){c=a.createElement("a");try{c.href=d.url,c.href=c.href,d.crossDomain=Ut.protocol+"//"+Ut.host!=c.protocol+"//"+c.host}catch(e){d.crossDomain=!0}}if(d.data&&d.processData&&"string"!=typeof d.data&&(d.data=T.param(d.data,d.traditional)),zt(qt,d,t,C),l)return C;for(h in(f=T.event&&d.global)&&0==T.active++&&T.event.trigger("ajaxStart"),d.type=d.type.toUpperCase(),d.hasContent=!Bt.test(d.type),i=d.url.replace(It,""),d.hasContent?d.data&&d.processData&&0===(d.contentType||"").indexOf("application/x-www-form-urlencoded")&&(d.data=d.data.replace(Lt,"+")):(p=d.url.slice(i.length),d.data&&(d.processData||"string"==typeof d.data)&&(i+=(At.test(i)?"&":"?")+d.data,delete d.data),!1===d.cache&&(i=i.replace(Mt,"$1"),p=(At.test(i)?"&":"?")+"_="+St+++p),d.url=i+p),d.ifModified&&(T.lastModified[i]&&C.setRequestHeader("If-Modified-Since",T.lastModified[i]),T.etag[i]&&C.setRequestHeader("If-None-Match",T.etag[i])),(d.data&&d.hasContent&&!1!==d.contentType||t.contentType)&&C.setRequestHeader("Content-Type",d.contentType),C.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+("*"!==d.dataTypes[0]?", "+Ht+"; q=0.01":""):d.accepts["*"]),d.headers)C.setRequestHeader(h,d.headers[h]);if(d.beforeSend&&(!1===d.beforeSend.call(v,C,d)||l))return C.abort();if(x="abort",m.add(d.complete),C.done(d.success),C.fail(d.error),r=zt(Ft,d,t,C)){if(C.readyState=1,f&&g.trigger("ajaxSend",[C,d]),l)return C;d.async&&d.timeout>0&&(u=n.setTimeout((function(){C.abort("timeout")}),d.timeout));try{l=!1,r.send(_,E)}catch(e){if(l)throw e;E(-1,e)}}else E(-1,"No Transport");function E(e,t,a,s){var c,h,p,_,w,x=t;l||(l=!0,u&&n.clearTimeout(u),r=void 0,o=s||"",C.readyState=e>0?4:0,c=e>=200&&e<300||304===e,a&&(_=function(e,t,n){for(var r,i,o,a,s=e.contents,u=e.dataTypes;"*"===u[0];)u.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("Content-Type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||e.converters[i+" "+u[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==u[0]&&u.unshift(o),n[o]}(d,C,a)),_=function(e,t,n,r){var i,o,a,s,u,c={},l=e.dataTypes.slice();if(l[1])for(a in e.converters)c[a.toLowerCase()]=e.converters[a];for(o=l.shift();o;)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!u&&r&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),u=o,o=l.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(!(a=c[u+" "+o]||c["* "+o]))for(i in c)if((s=i.split(" "))[1]===o&&(a=c[u+" "+s[0]]||c["* "+s[0]])){!0===a?a=c[i]:!0!==c[i]&&(o=s[0],l.unshift(s[1]));break}if(!0!==a)if(a&&e.throws)t=a(t);else try{t=a(t)}catch(e){return{state:"parsererror",error:a?e:"No conversion from "+u+" to "+o}}}return{state:"success",data:t}}(d,_,C,c),c?(d.ifModified&&((w=C.getResponseHeader("Last-Modified"))&&(T.lastModified[i]=w),(w=C.getResponseHeader("etag"))&&(T.etag[i]=w)),204===e||"HEAD"===d.type?x="nocontent":304===e?x="notmodified":(x=_.state,h=_.data,c=!(p=_.error))):(p=x,!e&&x||(x="error",e<0&&(e=0))),C.status=e,C.statusText=(t||x)+"",c?y.resolveWith(v,[h,x,C]):y.rejectWith(v,[C,x,p]),C.statusCode(b),b=void 0,f&&g.trigger(c?"ajaxSuccess":"ajaxError",[C,d,c?h:p]),m.fireWith(v,[C,x]),f&&(g.trigger("ajaxComplete",[C,d]),--T.active||T.event.trigger("ajaxStop")))}return C},getJSON:function(e,t,n){return T.get(e,t,n,"json")},getScript:function(e,t){return T.get(e,void 0,t,"script")}}),T.each(["get","post"],(function(e,t){T[t]=function(e,n,r,i){return m(n)&&(i=i||r,r=n,n=void 0),T.ajax(T.extend({url:e,type:t,dataType:i,data:n,success:r},T.isPlainObject(e)&&e))}})),T._evalUrl=function(e,t){return T.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){T.globalEval(e,t)}})},T.fn.extend({wrapAll:function(e){var t;return this[0]&&(m(e)&&(e=e.call(this[0])),t=T(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map((function(){for(var e=this;e.firstElementChild;)e=e.firstElementChild;return e})).append(this)),this},wrapInner:function(e){return m(e)?this.each((function(t){T(this).wrapInner(e.call(this,t))})):this.each((function(){var t=T(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)}))},wrap:function(e){var t=m(e);return this.each((function(n){T(this).wrapAll(t?e.call(this,n):e)}))},unwrap:function(e){return this.parent(e).not("body").each((function(){T(this).replaceWith(this.childNodes)})),this}}),T.expr.pseudos.hidden=function(e){return!T.expr.pseudos.visible(e)},T.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},T.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(e){}};var Vt={0:200,1223:204},Xt=T.ajaxSettings.xhr();y.cors=!!Xt&&"withCredentials"in Xt,y.ajax=Xt=!!Xt,T.ajaxTransport((function(e){var t,r;if(y.cors||Xt&&!e.crossDomain)return{send:function(i,o){var a,s=e.xhr();if(s.open(e.type,e.url,e.async,e.username,e.password),e.xhrFields)for(a in e.xhrFields)s[a]=e.xhrFields[a];for(a in e.mimeType&&s.overrideMimeType&&s.overrideMimeType(e.mimeType),e.crossDomain||i["X-Requested-With"]||(i["X-Requested-With"]="XMLHttpRequest"),i)s.setRequestHeader(a,i[a]);t=function(e){return function(){t&&(t=r=s.onload=s.onerror=s.onabort=s.ontimeout=s.onreadystatechange=null,"abort"===e?s.abort():"error"===e?"number"!=typeof s.status?o(0,"error"):o(s.status,s.statusText):o(Vt[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=t(),r=s.onerror=s.ontimeout=t("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout((function(){t&&r()}))},t=t("abort");try{s.send(e.hasContent&&e.data||null)}catch(e){if(t)throw e}},abort:function(){t&&t()}}})),T.ajaxPrefilter((function(e){e.crossDomain&&(e.contents.script=!1)})),T.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return T.globalEval(e),e}}}),T.ajaxPrefilter("script",(function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")})),T.ajaxTransport("script",(function(e){var t,n;if(e.crossDomain||e.scriptAttrs)return{send:function(r,i){t=T("<script>").attr(e.scriptAttrs||{}).prop({charset:e.scriptCharset,src:e.url}).on("load error",n=function(e){t.remove(),n=null,e&&i("error"===e.type?404:200,e.type)}),a.head.appendChild(t[0])},abort:function(){n&&n()}}}));var Yt,Gt=[],Jt=/(=)\?(?=&|$)|\?\?/;T.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Gt.pop()||T.expando+"_"+St++;return this[e]=!0,e}}),T.ajaxPrefilter("json jsonp",(function(e,t,r){var i,o,a,s=!1!==e.jsonp&&(Jt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&Jt.test(e.data)&&"data");if(s||"jsonp"===e.dataTypes[0])return i=e.jsonpCallback=m(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,s?e[s]=e[s].replace(Jt,"$1"+i):!1!==e.jsonp&&(e.url+=(At.test(e.url)?"&":"?")+e.jsonp+"="+i),e.converters["script json"]=function(){return a||T.error(i+" was not called"),a[0]},e.dataTypes[0]="json",o=n[i],n[i]=function(){a=arguments},r.always((function(){void 0===o?T(n).removeProp(i):n[i]=o,e[i]&&(e.jsonpCallback=t.jsonpCallback,Gt.push(i)),a&&m(o)&&o(a[0]),a=o=void 0})),"script"})),y.createHTMLDocument=((Yt=a.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Yt.childNodes.length),T.parseHTML=function(e,t,n){return"string"!=typeof e?[]:("boolean"==typeof t&&(n=t,t=!1),t||(y.createHTMLDocument?((r=(t=a.implementation.createHTMLDocument("")).createElement("base")).href=a.location.href,t.head.appendChild(r)):t=a),o=!n&&[],(i=P.exec(e))?[t.createElement(i[1])]:(i=Ce([e],t,o),o&&o.length&&T(o).remove(),T.merge([],i.childNodes)));var r,i,o},T.fn.load=function(e,t,n){var r,i,o,a=this,s=e.indexOf(" ");return s>-1&&(r=_t(e.slice(s)),e=e.slice(0,s)),m(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),a.length>0&&T.ajax({url:e,type:i||"GET",dataType:"html",data:t}).done((function(e){o=arguments,a.html(r?T("<div>").append(T.parseHTML(e)).find(r):e)})).always(n&&function(e,t){a.each((function(){n.apply(this,o||[e.responseText,t,e])}))}),this},T.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],(function(e,t){T.fn[t]=function(e){return this.on(t,e)}})),T.expr.pseudos.animated=function(e){return T.grep(T.timers,(function(t){return e===t.elem})).length},T.offset={setOffset:function(e,t,n){var r,i,o,a,s,u,c=T.css(e,"position"),l=T(e),f={};"static"===c&&(e.style.position="relative"),s=l.offset(),o=T.css(e,"top"),u=T.css(e,"left"),("absolute"===c||"fixed"===c)&&(o+u).indexOf("auto")>-1?(a=(r=l.position()).top,i=r.left):(a=parseFloat(o)||0,i=parseFloat(u)||0),m(t)&&(t=t.call(e,n,T.extend({},s))),null!=t.top&&(f.top=t.top-s.top+a),null!=t.left&&(f.left=t.left-s.left+i),"using"in t?t.using.call(e,f):l.css(f)}},T.fn.extend({offset:function(e){if(arguments.length)return void 0===e?this:this.each((function(t){T.offset.setOffset(this,e,t)}));var t,n,r=this[0];return r?r.getClientRects().length?(t=r.getBoundingClientRect(),n=r.ownerDocument.defaultView,{top:t.top+n.pageYOffset,left:t.left+n.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,n,r=this[0],i={top:0,left:0};if("fixed"===T.css(r,"position"))t=r.getBoundingClientRect();else{for(t=this.offset(),n=r.ownerDocument,e=r.offsetParent||n.documentElement;e&&(e===n.body||e===n.documentElement)&&"static"===T.css(e,"position");)e=e.parentNode;e&&e!==r&&1===e.nodeType&&((i=T(e).offset()).top+=T.css(e,"borderTopWidth",!0),i.left+=T.css(e,"borderLeftWidth",!0))}return{top:t.top-i.top-T.css(r,"marginTop",!0),left:t.left-i.left-T.css(r,"marginLeft",!0)}}},offsetParent:function(){return this.map((function(){for(var e=this.offsetParent;e&&"static"===T.css(e,"position");)e=e.offsetParent;return e||ae}))}}),T.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},(function(e,t){var n="pageYOffset"===t;T.fn[e]=function(r){return z(this,(function(e,r,i){var o;if(b(e)?o=e:9===e.nodeType&&(o=e.defaultView),void 0===i)return o?o[t]:e[r];o?o.scrollTo(n?o.pageXOffset:i,n?i:o.pageYOffset):e[r]=i}),e,r,arguments.length)}})),T.each(["top","left"],(function(e,t){T.cssHooks[t]=Xe(y.pixelPosition,(function(e,n){if(n)return n=Ve(e,t),We.test(n)?T(e).position()[t]+"px":n}))})),T.each({Height:"height",Width:"width"},(function(e,t){T.each({padding:"inner"+e,content:t,"":"outer"+e},(function(n,r){T.fn[r]=function(i,o){var a=arguments.length&&(n||"boolean"!=typeof i),s=n||(!0===i||!0===o?"margin":"border");return z(this,(function(t,n,i){var o;return b(t)?0===r.indexOf("outer")?t["inner"+e]:t.document.documentElement["client"+e]:9===t.nodeType?(o=t.documentElement,Math.max(t.body["scroll"+e],o["scroll"+e],t.body["offset"+e],o["offset"+e],o["client"+e])):void 0===i?T.css(t,n,s):T.style(t,n,i,s)}),t,a?i:void 0,a)}}))})),T.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),(function(e,t){T.fn[t]=function(e,n){return arguments.length>0?this.on(t,null,e,n):this.trigger(t)}})),T.fn.extend({hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),T.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)}}),T.proxy=function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),m(e))return r=u.call(arguments,2),(i=function(){return e.apply(t||this,r.concat(u.call(arguments)))}).guid=e.guid=e.guid||T.guid++,i},T.holdReady=function(e){e?T.readyWait++:T.ready(!0)},T.isArray=Array.isArray,T.parseJSON=JSON.parse,T.nodeName=D,T.isFunction=m,T.isWindow=b,T.camelCase=Y,T.type=x,T.now=Date.now,T.isNumeric=function(e){var t=T.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},void 0===(r=function(){return T}.apply(t,[]))||(e.exports=r);var Zt=n.jQuery,Qt=n.$;return T.noConflict=function(e){return n.$===T&&(n.$=Qt),e&&n.jQuery===T&&(n.jQuery=Zt),T},i||(n.jQuery=n.$=T),T}))},function(e,t){(function(){e.exports=function(){function e(e,t){this.layer=e,this.length=t,this.file=this.layer.file,this.section_end=this.file.tell()+this.length,this.data={}}return e.prototype.skip=function(){return this.file.seek(this.section_end)},e.prototype.parse=function(){return this.skip()},e}()}).call(this)},function(module,__webpack_exports__,__webpack_require__){"use strict";var jquery__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(0),jquery__WEBPACK_IMPORTED_MODULE_0___default=__webpack_require__.n(jquery__WEBPACK_IMPORTED_MODULE_0__),node_opencc__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(30),node_opencc__WEBPACK_IMPORTED_MODULE_1___default=__webpack_require__.n(node_opencc__WEBPACK_IMPORTED_MODULE_1__),_coffee__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(12),_psd_coffee__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(19),演出;__webpack_exports__.a=演出={"準備工作":function(){var e,t,n,r;for(jquery__WEBPACK_IMPORTED_MODULE_0___default()("<link>").attr({rel:"stylesheet",type:"text/css",href:v.主題css}).appendTo("head"),t=0,n=(r=v.自定css).length;t<n;t++)e=r[t],jquery__WEBPACK_IMPORTED_MODULE_0___default()("<link>").attr({rel:"stylesheet",type:"text/css",href:e}).appendTo("head");return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面").css("width",v.解析度[0]),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面").css("height",v.解析度[1]),v.邊界&&jquery__WEBPACK_IMPORTED_MODULE_0___default()("div").css("border","1px solid #22f"),this.縮放調整()},"縮放調整":function(){var e,t,n;return e=document.body.clientWidth/v.解析度[0],t=document.body.clientHeight/v.解析度[1],n=Math.min(e,t),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面").css({"transform-origin":"0% 0%",transform:"scale("+n+")"}),setTimeout(演出.縮放調整,200)},"更新":function(e=!1){return 山彥.狀態回調(!1,(function(t,n=!1){return 演出.改變演出狀態(t,e)}))},"步進更新":function(e=!1){return 山彥.狀態回調(!0,(function(t){return 演出.改變演出狀態(t,e)}))},"翻譯":function(e){return v.翻譯?node_opencc__WEBPACK_IMPORTED_MODULE_1___default.a[v.翻譯](e):e},"信息預處理":function(e){if(e.背景&&(e.背景[0]=`url('${v.圖片文件夾}/${e.背景[0]}')`.replace(/(\\)/g,"/")),e.cg&&(e.cg[0]=`url('${v.圖片文件夾}/${e.cg[0]}')`.replace(/\\/g,"/")),e.背景音樂&&(e.背景音樂[0]=v.音樂文件夾+"/"+e.背景音樂[0]),e.效果音&&(e.效果音[0]=v.音樂文件夾+"/"+e.效果音[0]),e.插入圖)return e.插入圖=`url('${v.圖片文件夾}/${e.插入圖}')`.replace(/\\/g,"/")},"當前狀態":{},"改變演出狀態":function(data,瞬間化=!1){var cg,e,html,js,名字,插入圖,效果音,特效表,立繪,背景,背景音樂,視頻,話語,語者,選項,額外信息;if(console.log(data),this.信息預處理(data),this.當前狀態=data,({"特效表":特效表,"插入圖":插入圖,"立繪":立繪,"名字":名字,"話語":話語,"額外信息":額外信息,"語者":語者,"背景":背景,"背景音樂":背景音樂,"效果音":效果音,cg:cg,"選項":選項,js:js,html:html,"視頻":視頻}=data),this.特效處理(特效表),!(選項.length>0)){if(插入圖)return this.換背景音樂(null),this.換圖("覆蓋",插入圖,0),void jquery__WEBPACK_IMPORTED_MODULE_0___default()("#覆蓋").attr("顯現","true");"true"===jquery__WEBPACK_IMPORTED_MODULE_0___default()("#覆蓋").attr("顯現")&&(瞬間化=!0),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#覆蓋").attr("顯現","false"),額外信息&&"load"===額外信息[0]&&this.load特效();try{eval(js)}catch(t){e=t,console.log(e)}return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#html疊加").html(html),this.放視頻(視頻),this.換cg(cg),this.換背景(背景,瞬間化),this.換立繪(立繪,瞬間化),this.換背景音樂(背景音樂),this.放效果音(效果音),this.換人名(語者,名字),this.換對話(話語,名字,瞬間化)}this.處理選項(選項)},"特效處理":function(e){var t,n,r,i,o;for(n=0,r=(o=["總畫面","adv畫面","主畫面","覆蓋","選項","cg","bg","立繪","對話歷史","對話框","名字框","名字","名字框背景","話語框","話語","話語框背景","對話框背景"]).length;n<r;n++)t=o[n],jquery__WEBPACK_IMPORTED_MODULE_0___default()("#"+t).attr("特效")&&jquery__WEBPACK_IMPORTED_MODULE_0___default()("#"+t).attr("特效","");for(t in i=[],e)i.push(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#"+t).attr("特效",e[t]));return i},"選擇之刻":!1,"處理選項":function(e){var t,n,r,i,o;for(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#選項").html(""),i=n=0,r=e.length;n<r;i=++n)t=e[i],o=jquery__WEBPACK_IMPORTED_MODULE_0___default()(`<a 選項號='${i}'>${t}</a>`),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#選項").append(o),o.click((function(){return 演出.點選項(parseInt(jquery__WEBPACK_IMPORTED_MODULE_0___default()(this).attr("選項號")))}));return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#選項").fadeIn(200),this.選擇之刻=!0},"點選項":function(e){return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#選項").fadeOut(50),山彥.選(e),this.選擇之刻=!1},"放視頻":function(e){var t,n,r;if(e)return[r,n]=e,(t=jquery__WEBPACK_IMPORTED_MODULE_0___default()("#視頻")).css("display","block"),t.attr("src",v.視頻文件夾+"/"+r),t.click(n?function(){return t.css("animation","_黑出 0.5s"),t.css("animation-fill-mode","forwards"),setTimeout((function(){return t.css("animation",""),t.attr("src",""),t[0].style.display="none"}),600)}:function(){return null}),t[0].addEventListener("ended",(function(){return t[0].style.display="none"}),!1),t[0].play()},"load特效":function(){return _coffee__WEBPACK_IMPORTED_MODULE_2__.a.左鍵屏蔽=!0,jquery__WEBPACK_IMPORTED_MODULE_0___default()("#adv畫面").fadeOut(0),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#adv畫面").fadeIn(400),setTimeout((function(){return _coffee__WEBPACK_IMPORTED_MODULE_2__.a.左鍵屏蔽=!1}),300)},"提示":function(e){return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#提示").html(e),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#提示").fadeIn(300),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#提示").hide(1e3)},"現在cg":null,"換cg":function(e){var t,n,r;if([t,n,r]=e||["",0,""],t!==this.現在cg)return this.現在cg=t,this.換圖("cg",t,n,r)},"當前人物組":[],"換立繪":async function(e,t=!1){var n,r,i,o,a,s,u,c,l,f,h,p,d,g,y;for(g=function(){var t,n,r;for(r=[],t=0,n=e.length;t<n;t++)y=e[t],r.push(y.名字);return r}(),n=0,o=(h=this.當前人物組).length;n<o;n++)d=h[n],-1===g.indexOf(d)?(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#立繪--"+d).remove(),console.log("去除 "+d)):jquery__WEBPACK_IMPORTED_MODULE_0___default()("#立繪--"+d).attr("特效","");for(r=0,a=g.length;r<a;r++)d=g[r],-1===this.當前人物組.indexOf(d)&&(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#立繪").append(jquery__WEBPACK_IMPORTED_MODULE_0___default()(`<div id='立繪--${d}'><div id='立繪--${d}--圖像'></div></div>`)),console.log("加入 "+d));for(i=0,s=e.length;i<s;i++)y=e[i],p=jquery__WEBPACK_IMPORTED_MODULE_0___default()("#立繪--"+y.名字),t?p.css("transition",""):(.5,p.css("transition","top 0.5s, left 0.5s, transform 0.5s")),p.css("left",y.位置[0]+"px"),p.css("top",y.位置[1]+"px"),p.css("transform",`scale(${y.位置[2]})`),jquery__WEBPACK_IMPORTED_MODULE_0___default()(`#立繪--${y.名字}--圖像`).attr("特效",y.特效.join(" "));for(c=0,u=e.length;c<u;c++)(y=e[c]).使用png?(l=`${v.psd立繪路徑}/${y.名字}.png`,await _psd_coffee__WEBPACK_IMPORTED_MODULE_3__.a.渲染png到div(l,`立繪--${y.名字}--圖像`)):(f=`${v.psd立繪路徑}/${y.名字}.psd`,await _psd_coffee__WEBPACK_IMPORTED_MODULE_3__.a.渲染圖層組到div(f,y.圖層,`立繪--${y.名字}--圖像`),-1===this.當前人物組.indexOf(y.名字)&&jquery__WEBPACK_IMPORTED_MODULE_0___default()("#立繪--"+y.名字).attr("特效","淡入"));return this.當前人物組=g},"現在背景":[null,"0% 0%"],"換背景":function(e,t){var n,r,i,o;return[o,r,n,i]=e||["",0,""],t&&(r=0),o!==this.現在背景[0]?(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#bg").css("background-position",n),this.換圖("bg",o,r,i)):n!==this.現在背景[1]&&jquery__WEBPACK_IMPORTED_MODULE_0___default()("#bg").css("background-position",n),this.現在背景=[o,n]},"換人名":function(e,t){return(t=this.翻譯(t))?(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#名字").html(t),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#名字框").css("opacity",1)):jquery__WEBPACK_IMPORTED_MODULE_0___default()("#名字框").css("opacity",0),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#對話歷史").append(t+"<br/>"),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#對話框").attr("名字",e)},"淡入過期時間":0,"換對話":function(e,t,n){var r,i;return e=this.翻譯(e),t=this.翻譯(t),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#對話歷史").append(e+"<br/><br/>"),""!==t?jquery__WEBPACK_IMPORTED_MODULE_0___default()("#對話框").attr("對話類型","對話"):jquery__WEBPACK_IMPORTED_MODULE_0___default()("#對話框").attr("對話類型","旁白"),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語").css("--幹你娘老子就是要每行都縮進")&&(i="　".repeat(parseInt(jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語").css("--幹你娘老子就是要每行都縮進"))),e=e.replace(/(^|\n)/g,"$1"+i)),n?jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語").html(e+"<span></span>"):(r=演出.文字淡入(e),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語").html(r.內容),演出.淡入過期時間=Date.now()+1e3*r.文字時間)},"早泄":function(){return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語 *").css("animation","None"),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#話語 *").css("opacity","1")},"當前曲名":null,"換背景音樂":function(e){var t,n,r,i,o,a,s;if([o,s]=e||[null,0],this.當前曲名!==o){for(this.當前曲名=o,n=0,r=(i=jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面 > audio.背景音樂")).length;n<r;n++)0===(t=i[n]).volume&&t.remove();return jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面 > audio.背景音樂").animate({volume:0},500),(a=jquery__WEBPACK_IMPORTED_MODULE_0___default()(`<audio src='${o}' class='背景音樂' autoplay loop></audio>`)).volume=s,jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面").append(a)}},"放效果音":function(e){var t,n,r;if(e)return[t,r]=e,(n=jquery__WEBPACK_IMPORTED_MODULE_0___default()(`<audio src='${t}' class='效果音' autoplay></audio>`)).volume=r,n[0].addEventListener("ended",(function(){return n.remove()}),!1),jquery__WEBPACK_IMPORTED_MODULE_0___default()("#總畫面").append(n)},"換圖":function(e,t,n,r="_淡出"){var i,o;if(i=(e=jquery__WEBPACK_IMPORTED_MODULE_0___default()("#"+e)).css("background-image"),e.css("background-image",t),e.html('<div class="舊淡出"></div>'),o=e.children(),n>0)return o.css("background-image",i),o.css("animation",`${r} ${n}s`),o.css("animation-fill-mode","forwards"),o.css("animation-play-state","running")},"文字淡入":function(e,t="_淡入"){var n,r,i,o,a;return a=v.用戶設置.文字速度.值/800,n=e.replace(/(\s*((<.*?>)|(.)))/g,"$1\0").split("\0"),i=8*a,o=0,{"內容":function(){var e,s,u;for(u=[],e=0,s=n.length;e<s;e++)"<"===(r=n[e])[0]?u.push(r):(o+=a,u.push(`<span style='animation:${t} ${i}s;animation-fill-mode:forwards;animation-delay:${o}s;opacity:0;'>${r}</span>`));return u}().join(""),"文字時間":o,"總時間":o+i}}}},function(e,t){(function(){e.exports=function(){function e(e){this.file=e,this.data={}}return e.prototype.parse=function(){var e,t,n,r,i;for(this.data.class=this.parseClass(),t=0,n=this.file.readInt();0<=n?t<n:t>n;0<=n?++t:--t)e=(r=this.parseKeyItem())[0],i=r[1],this.data[e]=i;return this.data},e.prototype.parseClass=function(){return{name:this.file.readUnicodeString(),id:this.parseId()}},e.prototype.parseId=function(){var e;return 0===(e=this.file.readInt())?this.file.readString(4):this.file.readString(e)},e.prototype.parseKeyItem=function(){return[this.parseId(),this.parseItem()]},e.prototype.parseItem=function(t){switch(null==t&&(t=null),null==t&&(t=this.file.readString(4)),t){case"bool":return this.parseBoolean();case"type":case"GlbC":return this.parseClass();case"Objc":case"GlbO":return new e(this.file).parse();case"doub":return this.parseDouble();case"enum":return this.parseEnum();case"alis":return this.parseAlias();case"Pth":return this.parseFilePath();case"long":return this.parseInteger();case"comp":return this.parseLargeInteger();case"VlLs":return this.parseList();case"ObAr":return this.parseObjectArray();case"tdta":return this.parseRawData();case"obj ":return this.parseReference();case"TEXT":return this.file.readUnicodeString();case"UntF":return this.parseUnitDouble();case"UnFl":return this.parseUnitFloat();case"uglg":return this.parseBoolean()}},e.prototype.parseBoolean=function(){return this.file.readBoolean()},e.prototype.parseDouble=function(){return this.file.readDouble()},e.prototype.parseInteger=function(){return this.file.readInt()},e.prototype.parseLargeInteger=function(){return this.file.readLongLong()},e.prototype.parseIdentifier=function(){return this.file.readInt()},e.prototype.parseIndex=function(){return this.file.readInt()},e.prototype.parseOffset=function(){return this.file.readInt()},e.prototype.parseProperty=function(){return{class:this.parseClass(),id:this.parseId()}},e.prototype.parseEnum=function(){return{type:this.parseId(),value:this.parseId()}},e.prototype.parseEnumReference=function(){return{class:this.parseClass(),type:this.parseId(),value:this.parseId()}},e.prototype.parseAlias=function(){var e;return e=this.file.readInt(),this.file.readString(e)},e.prototype.parseFilePath=function(){var e,t;return this.file.readInt(),t=this.file.readString(4),this.file.read("<i"),e=this.file.read("<i"),{sig:t,path:this.file.readUnicodeString(e)}},e.prototype.parseList=function(){var e,t,n;for(e=[],t=0,n=this.file.readInt();0<=n?t<n:t>n;0<=n?++t:--t)e.push(this.parseItem());return e},e.prototype.parseObjectArray=function(){throw"Descriptor object array not implemented yet @ "+this.file.tell()},e.prototype.parseRawData=function(){var e;return e=this.file.readInt(),this.file.read(e)},e.prototype.parseReference=function(){var e,t,n,r,i;for(e=[],t=0,n=this.file.readInt();0<=n?t<n:t>n;0<=n?++t:--t)r=this.file.readString(4),i=function(){switch(r){case"prop":return this.parseProperty();case"Clss":return this.parseClass();case"Enmr":return this.parseEnumReference();case"Idnt":return this.parseIdentifier();case"indx":return this.parseIndex();case"name":return this.file.readUnicodeString();case"rele":return this.parseOffset()}}.call(this),e.push({type:r,value:i});return e},e.prototype.parseUnitDouble=function(){var e,t,n;return t=this.file.readString(4),e=function(){switch(t){case"#Ang":return"Angle";case"#Rsl":return"Density";case"#Rlt":return"Distance";case"#Nne":return"None";case"#Prc":return"Percent";case"#Pxl":return"Pixels";case"#Mlm":return"Millimeters";case"#Pnt":return"Points"}}(),n=this.file.readDouble(),{id:t,unit:e,value:n}},e.prototype.parseUnitFloat=function(){var e,t,n;return t=this.file.readString(4),e=function(){switch(t){case"#Ang":return"Angle";case"#Rsl":return"Density";case"#Rlt":return"Distance";case"#Nne":return"None";case"#Prc":return"Percent";case"#Pxl":return"Pixels";case"#Mlm":return"Millimeters";case"#Pnt":return"Points"}}(),n=this.file.readFloat(),{id:t,unit:e,value:n}},e}()}).call(this)},function(e,t,n){(function(e,r){var i;
/**
 * @license
 * Lo-Dash 2.4.2 (Custom Build) <https://lodash.com/>
 * Build: `lodash modern -o ./dist/lodash.js`
 * Copyright 2012-2013 The Dojo Foundation <http://dojofoundation.org/>
 * Based on Underscore.js 1.5.2 <http://underscorejs.org/LICENSE>
 * Copyright 2009-2013 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 * Available under MIT license <https://lodash.com/license>
 */(function(){var o=[],a=[],s=0,u=+new Date+"",c=/\b__p \+= '';/g,l=/\b(__p \+=) '' \+/g,f=/(__e\(.*?\)|\b__t\)) \+\n'';/g,h=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g,p=/\w*$/,d=/^\s*function[ \n\r\t]+\w/,v=/<%=([\s\S]+?)%>/g,g=RegExp("^[ \t\v\f \ufeff\n\r\u2028\u2029 ᠎             　]*0+(?=.$)"),y=/($^)/,m=/\bthis\b/,b=/['\n\r\t\u2028\u2029\\]/g,_=["Array","Boolean","Date","Function","Math","Number","Object","RegExp","String","_","attachEvent","clearTimeout","isFinite","isNaN","parseInt","setTimeout"],w=0,x="[object Arguments]",T="[object Array]",C="[object Boolean]",E="[object Date]",k="[object Object]",S="[object String]",A={"[object Function]":!1};A[x]=A[T]=A[C]=A[E]=A["[object Number]"]=A[k]=A["[object RegExp]"]=A[S]=!0;var O={leading:!1,maxWait:0,trailing:!1},D={configurable:!1,enumerable:!1,value:null,writable:!1},P={boolean:!1,function:!0,object:!0,number:!1,string:!1,undefined:!1},N={"\\":"\\","'":"'","\n":"n","\r":"r","\t":"t","\u2028":"u2028","\u2029":"u2029"},j=P[typeof window]&&window||this,L=P[typeof t]&&t&&!t.nodeType&&t,I=P[typeof e]&&e&&!e.nodeType&&e,M=(I&&I.exports,P[typeof r]&&r);function R(e,t,n){for(var r=(n||0)-1,i=e?e.length:0;++r<i;)if(e[r]===t)return r;return-1}function B(e,t){var n=typeof t;if(e=e.cache,"boolean"==n||null==t)return e[t]?0:-1;"number"!=n&&"string"!=n&&(n="object");var r="number"==n?t:u+t;return e=(e=e[n])&&e[r],"object"==n?e&&R(e,t)>-1?0:-1:e?0:-1}function $(e){var t=this.cache,n=typeof e;if("boolean"==n||null==e)t[e]=!0;else{"number"!=n&&"string"!=n&&(n="object");var r="number"==n?e:u+e,i=t[n]||(t[n]={});"object"==n?(i[r]||(i[r]=[])).push(e):i[r]=!0}}function q(e){return e.charCodeAt(0)}function F(e,t){for(var n=e.criteria,r=t.criteria,i=-1,o=n.length;++i<o;){var a=n[i],s=r[i];if(a!==s){if(a>s||void 0===a)return 1;if(a<s||void 0===s)return-1}}return e.index-t.index}function H(e){var t=-1,n=e.length,r=e[0],i=e[n/2|0],o=e[n-1];if(r&&"object"==typeof r&&i&&"object"==typeof i&&o&&"object"==typeof o)return!1;var a=z();a.false=a.null=a.true=a[void 0]=!1;var s=z();for(s.array=e,s.cache=a,s.push=$;++t<n;)s.push(e[t]);return s}function U(e){return"\\"+N[e]}function W(){return o.pop()||[]}function z(){return a.pop()||{array:null,cache:null,criteria:null,false:!1,index:0,null:!1,number:null,object:null,push:null,string:null,true:!1,undefined:!1,value:null}}function K(e){e.length=0,o.length<40&&o.push(e)}function V(e){var t=e.cache;t&&V(t),e.array=e.cache=e.criteria=e.object=e.number=e.string=e.value=null,a.length<40&&a.push(e)}function X(e,t,n){t||(t=0),void 0===n&&(n=e?e.length:0);for(var r=-1,i=n-t||0,o=Array(i<0?0:i);++r<i;)o[r]=e[t+r];return o}!M||M.global!==M&&M.window!==M||(j=M);var Y=function e(t){var n=(t=t?Y.defaults(j.Object(),t,Y.pick(j,_)):j).Array,r=t.Boolean,i=t.Date,o=t.Function,a=t.Math,N=t.Number,L=t.Object,I=t.RegExp,M=t.String,$=t.TypeError,G=[],J=L.prototype,Z=t._,Q=J.toString,ee=I("^"+M(Q).replace(/[.*+?^${}()|[\]\\]/g,"\\$&").replace(/toString| for [^\]]+/g,".*?")+"$"),te=a.ceil,ne=t.clearTimeout,re=a.floor,ie=o.prototype.toString,oe=qe(oe=L.getPrototypeOf)&&oe,ae=J.hasOwnProperty,se=G.push,ue=t.setTimeout,ce=G.splice,le=G.unshift,fe=function(){try{var e={},t=qe(t=L.defineProperty)&&t,n=t(e,e,e)&&t}catch(e){}return n}(),he=qe(he=L.create)&&he,pe=qe(pe=n.isArray)&&pe,de=t.isFinite,ve=t.isNaN,ge=qe(ge=L.keys)&&ge,ye=a.max,me=a.min,be=t.parseInt,_e=a.random,we={};function xe(e){return e&&"object"==typeof e&&!ze(e)&&ae.call(e,"__wrapped__")?e:new Te(e)}function Te(e,t){this.__chain__=!!t,this.__wrapped__=e}we[T]=n,we[C]=r,we[E]=i,we["[object Function]"]=o,we[k]=L,we["[object Number]"]=N,we["[object RegExp]"]=I,we[S]=M,Te.prototype=xe.prototype;var Ce=xe.support={};function Ee(e){var t=e[0],n=e[2],r=e[4];function i(){if(n){var e=X(n);se.apply(e,arguments)}if(this instanceof i){var o=Se(t.prototype),a=t.apply(o,e||arguments);return ot(a)?a:o}return t.apply(r,e||arguments)}return Fe(i,e),i}function ke(e,t,n,r,i){if(n){var o=n(e);if(void 0!==o)return o}if(!ot(e))return e;var a=Q.call(e);if(!A[a])return e;var s=we[a];switch(a){case C:case E:return new s(+e);case"[object Number]":case S:return new s(e);case"[object RegExp]":return(o=s(e.source,p.exec(e))).lastIndex=e.lastIndex,o}var u=ze(e);if(t){var c=!r;r||(r=W()),i||(i=W());for(var l=r.length;l--;)if(r[l]==e)return i[l];o=u?s(e.length):{}}else o=u?X(e):Je({},e);return u&&(ae.call(e,"index")&&(o.index=e.index),ae.call(e,"input")&&(o.input=e.input)),t?(r.push(e),i.push(o),(u?vt:et)(e,(function(e,a){o[a]=ke(e,t,n,r,i)})),c&&(K(r),K(i)),o):o}function Se(e,t){return ot(e)?he(e):{}}function Ae(e,t,n){if("function"!=typeof e)return Mt;if(void 0===t||!("prototype"in e))return e;var r=e.__bindData__;if(void 0===r&&(Ce.funcNames&&(r=!e.name),!(r=r||!Ce.funcDecomp))){var i=ie.call(e);Ce.funcNames||(r=!d.test(i)),r||(r=m.test(i),Fe(e,r))}if(!1===r||!0!==r&&1&r[1])return e;switch(n){case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,i){return e.call(t,n,r,i)};case 4:return function(n,r,i,o){return e.call(t,n,r,i,o)}}return Lt(e,t)}function Oe(e){var t=e[0],n=e[1],r=e[2],i=e[3],o=e[4],a=e[5],s=1&n,u=2&n,c=4&n,l=8&n,f=t;function h(){var e=s?o:this;if(r){var p=X(r);se.apply(p,arguments)}if((i||c)&&(p||(p=X(arguments)),i&&se.apply(p,i),c&&p.length<a))return n|=16,Oe([t,l?n:-4&n,p,null,o,a]);if(p||(p=arguments),u&&(t=e[f]),this instanceof h){e=Se(t.prototype);var d=t.apply(e,p);return ot(d)?d:e}return t.apply(e,p)}return Fe(h,e),h}function De(e,t){var n=-1,r=$e(),i=e?e.length:0,o=i>=75&&r===R,a=[];if(o){var s=H(t);s?(r=B,t=s):o=!1}for(;++n<i;){var u=e[n];r(t,u)<0&&a.push(u)}return o&&V(t),a}function Pe(e,t,n,r){for(var i=(r||0)-1,o=e?e.length:0,a=[];++i<o;){var s=e[i];if(s&&"object"==typeof s&&"number"==typeof s.length&&(ze(s)||We(s))){t||(s=Pe(s,t,n));var u=-1,c=s.length,l=a.length;for(a.length+=c;++u<c;)a[l++]=s[u]}else n||a.push(s)}return a}function Ne(e,t,n,r,i,o){if(n){var a=n(e,t);if(void 0!==a)return!!a}if(e===t)return 0!==e||1/e==1/t;if(!(e!=e||e&&P[typeof e]||t&&P[typeof t]))return!1;if(null==e||null==t)return e===t;var s=Q.call(e),u=Q.call(t);if(s==x&&(s=k),u==x&&(u=k),s!=u)return!1;switch(s){case C:case E:return+e==+t;case"[object Number]":return e!=+e?t!=+t:0==e?1/e==1/t:e==+t;case"[object RegExp]":case S:return e==M(t)}var c=s==T;if(!c){var l=ae.call(e,"__wrapped__"),f=ae.call(t,"__wrapped__");if(l||f)return Ne(l?e.__wrapped__:e,f?t.__wrapped__:t,n,r,i,o);if(s!=k)return!1;var h=e.constructor,p=t.constructor;if(h!=p&&!(it(h)&&h instanceof h&&it(p)&&p instanceof p)&&"constructor"in e&&"constructor"in t)return!1}var d=!i;i||(i=W()),o||(o=W());for(var v=i.length;v--;)if(i[v]==e)return o[v]==t;var g=0;if(a=!0,i.push(e),o.push(t),c){if(v=e.length,g=t.length,(a=g==v)||r)for(;g--;){var y=v,m=t[g];if(r)for(;y--&&!(a=Ne(e[y],m,n,r,i,o)););else if(!(a=Ne(e[g],m,n,r,i,o)))break}}else Qe(t,(function(t,s,u){if(ae.call(u,s))return g++,a=ae.call(e,s)&&Ne(e[s],t,n,r,i,o)})),a&&!r&&Qe(e,(function(e,t,n){if(ae.call(n,t))return a=--g>-1}));return i.pop(),o.pop(),d&&(K(i),K(o)),a}function je(e,t,n,r,i){(ze(t)?vt:et)(t,(function(t,o){var a,s,u=t,c=e[o];if(t&&((s=ze(t))||st(t))){for(var l,f=r.length;f--;)if(a=r[f]==t){c=i[f];break}if(!a)n&&(l=void 0!==(u=n(c,t)))&&(c=u),l||(c=s?ze(c)?c:[]:st(c)?c:{}),r.push(t),i.push(c),l||je(c,t,n,r,i)}else n&&void 0===(u=n(c,t))&&(u=t),void 0!==u&&(c=u);e[o]=c}))}function Le(e,t){return e+re(_e()*(t-e+1))}function Ie(e,t,n){var r=-1,i=$e(),o=e?e.length:0,a=[],s=!t&&o>=75&&i===R,u=n||s?W():a;s&&(i=B,u=H(u));for(;++r<o;){var c=e[r],l=n?n(c,r,e):c;(t?!r||u[u.length-1]!==l:i(u,l)<0)&&((n||s)&&u.push(l),a.push(c))}return s?(K(u.array),V(u)):n&&K(u),a}function Me(e){return function(t,n,r){var i={};n=xe.createCallback(n,r,3);var o=-1,a=t?t.length:0;if("number"==typeof a)for(;++o<a;){var s=t[o];e(i,s,n(s,o,t),t)}else et(t,(function(t,r,o){e(i,t,n(t,r,o),o)}));return i}}function Re(e,t,n,r,i,o){var a=1&t,s=4&t,u=16&t,c=32&t;if(!(2&t)&&!it(e))throw new $;u&&!n.length&&(t&=-17,u=n=!1),c&&!r.length&&(t&=-33,c=r=!1);var l=e&&e.__bindData__;return l&&!0!==l?((l=X(l))[2]&&(l[2]=X(l[2])),l[3]&&(l[3]=X(l[3])),!a||1&l[1]||(l[4]=i),!a&&1&l[1]&&(t|=8),!s||4&l[1]||(l[5]=o),u&&se.apply(l[2]||(l[2]=[]),n),c&&le.apply(l[3]||(l[3]=[]),r),l[1]|=t,Re.apply(null,l)):(1==t||17===t?Ee:Oe)([e,t,n,r,i,o])}function Be(e){return Ve[e]}function $e(){var e=(e=xe.indexOf)===At?R:e;return e}function qe(e){return"function"==typeof e&&ee.test(e)}Ce.funcDecomp=!qe(t.WinRTError)&&m.test(e),Ce.funcNames="string"==typeof o.name,xe.templateSettings={escape:/<%-([\s\S]+?)%>/g,evaluate:/<%([\s\S]+?)%>/g,interpolate:v,variable:"",imports:{_:xe}},he||(Se=function(){function e(){}return function(n){if(ot(n)){e.prototype=n;var r=new e;e.prototype=null}return r||t.Object()}}());var Fe=fe?function(e,t){D.value=t,fe(e,"__bindData__",D),D.value=null}:Bt;function He(e){var t,n;return!(!e||Q.call(e)!=k||it(t=e.constructor)&&!(t instanceof t))&&(Qe(e,(function(e,t){n=t})),void 0===n||ae.call(e,n))}function Ue(e){return Xe[e]}function We(e){return e&&"object"==typeof e&&"number"==typeof e.length&&Q.call(e)==x||!1}var ze=pe||function(e){return e&&"object"==typeof e&&"number"==typeof e.length&&Q.call(e)==T||!1},Ke=ge?function(e){return ot(e)?ge(e):[]}:function(e){var t,n=e,r=[];if(!n)return r;if(!P[typeof e])return r;for(t in n)ae.call(n,t)&&r.push(t);return r},Ve={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},Xe=rt(Ve),Ye=I("("+Ke(Xe).join("|")+")","g"),Ge=I("["+Ke(Ve).join("")+"]","g"),Je=function(e,t,n){var r,i=e,o=i;if(!i)return o;var a=arguments,s=0,u="number"==typeof n?2:a.length;if(u>3&&"function"==typeof a[u-2])var c=Ae(a[--u-1],a[u--],2);else u>2&&"function"==typeof a[u-1]&&(c=a[--u]);for(;++s<u;)if((i=a[s])&&P[typeof i])for(var l=-1,f=P[typeof i]&&Ke(i),h=f?f.length:0;++l<h;)o[r=f[l]]=c?c(o[r],i[r]):i[r];return o},Ze=function(e,t,n){var r,i=e,o=i;if(!i)return o;for(var a=arguments,s=0,u="number"==typeof n?2:a.length;++s<u;)if((i=a[s])&&P[typeof i])for(var c=-1,l=P[typeof i]&&Ke(i),f=l?l.length:0;++c<f;)void 0===o[r=l[c]]&&(o[r]=i[r]);return o},Qe=function(e,t,n){var r,i=e,o=i;if(!i)return o;if(!P[typeof i])return o;for(r in t=t&&void 0===n?t:Ae(t,n,3),i)if(!1===t(i[r],r,e))return o;return o},et=function(e,t,n){var r,i=e,o=i;if(!i)return o;if(!P[typeof i])return o;t=t&&void 0===n?t:Ae(t,n,3);for(var a=-1,s=P[typeof i]&&Ke(i),u=s?s.length:0;++a<u;)if(!1===t(i[r=s[a]],r,e))return o;return o};function tt(e,t,n){var r=Ke(e),i=r.length;for(t=Ae(t,n,3);i--;){var o=r[i];if(!1===t(e[o],o,e))break}return e}function nt(e){var t=[];return Qe(e,(function(e,n){it(e)&&t.push(n)})),t.sort()}function rt(e){for(var t=-1,n=Ke(e),r=n.length,i={};++t<r;){var o=n[t];i[e[o]]=o}return i}function it(e){return"function"==typeof e}function ot(e){return!(!e||!P[typeof e])}function at(e){return"number"==typeof e||e&&"object"==typeof e&&"[object Number]"==Q.call(e)||!1}var st=oe?function(e){if(!e||Q.call(e)!=k)return!1;var t=e.valueOf,n=qe(t)&&(n=oe(t))&&oe(n);return n?e==n||oe(e)==n:He(e)}:He;function ut(e){return"string"==typeof e||e&&"object"==typeof e&&Q.call(e)==S||!1}function ct(e){for(var t=-1,r=Ke(e),i=r.length,o=n(i);++t<i;)o[t]=e[r[t]];return o}function lt(e,t,n){var r=-1,i=$e(),o=e?e.length:0,a=!1;return n=(n<0?ye(0,o+n):n)||0,ze(e)?a=i(e,t,n)>-1:"number"==typeof o?a=(ut(e)?e.indexOf(t,n):i(e,t,n))>-1:et(e,(function(e){if(++r>=n)return!(a=e===t)})),a}var ft=Me((function(e,t,n){ae.call(e,n)?e[n]++:e[n]=1}));function ht(e,t,n){var r=!0;t=xe.createCallback(t,n,3);var i=-1,o=e?e.length:0;if("number"==typeof o)for(;++i<o&&(r=!!t(e[i],i,e)););else et(e,(function(e,n,i){return r=!!t(e,n,i)}));return r}function pt(e,t,n){var r=[];t=xe.createCallback(t,n,3);var i=-1,o=e?e.length:0;if("number"==typeof o)for(;++i<o;){var a=e[i];t(a,i,e)&&r.push(a)}else et(e,(function(e,n,i){t(e,n,i)&&r.push(e)}));return r}function dt(e,t,n){t=xe.createCallback(t,n,3);var r,i=-1,o=e?e.length:0;if("number"!=typeof o)return et(e,(function(e,n,i){if(t(e,n,i))return r=e,!1})),r;for(;++i<o;){var a=e[i];if(t(a,i,e))return a}}function vt(e,t,n){var r=-1,i=e?e.length:0;if(t=t&&void 0===n?t:Ae(t,n,3),"number"==typeof i)for(;++r<i&&!1!==t(e[r],r,e););else et(e,t);return e}function gt(e,t,n){var r=e?e.length:0;if(t=t&&void 0===n?t:Ae(t,n,3),"number"==typeof r)for(;r--&&!1!==t(e[r],r,e););else{var i=Ke(e);r=i.length,et(e,(function(e,n,o){return n=i?i[--r]:--r,t(o[n],n,o)}))}return e}var yt=Me((function(e,t,n){(ae.call(e,n)?e[n]:e[n]=[]).push(t)})),mt=Me((function(e,t,n){e[n]=t}));function bt(e,t,r){var i=-1,o=e?e.length:0;if(t=xe.createCallback(t,r,3),"number"==typeof o)for(var a=n(o);++i<o;)a[i]=t(e[i],i,e);else a=[],et(e,(function(e,n,r){a[++i]=t(e,n,r)}));return a}function _t(e,t,n){var r=-1/0,i=r;if("function"!=typeof t&&n&&n[t]===e&&(t=null),null==t&&ze(e))for(var o=-1,a=e.length;++o<a;){var s=e[o];s>i&&(i=s)}else t=null==t&&ut(e)?q:xe.createCallback(t,n,3),vt(e,(function(e,n,o){var a=t(e,n,o);a>r&&(r=a,i=e)}));return i}var wt=bt;function xt(e,t,n,r){if(!e)return n;var i=arguments.length<3;t=xe.createCallback(t,r,4);var o=-1,a=e.length;if("number"==typeof a)for(i&&(n=e[++o]);++o<a;)n=t(n,e[o],o,e);else et(e,(function(e,r,o){n=i?(i=!1,e):t(n,e,r,o)}));return n}function Tt(e,t,n,r){var i=arguments.length<3;return t=xe.createCallback(t,r,4),gt(e,(function(e,r,o){n=i?(i=!1,e):t(n,e,r,o)})),n}function Ct(e){var t=-1,r=e?e.length:0,i=n("number"==typeof r?r:0);return vt(e,(function(e){var n=Le(0,++t);i[t]=i[n],i[n]=e})),i}function Et(e,t,n){var r;t=xe.createCallback(t,n,3);var i=-1,o=e?e.length:0;if("number"==typeof o)for(;++i<o&&!(r=t(e[i],i,e)););else et(e,(function(e,n,i){return!(r=t(e,n,i))}));return!!r}var kt=pt;function St(e,t,n){var r=0,i=e?e.length:0;if("number"!=typeof t&&null!=t){var o=-1;for(t=xe.createCallback(t,n,3);++o<i&&t(e[o],o,e);)r++}else if(null==(r=t)||n)return e?e[0]:void 0;return X(e,0,me(ye(0,r),i))}function At(e,t,n){if("number"==typeof n){var r=e?e.length:0;n=n<0?ye(0,r+n):n||0}else if(n){var i=Dt(e,t);return e[i]===t?i:-1}return R(e,t,n)}function Ot(e,t,n){if("number"!=typeof t&&null!=t){var r=0,i=-1,o=e?e.length:0;for(t=xe.createCallback(t,n,3);++i<o&&t(e[i],i,e);)r++}else r=null==t||n?1:ye(0,t);return X(e,r)}function Dt(e,t,n,r){var i=0,o=e?e.length:i;for(t=(n=n?xe.createCallback(n,r,1):Mt)(t);i<o;){var a=i+o>>>1;n(e[a])<t?i=a+1:o=a}return i}function Pt(e,t,n,r){return"boolean"!=typeof t&&null!=t&&(r=n,n="function"!=typeof t&&r&&r[t]===e?null:t,t=!1),null!=n&&(n=xe.createCallback(n,r,3)),Ie(e,t,n)}function Nt(){for(var e=arguments.length>1?arguments:arguments[0],t=-1,r=e?_t(wt(e,"length")):0,i=n(r<0?0:r);++t<r;)i[t]=wt(e,t);return i}function jt(e,t){var n=-1,r=e?e.length:0,i={};for(t||!r||ze(e[0])||(t=[]);++n<r;){var o=e[n];t?i[o]=t[n]:o&&(i[o[0]]=o[1])}return i}function Lt(e,t){return arguments.length>2?Re(e,17,X(arguments,2),null,t):Re(e,1,null,null,t)}function It(e,t,n){var r,i,o,a,s,u,c,l=0,f=!1,h=!0;if(!it(e))throw new $;if(t=ye(0,t)||0,!0===n){var p=!0;h=!1}else ot(n)&&(p=n.leading,f="maxWait"in n&&(ye(t,n.maxWait)||0),h="trailing"in n?n.trailing:h);var d=function(){var n=t-(qt()-a);if(n<=0){i&&ne(i);var f=c;i=u=c=void 0,f&&(l=qt(),o=e.apply(s,r),u||i||(r=s=null))}else u=ue(d,n)},v=function(){u&&ne(u),i=u=c=void 0,(h||f!==t)&&(l=qt(),o=e.apply(s,r),u||i||(r=s=null))};return function(){if(r=arguments,a=qt(),s=this,c=h&&(u||!p),!1===f)var n=p&&!u;else{i||p||(l=a);var g=f-(a-l),y=g<=0;y?(i&&(i=ne(i)),l=a,o=e.apply(s,r)):i||(i=ue(v,g))}return y&&u?u=ne(u):u||t===f||(u=ue(d,t)),n&&(y=!0,o=e.apply(s,r)),!y||u||i||(r=s=null),o}}function Mt(e){return e}function Rt(e,t,n){var r=!0,i=t&&nt(t);t&&(n||i.length)||(null==n&&(n=t),o=Te,t=e,e=xe,i=nt(t)),!1===n?r=!1:ot(n)&&"chain"in n&&(r=n.chain);var o=e,a=it(o);vt(i,(function(n){var i=e[n]=t[n];a&&(o.prototype[n]=function(){var t=this.__chain__,n=this.__wrapped__,a=[n];se.apply(a,arguments);var s=i.apply(e,a);if(r||t){if(n===s&&ot(s))return this;(s=new o(s)).__chain__=t}return s})}))}function Bt(){}var $t,qt=qe(qt=i.now)&&qt||function(){return(new i).getTime()},Ft=8==be(" \t\v\f \ufeff\n\r\u2028\u2029 ᠎             　08")?be:function(e,t){return be(ut(e)?e.replace(g,""):e,t||0)};function Ht(e){return function(t){return t[e]}}function Ut(){return this.__wrapped__}return xe.after=function(e,t){if(!it(t))throw new $;return function(){if(--e<1)return t.apply(this,arguments)}},xe.assign=Je,xe.at=function(e){for(var t=arguments,r=-1,i=Pe(t,!0,!1,1),o=t[2]&&t[2][t[1]]===e?1:i.length,a=n(o);++r<o;)a[r]=e[i[r]];return a},xe.bind=Lt,xe.bindAll=function(e){for(var t=arguments.length>1?Pe(arguments,!0,!1,1):nt(e),n=-1,r=t.length;++n<r;){var i=t[n];e[i]=Re(e[i],1,null,null,e)}return e},xe.bindKey=function(e,t){return arguments.length>2?Re(t,19,X(arguments,2),null,e):Re(t,3,null,null,e)},xe.chain=function(e){return(e=new Te(e)).__chain__=!0,e},xe.compact=function(e){for(var t=-1,n=e?e.length:0,r=[];++t<n;){var i=e[t];i&&r.push(i)}return r},xe.compose=function(){for(var e=arguments,t=e.length;t--;)if(!it(e[t]))throw new $;return function(){for(var t=arguments,n=e.length;n--;)t=[e[n].apply(this,t)];return t[0]}},xe.constant=function(e){return function(){return e}},xe.countBy=ft,xe.create=function(e,t){var n=Se(e);return t?Je(n,t):n},xe.createCallback=function(e,t,n){var r=typeof e;if(null==e||"function"==r)return Ae(e,t,n);if("object"!=r)return Ht(e);var i=Ke(e),o=i[0],a=e[o];return 1!=i.length||a!=a||ot(a)?function(t){for(var n=i.length,r=!1;n--&&(r=Ne(t[i[n]],e[i[n]],null,!0)););return r}:function(e){var t=e[o];return a===t&&(0!==a||1/a==1/t)}},xe.curry=function(e,t){return Re(e,4,null,null,null,t="number"==typeof t?t:+t||e.length)},xe.debounce=It,xe.defaults=Ze,xe.defer=function(e){if(!it(e))throw new $;var t=X(arguments,1);return ue((function(){e.apply(void 0,t)}),1)},xe.delay=function(e,t){if(!it(e))throw new $;var n=X(arguments,2);return ue((function(){e.apply(void 0,n)}),t)},xe.difference=function(e){return De(e,Pe(arguments,!0,!0,1))},xe.filter=pt,xe.flatten=function(e,t,n,r){return"boolean"!=typeof t&&null!=t&&(r=n,n="function"!=typeof t&&r&&r[t]===e?null:t,t=!1),null!=n&&(e=bt(e,n,r)),Pe(e,t)},xe.forEach=vt,xe.forEachRight=gt,xe.forIn=Qe,xe.forInRight=function(e,t,n){var r=[];Qe(e,(function(e,t){r.push(t,e)}));var i=r.length;for(t=Ae(t,n,3);i--&&!1!==t(r[i--],r[i],e););return e},xe.forOwn=et,xe.forOwnRight=tt,xe.functions=nt,xe.groupBy=yt,xe.indexBy=mt,xe.initial=function(e,t,n){var r=0,i=e?e.length:0;if("number"!=typeof t&&null!=t){var o=i;for(t=xe.createCallback(t,n,3);o--&&t(e[o],o,e);)r++}else r=null==t||n?1:t||r;return X(e,0,me(ye(0,i-r),i))},xe.intersection=function(){for(var e=[],t=-1,n=arguments.length,r=W(),i=$e(),o=i===R,a=W();++t<n;){var s=arguments[t];(ze(s)||We(s))&&(e.push(s),r.push(o&&s.length>=75&&H(t?e[t]:a)))}var u=e[0],c=-1,l=u?u.length:0,f=[];e:for(;++c<l;){var h=r[0];if(s=u[c],(h?B(h,s):i(a,s))<0){for(t=n,(h||a).push(s);--t;)if(((h=r[t])?B(h,s):i(e[t],s))<0)continue e;f.push(s)}}for(;n--;)(h=r[n])&&V(h);return K(r),K(a),f},xe.invert=rt,xe.invoke=function(e,t){var r=X(arguments,2),i=-1,o="function"==typeof t,a=e?e.length:0,s=n("number"==typeof a?a:0);return vt(e,(function(e){s[++i]=(o?t:e[t]).apply(e,r)})),s},xe.keys=Ke,xe.map=bt,xe.mapValues=function(e,t,n){var r={};return t=xe.createCallback(t,n,3),et(e,(function(e,n,i){r[n]=t(e,n,i)})),r},xe.max=_t,xe.memoize=function(e,t){if(!it(e))throw new $;var n=function(){var r=n.cache,i=t?t.apply(this,arguments):u+arguments[0];return ae.call(r,i)?r[i]:r[i]=e.apply(this,arguments)};return n.cache={},n},xe.merge=function(e){var t=arguments,n=2;if(!ot(e))return e;if("number"!=typeof t[2]&&(n=t.length),n>3&&"function"==typeof t[n-2])var r=Ae(t[--n-1],t[n--],2);else n>2&&"function"==typeof t[n-1]&&(r=t[--n]);for(var i=X(arguments,1,n),o=-1,a=W(),s=W();++o<n;)je(e,i[o],r,a,s);return K(a),K(s),e},xe.min=function(e,t,n){var r=1/0,i=r;if("function"!=typeof t&&n&&n[t]===e&&(t=null),null==t&&ze(e))for(var o=-1,a=e.length;++o<a;){var s=e[o];s<i&&(i=s)}else t=null==t&&ut(e)?q:xe.createCallback(t,n,3),vt(e,(function(e,n,o){var a=t(e,n,o);a<r&&(r=a,i=e)}));return i},xe.omit=function(e,t,n){var r={};if("function"!=typeof t){var i=[];Qe(e,(function(e,t){i.push(t)}));for(var o=-1,a=(i=De(i,Pe(arguments,!0,!1,1))).length;++o<a;){var s=i[o];r[s]=e[s]}}else t=xe.createCallback(t,n,3),Qe(e,(function(e,n,i){t(e,n,i)||(r[n]=e)}));return r},xe.once=function(e){var t,n;if(!it(e))throw new $;return function(){return t||(t=!0,n=e.apply(this,arguments),e=null),n}},xe.pairs=function(e){for(var t=-1,r=Ke(e),i=r.length,o=n(i);++t<i;){var a=r[t];o[t]=[a,e[a]]}return o},xe.partial=function(e){return Re(e,16,X(arguments,1))},xe.partialRight=function(e){return Re(e,32,null,X(arguments,1))},xe.pick=function(e,t,n){var r={};if("function"!=typeof t)for(var i=-1,o=Pe(arguments,!0,!1,1),a=ot(e)?o.length:0;++i<a;){var s=o[i];s in e&&(r[s]=e[s])}else t=xe.createCallback(t,n,3),Qe(e,(function(e,n,i){t(e,n,i)&&(r[n]=e)}));return r},xe.pluck=wt,xe.property=Ht,xe.pull=function(e){for(var t=arguments,n=0,r=t.length,i=e?e.length:0;++n<r;)for(var o=-1,a=t[n];++o<i;)e[o]===a&&(ce.call(e,o--,1),i--);return e},xe.range=function(e,t,r){e=+e||0,null==t&&(t=e,e=0);for(var i=-1,o=ye(0,te((t-e)/((r="number"==typeof r?r:+r||1)||1))),a=n(o);++i<o;)a[i]=e,e+=r;return a},xe.reject=function(e,t,n){return t=xe.createCallback(t,n,3),pt(e,(function(e,n,r){return!t(e,n,r)}))},xe.remove=function(e,t,n){var r=-1,i=e?e.length:0,o=[];for(t=xe.createCallback(t,n,3);++r<i;){var a=e[r];t(a,r,e)&&(o.push(a),ce.call(e,r--,1),i--)}return o},xe.rest=Ot,xe.shuffle=Ct,xe.sortBy=function(e,t,r){var i=-1,o=ze(t),a=e?e.length:0,s=n("number"==typeof a?a:0);for(o||(t=xe.createCallback(t,r,3)),vt(e,(function(e,n,r){var a=s[++i]=z();o?a.criteria=bt(t,(function(t){return e[t]})):(a.criteria=W())[0]=t(e,n,r),a.index=i,a.value=e})),a=s.length,s.sort(F);a--;){var u=s[a];s[a]=u.value,o||K(u.criteria),V(u)}return s},xe.tap=function(e,t){return t(e),e},xe.throttle=function(e,t,n){var r=!0,i=!0;if(!it(e))throw new $;return!1===n?r=!1:ot(n)&&(r="leading"in n?n.leading:r,i="trailing"in n?n.trailing:i),O.leading=r,O.maxWait=t,O.trailing=i,It(e,t,O)},xe.times=function(e,t,r){e=(e=+e)>-1?e:0;var i=-1,o=n(e);for(t=Ae(t,r,1);++i<e;)o[i]=t(i);return o},xe.toArray=function(e){return e&&"number"==typeof e.length?X(e):ct(e)},xe.transform=function(e,t,n,r){var i=ze(e);if(null==n)if(i)n=[];else{var o=e&&e.constructor,a=o&&o.prototype;n=Se(a)}return t&&(t=xe.createCallback(t,r,4),(i?vt:et)(e,(function(e,r,i){return t(n,e,r,i)}))),n},xe.union=function(){return Ie(Pe(arguments,!0,!0))},xe.uniq=Pt,xe.values=ct,xe.where=kt,xe.without=function(e){return De(e,X(arguments,1))},xe.wrap=function(e,t){return Re(t,16,[e])},xe.xor=function(){for(var e=-1,t=arguments.length;++e<t;){var n=arguments[e];if(ze(n)||We(n))var r=r?Ie(De(r,n).concat(De(n,r))):n}return r||[]},xe.zip=Nt,xe.zipObject=jt,xe.collect=bt,xe.drop=Ot,xe.each=vt,xe.eachRight=gt,xe.extend=Je,xe.methods=nt,xe.object=jt,xe.select=pt,xe.tail=Ot,xe.unique=Pt,xe.unzip=Nt,Rt(xe),xe.clone=function(e,t,n,r){return"boolean"!=typeof t&&null!=t&&(r=n,n=t,t=!1),ke(e,t,"function"==typeof n&&Ae(n,r,1))},xe.cloneDeep=function(e,t,n){return ke(e,!0,"function"==typeof t&&Ae(t,n,1))},xe.contains=lt,xe.escape=function(e){return null==e?"":M(e).replace(Ge,Be)},xe.every=ht,xe.find=dt,xe.findIndex=function(e,t,n){var r=-1,i=e?e.length:0;for(t=xe.createCallback(t,n,3);++r<i;)if(t(e[r],r,e))return r;return-1},xe.findKey=function(e,t,n){var r;return t=xe.createCallback(t,n,3),et(e,(function(e,n,i){if(t(e,n,i))return r=n,!1})),r},xe.findLast=function(e,t,n){var r;return t=xe.createCallback(t,n,3),gt(e,(function(e,n,i){if(t(e,n,i))return r=e,!1})),r},xe.findLastIndex=function(e,t,n){var r=e?e.length:0;for(t=xe.createCallback(t,n,3);r--;)if(t(e[r],r,e))return r;return-1},xe.findLastKey=function(e,t,n){var r;return t=xe.createCallback(t,n,3),tt(e,(function(e,n,i){if(t(e,n,i))return r=n,!1})),r},xe.has=function(e,t){return!!e&&ae.call(e,t)},xe.identity=Mt,xe.indexOf=At,xe.isArguments=We,xe.isArray=ze,xe.isBoolean=function(e){return!0===e||!1===e||e&&"object"==typeof e&&Q.call(e)==C||!1},xe.isDate=function(e){return e&&"object"==typeof e&&Q.call(e)==E||!1},xe.isElement=function(e){return e&&1===e.nodeType||!1},xe.isEmpty=function(e){var t=!0;if(!e)return t;var n=Q.call(e),r=e.length;return n==T||n==S||n==x||n==k&&"number"==typeof r&&it(e.splice)?!r:(et(e,(function(){return t=!1})),t)},xe.isEqual=function(e,t,n,r){return Ne(e,t,"function"==typeof n&&Ae(n,r,2))},xe.isFinite=function(e){return de(e)&&!ve(parseFloat(e))},xe.isFunction=it,xe.isNaN=function(e){return at(e)&&e!=+e},xe.isNull=function(e){return null===e},xe.isNumber=at,xe.isObject=ot,xe.isPlainObject=st,xe.isRegExp=function(e){return e&&"object"==typeof e&&"[object RegExp]"==Q.call(e)||!1},xe.isString=ut,xe.isUndefined=function(e){return void 0===e},xe.lastIndexOf=function(e,t,n){var r=e?e.length:0;for("number"==typeof n&&(r=(n<0?ye(0,r+n):me(n,r-1))+1);r--;)if(e[r]===t)return r;return-1},xe.mixin=Rt,xe.noConflict=function(){return t._=Z,this},xe.noop=Bt,xe.now=qt,xe.parseInt=Ft,xe.random=function(e,t,n){var r=null==e,i=null==t;if(null==n&&("boolean"==typeof e&&i?(n=e,e=1):i||"boolean"!=typeof t||(n=t,i=!0)),r&&i&&(t=1),e=+e||0,i?(t=e,e=0):t=+t||0,n||e%1||t%1){var o=_e();return me(e+o*(t-e+parseFloat("1e-"+((o+"").length-1))),t)}return Le(e,t)},xe.reduce=xt,xe.reduceRight=Tt,xe.result=function(e,t){if(e){var n=e[t];return it(n)?e[t]():n}},xe.runInContext=e,xe.size=function(e){var t=e?e.length:0;return"number"==typeof t?t:Ke(e).length},xe.some=Et,xe.sortedIndex=Dt,xe.template=function(e,t,n){var r=xe.templateSettings;e=M(e||""),n=Ze({},n,r);var i,a=Ze({},n.imports,r.imports),s=Ke(a),u=ct(a),p=0,d=n.interpolate||y,g="__p += '",m=I((n.escape||y).source+"|"+d.source+"|"+(d===v?h:y).source+"|"+(n.evaluate||y).source+"|$","g");e.replace(m,(function(t,n,r,o,a,s){return r||(r=o),g+=e.slice(p,s).replace(b,U),n&&(g+="' +\n__e("+n+") +\n'"),a&&(i=!0,g+="';\n"+a+";\n__p += '"),r&&(g+="' +\n((__t = ("+r+")) == null ? '' : __t) +\n'"),p=s+t.length,t})),g+="';\n";var _=n.variable,x=_;x||(g="with ("+(_="obj")+") {\n"+g+"\n}\n"),g=(i?g.replace(c,""):g).replace(l,"$1").replace(f,"$1;"),g="function("+_+") {\n"+(x?"":_+" || ("+_+" = {});\n")+"var __t, __p = '', __e = _.escape"+(i?", __j = Array.prototype.join;\nfunction print() { __p += __j.call(arguments, '') }\n":";\n")+g+"return __p\n}";var T="\n/*\n//# sourceURL="+(n.sourceURL||"/lodash/template/source["+w+++"]")+"\n*/";try{var C=o(s,"return "+g+T).apply(void 0,u)}catch(e){throw e.source=g,e}return t?C(t):(C.source=g,C)},xe.unescape=function(e){return null==e?"":M(e).replace(Ye,Ue)},xe.uniqueId=function(e){var t=++s;return M(null==e?"":e)+t},xe.all=ht,xe.any=Et,xe.detect=dt,xe.findWhere=dt,xe.foldl=xt,xe.foldr=Tt,xe.include=lt,xe.inject=xt,Rt(($t={},et(xe,(function(e,t){xe.prototype[t]||($t[t]=e)})),$t),!1),xe.first=St,xe.last=function(e,t,n){var r=0,i=e?e.length:0;if("number"!=typeof t&&null!=t){var o=i;for(t=xe.createCallback(t,n,3);o--&&t(e[o],o,e);)r++}else if(null==(r=t)||n)return e?e[i-1]:void 0;return X(e,ye(0,i-r))},xe.sample=function(e,t,n){if(e&&"number"!=typeof e.length&&(e=ct(e)),null==t||n)return e?e[Le(0,e.length-1)]:void 0;var r=Ct(e);return r.length=me(ye(0,t),r.length),r},xe.take=St,xe.head=St,et(xe,(function(e,t){var n="sample"!==t;xe.prototype[t]||(xe.prototype[t]=function(t,r){var i=this.__chain__,o=e(this.__wrapped__,t,r);return i||null!=t&&(!r||n&&"function"==typeof t)?new Te(o,i):o})})),xe.VERSION="2.4.2",xe.prototype.chain=function(){return this.__chain__=!0,this},xe.prototype.toString=function(){return M(this.__wrapped__)},xe.prototype.value=Ut,xe.prototype.valueOf=Ut,vt(["join","pop","shift"],(function(e){var t=G[e];xe.prototype[e]=function(){var e=this.__chain__,n=t.apply(this.__wrapped__,arguments);return e?new Te(n,e):n}})),vt(["push","reverse","sort","unshift"],(function(e){var t=G[e];xe.prototype[e]=function(){return t.apply(this.__wrapped__,arguments),this}})),vt(["concat","slice","splice"],(function(e){var t=G[e];xe.prototype[e]=function(){return new Te(t.apply(this.__wrapped__,arguments),this.__chain__)}})),xe}();j._=Y,void 0===(i=function(){return Y}.call(t,n,t,e))||(e.exports=i)}).call(this)}).call(this,n(72)(e),n(8))},function(e,t,n){"use strict";var r=n(0),i=n.n(r),o=n(2);t.a={"存檔準備":function(){return 山彥.取檔((function(e){return v.存檔讀檔.檔表=e,v.存檔讀檔.啓動功能="存檔",i()("#總畫面").attr("存檔讀檔面板","on")}))},"讀檔準備":function(){return 山彥.取檔((function(e){return v.存檔讀檔.檔表=e,v.存檔讀檔.啓動功能="讀檔",i()("#總畫面").attr("存檔讀檔面板","on")}))},"存檔":function(e,t){return this.截圖轉換(160,90,(function(n){return 山彥.存檔(e,t,n),山彥.取檔((function(e){return v.存檔讀檔.檔表=e}))}))},"讀檔":function(e){return 山彥.讀檔(e),i()("#總畫面").attr("存檔讀檔面板","off")},"快速存檔":function(){return 山彥.快速存檔()},"快速讀檔":function(){return 山彥.快速讀檔()},"截圖轉換":function(e,t,n){var r,i;return r=o.a.當前狀態.背景[0].slice(5,-2),(i=new Image).src=r,i.setAttribute("crossOrigin","Anonymous"),i.onload=function(){var r,o;return(o=document.createElement("canvas")).width=e,o.height=t,o.getContext("2d").drawImage(i,0,0,160,90),r=o.toDataURL("image/webp"),n(r)}}}},function(e,t){(function(){e.exports={pad2:function(e){return e+1&-2},pad4:function(e){return(e+4&-4)-1},getUnicodeCharacter:function(e){var t,n;return e>=0&&e<=55295||e>=57344&&e<=65535?String.fromCharCode(e):e>=65536&&e<=1114111?(t=55296+((1047552&(e-=65536))>>10),n=56320+(1023&e),String.fromCharCode(t)+String.fromCharCode(n)):void 0},clamp:function(e,t,n){return Math.min(Math.max(e,t),n)}}}).call(this)},function(e,t,n){e.exports=n(42)},function(e,t){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"==typeof window&&(n=window)}e.exports=n},function(e,t,n){"use strict";(function(t){var r,i=n(11),o=i.Buffer,a={};for(r in i)i.hasOwnProperty(r)&&"SlowBuffer"!==r&&"Buffer"!==r&&(a[r]=i[r]);var s=a.Buffer={};for(r in o)o.hasOwnProperty(r)&&"allocUnsafe"!==r&&"allocUnsafeSlow"!==r&&(s[r]=o[r]);if(a.Buffer.prototype=o.prototype,s.from&&s.from!==Uint8Array.from||(s.from=function(e,t,n){if("number"==typeof e)throw new TypeError('The "value" argument must not be of type number. Received type '+typeof e);if(e&&void 0===e.length)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof e);return o(e,t,n)}),s.alloc||(s.alloc=function(e,t,n){if("number"!=typeof e)throw new TypeError('The "size" argument must be of type number. Received type '+typeof e);if(e<0||e>=2*(1<<30))throw new RangeError('The value "'+e+'" is invalid for option "size"');var r=o(e);return t&&0!==t.length?"string"==typeof n?r.fill(t,n):r.fill(t):r.fill(0),r}),!a.kStringMaxLength)try{a.kStringMaxLength=t.binding("buffer").kStringMaxLength}catch(e){}a.constants||(a.constants={MAX_LENGTH:a.kMaxLength},a.kStringMaxLength&&(a.constants.MAX_STRING_LENGTH=a.kStringMaxLength)),e.exports=a}).call(this,n(10))},function(e,t){var n,r,i=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function a(){throw new Error("clearTimeout has not been defined")}function s(e){if(n===setTimeout)return setTimeout(e,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(e,0);try{return n(e,0)}catch(t){try{return n.call(null,e,0)}catch(t){return n.call(this,e,0)}}}!function(){try{n="function"==typeof setTimeout?setTimeout:o}catch(e){n=o}try{r="function"==typeof clearTimeout?clearTimeout:a}catch(e){r=a}}();var u,c=[],l=!1,f=-1;function h(){l&&u&&(l=!1,u.length?c=u.concat(c):f=-1,c.length&&p())}function p(){if(!l){var e=s(h);l=!0;for(var t=c.length;t;){for(u=c,c=[];++f<t;)u&&u[f].run();f=-1,t=c.length}u=null,l=!1,function(e){if(r===clearTimeout)return clearTimeout(e);if((r===a||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(e);try{r(e)}catch(t){try{return r.call(null,e)}catch(t){return r.call(this,e)}}}(e)}}function d(e,t){this.fun=e,this.array=t}function v(){}i.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)t[n-1]=arguments[n];c.push(new d(e,t)),1!==c.length||l||s(p)},d.prototype.run=function(){this.fun.apply(null,this.array)},i.title="browser",i.browser=!0,i.env={},i.argv=[],i.version="",i.versions={},i.on=v,i.addListener=v,i.once=v,i.off=v,i.removeListener=v,i.removeAllListeners=v,i.emit=v,i.prependListener=v,i.prependOnceListener=v,i.listeners=function(e){return[]},i.binding=function(e){throw new Error("process.binding is not supported")},i.cwd=function(){return"/"},i.chdir=function(e){throw new Error("process.chdir is not supported")},i.umask=function(){return 0}},function(e,t,n){"use strict";(function(e){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <http://feross.org>
 * @license  MIT
 */
var r=n(44),i=n(45),o=n(46);function a(){return u.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function s(e,t){if(a()<t)throw new RangeError("Invalid typed array length");return u.TYPED_ARRAY_SUPPORT?(e=new Uint8Array(t)).__proto__=u.prototype:(null===e&&(e=new u(t)),e.length=t),e}function u(e,t,n){if(!(u.TYPED_ARRAY_SUPPORT||this instanceof u))return new u(e,t,n);if("number"==typeof e){if("string"==typeof t)throw new Error("If encoding is specified then the first argument must be a string");return f(this,e)}return c(this,e,t,n)}function c(e,t,n,r){if("number"==typeof t)throw new TypeError('"value" argument must not be a number');return"undefined"!=typeof ArrayBuffer&&t instanceof ArrayBuffer?function(e,t,n,r){if(t.byteLength,n<0||t.byteLength<n)throw new RangeError("'offset' is out of bounds");if(t.byteLength<n+(r||0))throw new RangeError("'length' is out of bounds");t=void 0===n&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,n):new Uint8Array(t,n,r);u.TYPED_ARRAY_SUPPORT?(e=t).__proto__=u.prototype:e=h(e,t);return e}(e,t,n,r):"string"==typeof t?function(e,t,n){"string"==typeof n&&""!==n||(n="utf8");if(!u.isEncoding(n))throw new TypeError('"encoding" must be a valid string encoding');var r=0|d(t,n),i=(e=s(e,r)).write(t,n);i!==r&&(e=e.slice(0,i));return e}(e,t,n):function(e,t){if(u.isBuffer(t)){var n=0|p(t.length);return 0===(e=s(e,n)).length||t.copy(e,0,0,n),e}if(t){if("undefined"!=typeof ArrayBuffer&&t.buffer instanceof ArrayBuffer||"length"in t)return"number"!=typeof t.length||(r=t.length)!=r?s(e,0):h(e,t);if("Buffer"===t.type&&o(t.data))return h(e,t.data)}var r;throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}(e,t)}function l(e){if("number"!=typeof e)throw new TypeError('"size" argument must be a number');if(e<0)throw new RangeError('"size" argument must not be negative')}function f(e,t){if(l(t),e=s(e,t<0?0:0|p(t)),!u.TYPED_ARRAY_SUPPORT)for(var n=0;n<t;++n)e[n]=0;return e}function h(e,t){var n=t.length<0?0:0|p(t.length);e=s(e,n);for(var r=0;r<n;r+=1)e[r]=255&t[r];return e}function p(e){if(e>=a())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+a().toString(16)+" bytes");return 0|e}function d(e,t){if(u.isBuffer(e))return e.length;if("undefined"!=typeof ArrayBuffer&&"function"==typeof ArrayBuffer.isView&&(ArrayBuffer.isView(e)||e instanceof ArrayBuffer))return e.byteLength;"string"!=typeof e&&(e=""+e);var n=e.length;if(0===n)return 0;for(var r=!1;;)switch(t){case"ascii":case"latin1":case"binary":return n;case"utf8":case"utf-8":case void 0:return q(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*n;case"hex":return n>>>1;case"base64":return F(e).length;default:if(r)return q(e).length;t=(""+t).toLowerCase(),r=!0}}function v(e,t,n){var r=!1;if((void 0===t||t<0)&&(t=0),t>this.length)return"";if((void 0===n||n>this.length)&&(n=this.length),n<=0)return"";if((n>>>=0)<=(t>>>=0))return"";for(e||(e="utf8");;)switch(e){case"hex":return O(this,t,n);case"utf8":case"utf-8":return k(this,t,n);case"ascii":return S(this,t,n);case"latin1":case"binary":return A(this,t,n);case"base64":return E(this,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return D(this,t,n);default:if(r)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),r=!0}}function g(e,t,n){var r=e[t];e[t]=e[n],e[n]=r}function y(e,t,n,r,i){if(0===e.length)return-1;if("string"==typeof n?(r=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),n=+n,isNaN(n)&&(n=i?0:e.length-1),n<0&&(n=e.length+n),n>=e.length){if(i)return-1;n=e.length-1}else if(n<0){if(!i)return-1;n=0}if("string"==typeof t&&(t=u.from(t,r)),u.isBuffer(t))return 0===t.length?-1:m(e,t,n,r,i);if("number"==typeof t)return t&=255,u.TYPED_ARRAY_SUPPORT&&"function"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(e,t,n):Uint8Array.prototype.lastIndexOf.call(e,t,n):m(e,[t],n,r,i);throw new TypeError("val must be string, number or Buffer")}function m(e,t,n,r,i){var o,a=1,s=e.length,u=t.length;if(void 0!==r&&("ucs2"===(r=String(r).toLowerCase())||"ucs-2"===r||"utf16le"===r||"utf-16le"===r)){if(e.length<2||t.length<2)return-1;a=2,s/=2,u/=2,n/=2}function c(e,t){return 1===a?e[t]:e.readUInt16BE(t*a)}if(i){var l=-1;for(o=n;o<s;o++)if(c(e,o)===c(t,-1===l?0:o-l)){if(-1===l&&(l=o),o-l+1===u)return l*a}else-1!==l&&(o-=o-l),l=-1}else for(n+u>s&&(n=s-u),o=n;o>=0;o--){for(var f=!0,h=0;h<u;h++)if(c(e,o+h)!==c(t,h)){f=!1;break}if(f)return o}return-1}function b(e,t,n,r){n=Number(n)||0;var i=e.length-n;r?(r=Number(r))>i&&(r=i):r=i;var o=t.length;if(o%2!=0)throw new TypeError("Invalid hex string");r>o/2&&(r=o/2);for(var a=0;a<r;++a){var s=parseInt(t.substr(2*a,2),16);if(isNaN(s))return a;e[n+a]=s}return a}function _(e,t,n,r){return H(q(t,e.length-n),e,n,r)}function w(e,t,n,r){return H(function(e){for(var t=[],n=0;n<e.length;++n)t.push(255&e.charCodeAt(n));return t}(t),e,n,r)}function x(e,t,n,r){return w(e,t,n,r)}function T(e,t,n,r){return H(F(t),e,n,r)}function C(e,t,n,r){return H(function(e,t){for(var n,r,i,o=[],a=0;a<e.length&&!((t-=2)<0);++a)n=e.charCodeAt(a),r=n>>8,i=n%256,o.push(i),o.push(r);return o}(t,e.length-n),e,n,r)}function E(e,t,n){return 0===t&&n===e.length?r.fromByteArray(e):r.fromByteArray(e.slice(t,n))}function k(e,t,n){n=Math.min(e.length,n);for(var r=[],i=t;i<n;){var o,a,s,u,c=e[i],l=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=n)switch(f){case 1:c<128&&(l=c);break;case 2:128==(192&(o=e[i+1]))&&(u=(31&c)<<6|63&o)>127&&(l=u);break;case 3:o=e[i+1],a=e[i+2],128==(192&o)&&128==(192&a)&&(u=(15&c)<<12|(63&o)<<6|63&a)>2047&&(u<55296||u>57343)&&(l=u);break;case 4:o=e[i+1],a=e[i+2],s=e[i+3],128==(192&o)&&128==(192&a)&&128==(192&s)&&(u=(15&c)<<18|(63&o)<<12|(63&a)<<6|63&s)>65535&&u<1114112&&(l=u)}null===l?(l=65533,f=1):l>65535&&(l-=65536,r.push(l>>>10&1023|55296),l=56320|1023&l),r.push(l),i+=f}return function(e){var t=e.length;if(t<=4096)return String.fromCharCode.apply(String,e);var n="",r=0;for(;r<t;)n+=String.fromCharCode.apply(String,e.slice(r,r+=4096));return n}(r)}t.Buffer=u,t.SlowBuffer=function(e){+e!=e&&(e=0);return u.alloc(+e)},t.INSPECT_MAX_BYTES=50,u.TYPED_ARRAY_SUPPORT=void 0!==e.TYPED_ARRAY_SUPPORT?e.TYPED_ARRAY_SUPPORT:function(){try{var e=new Uint8Array(1);return e.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===e.foo()&&"function"==typeof e.subarray&&0===e.subarray(1,1).byteLength}catch(e){return!1}}(),t.kMaxLength=a(),u.poolSize=8192,u._augment=function(e){return e.__proto__=u.prototype,e},u.from=function(e,t,n){return c(null,e,t,n)},u.TYPED_ARRAY_SUPPORT&&(u.prototype.__proto__=Uint8Array.prototype,u.__proto__=Uint8Array,"undefined"!=typeof Symbol&&Symbol.species&&u[Symbol.species]===u&&Object.defineProperty(u,Symbol.species,{value:null,configurable:!0})),u.alloc=function(e,t,n){return function(e,t,n,r){return l(t),t<=0?s(e,t):void 0!==n?"string"==typeof r?s(e,t).fill(n,r):s(e,t).fill(n):s(e,t)}(null,e,t,n)},u.allocUnsafe=function(e){return f(null,e)},u.allocUnsafeSlow=function(e){return f(null,e)},u.isBuffer=function(e){return!(null==e||!e._isBuffer)},u.compare=function(e,t){if(!u.isBuffer(e)||!u.isBuffer(t))throw new TypeError("Arguments must be Buffers");if(e===t)return 0;for(var n=e.length,r=t.length,i=0,o=Math.min(n,r);i<o;++i)if(e[i]!==t[i]){n=e[i],r=t[i];break}return n<r?-1:r<n?1:0},u.isEncoding=function(e){switch(String(e).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},u.concat=function(e,t){if(!o(e))throw new TypeError('"list" argument must be an Array of Buffers');if(0===e.length)return u.alloc(0);var n;if(void 0===t)for(t=0,n=0;n<e.length;++n)t+=e[n].length;var r=u.allocUnsafe(t),i=0;for(n=0;n<e.length;++n){var a=e[n];if(!u.isBuffer(a))throw new TypeError('"list" argument must be an Array of Buffers');a.copy(r,i),i+=a.length}return r},u.byteLength=d,u.prototype._isBuffer=!0,u.prototype.swap16=function(){var e=this.length;if(e%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var t=0;t<e;t+=2)g(this,t,t+1);return this},u.prototype.swap32=function(){var e=this.length;if(e%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var t=0;t<e;t+=4)g(this,t,t+3),g(this,t+1,t+2);return this},u.prototype.swap64=function(){var e=this.length;if(e%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var t=0;t<e;t+=8)g(this,t,t+7),g(this,t+1,t+6),g(this,t+2,t+5),g(this,t+3,t+4);return this},u.prototype.toString=function(){var e=0|this.length;return 0===e?"":0===arguments.length?k(this,0,e):v.apply(this,arguments)},u.prototype.equals=function(e){if(!u.isBuffer(e))throw new TypeError("Argument must be a Buffer");return this===e||0===u.compare(this,e)},u.prototype.inspect=function(){var e="",n=t.INSPECT_MAX_BYTES;return this.length>0&&(e=this.toString("hex",0,n).match(/.{2}/g).join(" "),this.length>n&&(e+=" ... ")),"<Buffer "+e+">"},u.prototype.compare=function(e,t,n,r,i){if(!u.isBuffer(e))throw new TypeError("Argument must be a Buffer");if(void 0===t&&(t=0),void 0===n&&(n=e?e.length:0),void 0===r&&(r=0),void 0===i&&(i=this.length),t<0||n>e.length||r<0||i>this.length)throw new RangeError("out of range index");if(r>=i&&t>=n)return 0;if(r>=i)return-1;if(t>=n)return 1;if(this===e)return 0;for(var o=(i>>>=0)-(r>>>=0),a=(n>>>=0)-(t>>>=0),s=Math.min(o,a),c=this.slice(r,i),l=e.slice(t,n),f=0;f<s;++f)if(c[f]!==l[f]){o=c[f],a=l[f];break}return o<a?-1:a<o?1:0},u.prototype.includes=function(e,t,n){return-1!==this.indexOf(e,t,n)},u.prototype.indexOf=function(e,t,n){return y(this,e,t,n,!0)},u.prototype.lastIndexOf=function(e,t,n){return y(this,e,t,n,!1)},u.prototype.write=function(e,t,n,r){if(void 0===t)r="utf8",n=this.length,t=0;else if(void 0===n&&"string"==typeof t)r=t,n=this.length,t=0;else{if(!isFinite(t))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");t|=0,isFinite(n)?(n|=0,void 0===r&&(r="utf8")):(r=n,n=void 0)}var i=this.length-t;if((void 0===n||n>i)&&(n=i),e.length>0&&(n<0||t<0)||t>this.length)throw new RangeError("Attempt to write outside buffer bounds");r||(r="utf8");for(var o=!1;;)switch(r){case"hex":return b(this,e,t,n);case"utf8":case"utf-8":return _(this,e,t,n);case"ascii":return w(this,e,t,n);case"latin1":case"binary":return x(this,e,t,n);case"base64":return T(this,e,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return C(this,e,t,n);default:if(o)throw new TypeError("Unknown encoding: "+r);r=(""+r).toLowerCase(),o=!0}},u.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};function S(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;i<n;++i)r+=String.fromCharCode(127&e[i]);return r}function A(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;i<n;++i)r+=String.fromCharCode(e[i]);return r}function O(e,t,n){var r=e.length;(!t||t<0)&&(t=0),(!n||n<0||n>r)&&(n=r);for(var i="",o=t;o<n;++o)i+=$(e[o]);return i}function D(e,t,n){for(var r=e.slice(t,n),i="",o=0;o<r.length;o+=2)i+=String.fromCharCode(r[o]+256*r[o+1]);return i}function P(e,t,n){if(e%1!=0||e<0)throw new RangeError("offset is not uint");if(e+t>n)throw new RangeError("Trying to access beyond buffer length")}function N(e,t,n,r,i,o){if(!u.isBuffer(e))throw new TypeError('"buffer" argument must be a Buffer instance');if(t>i||t<o)throw new RangeError('"value" argument is out of bounds');if(n+r>e.length)throw new RangeError("Index out of range")}function j(e,t,n,r){t<0&&(t=65535+t+1);for(var i=0,o=Math.min(e.length-n,2);i<o;++i)e[n+i]=(t&255<<8*(r?i:1-i))>>>8*(r?i:1-i)}function L(e,t,n,r){t<0&&(t=4294967295+t+1);for(var i=0,o=Math.min(e.length-n,4);i<o;++i)e[n+i]=t>>>8*(r?i:3-i)&255}function I(e,t,n,r,i,o){if(n+r>e.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("Index out of range")}function M(e,t,n,r,o){return o||I(e,0,n,4),i.write(e,t,n,r,23,4),n+4}function R(e,t,n,r,o){return o||I(e,0,n,8),i.write(e,t,n,r,52,8),n+8}u.prototype.slice=function(e,t){var n,r=this.length;if((e=~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),(t=void 0===t?r:~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),t<e&&(t=e),u.TYPED_ARRAY_SUPPORT)(n=this.subarray(e,t)).__proto__=u.prototype;else{var i=t-e;n=new u(i,void 0);for(var o=0;o<i;++o)n[o]=this[o+e]}return n},u.prototype.readUIntLE=function(e,t,n){e|=0,t|=0,n||P(e,t,this.length);for(var r=this[e],i=1,o=0;++o<t&&(i*=256);)r+=this[e+o]*i;return r},u.prototype.readUIntBE=function(e,t,n){e|=0,t|=0,n||P(e,t,this.length);for(var r=this[e+--t],i=1;t>0&&(i*=256);)r+=this[e+--t]*i;return r},u.prototype.readUInt8=function(e,t){return t||P(e,1,this.length),this[e]},u.prototype.readUInt16LE=function(e,t){return t||P(e,2,this.length),this[e]|this[e+1]<<8},u.prototype.readUInt16BE=function(e,t){return t||P(e,2,this.length),this[e]<<8|this[e+1]},u.prototype.readUInt32LE=function(e,t){return t||P(e,4,this.length),(this[e]|this[e+1]<<8|this[e+2]<<16)+16777216*this[e+3]},u.prototype.readUInt32BE=function(e,t){return t||P(e,4,this.length),16777216*this[e]+(this[e+1]<<16|this[e+2]<<8|this[e+3])},u.prototype.readIntLE=function(e,t,n){e|=0,t|=0,n||P(e,t,this.length);for(var r=this[e],i=1,o=0;++o<t&&(i*=256);)r+=this[e+o]*i;return r>=(i*=128)&&(r-=Math.pow(2,8*t)),r},u.prototype.readIntBE=function(e,t,n){e|=0,t|=0,n||P(e,t,this.length);for(var r=t,i=1,o=this[e+--r];r>0&&(i*=256);)o+=this[e+--r]*i;return o>=(i*=128)&&(o-=Math.pow(2,8*t)),o},u.prototype.readInt8=function(e,t){return t||P(e,1,this.length),128&this[e]?-1*(255-this[e]+1):this[e]},u.prototype.readInt16LE=function(e,t){t||P(e,2,this.length);var n=this[e]|this[e+1]<<8;return 32768&n?4294901760|n:n},u.prototype.readInt16BE=function(e,t){t||P(e,2,this.length);var n=this[e+1]|this[e]<<8;return 32768&n?4294901760|n:n},u.prototype.readInt32LE=function(e,t){return t||P(e,4,this.length),this[e]|this[e+1]<<8|this[e+2]<<16|this[e+3]<<24},u.prototype.readInt32BE=function(e,t){return t||P(e,4,this.length),this[e]<<24|this[e+1]<<16|this[e+2]<<8|this[e+3]},u.prototype.readFloatLE=function(e,t){return t||P(e,4,this.length),i.read(this,e,!0,23,4)},u.prototype.readFloatBE=function(e,t){return t||P(e,4,this.length),i.read(this,e,!1,23,4)},u.prototype.readDoubleLE=function(e,t){return t||P(e,8,this.length),i.read(this,e,!0,52,8)},u.prototype.readDoubleBE=function(e,t){return t||P(e,8,this.length),i.read(this,e,!1,52,8)},u.prototype.writeUIntLE=function(e,t,n,r){(e=+e,t|=0,n|=0,r)||N(this,e,t,n,Math.pow(2,8*n)-1,0);var i=1,o=0;for(this[t]=255&e;++o<n&&(i*=256);)this[t+o]=e/i&255;return t+n},u.prototype.writeUIntBE=function(e,t,n,r){(e=+e,t|=0,n|=0,r)||N(this,e,t,n,Math.pow(2,8*n)-1,0);var i=n-1,o=1;for(this[t+i]=255&e;--i>=0&&(o*=256);)this[t+i]=e/o&255;return t+n},u.prototype.writeUInt8=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,1,255,0),u.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),this[t]=255&e,t+1},u.prototype.writeUInt16LE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,2,65535,0),u.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):j(this,e,t,!0),t+2},u.prototype.writeUInt16BE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,2,65535,0),u.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):j(this,e,t,!1),t+2},u.prototype.writeUInt32LE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,4,4294967295,0),u.TYPED_ARRAY_SUPPORT?(this[t+3]=e>>>24,this[t+2]=e>>>16,this[t+1]=e>>>8,this[t]=255&e):L(this,e,t,!0),t+4},u.prototype.writeUInt32BE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,4,4294967295,0),u.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):L(this,e,t,!1),t+4},u.prototype.writeIntLE=function(e,t,n,r){if(e=+e,t|=0,!r){var i=Math.pow(2,8*n-1);N(this,e,t,n,i-1,-i)}var o=0,a=1,s=0;for(this[t]=255&e;++o<n&&(a*=256);)e<0&&0===s&&0!==this[t+o-1]&&(s=1),this[t+o]=(e/a>>0)-s&255;return t+n},u.prototype.writeIntBE=function(e,t,n,r){if(e=+e,t|=0,!r){var i=Math.pow(2,8*n-1);N(this,e,t,n,i-1,-i)}var o=n-1,a=1,s=0;for(this[t+o]=255&e;--o>=0&&(a*=256);)e<0&&0===s&&0!==this[t+o+1]&&(s=1),this[t+o]=(e/a>>0)-s&255;return t+n},u.prototype.writeInt8=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,1,127,-128),u.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),e<0&&(e=255+e+1),this[t]=255&e,t+1},u.prototype.writeInt16LE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,2,32767,-32768),u.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):j(this,e,t,!0),t+2},u.prototype.writeInt16BE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,2,32767,-32768),u.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):j(this,e,t,!1),t+2},u.prototype.writeInt32LE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,4,2147483647,-2147483648),u.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8,this[t+2]=e>>>16,this[t+3]=e>>>24):L(this,e,t,!0),t+4},u.prototype.writeInt32BE=function(e,t,n){return e=+e,t|=0,n||N(this,e,t,4,2147483647,-2147483648),e<0&&(e=4294967295+e+1),u.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):L(this,e,t,!1),t+4},u.prototype.writeFloatLE=function(e,t,n){return M(this,e,t,!0,n)},u.prototype.writeFloatBE=function(e,t,n){return M(this,e,t,!1,n)},u.prototype.writeDoubleLE=function(e,t,n){return R(this,e,t,!0,n)},u.prototype.writeDoubleBE=function(e,t,n){return R(this,e,t,!1,n)},u.prototype.copy=function(e,t,n,r){if(n||(n=0),r||0===r||(r=this.length),t>=e.length&&(t=e.length),t||(t=0),r>0&&r<n&&(r=n),r===n)return 0;if(0===e.length||0===this.length)return 0;if(t<0)throw new RangeError("targetStart out of bounds");if(n<0||n>=this.length)throw new RangeError("sourceStart out of bounds");if(r<0)throw new RangeError("sourceEnd out of bounds");r>this.length&&(r=this.length),e.length-t<r-n&&(r=e.length-t+n);var i,o=r-n;if(this===e&&n<t&&t<r)for(i=o-1;i>=0;--i)e[i+t]=this[i+n];else if(o<1e3||!u.TYPED_ARRAY_SUPPORT)for(i=0;i<o;++i)e[i+t]=this[i+n];else Uint8Array.prototype.set.call(e,this.subarray(n,n+o),t);return o},u.prototype.fill=function(e,t,n,r){if("string"==typeof e){if("string"==typeof t?(r=t,t=0,n=this.length):"string"==typeof n&&(r=n,n=this.length),1===e.length){var i=e.charCodeAt(0);i<256&&(e=i)}if(void 0!==r&&"string"!=typeof r)throw new TypeError("encoding must be a string");if("string"==typeof r&&!u.isEncoding(r))throw new TypeError("Unknown encoding: "+r)}else"number"==typeof e&&(e&=255);if(t<0||this.length<t||this.length<n)throw new RangeError("Out of range index");if(n<=t)return this;var o;if(t>>>=0,n=void 0===n?this.length:n>>>0,e||(e=0),"number"==typeof e)for(o=t;o<n;++o)this[o]=e;else{var a=u.isBuffer(e)?e:q(new u(e,r).toString()),s=a.length;for(o=0;o<n-t;++o)this[o+t]=a[o%s]}return this};var B=/[^+\/0-9A-Za-z-_]/g;function $(e){return e<16?"0"+e.toString(16):e.toString(16)}function q(e,t){var n;t=t||1/0;for(var r=e.length,i=null,o=[],a=0;a<r;++a){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){if(n>56319){(t-=3)>-1&&o.push(239,191,189);continue}if(a+1===r){(t-=3)>-1&&o.push(239,191,189);continue}i=n;continue}if(n<56320){(t-=3)>-1&&o.push(239,191,189),i=n;continue}n=65536+(i-55296<<10|n-56320)}else i&&(t-=3)>-1&&o.push(239,191,189);if(i=null,n<128){if((t-=1)<0)break;o.push(n)}else if(n<2048){if((t-=2)<0)break;o.push(n>>6|192,63&n|128)}else if(n<65536){if((t-=3)<0)break;o.push(n>>12|224,n>>6&63|128,63&n|128)}else{if(!(n<1114112))throw new Error("Invalid code point");if((t-=4)<0)break;o.push(n>>18|240,n>>12&63|128,n>>6&63|128,63&n|128)}}return o}function F(e){return r.toByteArray(function(e){if((e=function(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}(e).replace(B,"")).length<2)return"";for(;e.length%4!=0;)e+="=";return e}(e))}function H(e,t,n,r){for(var i=0;i<r&&!(i+n>=t.length||i>=e.length);++i)t[i+n]=e[i];return i}}).call(this,n(8))},function(e,t,n){"use strict";var r,i,o=n(2),a=n(5);r=n(36),n(38)(r),t.a=i={"右鍵功能":function(){return window.event.returnValue=!1,r("#總畫面").attr("歷史","off"),"off"===r("#總畫面").attr("對話框")?r("#總畫面").attr("對話框","on"):r("#總畫面").attr("對話框","off")},"左鍵屏蔽":!1,"左鍵功能":function(){if(!this.左鍵屏蔽&&!o.a.選擇之刻)return"on"===r("#總畫面").attr("歷史")&&r("#總畫面").attr("歷史","off"),"off"===r("#總畫面").attr("對話框")?r("#總畫面").attr("對話框","on"):Date.now()<o.a.淡入過期時間?(o.a.淡入過期時間=0,o.a.早泄()):o.a.步進更新()},"顯示履歷":function(){return r("#總畫面").attr("歷史","on"),r("#總畫面").attr("對話框","off"),r("#對話歷史").scrollTop(r("#對話歷史")[0].scrollHeight)},"正在快進":!1,"開始快進":function(){if(!1===this.正在快進)return this.正在快進=!0,this.快進輪迴()},"結束快進":function(){return this.正在快進=!1},"切換快進":function(){return!1===this.正在快進?(this.正在快進=!0,this.快進輪迴()):this.正在快進=!1},"快進輪迴":function(){if(i.正在快進)return i.左鍵功能(),setTimeout(i.快進輪迴,35)},"進入設置":function(){return r("#總畫面").attr("配置面板","on")},"退出設置":function(){return r("#總畫面").attr("配置面板","off")},"退出存檔讀檔":function(){return r("#總畫面").attr("存檔讀檔面板","off")},"控制初始化":function(){return window.document.onkeydown=function(e){var t;if(17===(t=e.keyCode)&&(console.log("ctrl按下"),i.開始快進()),32!==t&&13!==t&&90!==t||i.左鍵功能(),27===t&&i.右鍵功能(),33===t)return i.顯示履歷()},window.document.onkeyup=function(e){if(17===e.keyCode)return console.log("ctrl放開"),i.結束快進()},r("#主畫面").mousewheel((function(e,t){if(t>0&&i.顯示履歷(),t<0)return i.左鍵功能()})),r("#主畫面").mousedown((function(e){return 3===e.which?i.右鍵功能():1===e.which?i.左鍵功能():void 0})),r("#存檔準備").click((function(){return a.a.存檔準備()})),r("#讀檔準備").click((function(){return a.a.讀檔準備()})),r("#快速存檔").click((function(){return a.a.快速存檔()})),r("#快速讀檔").click((function(){return a.a.快速讀檔()})),r("#自動模式").click((function(){return alert("沒做這個功能")})),r("#切換快進").click((function(){return i.切換快進()})),r("#進入設置").click((function(){return i.進入設置()})),r("#回標題").click((function(){return 山彥.回標題()})),r("#退出設置").click((function(){return i.退出設置()})),r("#退出存檔讀檔").click((function(){return i.退出存檔讀檔()})),r("body").on("click",".檔 > .讀取",(function(e){var t;return t=r(this).parent().attr("名字"),a.a.讀檔(t)})),r("body").on("click",".檔 > .覆蓋",(function(e){var t,n;return t=r(this).parent().attr("名字"),n=o.a.當前狀態.話語,a.a.存檔(t,n)})),r("body").on("click","#新建存檔",(function(e){var t,n;return t="存檔"+(new Date).getTime(),n=o.a.當前狀態.話語,a.a.存檔(t,n)}))}}},function(e,t,n){"use strict";(function(e,n){
/*!
 * Vue.js v2.6.11
 * (c) 2014-2019 Evan You
 * Released under the MIT License.
 */
var r=Object.freeze({});function i(e){return null==e}function o(e){return null!=e}function a(e){return!0===e}function s(e){return"string"==typeof e||"number"==typeof e||"symbol"==typeof e||"boolean"==typeof e}function u(e){return null!==e&&"object"==typeof e}var c=Object.prototype.toString;function l(e){return"[object Object]"===c.call(e)}function f(e){return"[object RegExp]"===c.call(e)}function h(e){var t=parseFloat(String(e));return t>=0&&Math.floor(t)===t&&isFinite(e)}function p(e){return o(e)&&"function"==typeof e.then&&"function"==typeof e.catch}function d(e){return null==e?"":Array.isArray(e)||l(e)&&e.toString===c?JSON.stringify(e,null,2):String(e)}function v(e){var t=parseFloat(e);return isNaN(t)?e:t}function g(e,t){for(var n=Object.create(null),r=e.split(","),i=0;i<r.length;i++)n[r[i]]=!0;return t?function(e){return n[e.toLowerCase()]}:function(e){return n[e]}}var y=g("slot,component",!0),m=g("key,ref,slot,slot-scope,is");function b(e,t){if(e.length){var n=e.indexOf(t);if(n>-1)return e.splice(n,1)}}var _=Object.prototype.hasOwnProperty;function w(e,t){return _.call(e,t)}function x(e){var t=Object.create(null);return function(n){return t[n]||(t[n]=e(n))}}var T=/-(\w)/g,C=x((function(e){return e.replace(T,(function(e,t){return t?t.toUpperCase():""}))})),E=x((function(e){return e.charAt(0).toUpperCase()+e.slice(1)})),k=/\B([A-Z])/g,S=x((function(e){return e.replace(k,"-$1").toLowerCase()}));var A=Function.prototype.bind?function(e,t){return e.bind(t)}:function(e,t){function n(n){var r=arguments.length;return r?r>1?e.apply(t,arguments):e.call(t,n):e.call(t)}return n._length=e.length,n};function O(e,t){t=t||0;for(var n=e.length-t,r=new Array(n);n--;)r[n]=e[n+t];return r}function D(e,t){for(var n in t)e[n]=t[n];return e}function P(e){for(var t={},n=0;n<e.length;n++)e[n]&&D(t,e[n]);return t}function N(e,t,n){}var j=function(e,t,n){return!1},L=function(e){return e};function I(e,t){if(e===t)return!0;var n=u(e),r=u(t);if(!n||!r)return!n&&!r&&String(e)===String(t);try{var i=Array.isArray(e),o=Array.isArray(t);if(i&&o)return e.length===t.length&&e.every((function(e,n){return I(e,t[n])}));if(e instanceof Date&&t instanceof Date)return e.getTime()===t.getTime();if(i||o)return!1;var a=Object.keys(e),s=Object.keys(t);return a.length===s.length&&a.every((function(n){return I(e[n],t[n])}))}catch(e){return!1}}function M(e,t){for(var n=0;n<e.length;n++)if(I(e[n],t))return n;return-1}function R(e){var t=!1;return function(){t||(t=!0,e.apply(this,arguments))}}var B=["component","directive","filter"],$=["beforeCreate","created","beforeMount","mounted","beforeUpdate","updated","beforeDestroy","destroyed","activated","deactivated","errorCaptured","serverPrefetch"],q={optionMergeStrategies:Object.create(null),silent:!1,productionTip:!1,devtools:!1,performance:!1,errorHandler:null,warnHandler:null,ignoredElements:[],keyCodes:Object.create(null),isReservedTag:j,isReservedAttr:j,isUnknownElement:j,getTagNamespace:N,parsePlatformTagName:L,mustUseProp:j,async:!0,_lifecycleHooks:$},F=/a-zA-Z\u00B7\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u037D\u037F-\u1FFF\u200C-\u200D\u203F-\u2040\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD/;function H(e){var t=(e+"").charCodeAt(0);return 36===t||95===t}function U(e,t,n,r){Object.defineProperty(e,t,{value:n,enumerable:!!r,writable:!0,configurable:!0})}var W=new RegExp("[^"+F.source+".$_\\d]");var z,K="__proto__"in{},V="undefined"!=typeof window,X="undefined"!=typeof WXEnvironment&&!!WXEnvironment.platform,Y=X&&WXEnvironment.platform.toLowerCase(),G=V&&window.navigator.userAgent.toLowerCase(),J=G&&/msie|trident/.test(G),Z=G&&G.indexOf("msie 9.0")>0,Q=G&&G.indexOf("edge/")>0,ee=(G&&G.indexOf("android"),G&&/iphone|ipad|ipod|ios/.test(G)||"ios"===Y),te=(G&&/chrome\/\d+/.test(G),G&&/phantomjs/.test(G),G&&G.match(/firefox\/(\d+)/)),ne={}.watch,re=!1;if(V)try{var ie={};Object.defineProperty(ie,"passive",{get:function(){re=!0}}),window.addEventListener("test-passive",null,ie)}catch(e){}var oe=function(){return void 0===z&&(z=!V&&!X&&void 0!==e&&(e.process&&"server"===e.process.env.VUE_ENV)),z},ae=V&&window.__VUE_DEVTOOLS_GLOBAL_HOOK__;function se(e){return"function"==typeof e&&/native code/.test(e.toString())}var ue,ce="undefined"!=typeof Symbol&&se(Symbol)&&"undefined"!=typeof Reflect&&se(Reflect.ownKeys);ue="undefined"!=typeof Set&&se(Set)?Set:function(){function e(){this.set=Object.create(null)}return e.prototype.has=function(e){return!0===this.set[e]},e.prototype.add=function(e){this.set[e]=!0},e.prototype.clear=function(){this.set=Object.create(null)},e}();var le=N,fe=0,he=function(){this.id=fe++,this.subs=[]};he.prototype.addSub=function(e){this.subs.push(e)},he.prototype.removeSub=function(e){b(this.subs,e)},he.prototype.depend=function(){he.target&&he.target.addDep(this)},he.prototype.notify=function(){var e=this.subs.slice();for(var t=0,n=e.length;t<n;t++)e[t].update()},he.target=null;var pe=[];function de(e){pe.push(e),he.target=e}function ve(){pe.pop(),he.target=pe[pe.length-1]}var ge=function(e,t,n,r,i,o,a,s){this.tag=e,this.data=t,this.children=n,this.text=r,this.elm=i,this.ns=void 0,this.context=o,this.fnContext=void 0,this.fnOptions=void 0,this.fnScopeId=void 0,this.key=t&&t.key,this.componentOptions=a,this.componentInstance=void 0,this.parent=void 0,this.raw=!1,this.isStatic=!1,this.isRootInsert=!0,this.isComment=!1,this.isCloned=!1,this.isOnce=!1,this.asyncFactory=s,this.asyncMeta=void 0,this.isAsyncPlaceholder=!1},ye={child:{configurable:!0}};ye.child.get=function(){return this.componentInstance},Object.defineProperties(ge.prototype,ye);var me=function(e){void 0===e&&(e="");var t=new ge;return t.text=e,t.isComment=!0,t};function be(e){return new ge(void 0,void 0,void 0,String(e))}function _e(e){var t=new ge(e.tag,e.data,e.children&&e.children.slice(),e.text,e.elm,e.context,e.componentOptions,e.asyncFactory);return t.ns=e.ns,t.isStatic=e.isStatic,t.key=e.key,t.isComment=e.isComment,t.fnContext=e.fnContext,t.fnOptions=e.fnOptions,t.fnScopeId=e.fnScopeId,t.asyncMeta=e.asyncMeta,t.isCloned=!0,t}var we=Array.prototype,xe=Object.create(we);["push","pop","shift","unshift","splice","sort","reverse"].forEach((function(e){var t=we[e];U(xe,e,(function(){for(var n=[],r=arguments.length;r--;)n[r]=arguments[r];var i,o=t.apply(this,n),a=this.__ob__;switch(e){case"push":case"unshift":i=n;break;case"splice":i=n.slice(2)}return i&&a.observeArray(i),a.dep.notify(),o}))}));var Te=Object.getOwnPropertyNames(xe),Ce=!0;function Ee(e){Ce=e}var ke=function(e){this.value=e,this.dep=new he,this.vmCount=0,U(e,"__ob__",this),Array.isArray(e)?(K?function(e,t){e.__proto__=t}(e,xe):function(e,t,n){for(var r=0,i=n.length;r<i;r++){var o=n[r];U(e,o,t[o])}}(e,xe,Te),this.observeArray(e)):this.walk(e)};function Se(e,t){var n;if(u(e)&&!(e instanceof ge))return w(e,"__ob__")&&e.__ob__ instanceof ke?n=e.__ob__:Ce&&!oe()&&(Array.isArray(e)||l(e))&&Object.isExtensible(e)&&!e._isVue&&(n=new ke(e)),t&&n&&n.vmCount++,n}function Ae(e,t,n,r,i){var o=new he,a=Object.getOwnPropertyDescriptor(e,t);if(!a||!1!==a.configurable){var s=a&&a.get,u=a&&a.set;s&&!u||2!==arguments.length||(n=e[t]);var c=!i&&Se(n);Object.defineProperty(e,t,{enumerable:!0,configurable:!0,get:function(){var t=s?s.call(e):n;return he.target&&(o.depend(),c&&(c.dep.depend(),Array.isArray(t)&&Pe(t))),t},set:function(t){var r=s?s.call(e):n;t===r||t!=t&&r!=r||s&&!u||(u?u.call(e,t):n=t,c=!i&&Se(t),o.notify())}})}}function Oe(e,t,n){if(Array.isArray(e)&&h(t))return e.length=Math.max(e.length,t),e.splice(t,1,n),n;if(t in e&&!(t in Object.prototype))return e[t]=n,n;var r=e.__ob__;return e._isVue||r&&r.vmCount?n:r?(Ae(r.value,t,n),r.dep.notify(),n):(e[t]=n,n)}function De(e,t){if(Array.isArray(e)&&h(t))e.splice(t,1);else{var n=e.__ob__;e._isVue||n&&n.vmCount||w(e,t)&&(delete e[t],n&&n.dep.notify())}}function Pe(e){for(var t=void 0,n=0,r=e.length;n<r;n++)(t=e[n])&&t.__ob__&&t.__ob__.dep.depend(),Array.isArray(t)&&Pe(t)}ke.prototype.walk=function(e){for(var t=Object.keys(e),n=0;n<t.length;n++)Ae(e,t[n])},ke.prototype.observeArray=function(e){for(var t=0,n=e.length;t<n;t++)Se(e[t])};var Ne=q.optionMergeStrategies;function je(e,t){if(!t)return e;for(var n,r,i,o=ce?Reflect.ownKeys(t):Object.keys(t),a=0;a<o.length;a++)"__ob__"!==(n=o[a])&&(r=e[n],i=t[n],w(e,n)?r!==i&&l(r)&&l(i)&&je(r,i):Oe(e,n,i));return e}function Le(e,t,n){return n?function(){var r="function"==typeof t?t.call(n,n):t,i="function"==typeof e?e.call(n,n):e;return r?je(r,i):i}:t?e?function(){return je("function"==typeof t?t.call(this,this):t,"function"==typeof e?e.call(this,this):e)}:t:e}function Ie(e,t){var n=t?e?e.concat(t):Array.isArray(t)?t:[t]:e;return n?function(e){for(var t=[],n=0;n<e.length;n++)-1===t.indexOf(e[n])&&t.push(e[n]);return t}(n):n}function Me(e,t,n,r){var i=Object.create(e||null);return t?D(i,t):i}Ne.data=function(e,t,n){return n?Le(e,t,n):t&&"function"!=typeof t?e:Le(e,t)},$.forEach((function(e){Ne[e]=Ie})),B.forEach((function(e){Ne[e+"s"]=Me})),Ne.watch=function(e,t,n,r){if(e===ne&&(e=void 0),t===ne&&(t=void 0),!t)return Object.create(e||null);if(!e)return t;var i={};for(var o in D(i,e),t){var a=i[o],s=t[o];a&&!Array.isArray(a)&&(a=[a]),i[o]=a?a.concat(s):Array.isArray(s)?s:[s]}return i},Ne.props=Ne.methods=Ne.inject=Ne.computed=function(e,t,n,r){if(!e)return t;var i=Object.create(null);return D(i,e),t&&D(i,t),i},Ne.provide=Le;var Re=function(e,t){return void 0===t?e:t};function Be(e,t,n){if("function"==typeof t&&(t=t.options),function(e,t){var n=e.props;if(n){var r,i,o={};if(Array.isArray(n))for(r=n.length;r--;)"string"==typeof(i=n[r])&&(o[C(i)]={type:null});else if(l(n))for(var a in n)i=n[a],o[C(a)]=l(i)?i:{type:i};else 0;e.props=o}}(t),function(e,t){var n=e.inject;if(n){var r=e.inject={};if(Array.isArray(n))for(var i=0;i<n.length;i++)r[n[i]]={from:n[i]};else if(l(n))for(var o in n){var a=n[o];r[o]=l(a)?D({from:o},a):{from:a}}else 0}}(t),function(e){var t=e.directives;if(t)for(var n in t){var r=t[n];"function"==typeof r&&(t[n]={bind:r,update:r})}}(t),!t._base&&(t.extends&&(e=Be(e,t.extends,n)),t.mixins))for(var r=0,i=t.mixins.length;r<i;r++)e=Be(e,t.mixins[r],n);var o,a={};for(o in e)s(o);for(o in t)w(e,o)||s(o);function s(r){var i=Ne[r]||Re;a[r]=i(e[r],t[r],n,r)}return a}function $e(e,t,n,r){if("string"==typeof n){var i=e[t];if(w(i,n))return i[n];var o=C(n);if(w(i,o))return i[o];var a=E(o);return w(i,a)?i[a]:i[n]||i[o]||i[a]}}function qe(e,t,n,r){var i=t[e],o=!w(n,e),a=n[e],s=Ue(Boolean,i.type);if(s>-1)if(o&&!w(i,"default"))a=!1;else if(""===a||a===S(e)){var u=Ue(String,i.type);(u<0||s<u)&&(a=!0)}if(void 0===a){a=function(e,t,n){if(!w(t,"default"))return;var r=t.default;0;if(e&&e.$options.propsData&&void 0===e.$options.propsData[n]&&void 0!==e._props[n])return e._props[n];return"function"==typeof r&&"Function"!==Fe(t.type)?r.call(e):r}(r,i,e);var c=Ce;Ee(!0),Se(a),Ee(c)}return a}function Fe(e){var t=e&&e.toString().match(/^\s*function (\w+)/);return t?t[1]:""}function He(e,t){return Fe(e)===Fe(t)}function Ue(e,t){if(!Array.isArray(t))return He(t,e)?0:-1;for(var n=0,r=t.length;n<r;n++)if(He(t[n],e))return n;return-1}function We(e,t,n){de();try{if(t)for(var r=t;r=r.$parent;){var i=r.$options.errorCaptured;if(i)for(var o=0;o<i.length;o++)try{if(!1===i[o].call(r,e,t,n))return}catch(e){Ke(e,r,"errorCaptured hook")}}Ke(e,t,n)}finally{ve()}}function ze(e,t,n,r,i){var o;try{(o=n?e.apply(t,n):e.call(t))&&!o._isVue&&p(o)&&!o._handled&&(o.catch((function(e){return We(e,r,i+" (Promise/async)")})),o._handled=!0)}catch(e){We(e,r,i)}return o}function Ke(e,t,n){if(q.errorHandler)try{return q.errorHandler.call(null,e,t,n)}catch(t){t!==e&&Ve(t,null,"config.errorHandler")}Ve(e,t,n)}function Ve(e,t,n){if(!V&&!X||"undefined"==typeof console)throw e;console.error(e)}var Xe,Ye=!1,Ge=[],Je=!1;function Ze(){Je=!1;var e=Ge.slice(0);Ge.length=0;for(var t=0;t<e.length;t++)e[t]()}if("undefined"!=typeof Promise&&se(Promise)){var Qe=Promise.resolve();Xe=function(){Qe.then(Ze),ee&&setTimeout(N)},Ye=!0}else if(J||"undefined"==typeof MutationObserver||!se(MutationObserver)&&"[object MutationObserverConstructor]"!==MutationObserver.toString())Xe=void 0!==n&&se(n)?function(){n(Ze)}:function(){setTimeout(Ze,0)};else{var et=1,tt=new MutationObserver(Ze),nt=document.createTextNode(String(et));tt.observe(nt,{characterData:!0}),Xe=function(){et=(et+1)%2,nt.data=String(et)},Ye=!0}function rt(e,t){var n;if(Ge.push((function(){if(e)try{e.call(t)}catch(e){We(e,t,"nextTick")}else n&&n(t)})),Je||(Je=!0,Xe()),!e&&"undefined"!=typeof Promise)return new Promise((function(e){n=e}))}var it=new ue;function ot(e){!function e(t,n){var r,i,o=Array.isArray(t);if(!o&&!u(t)||Object.isFrozen(t)||t instanceof ge)return;if(t.__ob__){var a=t.__ob__.dep.id;if(n.has(a))return;n.add(a)}if(o)for(r=t.length;r--;)e(t[r],n);else for(i=Object.keys(t),r=i.length;r--;)e(t[i[r]],n)}(e,it),it.clear()}var at=x((function(e){var t="&"===e.charAt(0),n="~"===(e=t?e.slice(1):e).charAt(0),r="!"===(e=n?e.slice(1):e).charAt(0);return{name:e=r?e.slice(1):e,once:n,capture:r,passive:t}}));function st(e,t){function n(){var e=arguments,r=n.fns;if(!Array.isArray(r))return ze(r,null,arguments,t,"v-on handler");for(var i=r.slice(),o=0;o<i.length;o++)ze(i[o],null,e,t,"v-on handler")}return n.fns=e,n}function ut(e,t,n,r,o,s){var u,c,l,f;for(u in e)c=e[u],l=t[u],f=at(u),i(c)||(i(l)?(i(c.fns)&&(c=e[u]=st(c,s)),a(f.once)&&(c=e[u]=o(f.name,c,f.capture)),n(f.name,c,f.capture,f.passive,f.params)):c!==l&&(l.fns=c,e[u]=l));for(u in t)i(e[u])&&r((f=at(u)).name,t[u],f.capture)}function ct(e,t,n){var r;e instanceof ge&&(e=e.data.hook||(e.data.hook={}));var s=e[t];function u(){n.apply(this,arguments),b(r.fns,u)}i(s)?r=st([u]):o(s.fns)&&a(s.merged)?(r=s).fns.push(u):r=st([s,u]),r.merged=!0,e[t]=r}function lt(e,t,n,r,i){if(o(t)){if(w(t,n))return e[n]=t[n],i||delete t[n],!0;if(w(t,r))return e[n]=t[r],i||delete t[r],!0}return!1}function ft(e){return s(e)?[be(e)]:Array.isArray(e)?function e(t,n){var r,u,c,l,f=[];for(r=0;r<t.length;r++)i(u=t[r])||"boolean"==typeof u||(c=f.length-1,l=f[c],Array.isArray(u)?u.length>0&&(ht((u=e(u,(n||"")+"_"+r))[0])&&ht(l)&&(f[c]=be(l.text+u[0].text),u.shift()),f.push.apply(f,u)):s(u)?ht(l)?f[c]=be(l.text+u):""!==u&&f.push(be(u)):ht(u)&&ht(l)?f[c]=be(l.text+u.text):(a(t._isVList)&&o(u.tag)&&i(u.key)&&o(n)&&(u.key="__vlist"+n+"_"+r+"__"),f.push(u)));return f}(e):void 0}function ht(e){return o(e)&&o(e.text)&&function(e){return!1===e}(e.isComment)}function pt(e,t){if(e){for(var n=Object.create(null),r=ce?Reflect.ownKeys(e):Object.keys(e),i=0;i<r.length;i++){var o=r[i];if("__ob__"!==o){for(var a=e[o].from,s=t;s;){if(s._provided&&w(s._provided,a)){n[o]=s._provided[a];break}s=s.$parent}if(!s)if("default"in e[o]){var u=e[o].default;n[o]="function"==typeof u?u.call(t):u}else 0}}return n}}function dt(e,t){if(!e||!e.length)return{};for(var n={},r=0,i=e.length;r<i;r++){var o=e[r],a=o.data;if(a&&a.attrs&&a.attrs.slot&&delete a.attrs.slot,o.context!==t&&o.fnContext!==t||!a||null==a.slot)(n.default||(n.default=[])).push(o);else{var s=a.slot,u=n[s]||(n[s]=[]);"template"===o.tag?u.push.apply(u,o.children||[]):u.push(o)}}for(var c in n)n[c].every(vt)&&delete n[c];return n}function vt(e){return e.isComment&&!e.asyncFactory||" "===e.text}function gt(e,t,n){var i,o=Object.keys(t).length>0,a=e?!!e.$stable:!o,s=e&&e.$key;if(e){if(e._normalized)return e._normalized;if(a&&n&&n!==r&&s===n.$key&&!o&&!n.$hasNormal)return n;for(var u in i={},e)e[u]&&"$"!==u[0]&&(i[u]=yt(t,u,e[u]))}else i={};for(var c in t)c in i||(i[c]=mt(t,c));return e&&Object.isExtensible(e)&&(e._normalized=i),U(i,"$stable",a),U(i,"$key",s),U(i,"$hasNormal",o),i}function yt(e,t,n){var r=function(){var e=arguments.length?n.apply(null,arguments):n({});return(e=e&&"object"==typeof e&&!Array.isArray(e)?[e]:ft(e))&&(0===e.length||1===e.length&&e[0].isComment)?void 0:e};return n.proxy&&Object.defineProperty(e,t,{get:r,enumerable:!0,configurable:!0}),r}function mt(e,t){return function(){return e[t]}}function bt(e,t){var n,r,i,a,s;if(Array.isArray(e)||"string"==typeof e)for(n=new Array(e.length),r=0,i=e.length;r<i;r++)n[r]=t(e[r],r);else if("number"==typeof e)for(n=new Array(e),r=0;r<e;r++)n[r]=t(r+1,r);else if(u(e))if(ce&&e[Symbol.iterator]){n=[];for(var c=e[Symbol.iterator](),l=c.next();!l.done;)n.push(t(l.value,n.length)),l=c.next()}else for(a=Object.keys(e),n=new Array(a.length),r=0,i=a.length;r<i;r++)s=a[r],n[r]=t(e[s],s,r);return o(n)||(n=[]),n._isVList=!0,n}function _t(e,t,n,r){var i,o=this.$scopedSlots[e];o?(n=n||{},r&&(n=D(D({},r),n)),i=o(n)||t):i=this.$slots[e]||t;var a=n&&n.slot;return a?this.$createElement("template",{slot:a},i):i}function wt(e){return $e(this.$options,"filters",e)||L}function xt(e,t){return Array.isArray(e)?-1===e.indexOf(t):e!==t}function Tt(e,t,n,r,i){var o=q.keyCodes[t]||n;return i&&r&&!q.keyCodes[t]?xt(i,r):o?xt(o,e):r?S(r)!==t:void 0}function Ct(e,t,n,r,i){if(n)if(u(n)){var o;Array.isArray(n)&&(n=P(n));var a=function(a){if("class"===a||"style"===a||m(a))o=e;else{var s=e.attrs&&e.attrs.type;o=r||q.mustUseProp(t,s,a)?e.domProps||(e.domProps={}):e.attrs||(e.attrs={})}var u=C(a),c=S(a);u in o||c in o||(o[a]=n[a],i&&((e.on||(e.on={}))["update:"+a]=function(e){n[a]=e}))};for(var s in n)a(s)}else;return e}function Et(e,t){var n=this._staticTrees||(this._staticTrees=[]),r=n[e];return r&&!t||St(r=n[e]=this.$options.staticRenderFns[e].call(this._renderProxy,null,this),"__static__"+e,!1),r}function kt(e,t,n){return St(e,"__once__"+t+(n?"_"+n:""),!0),e}function St(e,t,n){if(Array.isArray(e))for(var r=0;r<e.length;r++)e[r]&&"string"!=typeof e[r]&&At(e[r],t+"_"+r,n);else At(e,t,n)}function At(e,t,n){e.isStatic=!0,e.key=t,e.isOnce=n}function Ot(e,t){if(t)if(l(t)){var n=e.on=e.on?D({},e.on):{};for(var r in t){var i=n[r],o=t[r];n[r]=i?[].concat(i,o):o}}else;return e}function Dt(e,t,n,r){t=t||{$stable:!n};for(var i=0;i<e.length;i++){var o=e[i];Array.isArray(o)?Dt(o,t,n):o&&(o.proxy&&(o.fn.proxy=!0),t[o.key]=o.fn)}return r&&(t.$key=r),t}function Pt(e,t){for(var n=0;n<t.length;n+=2){var r=t[n];"string"==typeof r&&r&&(e[t[n]]=t[n+1])}return e}function Nt(e,t){return"string"==typeof e?t+e:e}function jt(e){e._o=kt,e._n=v,e._s=d,e._l=bt,e._t=_t,e._q=I,e._i=M,e._m=Et,e._f=wt,e._k=Tt,e._b=Ct,e._v=be,e._e=me,e._u=Dt,e._g=Ot,e._d=Pt,e._p=Nt}function Lt(e,t,n,i,o){var s,u=this,c=o.options;w(i,"_uid")?(s=Object.create(i))._original=i:(s=i,i=i._original);var l=a(c._compiled),f=!l;this.data=e,this.props=t,this.children=n,this.parent=i,this.listeners=e.on||r,this.injections=pt(c.inject,i),this.slots=function(){return u.$slots||gt(e.scopedSlots,u.$slots=dt(n,i)),u.$slots},Object.defineProperty(this,"scopedSlots",{enumerable:!0,get:function(){return gt(e.scopedSlots,this.slots())}}),l&&(this.$options=c,this.$slots=this.slots(),this.$scopedSlots=gt(e.scopedSlots,this.$slots)),c._scopeId?this._c=function(e,t,n,r){var o=Ft(s,e,t,n,r,f);return o&&!Array.isArray(o)&&(o.fnScopeId=c._scopeId,o.fnContext=i),o}:this._c=function(e,t,n,r){return Ft(s,e,t,n,r,f)}}function It(e,t,n,r,i){var o=_e(e);return o.fnContext=n,o.fnOptions=r,t.slot&&((o.data||(o.data={})).slot=t.slot),o}function Mt(e,t){for(var n in t)e[C(n)]=t[n]}jt(Lt.prototype);var Rt={init:function(e,t){if(e.componentInstance&&!e.componentInstance._isDestroyed&&e.data.keepAlive){var n=e;Rt.prepatch(n,n)}else{(e.componentInstance=function(e,t){var n={_isComponent:!0,_parentVnode:e,parent:t},r=e.data.inlineTemplate;o(r)&&(n.render=r.render,n.staticRenderFns=r.staticRenderFns);return new e.componentOptions.Ctor(n)}(e,Jt)).$mount(t?e.elm:void 0,t)}},prepatch:function(e,t){var n=t.componentOptions;!function(e,t,n,i,o){0;var a=i.data.scopedSlots,s=e.$scopedSlots,u=!!(a&&!a.$stable||s!==r&&!s.$stable||a&&e.$scopedSlots.$key!==a.$key),c=!!(o||e.$options._renderChildren||u);e.$options._parentVnode=i,e.$vnode=i,e._vnode&&(e._vnode.parent=i);if(e.$options._renderChildren=o,e.$attrs=i.data.attrs||r,e.$listeners=n||r,t&&e.$options.props){Ee(!1);for(var l=e._props,f=e.$options._propKeys||[],h=0;h<f.length;h++){var p=f[h],d=e.$options.props;l[p]=qe(p,d,t,e)}Ee(!0),e.$options.propsData=t}n=n||r;var v=e.$options._parentListeners;e.$options._parentListeners=n,Gt(e,n,v),c&&(e.$slots=dt(o,i.context),e.$forceUpdate());0}(t.componentInstance=e.componentInstance,n.propsData,n.listeners,t,n.children)},insert:function(e){var t,n=e.context,r=e.componentInstance;r._isMounted||(r._isMounted=!0,tn(r,"mounted")),e.data.keepAlive&&(n._isMounted?((t=r)._inactive=!1,rn.push(t)):en(r,!0))},destroy:function(e){var t=e.componentInstance;t._isDestroyed||(e.data.keepAlive?function e(t,n){if(n&&(t._directInactive=!0,Qt(t)))return;if(!t._inactive){t._inactive=!0;for(var r=0;r<t.$children.length;r++)e(t.$children[r]);tn(t,"deactivated")}}(t,!0):t.$destroy())}},Bt=Object.keys(Rt);function $t(e,t,n,s,c){if(!i(e)){var l=n.$options._base;if(u(e)&&(e=l.extend(e)),"function"==typeof e){var f;if(i(e.cid)&&void 0===(e=function(e,t){if(a(e.error)&&o(e.errorComp))return e.errorComp;if(o(e.resolved))return e.resolved;var n=Ut;n&&o(e.owners)&&-1===e.owners.indexOf(n)&&e.owners.push(n);if(a(e.loading)&&o(e.loadingComp))return e.loadingComp;if(n&&!o(e.owners)){var r=e.owners=[n],s=!0,c=null,l=null;n.$on("hook:destroyed",(function(){return b(r,n)}));var f=function(e){for(var t=0,n=r.length;t<n;t++)r[t].$forceUpdate();e&&(r.length=0,null!==c&&(clearTimeout(c),c=null),null!==l&&(clearTimeout(l),l=null))},h=R((function(n){e.resolved=Wt(n,t),s?r.length=0:f(!0)})),d=R((function(t){o(e.errorComp)&&(e.error=!0,f(!0))})),v=e(h,d);return u(v)&&(p(v)?i(e.resolved)&&v.then(h,d):p(v.component)&&(v.component.then(h,d),o(v.error)&&(e.errorComp=Wt(v.error,t)),o(v.loading)&&(e.loadingComp=Wt(v.loading,t),0===v.delay?e.loading=!0:c=setTimeout((function(){c=null,i(e.resolved)&&i(e.error)&&(e.loading=!0,f(!1))}),v.delay||200)),o(v.timeout)&&(l=setTimeout((function(){l=null,i(e.resolved)&&d(null)}),v.timeout)))),s=!1,e.loading?e.loadingComp:e.resolved}}(f=e,l)))return function(e,t,n,r,i){var o=me();return o.asyncFactory=e,o.asyncMeta={data:t,context:n,children:r,tag:i},o}(f,t,n,s,c);t=t||{},Cn(e),o(t.model)&&function(e,t){var n=e.model&&e.model.prop||"value",r=e.model&&e.model.event||"input";(t.attrs||(t.attrs={}))[n]=t.model.value;var i=t.on||(t.on={}),a=i[r],s=t.model.callback;o(a)?(Array.isArray(a)?-1===a.indexOf(s):a!==s)&&(i[r]=[s].concat(a)):i[r]=s}(e.options,t);var h=function(e,t,n){var r=t.options.props;if(!i(r)){var a={},s=e.attrs,u=e.props;if(o(s)||o(u))for(var c in r){var l=S(c);lt(a,u,c,l,!0)||lt(a,s,c,l,!1)}return a}}(t,e);if(a(e.options.functional))return function(e,t,n,i,a){var s=e.options,u={},c=s.props;if(o(c))for(var l in c)u[l]=qe(l,c,t||r);else o(n.attrs)&&Mt(u,n.attrs),o(n.props)&&Mt(u,n.props);var f=new Lt(n,u,a,i,e),h=s.render.call(null,f._c,f);if(h instanceof ge)return It(h,n,f.parent,s,f);if(Array.isArray(h)){for(var p=ft(h)||[],d=new Array(p.length),v=0;v<p.length;v++)d[v]=It(p[v],n,f.parent,s,f);return d}}(e,h,t,n,s);var d=t.on;if(t.on=t.nativeOn,a(e.options.abstract)){var v=t.slot;t={},v&&(t.slot=v)}!function(e){for(var t=e.hook||(e.hook={}),n=0;n<Bt.length;n++){var r=Bt[n],i=t[r],o=Rt[r];i===o||i&&i._merged||(t[r]=i?qt(o,i):o)}}(t);var g=e.options.name||c;return new ge("vue-component-"+e.cid+(g?"-"+g:""),t,void 0,void 0,void 0,n,{Ctor:e,propsData:h,listeners:d,tag:c,children:s},f)}}}function qt(e,t){var n=function(n,r){e(n,r),t(n,r)};return n._merged=!0,n}function Ft(e,t,n,r,c,l){return(Array.isArray(n)||s(n))&&(c=r,r=n,n=void 0),a(l)&&(c=2),function(e,t,n,r,s){if(o(n)&&o(n.__ob__))return me();o(n)&&o(n.is)&&(t=n.is);if(!t)return me();0;Array.isArray(r)&&"function"==typeof r[0]&&((n=n||{}).scopedSlots={default:r[0]},r.length=0);2===s?r=ft(r):1===s&&(r=function(e){for(var t=0;t<e.length;t++)if(Array.isArray(e[t]))return Array.prototype.concat.apply([],e);return e}(r));var c,l;if("string"==typeof t){var f;l=e.$vnode&&e.$vnode.ns||q.getTagNamespace(t),c=q.isReservedTag(t)?new ge(q.parsePlatformTagName(t),n,r,void 0,void 0,e):n&&n.pre||!o(f=$e(e.$options,"components",t))?new ge(t,n,r,void 0,void 0,e):$t(f,n,e,r,t)}else c=$t(t,n,e,r);return Array.isArray(c)?c:o(c)?(o(l)&&function e(t,n,r){t.ns=n,"foreignObject"===t.tag&&(n=void 0,r=!0);if(o(t.children))for(var s=0,u=t.children.length;s<u;s++){var c=t.children[s];o(c.tag)&&(i(c.ns)||a(r)&&"svg"!==c.tag)&&e(c,n,r)}}(c,l),o(n)&&function(e){u(e.style)&&ot(e.style);u(e.class)&&ot(e.class)}(n),c):me()}(e,t,n,r,c)}var Ht,Ut=null;function Wt(e,t){return(e.__esModule||ce&&"Module"===e[Symbol.toStringTag])&&(e=e.default),u(e)?t.extend(e):e}function zt(e){return e.isComment&&e.asyncFactory}function Kt(e){if(Array.isArray(e))for(var t=0;t<e.length;t++){var n=e[t];if(o(n)&&(o(n.componentOptions)||zt(n)))return n}}function Vt(e,t){Ht.$on(e,t)}function Xt(e,t){Ht.$off(e,t)}function Yt(e,t){var n=Ht;return function r(){var i=t.apply(null,arguments);null!==i&&n.$off(e,r)}}function Gt(e,t,n){Ht=e,ut(t,n||{},Vt,Xt,Yt,e),Ht=void 0}var Jt=null;function Zt(e){var t=Jt;return Jt=e,function(){Jt=t}}function Qt(e){for(;e&&(e=e.$parent);)if(e._inactive)return!0;return!1}function en(e,t){if(t){if(e._directInactive=!1,Qt(e))return}else if(e._directInactive)return;if(e._inactive||null===e._inactive){e._inactive=!1;for(var n=0;n<e.$children.length;n++)en(e.$children[n]);tn(e,"activated")}}function tn(e,t){de();var n=e.$options[t],r=t+" hook";if(n)for(var i=0,o=n.length;i<o;i++)ze(n[i],e,null,e,r);e._hasHookEvent&&e.$emit("hook:"+t),ve()}var nn=[],rn=[],on={},an=!1,sn=!1,un=0;var cn=0,ln=Date.now;if(V&&!J){var fn=window.performance;fn&&"function"==typeof fn.now&&ln()>document.createEvent("Event").timeStamp&&(ln=function(){return fn.now()})}function hn(){var e,t;for(cn=ln(),sn=!0,nn.sort((function(e,t){return e.id-t.id})),un=0;un<nn.length;un++)(e=nn[un]).before&&e.before(),t=e.id,on[t]=null,e.run();var n=rn.slice(),r=nn.slice();un=nn.length=rn.length=0,on={},an=sn=!1,function(e){for(var t=0;t<e.length;t++)e[t]._inactive=!0,en(e[t],!0)}(n),function(e){var t=e.length;for(;t--;){var n=e[t],r=n.vm;r._watcher===n&&r._isMounted&&!r._isDestroyed&&tn(r,"updated")}}(r),ae&&q.devtools&&ae.emit("flush")}var pn=0,dn=function(e,t,n,r,i){this.vm=e,i&&(e._watcher=this),e._watchers.push(this),r?(this.deep=!!r.deep,this.user=!!r.user,this.lazy=!!r.lazy,this.sync=!!r.sync,this.before=r.before):this.deep=this.user=this.lazy=this.sync=!1,this.cb=n,this.id=++pn,this.active=!0,this.dirty=this.lazy,this.deps=[],this.newDeps=[],this.depIds=new ue,this.newDepIds=new ue,this.expression="","function"==typeof t?this.getter=t:(this.getter=function(e){if(!W.test(e)){var t=e.split(".");return function(e){for(var n=0;n<t.length;n++){if(!e)return;e=e[t[n]]}return e}}}(t),this.getter||(this.getter=N)),this.value=this.lazy?void 0:this.get()};dn.prototype.get=function(){var e;de(this);var t=this.vm;try{e=this.getter.call(t,t)}catch(e){if(!this.user)throw e;We(e,t,'getter for watcher "'+this.expression+'"')}finally{this.deep&&ot(e),ve(),this.cleanupDeps()}return e},dn.prototype.addDep=function(e){var t=e.id;this.newDepIds.has(t)||(this.newDepIds.add(t),this.newDeps.push(e),this.depIds.has(t)||e.addSub(this))},dn.prototype.cleanupDeps=function(){for(var e=this.deps.length;e--;){var t=this.deps[e];this.newDepIds.has(t.id)||t.removeSub(this)}var n=this.depIds;this.depIds=this.newDepIds,this.newDepIds=n,this.newDepIds.clear(),n=this.deps,this.deps=this.newDeps,this.newDeps=n,this.newDeps.length=0},dn.prototype.update=function(){this.lazy?this.dirty=!0:this.sync?this.run():function(e){var t=e.id;if(null==on[t]){if(on[t]=!0,sn){for(var n=nn.length-1;n>un&&nn[n].id>e.id;)n--;nn.splice(n+1,0,e)}else nn.push(e);an||(an=!0,rt(hn))}}(this)},dn.prototype.run=function(){if(this.active){var e=this.get();if(e!==this.value||u(e)||this.deep){var t=this.value;if(this.value=e,this.user)try{this.cb.call(this.vm,e,t)}catch(e){We(e,this.vm,'callback for watcher "'+this.expression+'"')}else this.cb.call(this.vm,e,t)}}},dn.prototype.evaluate=function(){this.value=this.get(),this.dirty=!1},dn.prototype.depend=function(){for(var e=this.deps.length;e--;)this.deps[e].depend()},dn.prototype.teardown=function(){if(this.active){this.vm._isBeingDestroyed||b(this.vm._watchers,this);for(var e=this.deps.length;e--;)this.deps[e].removeSub(this);this.active=!1}};var vn={enumerable:!0,configurable:!0,get:N,set:N};function gn(e,t,n){vn.get=function(){return this[t][n]},vn.set=function(e){this[t][n]=e},Object.defineProperty(e,n,vn)}function yn(e){e._watchers=[];var t=e.$options;t.props&&function(e,t){var n=e.$options.propsData||{},r=e._props={},i=e.$options._propKeys=[];e.$parent&&Ee(!1);var o=function(o){i.push(o);var a=qe(o,t,n,e);Ae(r,o,a),o in e||gn(e,"_props",o)};for(var a in t)o(a);Ee(!0)}(e,t.props),t.methods&&function(e,t){e.$options.props;for(var n in t)e[n]="function"!=typeof t[n]?N:A(t[n],e)}(e,t.methods),t.data?function(e){var t=e.$options.data;l(t=e._data="function"==typeof t?function(e,t){de();try{return e.call(t,t)}catch(e){return We(e,t,"data()"),{}}finally{ve()}}(t,e):t||{})||(t={});var n=Object.keys(t),r=e.$options.props,i=(e.$options.methods,n.length);for(;i--;){var o=n[i];0,r&&w(r,o)||H(o)||gn(e,"_data",o)}Se(t,!0)}(e):Se(e._data={},!0),t.computed&&function(e,t){var n=e._computedWatchers=Object.create(null),r=oe();for(var i in t){var o=t[i],a="function"==typeof o?o:o.get;0,r||(n[i]=new dn(e,a||N,N,mn)),i in e||bn(e,i,o)}}(e,t.computed),t.watch&&t.watch!==ne&&function(e,t){for(var n in t){var r=t[n];if(Array.isArray(r))for(var i=0;i<r.length;i++)xn(e,n,r[i]);else xn(e,n,r)}}(e,t.watch)}var mn={lazy:!0};function bn(e,t,n){var r=!oe();"function"==typeof n?(vn.get=r?_n(t):wn(n),vn.set=N):(vn.get=n.get?r&&!1!==n.cache?_n(t):wn(n.get):N,vn.set=n.set||N),Object.defineProperty(e,t,vn)}function _n(e){return function(){var t=this._computedWatchers&&this._computedWatchers[e];if(t)return t.dirty&&t.evaluate(),he.target&&t.depend(),t.value}}function wn(e){return function(){return e.call(this,this)}}function xn(e,t,n,r){return l(n)&&(r=n,n=n.handler),"string"==typeof n&&(n=e[n]),e.$watch(t,n,r)}var Tn=0;function Cn(e){var t=e.options;if(e.super){var n=Cn(e.super);if(n!==e.superOptions){e.superOptions=n;var r=function(e){var t,n=e.options,r=e.sealedOptions;for(var i in n)n[i]!==r[i]&&(t||(t={}),t[i]=n[i]);return t}(e);r&&D(e.extendOptions,r),(t=e.options=Be(n,e.extendOptions)).name&&(t.components[t.name]=e)}}return t}function En(e){this._init(e)}function kn(e){e.cid=0;var t=1;e.extend=function(e){e=e||{};var n=this,r=n.cid,i=e._Ctor||(e._Ctor={});if(i[r])return i[r];var o=e.name||n.options.name;var a=function(e){this._init(e)};return(a.prototype=Object.create(n.prototype)).constructor=a,a.cid=t++,a.options=Be(n.options,e),a.super=n,a.options.props&&function(e){var t=e.options.props;for(var n in t)gn(e.prototype,"_props",n)}(a),a.options.computed&&function(e){var t=e.options.computed;for(var n in t)bn(e.prototype,n,t[n])}(a),a.extend=n.extend,a.mixin=n.mixin,a.use=n.use,B.forEach((function(e){a[e]=n[e]})),o&&(a.options.components[o]=a),a.superOptions=n.options,a.extendOptions=e,a.sealedOptions=D({},a.options),i[r]=a,a}}function Sn(e){return e&&(e.Ctor.options.name||e.tag)}function An(e,t){return Array.isArray(e)?e.indexOf(t)>-1:"string"==typeof e?e.split(",").indexOf(t)>-1:!!f(e)&&e.test(t)}function On(e,t){var n=e.cache,r=e.keys,i=e._vnode;for(var o in n){var a=n[o];if(a){var s=Sn(a.componentOptions);s&&!t(s)&&Dn(n,o,r,i)}}}function Dn(e,t,n,r){var i=e[t];!i||r&&i.tag===r.tag||i.componentInstance.$destroy(),e[t]=null,b(n,t)}!function(e){e.prototype._init=function(e){var t=this;t._uid=Tn++,t._isVue=!0,e&&e._isComponent?function(e,t){var n=e.$options=Object.create(e.constructor.options),r=t._parentVnode;n.parent=t.parent,n._parentVnode=r;var i=r.componentOptions;n.propsData=i.propsData,n._parentListeners=i.listeners,n._renderChildren=i.children,n._componentTag=i.tag,t.render&&(n.render=t.render,n.staticRenderFns=t.staticRenderFns)}(t,e):t.$options=Be(Cn(t.constructor),e||{},t),t._renderProxy=t,t._self=t,function(e){var t=e.$options,n=t.parent;if(n&&!t.abstract){for(;n.$options.abstract&&n.$parent;)n=n.$parent;n.$children.push(e)}e.$parent=n,e.$root=n?n.$root:e,e.$children=[],e.$refs={},e._watcher=null,e._inactive=null,e._directInactive=!1,e._isMounted=!1,e._isDestroyed=!1,e._isBeingDestroyed=!1}(t),function(e){e._events=Object.create(null),e._hasHookEvent=!1;var t=e.$options._parentListeners;t&&Gt(e,t)}(t),function(e){e._vnode=null,e._staticTrees=null;var t=e.$options,n=e.$vnode=t._parentVnode,i=n&&n.context;e.$slots=dt(t._renderChildren,i),e.$scopedSlots=r,e._c=function(t,n,r,i){return Ft(e,t,n,r,i,!1)},e.$createElement=function(t,n,r,i){return Ft(e,t,n,r,i,!0)};var o=n&&n.data;Ae(e,"$attrs",o&&o.attrs||r,null,!0),Ae(e,"$listeners",t._parentListeners||r,null,!0)}(t),tn(t,"beforeCreate"),function(e){var t=pt(e.$options.inject,e);t&&(Ee(!1),Object.keys(t).forEach((function(n){Ae(e,n,t[n])})),Ee(!0))}(t),yn(t),function(e){var t=e.$options.provide;t&&(e._provided="function"==typeof t?t.call(e):t)}(t),tn(t,"created"),t.$options.el&&t.$mount(t.$options.el)}}(En),function(e){var t={get:function(){return this._data}},n={get:function(){return this._props}};Object.defineProperty(e.prototype,"$data",t),Object.defineProperty(e.prototype,"$props",n),e.prototype.$set=Oe,e.prototype.$delete=De,e.prototype.$watch=function(e,t,n){if(l(t))return xn(this,e,t,n);(n=n||{}).user=!0;var r=new dn(this,e,t,n);if(n.immediate)try{t.call(this,r.value)}catch(e){We(e,this,'callback for immediate watcher "'+r.expression+'"')}return function(){r.teardown()}}}(En),function(e){var t=/^hook:/;e.prototype.$on=function(e,n){var r=this;if(Array.isArray(e))for(var i=0,o=e.length;i<o;i++)r.$on(e[i],n);else(r._events[e]||(r._events[e]=[])).push(n),t.test(e)&&(r._hasHookEvent=!0);return r},e.prototype.$once=function(e,t){var n=this;function r(){n.$off(e,r),t.apply(n,arguments)}return r.fn=t,n.$on(e,r),n},e.prototype.$off=function(e,t){var n=this;if(!arguments.length)return n._events=Object.create(null),n;if(Array.isArray(e)){for(var r=0,i=e.length;r<i;r++)n.$off(e[r],t);return n}var o,a=n._events[e];if(!a)return n;if(!t)return n._events[e]=null,n;for(var s=a.length;s--;)if((o=a[s])===t||o.fn===t){a.splice(s,1);break}return n},e.prototype.$emit=function(e){var t=this,n=t._events[e];if(n){n=n.length>1?O(n):n;for(var r=O(arguments,1),i='event handler for "'+e+'"',o=0,a=n.length;o<a;o++)ze(n[o],t,r,t,i)}return t}}(En),function(e){e.prototype._update=function(e,t){var n=this,r=n.$el,i=n._vnode,o=Zt(n);n._vnode=e,n.$el=i?n.__patch__(i,e):n.__patch__(n.$el,e,t,!1),o(),r&&(r.__vue__=null),n.$el&&(n.$el.__vue__=n),n.$vnode&&n.$parent&&n.$vnode===n.$parent._vnode&&(n.$parent.$el=n.$el)},e.prototype.$forceUpdate=function(){this._watcher&&this._watcher.update()},e.prototype.$destroy=function(){var e=this;if(!e._isBeingDestroyed){tn(e,"beforeDestroy"),e._isBeingDestroyed=!0;var t=e.$parent;!t||t._isBeingDestroyed||e.$options.abstract||b(t.$children,e),e._watcher&&e._watcher.teardown();for(var n=e._watchers.length;n--;)e._watchers[n].teardown();e._data.__ob__&&e._data.__ob__.vmCount--,e._isDestroyed=!0,e.__patch__(e._vnode,null),tn(e,"destroyed"),e.$off(),e.$el&&(e.$el.__vue__=null),e.$vnode&&(e.$vnode.parent=null)}}}(En),function(e){jt(e.prototype),e.prototype.$nextTick=function(e){return rt(e,this)},e.prototype._render=function(){var e,t=this,n=t.$options,r=n.render,i=n._parentVnode;i&&(t.$scopedSlots=gt(i.data.scopedSlots,t.$slots,t.$scopedSlots)),t.$vnode=i;try{Ut=t,e=r.call(t._renderProxy,t.$createElement)}catch(n){We(n,t,"render"),e=t._vnode}finally{Ut=null}return Array.isArray(e)&&1===e.length&&(e=e[0]),e instanceof ge||(e=me()),e.parent=i,e}}(En);var Pn=[String,RegExp,Array],Nn={KeepAlive:{name:"keep-alive",abstract:!0,props:{include:Pn,exclude:Pn,max:[String,Number]},created:function(){this.cache=Object.create(null),this.keys=[]},destroyed:function(){for(var e in this.cache)Dn(this.cache,e,this.keys)},mounted:function(){var e=this;this.$watch("include",(function(t){On(e,(function(e){return An(t,e)}))})),this.$watch("exclude",(function(t){On(e,(function(e){return!An(t,e)}))}))},render:function(){var e=this.$slots.default,t=Kt(e),n=t&&t.componentOptions;if(n){var r=Sn(n),i=this.include,o=this.exclude;if(i&&(!r||!An(i,r))||o&&r&&An(o,r))return t;var a=this.cache,s=this.keys,u=null==t.key?n.Ctor.cid+(n.tag?"::"+n.tag:""):t.key;a[u]?(t.componentInstance=a[u].componentInstance,b(s,u),s.push(u)):(a[u]=t,s.push(u),this.max&&s.length>parseInt(this.max)&&Dn(a,s[0],s,this._vnode)),t.data.keepAlive=!0}return t||e&&e[0]}}};!function(e){var t={get:function(){return q}};Object.defineProperty(e,"config",t),e.util={warn:le,extend:D,mergeOptions:Be,defineReactive:Ae},e.set=Oe,e.delete=De,e.nextTick=rt,e.observable=function(e){return Se(e),e},e.options=Object.create(null),B.forEach((function(t){e.options[t+"s"]=Object.create(null)})),e.options._base=e,D(e.options.components,Nn),function(e){e.use=function(e){var t=this._installedPlugins||(this._installedPlugins=[]);if(t.indexOf(e)>-1)return this;var n=O(arguments,1);return n.unshift(this),"function"==typeof e.install?e.install.apply(e,n):"function"==typeof e&&e.apply(null,n),t.push(e),this}}(e),function(e){e.mixin=function(e){return this.options=Be(this.options,e),this}}(e),kn(e),function(e){B.forEach((function(t){e[t]=function(e,n){return n?("component"===t&&l(n)&&(n.name=n.name||e,n=this.options._base.extend(n)),"directive"===t&&"function"==typeof n&&(n={bind:n,update:n}),this.options[t+"s"][e]=n,n):this.options[t+"s"][e]}}))}(e)}(En),Object.defineProperty(En.prototype,"$isServer",{get:oe}),Object.defineProperty(En.prototype,"$ssrContext",{get:function(){return this.$vnode&&this.$vnode.ssrContext}}),Object.defineProperty(En,"FunctionalRenderContext",{value:Lt}),En.version="2.6.11";var jn=g("style,class"),Ln=g("input,textarea,option,select,progress"),In=function(e,t,n){return"value"===n&&Ln(e)&&"button"!==t||"selected"===n&&"option"===e||"checked"===n&&"input"===e||"muted"===n&&"video"===e},Mn=g("contenteditable,draggable,spellcheck"),Rn=g("events,caret,typing,plaintext-only"),Bn=g("allowfullscreen,async,autofocus,autoplay,checked,compact,controls,declare,default,defaultchecked,defaultmuted,defaultselected,defer,disabled,enabled,formnovalidate,hidden,indeterminate,inert,ismap,itemscope,loop,multiple,muted,nohref,noresize,noshade,novalidate,nowrap,open,pauseonexit,readonly,required,reversed,scoped,seamless,selected,sortable,translate,truespeed,typemustmatch,visible"),$n="http://www.w3.org/1999/xlink",qn=function(e){return":"===e.charAt(5)&&"xlink"===e.slice(0,5)},Fn=function(e){return qn(e)?e.slice(6,e.length):""},Hn=function(e){return null==e||!1===e};function Un(e){for(var t=e.data,n=e,r=e;o(r.componentInstance);)(r=r.componentInstance._vnode)&&r.data&&(t=Wn(r.data,t));for(;o(n=n.parent);)n&&n.data&&(t=Wn(t,n.data));return function(e,t){if(o(e)||o(t))return zn(e,Kn(t));return""}(t.staticClass,t.class)}function Wn(e,t){return{staticClass:zn(e.staticClass,t.staticClass),class:o(e.class)?[e.class,t.class]:t.class}}function zn(e,t){return e?t?e+" "+t:e:t||""}function Kn(e){return Array.isArray(e)?function(e){for(var t,n="",r=0,i=e.length;r<i;r++)o(t=Kn(e[r]))&&""!==t&&(n&&(n+=" "),n+=t);return n}(e):u(e)?function(e){var t="";for(var n in e)e[n]&&(t&&(t+=" "),t+=n);return t}(e):"string"==typeof e?e:""}var Vn={svg:"http://www.w3.org/2000/svg",math:"http://www.w3.org/1998/Math/MathML"},Xn=g("html,body,base,head,link,meta,style,title,address,article,aside,footer,header,h1,h2,h3,h4,h5,h6,hgroup,nav,section,div,dd,dl,dt,figcaption,figure,picture,hr,img,li,main,ol,p,pre,ul,a,b,abbr,bdi,bdo,br,cite,code,data,dfn,em,i,kbd,mark,q,rp,rt,rtc,ruby,s,samp,small,span,strong,sub,sup,time,u,var,wbr,area,audio,map,track,video,embed,object,param,source,canvas,script,noscript,del,ins,caption,col,colgroup,table,thead,tbody,td,th,tr,button,datalist,fieldset,form,input,label,legend,meter,optgroup,option,output,progress,select,textarea,details,dialog,menu,menuitem,summary,content,element,shadow,template,blockquote,iframe,tfoot"),Yn=g("svg,animate,circle,clippath,cursor,defs,desc,ellipse,filter,font-face,foreignObject,g,glyph,image,line,marker,mask,missing-glyph,path,pattern,polygon,polyline,rect,switch,symbol,text,textpath,tspan,use,view",!0),Gn=function(e){return Xn(e)||Yn(e)};function Jn(e){return Yn(e)?"svg":"math"===e?"math":void 0}var Zn=Object.create(null);var Qn=g("text,number,password,search,email,tel,url");function er(e){if("string"==typeof e){var t=document.querySelector(e);return t||document.createElement("div")}return e}var tr=Object.freeze({createElement:function(e,t){var n=document.createElement(e);return"select"!==e||t.data&&t.data.attrs&&void 0!==t.data.attrs.multiple&&n.setAttribute("multiple","multiple"),n},createElementNS:function(e,t){return document.createElementNS(Vn[e],t)},createTextNode:function(e){return document.createTextNode(e)},createComment:function(e){return document.createComment(e)},insertBefore:function(e,t,n){e.insertBefore(t,n)},removeChild:function(e,t){e.removeChild(t)},appendChild:function(e,t){e.appendChild(t)},parentNode:function(e){return e.parentNode},nextSibling:function(e){return e.nextSibling},tagName:function(e){return e.tagName},setTextContent:function(e,t){e.textContent=t},setStyleScope:function(e,t){e.setAttribute(t,"")}}),nr={create:function(e,t){rr(t)},update:function(e,t){e.data.ref!==t.data.ref&&(rr(e,!0),rr(t))},destroy:function(e){rr(e,!0)}};function rr(e,t){var n=e.data.ref;if(o(n)){var r=e.context,i=e.componentInstance||e.elm,a=r.$refs;t?Array.isArray(a[n])?b(a[n],i):a[n]===i&&(a[n]=void 0):e.data.refInFor?Array.isArray(a[n])?a[n].indexOf(i)<0&&a[n].push(i):a[n]=[i]:a[n]=i}}var ir=new ge("",{},[]),or=["create","activate","update","remove","destroy"];function ar(e,t){return e.key===t.key&&(e.tag===t.tag&&e.isComment===t.isComment&&o(e.data)===o(t.data)&&function(e,t){if("input"!==e.tag)return!0;var n,r=o(n=e.data)&&o(n=n.attrs)&&n.type,i=o(n=t.data)&&o(n=n.attrs)&&n.type;return r===i||Qn(r)&&Qn(i)}(e,t)||a(e.isAsyncPlaceholder)&&e.asyncFactory===t.asyncFactory&&i(t.asyncFactory.error))}function sr(e,t,n){var r,i,a={};for(r=t;r<=n;++r)o(i=e[r].key)&&(a[i]=r);return a}var ur={create:cr,update:cr,destroy:function(e){cr(e,ir)}};function cr(e,t){(e.data.directives||t.data.directives)&&function(e,t){var n,r,i,o=e===ir,a=t===ir,s=fr(e.data.directives,e.context),u=fr(t.data.directives,t.context),c=[],l=[];for(n in u)r=s[n],i=u[n],r?(i.oldValue=r.value,i.oldArg=r.arg,pr(i,"update",t,e),i.def&&i.def.componentUpdated&&l.push(i)):(pr(i,"bind",t,e),i.def&&i.def.inserted&&c.push(i));if(c.length){var f=function(){for(var n=0;n<c.length;n++)pr(c[n],"inserted",t,e)};o?ct(t,"insert",f):f()}l.length&&ct(t,"postpatch",(function(){for(var n=0;n<l.length;n++)pr(l[n],"componentUpdated",t,e)}));if(!o)for(n in s)u[n]||pr(s[n],"unbind",e,e,a)}(e,t)}var lr=Object.create(null);function fr(e,t){var n,r,i=Object.create(null);if(!e)return i;for(n=0;n<e.length;n++)(r=e[n]).modifiers||(r.modifiers=lr),i[hr(r)]=r,r.def=$e(t.$options,"directives",r.name);return i}function hr(e){return e.rawName||e.name+"."+Object.keys(e.modifiers||{}).join(".")}function pr(e,t,n,r,i){var o=e.def&&e.def[t];if(o)try{o(n.elm,e,n,r,i)}catch(r){We(r,n.context,"directive "+e.name+" "+t+" hook")}}var dr=[nr,ur];function vr(e,t){var n=t.componentOptions;if(!(o(n)&&!1===n.Ctor.options.inheritAttrs||i(e.data.attrs)&&i(t.data.attrs))){var r,a,s=t.elm,u=e.data.attrs||{},c=t.data.attrs||{};for(r in o(c.__ob__)&&(c=t.data.attrs=D({},c)),c)a=c[r],u[r]!==a&&gr(s,r,a);for(r in(J||Q)&&c.value!==u.value&&gr(s,"value",c.value),u)i(c[r])&&(qn(r)?s.removeAttributeNS($n,Fn(r)):Mn(r)||s.removeAttribute(r))}}function gr(e,t,n){e.tagName.indexOf("-")>-1?yr(e,t,n):Bn(t)?Hn(n)?e.removeAttribute(t):(n="allowfullscreen"===t&&"EMBED"===e.tagName?"true":t,e.setAttribute(t,n)):Mn(t)?e.setAttribute(t,function(e,t){return Hn(t)||"false"===t?"false":"contenteditable"===e&&Rn(t)?t:"true"}(t,n)):qn(t)?Hn(n)?e.removeAttributeNS($n,Fn(t)):e.setAttributeNS($n,t,n):yr(e,t,n)}function yr(e,t,n){if(Hn(n))e.removeAttribute(t);else{if(J&&!Z&&"TEXTAREA"===e.tagName&&"placeholder"===t&&""!==n&&!e.__ieph){var r=function(t){t.stopImmediatePropagation(),e.removeEventListener("input",r)};e.addEventListener("input",r),e.__ieph=!0}e.setAttribute(t,n)}}var mr={create:vr,update:vr};function br(e,t){var n=t.elm,r=t.data,a=e.data;if(!(i(r.staticClass)&&i(r.class)&&(i(a)||i(a.staticClass)&&i(a.class)))){var s=Un(t),u=n._transitionClasses;o(u)&&(s=zn(s,Kn(u))),s!==n._prevClass&&(n.setAttribute("class",s),n._prevClass=s)}}var _r,wr,xr,Tr,Cr,Er,kr={create:br,update:br},Sr=/[\w).+\-_$\]]/;function Ar(e){var t,n,r,i,o,a=!1,s=!1,u=!1,c=!1,l=0,f=0,h=0,p=0;for(r=0;r<e.length;r++)if(n=t,t=e.charCodeAt(r),a)39===t&&92!==n&&(a=!1);else if(s)34===t&&92!==n&&(s=!1);else if(u)96===t&&92!==n&&(u=!1);else if(c)47===t&&92!==n&&(c=!1);else if(124!==t||124===e.charCodeAt(r+1)||124===e.charCodeAt(r-1)||l||f||h){switch(t){case 34:s=!0;break;case 39:a=!0;break;case 96:u=!0;break;case 40:h++;break;case 41:h--;break;case 91:f++;break;case 93:f--;break;case 123:l++;break;case 125:l--}if(47===t){for(var d=r-1,v=void 0;d>=0&&" "===(v=e.charAt(d));d--);v&&Sr.test(v)||(c=!0)}}else void 0===i?(p=r+1,i=e.slice(0,r).trim()):g();function g(){(o||(o=[])).push(e.slice(p,r).trim()),p=r+1}if(void 0===i?i=e.slice(0,r).trim():0!==p&&g(),o)for(r=0;r<o.length;r++)i=Or(i,o[r]);return i}function Or(e,t){var n=t.indexOf("(");if(n<0)return'_f("'+t+'")('+e+")";var r=t.slice(0,n),i=t.slice(n+1);return'_f("'+r+'")('+e+(")"!==i?","+i:i)}function Dr(e,t){console.error("[Vue compiler]: "+e)}function Pr(e,t){return e?e.map((function(e){return e[t]})).filter((function(e){return e})):[]}function Nr(e,t,n,r,i){(e.props||(e.props=[])).push(Fr({name:t,value:n,dynamic:i},r)),e.plain=!1}function jr(e,t,n,r,i){(i?e.dynamicAttrs||(e.dynamicAttrs=[]):e.attrs||(e.attrs=[])).push(Fr({name:t,value:n,dynamic:i},r)),e.plain=!1}function Lr(e,t,n,r){e.attrsMap[t]=n,e.attrsList.push(Fr({name:t,value:n},r))}function Ir(e,t,n,r,i,o,a,s){(e.directives||(e.directives=[])).push(Fr({name:t,rawName:n,value:r,arg:i,isDynamicArg:o,modifiers:a},s)),e.plain=!1}function Mr(e,t,n){return n?"_p("+t+',"'+e+'")':e+t}function Rr(e,t,n,i,o,a,s,u){var c;(i=i||r).right?u?t="("+t+")==='click'?'contextmenu':("+t+")":"click"===t&&(t="contextmenu",delete i.right):i.middle&&(u?t="("+t+")==='click'?'mouseup':("+t+")":"click"===t&&(t="mouseup")),i.capture&&(delete i.capture,t=Mr("!",t,u)),i.once&&(delete i.once,t=Mr("~",t,u)),i.passive&&(delete i.passive,t=Mr("&",t,u)),i.native?(delete i.native,c=e.nativeEvents||(e.nativeEvents={})):c=e.events||(e.events={});var l=Fr({value:n.trim(),dynamic:u},s);i!==r&&(l.modifiers=i);var f=c[t];Array.isArray(f)?o?f.unshift(l):f.push(l):c[t]=f?o?[l,f]:[f,l]:l,e.plain=!1}function Br(e,t,n){var r=$r(e,":"+t)||$r(e,"v-bind:"+t);if(null!=r)return Ar(r);if(!1!==n){var i=$r(e,t);if(null!=i)return JSON.stringify(i)}}function $r(e,t,n){var r;if(null!=(r=e.attrsMap[t]))for(var i=e.attrsList,o=0,a=i.length;o<a;o++)if(i[o].name===t){i.splice(o,1);break}return n&&delete e.attrsMap[t],r}function qr(e,t){for(var n=e.attrsList,r=0,i=n.length;r<i;r++){var o=n[r];if(t.test(o.name))return n.splice(r,1),o}}function Fr(e,t){return t&&(null!=t.start&&(e.start=t.start),null!=t.end&&(e.end=t.end)),e}function Hr(e,t,n){var r=n||{},i=r.number,o="$$v";r.trim&&(o="(typeof $$v === 'string'? $$v.trim(): $$v)"),i&&(o="_n("+o+")");var a=Ur(t,o);e.model={value:"("+t+")",expression:JSON.stringify(t),callback:"function ($$v) {"+a+"}"}}function Ur(e,t){var n=function(e){if(e=e.trim(),_r=e.length,e.indexOf("[")<0||e.lastIndexOf("]")<_r-1)return(Tr=e.lastIndexOf("."))>-1?{exp:e.slice(0,Tr),key:'"'+e.slice(Tr+1)+'"'}:{exp:e,key:null};wr=e,Tr=Cr=Er=0;for(;!zr();)Kr(xr=Wr())?Xr(xr):91===xr&&Vr(xr);return{exp:e.slice(0,Cr),key:e.slice(Cr+1,Er)}}(e);return null===n.key?e+"="+t:"$set("+n.exp+", "+n.key+", "+t+")"}function Wr(){return wr.charCodeAt(++Tr)}function zr(){return Tr>=_r}function Kr(e){return 34===e||39===e}function Vr(e){var t=1;for(Cr=Tr;!zr();)if(Kr(e=Wr()))Xr(e);else if(91===e&&t++,93===e&&t--,0===t){Er=Tr;break}}function Xr(e){for(var t=e;!zr()&&(e=Wr())!==t;);}var Yr;function Gr(e,t,n){var r=Yr;return function i(){var o=t.apply(null,arguments);null!==o&&Qr(e,i,n,r)}}var Jr=Ye&&!(te&&Number(te[1])<=53);function Zr(e,t,n,r){if(Jr){var i=cn,o=t;t=o._wrapper=function(e){if(e.target===e.currentTarget||e.timeStamp>=i||e.timeStamp<=0||e.target.ownerDocument!==document)return o.apply(this,arguments)}}Yr.addEventListener(e,t,re?{capture:n,passive:r}:n)}function Qr(e,t,n,r){(r||Yr).removeEventListener(e,t._wrapper||t,n)}function ei(e,t){if(!i(e.data.on)||!i(t.data.on)){var n=t.data.on||{},r=e.data.on||{};Yr=t.elm,function(e){if(o(e.__r)){var t=J?"change":"input";e[t]=[].concat(e.__r,e[t]||[]),delete e.__r}o(e.__c)&&(e.change=[].concat(e.__c,e.change||[]),delete e.__c)}(n),ut(n,r,Zr,Qr,Gr,t.context),Yr=void 0}}var ti,ni={create:ei,update:ei};function ri(e,t){if(!i(e.data.domProps)||!i(t.data.domProps)){var n,r,a=t.elm,s=e.data.domProps||{},u=t.data.domProps||{};for(n in o(u.__ob__)&&(u=t.data.domProps=D({},u)),s)n in u||(a[n]="");for(n in u){if(r=u[n],"textContent"===n||"innerHTML"===n){if(t.children&&(t.children.length=0),r===s[n])continue;1===a.childNodes.length&&a.removeChild(a.childNodes[0])}if("value"===n&&"PROGRESS"!==a.tagName){a._value=r;var c=i(r)?"":String(r);ii(a,c)&&(a.value=c)}else if("innerHTML"===n&&Yn(a.tagName)&&i(a.innerHTML)){(ti=ti||document.createElement("div")).innerHTML="<svg>"+r+"</svg>";for(var l=ti.firstChild;a.firstChild;)a.removeChild(a.firstChild);for(;l.firstChild;)a.appendChild(l.firstChild)}else if(r!==s[n])try{a[n]=r}catch(e){}}}}function ii(e,t){return!e.composing&&("OPTION"===e.tagName||function(e,t){var n=!0;try{n=document.activeElement!==e}catch(e){}return n&&e.value!==t}(e,t)||function(e,t){var n=e.value,r=e._vModifiers;if(o(r)){if(r.number)return v(n)!==v(t);if(r.trim)return n.trim()!==t.trim()}return n!==t}(e,t))}var oi={create:ri,update:ri},ai=x((function(e){var t={},n=/:(.+)/;return e.split(/;(?![^(]*\))/g).forEach((function(e){if(e){var r=e.split(n);r.length>1&&(t[r[0].trim()]=r[1].trim())}})),t}));function si(e){var t=ui(e.style);return e.staticStyle?D(e.staticStyle,t):t}function ui(e){return Array.isArray(e)?P(e):"string"==typeof e?ai(e):e}var ci,li=/^--/,fi=/\s*!important$/,hi=function(e,t,n){if(li.test(t))e.style.setProperty(t,n);else if(fi.test(n))e.style.setProperty(S(t),n.replace(fi,""),"important");else{var r=di(t);if(Array.isArray(n))for(var i=0,o=n.length;i<o;i++)e.style[r]=n[i];else e.style[r]=n}},pi=["Webkit","Moz","ms"],di=x((function(e){if(ci=ci||document.createElement("div").style,"filter"!==(e=C(e))&&e in ci)return e;for(var t=e.charAt(0).toUpperCase()+e.slice(1),n=0;n<pi.length;n++){var r=pi[n]+t;if(r in ci)return r}}));function vi(e,t){var n=t.data,r=e.data;if(!(i(n.staticStyle)&&i(n.style)&&i(r.staticStyle)&&i(r.style))){var a,s,u=t.elm,c=r.staticStyle,l=r.normalizedStyle||r.style||{},f=c||l,h=ui(t.data.style)||{};t.data.normalizedStyle=o(h.__ob__)?D({},h):h;var p=function(e,t){var n,r={};if(t)for(var i=e;i.componentInstance;)(i=i.componentInstance._vnode)&&i.data&&(n=si(i.data))&&D(r,n);(n=si(e.data))&&D(r,n);for(var o=e;o=o.parent;)o.data&&(n=si(o.data))&&D(r,n);return r}(t,!0);for(s in f)i(p[s])&&hi(u,s,"");for(s in p)(a=p[s])!==f[s]&&hi(u,s,null==a?"":a)}}var gi={create:vi,update:vi},yi=/\s+/;function mi(e,t){if(t&&(t=t.trim()))if(e.classList)t.indexOf(" ")>-1?t.split(yi).forEach((function(t){return e.classList.add(t)})):e.classList.add(t);else{var n=" "+(e.getAttribute("class")||"")+" ";n.indexOf(" "+t+" ")<0&&e.setAttribute("class",(n+t).trim())}}function bi(e,t){if(t&&(t=t.trim()))if(e.classList)t.indexOf(" ")>-1?t.split(yi).forEach((function(t){return e.classList.remove(t)})):e.classList.remove(t),e.classList.length||e.removeAttribute("class");else{for(var n=" "+(e.getAttribute("class")||"")+" ",r=" "+t+" ";n.indexOf(r)>=0;)n=n.replace(r," ");(n=n.trim())?e.setAttribute("class",n):e.removeAttribute("class")}}function _i(e){if(e){if("object"==typeof e){var t={};return!1!==e.css&&D(t,wi(e.name||"v")),D(t,e),t}return"string"==typeof e?wi(e):void 0}}var wi=x((function(e){return{enterClass:e+"-enter",enterToClass:e+"-enter-to",enterActiveClass:e+"-enter-active",leaveClass:e+"-leave",leaveToClass:e+"-leave-to",leaveActiveClass:e+"-leave-active"}})),xi=V&&!Z,Ti="transition",Ci="transitionend",Ei="animation",ki="animationend";xi&&(void 0===window.ontransitionend&&void 0!==window.onwebkittransitionend&&(Ti="WebkitTransition",Ci="webkitTransitionEnd"),void 0===window.onanimationend&&void 0!==window.onwebkitanimationend&&(Ei="WebkitAnimation",ki="webkitAnimationEnd"));var Si=V?window.requestAnimationFrame?window.requestAnimationFrame.bind(window):setTimeout:function(e){return e()};function Ai(e){Si((function(){Si(e)}))}function Oi(e,t){var n=e._transitionClasses||(e._transitionClasses=[]);n.indexOf(t)<0&&(n.push(t),mi(e,t))}function Di(e,t){e._transitionClasses&&b(e._transitionClasses,t),bi(e,t)}function Pi(e,t,n){var r=ji(e,t),i=r.type,o=r.timeout,a=r.propCount;if(!i)return n();var s="transition"===i?Ci:ki,u=0,c=function(){e.removeEventListener(s,l),n()},l=function(t){t.target===e&&++u>=a&&c()};setTimeout((function(){u<a&&c()}),o+1),e.addEventListener(s,l)}var Ni=/\b(transform|all)(,|$)/;function ji(e,t){var n,r=window.getComputedStyle(e),i=(r[Ti+"Delay"]||"").split(", "),o=(r[Ti+"Duration"]||"").split(", "),a=Li(i,o),s=(r[Ei+"Delay"]||"").split(", "),u=(r[Ei+"Duration"]||"").split(", "),c=Li(s,u),l=0,f=0;return"transition"===t?a>0&&(n="transition",l=a,f=o.length):"animation"===t?c>0&&(n="animation",l=c,f=u.length):f=(n=(l=Math.max(a,c))>0?a>c?"transition":"animation":null)?"transition"===n?o.length:u.length:0,{type:n,timeout:l,propCount:f,hasTransform:"transition"===n&&Ni.test(r[Ti+"Property"])}}function Li(e,t){for(;e.length<t.length;)e=e.concat(e);return Math.max.apply(null,t.map((function(t,n){return Ii(t)+Ii(e[n])})))}function Ii(e){return 1e3*Number(e.slice(0,-1).replace(",","."))}function Mi(e,t){var n=e.elm;o(n._leaveCb)&&(n._leaveCb.cancelled=!0,n._leaveCb());var r=_i(e.data.transition);if(!i(r)&&!o(n._enterCb)&&1===n.nodeType){for(var a=r.css,s=r.type,c=r.enterClass,l=r.enterToClass,f=r.enterActiveClass,h=r.appearClass,p=r.appearToClass,d=r.appearActiveClass,g=r.beforeEnter,y=r.enter,m=r.afterEnter,b=r.enterCancelled,_=r.beforeAppear,w=r.appear,x=r.afterAppear,T=r.appearCancelled,C=r.duration,E=Jt,k=Jt.$vnode;k&&k.parent;)E=k.context,k=k.parent;var S=!E._isMounted||!e.isRootInsert;if(!S||w||""===w){var A=S&&h?h:c,O=S&&d?d:f,D=S&&p?p:l,P=S&&_||g,N=S&&"function"==typeof w?w:y,j=S&&x||m,L=S&&T||b,I=v(u(C)?C.enter:C);0;var M=!1!==a&&!Z,B=$i(N),$=n._enterCb=R((function(){M&&(Di(n,D),Di(n,O)),$.cancelled?(M&&Di(n,A),L&&L(n)):j&&j(n),n._enterCb=null}));e.data.show||ct(e,"insert",(function(){var t=n.parentNode,r=t&&t._pending&&t._pending[e.key];r&&r.tag===e.tag&&r.elm._leaveCb&&r.elm._leaveCb(),N&&N(n,$)})),P&&P(n),M&&(Oi(n,A),Oi(n,O),Ai((function(){Di(n,A),$.cancelled||(Oi(n,D),B||(Bi(I)?setTimeout($,I):Pi(n,s,$)))}))),e.data.show&&(t&&t(),N&&N(n,$)),M||B||$()}}}function Ri(e,t){var n=e.elm;o(n._enterCb)&&(n._enterCb.cancelled=!0,n._enterCb());var r=_i(e.data.transition);if(i(r)||1!==n.nodeType)return t();if(!o(n._leaveCb)){var a=r.css,s=r.type,c=r.leaveClass,l=r.leaveToClass,f=r.leaveActiveClass,h=r.beforeLeave,p=r.leave,d=r.afterLeave,g=r.leaveCancelled,y=r.delayLeave,m=r.duration,b=!1!==a&&!Z,_=$i(p),w=v(u(m)?m.leave:m);0;var x=n._leaveCb=R((function(){n.parentNode&&n.parentNode._pending&&(n.parentNode._pending[e.key]=null),b&&(Di(n,l),Di(n,f)),x.cancelled?(b&&Di(n,c),g&&g(n)):(t(),d&&d(n)),n._leaveCb=null}));y?y(T):T()}function T(){x.cancelled||(!e.data.show&&n.parentNode&&((n.parentNode._pending||(n.parentNode._pending={}))[e.key]=e),h&&h(n),b&&(Oi(n,c),Oi(n,f),Ai((function(){Di(n,c),x.cancelled||(Oi(n,l),_||(Bi(w)?setTimeout(x,w):Pi(n,s,x)))}))),p&&p(n,x),b||_||x())}}function Bi(e){return"number"==typeof e&&!isNaN(e)}function $i(e){if(i(e))return!1;var t=e.fns;return o(t)?$i(Array.isArray(t)?t[0]:t):(e._length||e.length)>1}function qi(e,t){!0!==t.data.show&&Mi(t)}var Fi=function(e){var t,n,r={},u=e.modules,c=e.nodeOps;for(t=0;t<or.length;++t)for(r[or[t]]=[],n=0;n<u.length;++n)o(u[n][or[t]])&&r[or[t]].push(u[n][or[t]]);function l(e){var t=c.parentNode(e);o(t)&&c.removeChild(t,e)}function f(e,t,n,i,s,u,l){if(o(e.elm)&&o(u)&&(e=u[l]=_e(e)),e.isRootInsert=!s,!function(e,t,n,i){var s=e.data;if(o(s)){var u=o(e.componentInstance)&&s.keepAlive;if(o(s=s.hook)&&o(s=s.init)&&s(e,!1),o(e.componentInstance))return h(e,t),p(n,e.elm,i),a(u)&&function(e,t,n,i){var a,s=e;for(;s.componentInstance;)if(s=s.componentInstance._vnode,o(a=s.data)&&o(a=a.transition)){for(a=0;a<r.activate.length;++a)r.activate[a](ir,s);t.push(s);break}p(n,e.elm,i)}(e,t,n,i),!0}}(e,t,n,i)){var f=e.data,v=e.children,g=e.tag;o(g)?(e.elm=e.ns?c.createElementNS(e.ns,g):c.createElement(g,e),m(e),d(e,v,t),o(f)&&y(e,t),p(n,e.elm,i)):a(e.isComment)?(e.elm=c.createComment(e.text),p(n,e.elm,i)):(e.elm=c.createTextNode(e.text),p(n,e.elm,i))}}function h(e,t){o(e.data.pendingInsert)&&(t.push.apply(t,e.data.pendingInsert),e.data.pendingInsert=null),e.elm=e.componentInstance.$el,v(e)?(y(e,t),m(e)):(rr(e),t.push(e))}function p(e,t,n){o(e)&&(o(n)?c.parentNode(n)===e&&c.insertBefore(e,t,n):c.appendChild(e,t))}function d(e,t,n){if(Array.isArray(t)){0;for(var r=0;r<t.length;++r)f(t[r],n,e.elm,null,!0,t,r)}else s(e.text)&&c.appendChild(e.elm,c.createTextNode(String(e.text)))}function v(e){for(;e.componentInstance;)e=e.componentInstance._vnode;return o(e.tag)}function y(e,n){for(var i=0;i<r.create.length;++i)r.create[i](ir,e);o(t=e.data.hook)&&(o(t.create)&&t.create(ir,e),o(t.insert)&&n.push(e))}function m(e){var t;if(o(t=e.fnScopeId))c.setStyleScope(e.elm,t);else for(var n=e;n;)o(t=n.context)&&o(t=t.$options._scopeId)&&c.setStyleScope(e.elm,t),n=n.parent;o(t=Jt)&&t!==e.context&&t!==e.fnContext&&o(t=t.$options._scopeId)&&c.setStyleScope(e.elm,t)}function b(e,t,n,r,i,o){for(;r<=i;++r)f(n[r],o,e,t,!1,n,r)}function _(e){var t,n,i=e.data;if(o(i))for(o(t=i.hook)&&o(t=t.destroy)&&t(e),t=0;t<r.destroy.length;++t)r.destroy[t](e);if(o(t=e.children))for(n=0;n<e.children.length;++n)_(e.children[n])}function w(e,t,n){for(;t<=n;++t){var r=e[t];o(r)&&(o(r.tag)?(x(r),_(r)):l(r.elm))}}function x(e,t){if(o(t)||o(e.data)){var n,i=r.remove.length+1;for(o(t)?t.listeners+=i:t=function(e,t){function n(){0==--n.listeners&&l(e)}return n.listeners=t,n}(e.elm,i),o(n=e.componentInstance)&&o(n=n._vnode)&&o(n.data)&&x(n,t),n=0;n<r.remove.length;++n)r.remove[n](e,t);o(n=e.data.hook)&&o(n=n.remove)?n(e,t):t()}else l(e.elm)}function T(e,t,n,r){for(var i=n;i<r;i++){var a=t[i];if(o(a)&&ar(e,a))return i}}function C(e,t,n,s,u,l){if(e!==t){o(t.elm)&&o(s)&&(t=s[u]=_e(t));var h=t.elm=e.elm;if(a(e.isAsyncPlaceholder))o(t.asyncFactory.resolved)?S(e.elm,t,n):t.isAsyncPlaceholder=!0;else if(a(t.isStatic)&&a(e.isStatic)&&t.key===e.key&&(a(t.isCloned)||a(t.isOnce)))t.componentInstance=e.componentInstance;else{var p,d=t.data;o(d)&&o(p=d.hook)&&o(p=p.prepatch)&&p(e,t);var g=e.children,y=t.children;if(o(d)&&v(t)){for(p=0;p<r.update.length;++p)r.update[p](e,t);o(p=d.hook)&&o(p=p.update)&&p(e,t)}i(t.text)?o(g)&&o(y)?g!==y&&function(e,t,n,r,a){var s,u,l,h=0,p=0,d=t.length-1,v=t[0],g=t[d],y=n.length-1,m=n[0],_=n[y],x=!a;for(0;h<=d&&p<=y;)i(v)?v=t[++h]:i(g)?g=t[--d]:ar(v,m)?(C(v,m,r,n,p),v=t[++h],m=n[++p]):ar(g,_)?(C(g,_,r,n,y),g=t[--d],_=n[--y]):ar(v,_)?(C(v,_,r,n,y),x&&c.insertBefore(e,v.elm,c.nextSibling(g.elm)),v=t[++h],_=n[--y]):ar(g,m)?(C(g,m,r,n,p),x&&c.insertBefore(e,g.elm,v.elm),g=t[--d],m=n[++p]):(i(s)&&(s=sr(t,h,d)),i(u=o(m.key)?s[m.key]:T(m,t,h,d))?f(m,r,e,v.elm,!1,n,p):ar(l=t[u],m)?(C(l,m,r,n,p),t[u]=void 0,x&&c.insertBefore(e,l.elm,v.elm)):f(m,r,e,v.elm,!1,n,p),m=n[++p]);h>d?b(e,i(n[y+1])?null:n[y+1].elm,n,p,y,r):p>y&&w(t,h,d)}(h,g,y,n,l):o(y)?(o(e.text)&&c.setTextContent(h,""),b(h,null,y,0,y.length-1,n)):o(g)?w(g,0,g.length-1):o(e.text)&&c.setTextContent(h,""):e.text!==t.text&&c.setTextContent(h,t.text),o(d)&&o(p=d.hook)&&o(p=p.postpatch)&&p(e,t)}}}function E(e,t,n){if(a(n)&&o(e.parent))e.parent.data.pendingInsert=t;else for(var r=0;r<t.length;++r)t[r].data.hook.insert(t[r])}var k=g("attrs,class,staticClass,staticStyle,key");function S(e,t,n,r){var i,s=t.tag,u=t.data,c=t.children;if(r=r||u&&u.pre,t.elm=e,a(t.isComment)&&o(t.asyncFactory))return t.isAsyncPlaceholder=!0,!0;if(o(u)&&(o(i=u.hook)&&o(i=i.init)&&i(t,!0),o(i=t.componentInstance)))return h(t,n),!0;if(o(s)){if(o(c))if(e.hasChildNodes())if(o(i=u)&&o(i=i.domProps)&&o(i=i.innerHTML)){if(i!==e.innerHTML)return!1}else{for(var l=!0,f=e.firstChild,p=0;p<c.length;p++){if(!f||!S(f,c[p],n,r)){l=!1;break}f=f.nextSibling}if(!l||f)return!1}else d(t,c,n);if(o(u)){var v=!1;for(var g in u)if(!k(g)){v=!0,y(t,n);break}!v&&u.class&&ot(u.class)}}else e.data!==t.text&&(e.data=t.text);return!0}return function(e,t,n,s){if(!i(t)){var u,l=!1,h=[];if(i(e))l=!0,f(t,h);else{var p=o(e.nodeType);if(!p&&ar(e,t))C(e,t,h,null,null,s);else{if(p){if(1===e.nodeType&&e.hasAttribute("data-server-rendered")&&(e.removeAttribute("data-server-rendered"),n=!0),a(n)&&S(e,t,h))return E(t,h,!0),e;u=e,e=new ge(c.tagName(u).toLowerCase(),{},[],void 0,u)}var d=e.elm,g=c.parentNode(d);if(f(t,h,d._leaveCb?null:g,c.nextSibling(d)),o(t.parent))for(var y=t.parent,m=v(t);y;){for(var b=0;b<r.destroy.length;++b)r.destroy[b](y);if(y.elm=t.elm,m){for(var x=0;x<r.create.length;++x)r.create[x](ir,y);var T=y.data.hook.insert;if(T.merged)for(var k=1;k<T.fns.length;k++)T.fns[k]()}else rr(y);y=y.parent}o(g)?w([e],0,0):o(e.tag)&&_(e)}}return E(t,h,l),t.elm}o(e)&&_(e)}}({nodeOps:tr,modules:[mr,kr,ni,oi,gi,V?{create:qi,activate:qi,remove:function(e,t){!0!==e.data.show?Ri(e,t):t()}}:{}].concat(dr)});Z&&document.addEventListener("selectionchange",(function(){var e=document.activeElement;e&&e.vmodel&&Yi(e,"input")}));var Hi={inserted:function(e,t,n,r){"select"===n.tag?(r.elm&&!r.elm._vOptions?ct(n,"postpatch",(function(){Hi.componentUpdated(e,t,n)})):Ui(e,t,n.context),e._vOptions=[].map.call(e.options,Ki)):("textarea"===n.tag||Qn(e.type))&&(e._vModifiers=t.modifiers,t.modifiers.lazy||(e.addEventListener("compositionstart",Vi),e.addEventListener("compositionend",Xi),e.addEventListener("change",Xi),Z&&(e.vmodel=!0)))},componentUpdated:function(e,t,n){if("select"===n.tag){Ui(e,t,n.context);var r=e._vOptions,i=e._vOptions=[].map.call(e.options,Ki);if(i.some((function(e,t){return!I(e,r[t])})))(e.multiple?t.value.some((function(e){return zi(e,i)})):t.value!==t.oldValue&&zi(t.value,i))&&Yi(e,"change")}}};function Ui(e,t,n){Wi(e,t,n),(J||Q)&&setTimeout((function(){Wi(e,t,n)}),0)}function Wi(e,t,n){var r=t.value,i=e.multiple;if(!i||Array.isArray(r)){for(var o,a,s=0,u=e.options.length;s<u;s++)if(a=e.options[s],i)o=M(r,Ki(a))>-1,a.selected!==o&&(a.selected=o);else if(I(Ki(a),r))return void(e.selectedIndex!==s&&(e.selectedIndex=s));i||(e.selectedIndex=-1)}}function zi(e,t){return t.every((function(t){return!I(t,e)}))}function Ki(e){return"_value"in e?e._value:e.value}function Vi(e){e.target.composing=!0}function Xi(e){e.target.composing&&(e.target.composing=!1,Yi(e.target,"input"))}function Yi(e,t){var n=document.createEvent("HTMLEvents");n.initEvent(t,!0,!0),e.dispatchEvent(n)}function Gi(e){return!e.componentInstance||e.data&&e.data.transition?e:Gi(e.componentInstance._vnode)}var Ji={model:Hi,show:{bind:function(e,t,n){var r=t.value,i=(n=Gi(n)).data&&n.data.transition,o=e.__vOriginalDisplay="none"===e.style.display?"":e.style.display;r&&i?(n.data.show=!0,Mi(n,(function(){e.style.display=o}))):e.style.display=r?o:"none"},update:function(e,t,n){var r=t.value;!r!=!t.oldValue&&((n=Gi(n)).data&&n.data.transition?(n.data.show=!0,r?Mi(n,(function(){e.style.display=e.__vOriginalDisplay})):Ri(n,(function(){e.style.display="none"}))):e.style.display=r?e.__vOriginalDisplay:"none")},unbind:function(e,t,n,r,i){i||(e.style.display=e.__vOriginalDisplay)}}},Zi={name:String,appear:Boolean,css:Boolean,mode:String,type:String,enterClass:String,leaveClass:String,enterToClass:String,leaveToClass:String,enterActiveClass:String,leaveActiveClass:String,appearClass:String,appearActiveClass:String,appearToClass:String,duration:[Number,String,Object]};function Qi(e){var t=e&&e.componentOptions;return t&&t.Ctor.options.abstract?Qi(Kt(t.children)):e}function eo(e){var t={},n=e.$options;for(var r in n.propsData)t[r]=e[r];var i=n._parentListeners;for(var o in i)t[C(o)]=i[o];return t}function to(e,t){if(/\d-keep-alive$/.test(t.tag))return e("keep-alive",{props:t.componentOptions.propsData})}var no=function(e){return e.tag||zt(e)},ro=function(e){return"show"===e.name},io={name:"transition",props:Zi,abstract:!0,render:function(e){var t=this,n=this.$slots.default;if(n&&(n=n.filter(no)).length){0;var r=this.mode;0;var i=n[0];if(function(e){for(;e=e.parent;)if(e.data.transition)return!0}(this.$vnode))return i;var o=Qi(i);if(!o)return i;if(this._leaving)return to(e,i);var a="__transition-"+this._uid+"-";o.key=null==o.key?o.isComment?a+"comment":a+o.tag:s(o.key)?0===String(o.key).indexOf(a)?o.key:a+o.key:o.key;var u=(o.data||(o.data={})).transition=eo(this),c=this._vnode,l=Qi(c);if(o.data.directives&&o.data.directives.some(ro)&&(o.data.show=!0),l&&l.data&&!function(e,t){return t.key===e.key&&t.tag===e.tag}(o,l)&&!zt(l)&&(!l.componentInstance||!l.componentInstance._vnode.isComment)){var f=l.data.transition=D({},u);if("out-in"===r)return this._leaving=!0,ct(f,"afterLeave",(function(){t._leaving=!1,t.$forceUpdate()})),to(e,i);if("in-out"===r){if(zt(o))return c;var h,p=function(){h()};ct(u,"afterEnter",p),ct(u,"enterCancelled",p),ct(f,"delayLeave",(function(e){h=e}))}}return i}}},oo=D({tag:String,moveClass:String},Zi);function ao(e){e.elm._moveCb&&e.elm._moveCb(),e.elm._enterCb&&e.elm._enterCb()}function so(e){e.data.newPos=e.elm.getBoundingClientRect()}function uo(e){var t=e.data.pos,n=e.data.newPos,r=t.left-n.left,i=t.top-n.top;if(r||i){e.data.moved=!0;var o=e.elm.style;o.transform=o.WebkitTransform="translate("+r+"px,"+i+"px)",o.transitionDuration="0s"}}delete oo.mode;var co={Transition:io,TransitionGroup:{props:oo,beforeMount:function(){var e=this,t=this._update;this._update=function(n,r){var i=Zt(e);e.__patch__(e._vnode,e.kept,!1,!0),e._vnode=e.kept,i(),t.call(e,n,r)}},render:function(e){for(var t=this.tag||this.$vnode.data.tag||"span",n=Object.create(null),r=this.prevChildren=this.children,i=this.$slots.default||[],o=this.children=[],a=eo(this),s=0;s<i.length;s++){var u=i[s];if(u.tag)if(null!=u.key&&0!==String(u.key).indexOf("__vlist"))o.push(u),n[u.key]=u,(u.data||(u.data={})).transition=a;else;}if(r){for(var c=[],l=[],f=0;f<r.length;f++){var h=r[f];h.data.transition=a,h.data.pos=h.elm.getBoundingClientRect(),n[h.key]?c.push(h):l.push(h)}this.kept=e(t,null,c),this.removed=l}return e(t,null,o)},updated:function(){var e=this.prevChildren,t=this.moveClass||(this.name||"v")+"-move";e.length&&this.hasMove(e[0].elm,t)&&(e.forEach(ao),e.forEach(so),e.forEach(uo),this._reflow=document.body.offsetHeight,e.forEach((function(e){if(e.data.moved){var n=e.elm,r=n.style;Oi(n,t),r.transform=r.WebkitTransform=r.transitionDuration="",n.addEventListener(Ci,n._moveCb=function e(r){r&&r.target!==n||r&&!/transform$/.test(r.propertyName)||(n.removeEventListener(Ci,e),n._moveCb=null,Di(n,t))})}})))},methods:{hasMove:function(e,t){if(!xi)return!1;if(this._hasMove)return this._hasMove;var n=e.cloneNode();e._transitionClasses&&e._transitionClasses.forEach((function(e){bi(n,e)})),mi(n,t),n.style.display="none",this.$el.appendChild(n);var r=ji(n);return this.$el.removeChild(n),this._hasMove=r.hasTransform}}}};En.config.mustUseProp=In,En.config.isReservedTag=Gn,En.config.isReservedAttr=jn,En.config.getTagNamespace=Jn,En.config.isUnknownElement=function(e){if(!V)return!0;if(Gn(e))return!1;if(e=e.toLowerCase(),null!=Zn[e])return Zn[e];var t=document.createElement(e);return e.indexOf("-")>-1?Zn[e]=t.constructor===window.HTMLUnknownElement||t.constructor===window.HTMLElement:Zn[e]=/HTMLUnknownElement/.test(t.toString())},D(En.options.directives,Ji),D(En.options.components,co),En.prototype.__patch__=V?Fi:N,En.prototype.$mount=function(e,t){return function(e,t,n){var r;return e.$el=t,e.$options.render||(e.$options.render=me),tn(e,"beforeMount"),r=function(){e._update(e._render(),n)},new dn(e,r,N,{before:function(){e._isMounted&&!e._isDestroyed&&tn(e,"beforeUpdate")}},!0),n=!1,null==e.$vnode&&(e._isMounted=!0,tn(e,"mounted")),e}(this,e=e&&V?er(e):void 0,t)},V&&setTimeout((function(){q.devtools&&ae&&ae.emit("init",En)}),0);var lo=/\{\{((?:.|\r?\n)+?)\}\}/g,fo=/[-.*+?^${}()|[\]\/\\]/g,ho=x((function(e){var t=e[0].replace(fo,"\\$&"),n=e[1].replace(fo,"\\$&");return new RegExp(t+"((?:.|\\n)+?)"+n,"g")}));var po={staticKeys:["staticClass"],transformNode:function(e,t){t.warn;var n=$r(e,"class");n&&(e.staticClass=JSON.stringify(n));var r=Br(e,"class",!1);r&&(e.classBinding=r)},genData:function(e){var t="";return e.staticClass&&(t+="staticClass:"+e.staticClass+","),e.classBinding&&(t+="class:"+e.classBinding+","),t}};var vo,go={staticKeys:["staticStyle"],transformNode:function(e,t){t.warn;var n=$r(e,"style");n&&(e.staticStyle=JSON.stringify(ai(n)));var r=Br(e,"style",!1);r&&(e.styleBinding=r)},genData:function(e){var t="";return e.staticStyle&&(t+="staticStyle:"+e.staticStyle+","),e.styleBinding&&(t+="style:("+e.styleBinding+"),"),t}},yo=function(e){return(vo=vo||document.createElement("div")).innerHTML=e,vo.textContent},mo=g("area,base,br,col,embed,frame,hr,img,input,isindex,keygen,link,meta,param,source,track,wbr"),bo=g("colgroup,dd,dt,li,options,p,td,tfoot,th,thead,tr,source"),_o=g("address,article,aside,base,blockquote,body,caption,col,colgroup,dd,details,dialog,div,dl,dt,fieldset,figcaption,figure,footer,form,h1,h2,h3,h4,h5,h6,head,header,hgroup,hr,html,legend,li,menuitem,meta,optgroup,option,param,rp,rt,source,style,summary,tbody,td,tfoot,th,thead,title,tr,track"),wo=/^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/,xo=/^\s*((?:v-[\w-]+:|@|:|#)\[[^=]+\][^\s"'<>\/=]*)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/,To="[a-zA-Z_][\\-\\.0-9_a-zA-Z"+F.source+"]*",Co="((?:"+To+"\\:)?"+To+")",Eo=new RegExp("^<"+Co),ko=/^\s*(\/?)>/,So=new RegExp("^<\\/"+Co+"[^>]*>"),Ao=/^<!DOCTYPE [^>]+>/i,Oo=/^<!\--/,Do=/^<!\[/,Po=g("script,style,textarea",!0),No={},jo={"&lt;":"<","&gt;":">","&quot;":'"',"&amp;":"&","&#10;":"\n","&#9;":"\t","&#39;":"'"},Lo=/&(?:lt|gt|quot|amp|#39);/g,Io=/&(?:lt|gt|quot|amp|#39|#10|#9);/g,Mo=g("pre,textarea",!0),Ro=function(e,t){return e&&Mo(e)&&"\n"===t[0]};function Bo(e,t){var n=t?Io:Lo;return e.replace(n,(function(e){return jo[e]}))}var $o,qo,Fo,Ho,Uo,Wo,zo,Ko,Vo=/^@|^v-on:/,Xo=/^v-|^@|^:|^#/,Yo=/([\s\S]*?)\s+(?:in|of)\s+([\s\S]*)/,Go=/,([^,\}\]]*)(?:,([^,\}\]]*))?$/,Jo=/^\(|\)$/g,Zo=/^\[.*\]$/,Qo=/:(.*)$/,ea=/^:|^\.|^v-bind:/,ta=/\.[^.\]]+(?=[^\]]*$)/g,na=/^v-slot(:|$)|^#/,ra=/[\r\n]/,ia=/\s+/g,oa=x(yo);function aa(e,t,n){return{type:1,tag:e,attrsList:t,attrsMap:pa(t),rawAttrsMap:{},parent:n,children:[]}}function sa(e,t){$o=t.warn||Dr,Wo=t.isPreTag||j,zo=t.mustUseProp||j,Ko=t.getTagNamespace||j;var n=t.isReservedTag||j;(function(e){return!!e.component||!n(e.tag)}),Fo=Pr(t.modules,"transformNode"),Ho=Pr(t.modules,"preTransformNode"),Uo=Pr(t.modules,"postTransformNode"),qo=t.delimiters;var r,i,o=[],a=!1!==t.preserveWhitespace,s=t.whitespace,u=!1,c=!1;function l(e){if(f(e),u||e.processed||(e=ua(e,t)),o.length||e===r||r.if&&(e.elseif||e.else)&&la(r,{exp:e.elseif,block:e}),i&&!e.forbidden)if(e.elseif||e.else)a=e,(s=function(e){for(var t=e.length;t--;){if(1===e[t].type)return e[t];e.pop()}}(i.children))&&s.if&&la(s,{exp:a.elseif,block:a});else{if(e.slotScope){var n=e.slotTarget||'"default"';(i.scopedSlots||(i.scopedSlots={}))[n]=e}i.children.push(e),e.parent=i}var a,s;e.children=e.children.filter((function(e){return!e.slotScope})),f(e),e.pre&&(u=!1),Wo(e.tag)&&(c=!1);for(var l=0;l<Uo.length;l++)Uo[l](e,t)}function f(e){if(!c)for(var t;(t=e.children[e.children.length-1])&&3===t.type&&" "===t.text;)e.children.pop()}return function(e,t){for(var n,r,i=[],o=t.expectHTML,a=t.isUnaryTag||j,s=t.canBeLeftOpenTag||j,u=0;e;){if(n=e,r&&Po(r)){var c=0,l=r.toLowerCase(),f=No[l]||(No[l]=new RegExp("([\\s\\S]*?)(</"+l+"[^>]*>)","i")),h=e.replace(f,(function(e,n,r){return c=r.length,Po(l)||"noscript"===l||(n=n.replace(/<!\--([\s\S]*?)-->/g,"$1").replace(/<!\[CDATA\[([\s\S]*?)]]>/g,"$1")),Ro(l,n)&&(n=n.slice(1)),t.chars&&t.chars(n),""}));u+=e.length-h.length,e=h,k(l,u-c,u)}else{var p=e.indexOf("<");if(0===p){if(Oo.test(e)){var d=e.indexOf("--\x3e");if(d>=0){t.shouldKeepComment&&t.comment(e.substring(4,d),u,u+d+3),T(d+3);continue}}if(Do.test(e)){var v=e.indexOf("]>");if(v>=0){T(v+2);continue}}var g=e.match(Ao);if(g){T(g[0].length);continue}var y=e.match(So);if(y){var m=u;T(y[0].length),k(y[1],m,u);continue}var b=C();if(b){E(b),Ro(b.tagName,e)&&T(1);continue}}var _=void 0,w=void 0,x=void 0;if(p>=0){for(w=e.slice(p);!(So.test(w)||Eo.test(w)||Oo.test(w)||Do.test(w)||(x=w.indexOf("<",1))<0);)p+=x,w=e.slice(p);_=e.substring(0,p)}p<0&&(_=e),_&&T(_.length),t.chars&&_&&t.chars(_,u-_.length,u)}if(e===n){t.chars&&t.chars(e);break}}function T(t){u+=t,e=e.substring(t)}function C(){var t=e.match(Eo);if(t){var n,r,i={tagName:t[1],attrs:[],start:u};for(T(t[0].length);!(n=e.match(ko))&&(r=e.match(xo)||e.match(wo));)r.start=u,T(r[0].length),r.end=u,i.attrs.push(r);if(n)return i.unarySlash=n[1],T(n[0].length),i.end=u,i}}function E(e){var n=e.tagName,u=e.unarySlash;o&&("p"===r&&_o(n)&&k(r),s(n)&&r===n&&k(n));for(var c=a(n)||!!u,l=e.attrs.length,f=new Array(l),h=0;h<l;h++){var p=e.attrs[h],d=p[3]||p[4]||p[5]||"",v="a"===n&&"href"===p[1]?t.shouldDecodeNewlinesForHref:t.shouldDecodeNewlines;f[h]={name:p[1],value:Bo(d,v)}}c||(i.push({tag:n,lowerCasedTag:n.toLowerCase(),attrs:f,start:e.start,end:e.end}),r=n),t.start&&t.start(n,f,c,e.start,e.end)}function k(e,n,o){var a,s;if(null==n&&(n=u),null==o&&(o=u),e)for(s=e.toLowerCase(),a=i.length-1;a>=0&&i[a].lowerCasedTag!==s;a--);else a=0;if(a>=0){for(var c=i.length-1;c>=a;c--)t.end&&t.end(i[c].tag,n,o);i.length=a,r=a&&i[a-1].tag}else"br"===s?t.start&&t.start(e,[],!0,n,o):"p"===s&&(t.start&&t.start(e,[],!1,n,o),t.end&&t.end(e,n,o))}k()}(e,{warn:$o,expectHTML:t.expectHTML,isUnaryTag:t.isUnaryTag,canBeLeftOpenTag:t.canBeLeftOpenTag,shouldDecodeNewlines:t.shouldDecodeNewlines,shouldDecodeNewlinesForHref:t.shouldDecodeNewlinesForHref,shouldKeepComment:t.comments,outputSourceRange:t.outputSourceRange,start:function(e,n,a,s,f){var h=i&&i.ns||Ko(e);J&&"svg"===h&&(n=function(e){for(var t=[],n=0;n<e.length;n++){var r=e[n];da.test(r.name)||(r.name=r.name.replace(va,""),t.push(r))}return t}(n));var p,d=aa(e,n,i);h&&(d.ns=h),"style"!==(p=d).tag&&("script"!==p.tag||p.attrsMap.type&&"text/javascript"!==p.attrsMap.type)||oe()||(d.forbidden=!0);for(var v=0;v<Ho.length;v++)d=Ho[v](d,t)||d;u||(!function(e){null!=$r(e,"v-pre")&&(e.pre=!0)}(d),d.pre&&(u=!0)),Wo(d.tag)&&(c=!0),u?function(e){var t=e.attrsList,n=t.length;if(n)for(var r=e.attrs=new Array(n),i=0;i<n;i++)r[i]={name:t[i].name,value:JSON.stringify(t[i].value)},null!=t[i].start&&(r[i].start=t[i].start,r[i].end=t[i].end);else e.pre||(e.plain=!0)}(d):d.processed||(ca(d),function(e){var t=$r(e,"v-if");if(t)e.if=t,la(e,{exp:t,block:e});else{null!=$r(e,"v-else")&&(e.else=!0);var n=$r(e,"v-else-if");n&&(e.elseif=n)}}(d),function(e){null!=$r(e,"v-once")&&(e.once=!0)}(d)),r||(r=d),a?l(d):(i=d,o.push(d))},end:function(e,t,n){var r=o[o.length-1];o.length-=1,i=o[o.length-1],l(r)},chars:function(e,t,n){if(i&&(!J||"textarea"!==i.tag||i.attrsMap.placeholder!==e)){var r,o,l,f=i.children;if(e=c||e.trim()?"script"===(r=i).tag||"style"===r.tag?e:oa(e):f.length?s?"condense"===s&&ra.test(e)?"":" ":a?" ":"":"")c||"condense"!==s||(e=e.replace(ia," ")),!u&&" "!==e&&(o=function(e,t){var n=t?ho(t):lo;if(n.test(e)){for(var r,i,o,a=[],s=[],u=n.lastIndex=0;r=n.exec(e);){(i=r.index)>u&&(s.push(o=e.slice(u,i)),a.push(JSON.stringify(o)));var c=Ar(r[1].trim());a.push("_s("+c+")"),s.push({"@binding":c}),u=i+r[0].length}return u<e.length&&(s.push(o=e.slice(u)),a.push(JSON.stringify(o))),{expression:a.join("+"),tokens:s}}}(e,qo))?l={type:2,expression:o.expression,tokens:o.tokens,text:e}:" "===e&&f.length&&" "===f[f.length-1].text||(l={type:3,text:e}),l&&f.push(l)}},comment:function(e,t,n){if(i){var r={type:3,text:e,isComment:!0};0,i.children.push(r)}}}),r}function ua(e,t){var n;!function(e){var t=Br(e,"key");if(t){e.key=t}}(e),e.plain=!e.key&&!e.scopedSlots&&!e.attrsList.length,function(e){var t=Br(e,"ref");t&&(e.ref=t,e.refInFor=function(e){var t=e;for(;t;){if(void 0!==t.for)return!0;t=t.parent}return!1}(e))}(e),function(e){var t;"template"===e.tag?(t=$r(e,"scope"),e.slotScope=t||$r(e,"slot-scope")):(t=$r(e,"slot-scope"))&&(e.slotScope=t);var n=Br(e,"slot");n&&(e.slotTarget='""'===n?'"default"':n,e.slotTargetDynamic=!(!e.attrsMap[":slot"]&&!e.attrsMap["v-bind:slot"]),"template"===e.tag||e.slotScope||jr(e,"slot",n,function(e,t){return e.rawAttrsMap[":"+t]||e.rawAttrsMap["v-bind:"+t]||e.rawAttrsMap[t]}(e,"slot")));if("template"===e.tag){var r=qr(e,na);if(r){0;var i=fa(r),o=i.name,a=i.dynamic;e.slotTarget=o,e.slotTargetDynamic=a,e.slotScope=r.value||"_empty_"}}else{var s=qr(e,na);if(s){0;var u=e.scopedSlots||(e.scopedSlots={}),c=fa(s),l=c.name,f=c.dynamic,h=u[l]=aa("template",[],e);h.slotTarget=l,h.slotTargetDynamic=f,h.children=e.children.filter((function(e){if(!e.slotScope)return e.parent=h,!0})),h.slotScope=s.value||"_empty_",e.children=[],e.plain=!1}}}(e),"slot"===(n=e).tag&&(n.slotName=Br(n,"name")),function(e){var t;(t=Br(e,"is"))&&(e.component=t);null!=$r(e,"inline-template")&&(e.inlineTemplate=!0)}(e);for(var r=0;r<Fo.length;r++)e=Fo[r](e,t)||e;return function(e){var t,n,r,i,o,a,s,u,c=e.attrsList;for(t=0,n=c.length;t<n;t++){if(r=i=c[t].name,o=c[t].value,Xo.test(r))if(e.hasBindings=!0,(a=ha(r.replace(Xo,"")))&&(r=r.replace(ta,"")),ea.test(r))r=r.replace(ea,""),o=Ar(o),(u=Zo.test(r))&&(r=r.slice(1,-1)),a&&(a.prop&&!u&&"innerHtml"===(r=C(r))&&(r="innerHTML"),a.camel&&!u&&(r=C(r)),a.sync&&(s=Ur(o,"$event"),u?Rr(e,'"update:"+('+r+")",s,null,!1,0,c[t],!0):(Rr(e,"update:"+C(r),s,null,!1,0,c[t]),S(r)!==C(r)&&Rr(e,"update:"+S(r),s,null,!1,0,c[t])))),a&&a.prop||!e.component&&zo(e.tag,e.attrsMap.type,r)?Nr(e,r,o,c[t],u):jr(e,r,o,c[t],u);else if(Vo.test(r))r=r.replace(Vo,""),(u=Zo.test(r))&&(r=r.slice(1,-1)),Rr(e,r,o,a,!1,0,c[t],u);else{var l=(r=r.replace(Xo,"")).match(Qo),f=l&&l[1];u=!1,f&&(r=r.slice(0,-(f.length+1)),Zo.test(f)&&(f=f.slice(1,-1),u=!0)),Ir(e,r,i,o,f,u,a,c[t])}else jr(e,r,JSON.stringify(o),c[t]),!e.component&&"muted"===r&&zo(e.tag,e.attrsMap.type,r)&&Nr(e,r,"true",c[t])}}(e),e}function ca(e){var t;if(t=$r(e,"v-for")){var n=function(e){var t=e.match(Yo);if(!t)return;var n={};n.for=t[2].trim();var r=t[1].trim().replace(Jo,""),i=r.match(Go);i?(n.alias=r.replace(Go,"").trim(),n.iterator1=i[1].trim(),i[2]&&(n.iterator2=i[2].trim())):n.alias=r;return n}(t);n&&D(e,n)}}function la(e,t){e.ifConditions||(e.ifConditions=[]),e.ifConditions.push(t)}function fa(e){var t=e.name.replace(na,"");return t||"#"!==e.name[0]&&(t="default"),Zo.test(t)?{name:t.slice(1,-1),dynamic:!0}:{name:'"'+t+'"',dynamic:!1}}function ha(e){var t=e.match(ta);if(t){var n={};return t.forEach((function(e){n[e.slice(1)]=!0})),n}}function pa(e){for(var t={},n=0,r=e.length;n<r;n++)t[e[n].name]=e[n].value;return t}var da=/^xmlns:NS\d+/,va=/^NS\d+:/;function ga(e){return aa(e.tag,e.attrsList.slice(),e.parent)}var ya=[po,go,{preTransformNode:function(e,t){if("input"===e.tag){var n,r=e.attrsMap;if(!r["v-model"])return;if((r[":type"]||r["v-bind:type"])&&(n=Br(e,"type")),r.type||n||!r["v-bind"]||(n="("+r["v-bind"]+").type"),n){var i=$r(e,"v-if",!0),o=i?"&&("+i+")":"",a=null!=$r(e,"v-else",!0),s=$r(e,"v-else-if",!0),u=ga(e);ca(u),Lr(u,"type","checkbox"),ua(u,t),u.processed=!0,u.if="("+n+")==='checkbox'"+o,la(u,{exp:u.if,block:u});var c=ga(e);$r(c,"v-for",!0),Lr(c,"type","radio"),ua(c,t),la(u,{exp:"("+n+")==='radio'"+o,block:c});var l=ga(e);return $r(l,"v-for",!0),Lr(l,":type",n),ua(l,t),la(u,{exp:i,block:l}),a?u.else=!0:s&&(u.elseif=s),u}}}}];var ma,ba,_a={expectHTML:!0,modules:ya,directives:{model:function(e,t,n){n;var r=t.value,i=t.modifiers,o=e.tag,a=e.attrsMap.type;if(e.component)return Hr(e,r,i),!1;if("select"===o)!function(e,t,n){var r='var $$selectedVal = Array.prototype.filter.call($event.target.options,function(o){return o.selected}).map(function(o){var val = "_value" in o ? o._value : o.value;return '+(n&&n.number?"_n(val)":"val")+"});";r=r+" "+Ur(t,"$event.target.multiple ? $$selectedVal : $$selectedVal[0]"),Rr(e,"change",r,null,!0)}(e,r,i);else if("input"===o&&"checkbox"===a)!function(e,t,n){var r=n&&n.number,i=Br(e,"value")||"null",o=Br(e,"true-value")||"true",a=Br(e,"false-value")||"false";Nr(e,"checked","Array.isArray("+t+")?_i("+t+","+i+")>-1"+("true"===o?":("+t+")":":_q("+t+","+o+")")),Rr(e,"change","var $$a="+t+",$$el=$event.target,$$c=$$el.checked?("+o+"):("+a+");if(Array.isArray($$a)){var $$v="+(r?"_n("+i+")":i)+",$$i=_i($$a,$$v);if($$el.checked){$$i<0&&("+Ur(t,"$$a.concat([$$v])")+")}else{$$i>-1&&("+Ur(t,"$$a.slice(0,$$i).concat($$a.slice($$i+1))")+")}}else{"+Ur(t,"$$c")+"}",null,!0)}(e,r,i);else if("input"===o&&"radio"===a)!function(e,t,n){var r=n&&n.number,i=Br(e,"value")||"null";Nr(e,"checked","_q("+t+","+(i=r?"_n("+i+")":i)+")"),Rr(e,"change",Ur(t,i),null,!0)}(e,r,i);else if("input"===o||"textarea"===o)!function(e,t,n){var r=e.attrsMap.type;0;var i=n||{},o=i.lazy,a=i.number,s=i.trim,u=!o&&"range"!==r,c=o?"change":"range"===r?"__r":"input",l="$event.target.value";s&&(l="$event.target.value.trim()");a&&(l="_n("+l+")");var f=Ur(t,l);u&&(f="if($event.target.composing)return;"+f);Nr(e,"value","("+t+")"),Rr(e,c,f,null,!0),(s||a)&&Rr(e,"blur","$forceUpdate()")}(e,r,i);else{if(!q.isReservedTag(o))return Hr(e,r,i),!1}return!0},text:function(e,t){t.value&&Nr(e,"textContent","_s("+t.value+")",t)},html:function(e,t){t.value&&Nr(e,"innerHTML","_s("+t.value+")",t)}},isPreTag:function(e){return"pre"===e},isUnaryTag:mo,mustUseProp:In,canBeLeftOpenTag:bo,isReservedTag:Gn,getTagNamespace:Jn,staticKeys:function(e){return e.reduce((function(e,t){return e.concat(t.staticKeys||[])}),[]).join(",")}(ya)},wa=x((function(e){return g("type,tag,attrsList,attrsMap,plain,parent,children,attrs,start,end,rawAttrsMap"+(e?","+e:""))}));function xa(e,t){e&&(ma=wa(t.staticKeys||""),ba=t.isReservedTag||j,function e(t){if(t.static=function(e){if(2===e.type)return!1;if(3===e.type)return!0;return!(!e.pre&&(e.hasBindings||e.if||e.for||y(e.tag)||!ba(e.tag)||function(e){for(;e.parent;){if("template"!==(e=e.parent).tag)return!1;if(e.for)return!0}return!1}(e)||!Object.keys(e).every(ma)))}(t),1===t.type){if(!ba(t.tag)&&"slot"!==t.tag&&null==t.attrsMap["inline-template"])return;for(var n=0,r=t.children.length;n<r;n++){var i=t.children[n];e(i),i.static||(t.static=!1)}if(t.ifConditions)for(var o=1,a=t.ifConditions.length;o<a;o++){var s=t.ifConditions[o].block;e(s),s.static||(t.static=!1)}}}(e),function e(t,n){if(1===t.type){if((t.static||t.once)&&(t.staticInFor=n),t.static&&t.children.length&&(1!==t.children.length||3!==t.children[0].type))return void(t.staticRoot=!0);if(t.staticRoot=!1,t.children)for(var r=0,i=t.children.length;r<i;r++)e(t.children[r],n||!!t.for);if(t.ifConditions)for(var o=1,a=t.ifConditions.length;o<a;o++)e(t.ifConditions[o].block,n)}}(e,!1))}var Ta=/^([\w$_]+|\([^)]*?\))\s*=>|^function(?:\s+[\w$]+)?\s*\(/,Ca=/\([^)]*?\);*$/,Ea=/^[A-Za-z_$][\w$]*(?:\.[A-Za-z_$][\w$]*|\['[^']*?']|\["[^"]*?"]|\[\d+]|\[[A-Za-z_$][\w$]*])*$/,ka={esc:27,tab:9,enter:13,space:32,up:38,left:37,right:39,down:40,delete:[8,46]},Sa={esc:["Esc","Escape"],tab:"Tab",enter:"Enter",space:[" ","Spacebar"],up:["Up","ArrowUp"],left:["Left","ArrowLeft"],right:["Right","ArrowRight"],down:["Down","ArrowDown"],delete:["Backspace","Delete","Del"]},Aa=function(e){return"if("+e+")return null;"},Oa={stop:"$event.stopPropagation();",prevent:"$event.preventDefault();",self:Aa("$event.target !== $event.currentTarget"),ctrl:Aa("!$event.ctrlKey"),shift:Aa("!$event.shiftKey"),alt:Aa("!$event.altKey"),meta:Aa("!$event.metaKey"),left:Aa("'button' in $event && $event.button !== 0"),middle:Aa("'button' in $event && $event.button !== 1"),right:Aa("'button' in $event && $event.button !== 2")};function Da(e,t){var n=t?"nativeOn:":"on:",r="",i="";for(var o in e){var a=Pa(e[o]);e[o]&&e[o].dynamic?i+=o+","+a+",":r+='"'+o+'":'+a+","}return r="{"+r.slice(0,-1)+"}",i?n+"_d("+r+",["+i.slice(0,-1)+"])":n+r}function Pa(e){if(!e)return"function(){}";if(Array.isArray(e))return"["+e.map((function(e){return Pa(e)})).join(",")+"]";var t=Ea.test(e.value),n=Ta.test(e.value),r=Ea.test(e.value.replace(Ca,""));if(e.modifiers){var i="",o="",a=[];for(var s in e.modifiers)if(Oa[s])o+=Oa[s],ka[s]&&a.push(s);else if("exact"===s){var u=e.modifiers;o+=Aa(["ctrl","shift","alt","meta"].filter((function(e){return!u[e]})).map((function(e){return"$event."+e+"Key"})).join("||"))}else a.push(s);return a.length&&(i+=function(e){return"if(!$event.type.indexOf('key')&&"+e.map(Na).join("&&")+")return null;"}(a)),o&&(i+=o),"function($event){"+i+(t?"return "+e.value+"($event)":n?"return ("+e.value+")($event)":r?"return "+e.value:e.value)+"}"}return t||n?e.value:"function($event){"+(r?"return "+e.value:e.value)+"}"}function Na(e){var t=parseInt(e,10);if(t)return"$event.keyCode!=="+t;var n=ka[e],r=Sa[e];return"_k($event.keyCode,"+JSON.stringify(e)+","+JSON.stringify(n)+",$event.key,"+JSON.stringify(r)+")"}var ja={on:function(e,t){e.wrapListeners=function(e){return"_g("+e+","+t.value+")"}},bind:function(e,t){e.wrapData=function(n){return"_b("+n+",'"+e.tag+"',"+t.value+","+(t.modifiers&&t.modifiers.prop?"true":"false")+(t.modifiers&&t.modifiers.sync?",true":"")+")"}},cloak:N},La=function(e){this.options=e,this.warn=e.warn||Dr,this.transforms=Pr(e.modules,"transformCode"),this.dataGenFns=Pr(e.modules,"genData"),this.directives=D(D({},ja),e.directives);var t=e.isReservedTag||j;this.maybeComponent=function(e){return!!e.component||!t(e.tag)},this.onceId=0,this.staticRenderFns=[],this.pre=!1};function Ia(e,t){var n=new La(t);return{render:"with(this){return "+(e?Ma(e,n):'_c("div")')+"}",staticRenderFns:n.staticRenderFns}}function Ma(e,t){if(e.parent&&(e.pre=e.pre||e.parent.pre),e.staticRoot&&!e.staticProcessed)return Ra(e,t);if(e.once&&!e.onceProcessed)return Ba(e,t);if(e.for&&!e.forProcessed)return qa(e,t);if(e.if&&!e.ifProcessed)return $a(e,t);if("template"!==e.tag||e.slotTarget||t.pre){if("slot"===e.tag)return function(e,t){var n=e.slotName||'"default"',r=Wa(e,t),i="_t("+n+(r?","+r:""),o=e.attrs||e.dynamicAttrs?Va((e.attrs||[]).concat(e.dynamicAttrs||[]).map((function(e){return{name:C(e.name),value:e.value,dynamic:e.dynamic}}))):null,a=e.attrsMap["v-bind"];!o&&!a||r||(i+=",null");o&&(i+=","+o);a&&(i+=(o?"":",null")+","+a);return i+")"}(e,t);var n;if(e.component)n=function(e,t,n){var r=t.inlineTemplate?null:Wa(t,n,!0);return"_c("+e+","+Fa(t,n)+(r?","+r:"")+")"}(e.component,e,t);else{var r;(!e.plain||e.pre&&t.maybeComponent(e))&&(r=Fa(e,t));var i=e.inlineTemplate?null:Wa(e,t,!0);n="_c('"+e.tag+"'"+(r?","+r:"")+(i?","+i:"")+")"}for(var o=0;o<t.transforms.length;o++)n=t.transforms[o](e,n);return n}return Wa(e,t)||"void 0"}function Ra(e,t){e.staticProcessed=!0;var n=t.pre;return e.pre&&(t.pre=e.pre),t.staticRenderFns.push("with(this){return "+Ma(e,t)+"}"),t.pre=n,"_m("+(t.staticRenderFns.length-1)+(e.staticInFor?",true":"")+")"}function Ba(e,t){if(e.onceProcessed=!0,e.if&&!e.ifProcessed)return $a(e,t);if(e.staticInFor){for(var n="",r=e.parent;r;){if(r.for){n=r.key;break}r=r.parent}return n?"_o("+Ma(e,t)+","+t.onceId+++","+n+")":Ma(e,t)}return Ra(e,t)}function $a(e,t,n,r){return e.ifProcessed=!0,function e(t,n,r,i){if(!t.length)return i||"_e()";var o=t.shift();return o.exp?"("+o.exp+")?"+a(o.block)+":"+e(t,n,r,i):""+a(o.block);function a(e){return r?r(e,n):e.once?Ba(e,n):Ma(e,n)}}(e.ifConditions.slice(),t,n,r)}function qa(e,t,n,r){var i=e.for,o=e.alias,a=e.iterator1?","+e.iterator1:"",s=e.iterator2?","+e.iterator2:"";return e.forProcessed=!0,(r||"_l")+"(("+i+"),function("+o+a+s+"){return "+(n||Ma)(e,t)+"})"}function Fa(e,t){var n="{",r=function(e,t){var n=e.directives;if(!n)return;var r,i,o,a,s="directives:[",u=!1;for(r=0,i=n.length;r<i;r++){o=n[r],a=!0;var c=t.directives[o.name];c&&(a=!!c(e,o,t.warn)),a&&(u=!0,s+='{name:"'+o.name+'",rawName:"'+o.rawName+'"'+(o.value?",value:("+o.value+"),expression:"+JSON.stringify(o.value):"")+(o.arg?",arg:"+(o.isDynamicArg?o.arg:'"'+o.arg+'"'):"")+(o.modifiers?",modifiers:"+JSON.stringify(o.modifiers):"")+"},")}if(u)return s.slice(0,-1)+"]"}(e,t);r&&(n+=r+","),e.key&&(n+="key:"+e.key+","),e.ref&&(n+="ref:"+e.ref+","),e.refInFor&&(n+="refInFor:true,"),e.pre&&(n+="pre:true,"),e.component&&(n+='tag:"'+e.tag+'",');for(var i=0;i<t.dataGenFns.length;i++)n+=t.dataGenFns[i](e);if(e.attrs&&(n+="attrs:"+Va(e.attrs)+","),e.props&&(n+="domProps:"+Va(e.props)+","),e.events&&(n+=Da(e.events,!1)+","),e.nativeEvents&&(n+=Da(e.nativeEvents,!0)+","),e.slotTarget&&!e.slotScope&&(n+="slot:"+e.slotTarget+","),e.scopedSlots&&(n+=function(e,t,n){var r=e.for||Object.keys(t).some((function(e){var n=t[e];return n.slotTargetDynamic||n.if||n.for||Ha(n)})),i=!!e.if;if(!r)for(var o=e.parent;o;){if(o.slotScope&&"_empty_"!==o.slotScope||o.for){r=!0;break}o.if&&(i=!0),o=o.parent}var a=Object.keys(t).map((function(e){return Ua(t[e],n)})).join(",");return"scopedSlots:_u(["+a+"]"+(r?",null,true":"")+(!r&&i?",null,false,"+function(e){var t=5381,n=e.length;for(;n;)t=33*t^e.charCodeAt(--n);return t>>>0}(a):"")+")"}(e,e.scopedSlots,t)+","),e.model&&(n+="model:{value:"+e.model.value+",callback:"+e.model.callback+",expression:"+e.model.expression+"},"),e.inlineTemplate){var o=function(e,t){var n=e.children[0];0;if(n&&1===n.type){var r=Ia(n,t.options);return"inlineTemplate:{render:function(){"+r.render+"},staticRenderFns:["+r.staticRenderFns.map((function(e){return"function(){"+e+"}"})).join(",")+"]}"}}(e,t);o&&(n+=o+",")}return n=n.replace(/,$/,"")+"}",e.dynamicAttrs&&(n="_b("+n+',"'+e.tag+'",'+Va(e.dynamicAttrs)+")"),e.wrapData&&(n=e.wrapData(n)),e.wrapListeners&&(n=e.wrapListeners(n)),n}function Ha(e){return 1===e.type&&("slot"===e.tag||e.children.some(Ha))}function Ua(e,t){var n=e.attrsMap["slot-scope"];if(e.if&&!e.ifProcessed&&!n)return $a(e,t,Ua,"null");if(e.for&&!e.forProcessed)return qa(e,t,Ua);var r="_empty_"===e.slotScope?"":String(e.slotScope),i="function("+r+"){return "+("template"===e.tag?e.if&&n?"("+e.if+")?"+(Wa(e,t)||"undefined")+":undefined":Wa(e,t)||"undefined":Ma(e,t))+"}",o=r?"":",proxy:true";return"{key:"+(e.slotTarget||'"default"')+",fn:"+i+o+"}"}function Wa(e,t,n,r,i){var o=e.children;if(o.length){var a=o[0];if(1===o.length&&a.for&&"template"!==a.tag&&"slot"!==a.tag){var s=n?t.maybeComponent(a)?",1":",0":"";return""+(r||Ma)(a,t)+s}var u=n?function(e,t){for(var n=0,r=0;r<e.length;r++){var i=e[r];if(1===i.type){if(za(i)||i.ifConditions&&i.ifConditions.some((function(e){return za(e.block)}))){n=2;break}(t(i)||i.ifConditions&&i.ifConditions.some((function(e){return t(e.block)})))&&(n=1)}}return n}(o,t.maybeComponent):0,c=i||Ka;return"["+o.map((function(e){return c(e,t)})).join(",")+"]"+(u?","+u:"")}}function za(e){return void 0!==e.for||"template"===e.tag||"slot"===e.tag}function Ka(e,t){return 1===e.type?Ma(e,t):3===e.type&&e.isComment?function(e){return"_e("+JSON.stringify(e.text)+")"}(e):function(e){return"_v("+(2===e.type?e.expression:Xa(JSON.stringify(e.text)))+")"}(e)}function Va(e){for(var t="",n="",r=0;r<e.length;r++){var i=e[r],o=Xa(i.value);i.dynamic?n+=i.name+","+o+",":t+='"'+i.name+'":'+o+","}return t="{"+t.slice(0,-1)+"}",n?"_d("+t+",["+n.slice(0,-1)+"])":t}function Xa(e){return e.replace(/\u2028/g,"\\u2028").replace(/\u2029/g,"\\u2029")}new RegExp("\\b"+"do,if,for,let,new,try,var,case,else,with,await,break,catch,class,const,super,throw,while,yield,delete,export,import,return,switch,default,extends,finally,continue,debugger,function,arguments".split(",").join("\\b|\\b")+"\\b"),new RegExp("\\b"+"delete,typeof,void".split(",").join("\\s*\\([^\\)]*\\)|\\b")+"\\s*\\([^\\)]*\\)");function Ya(e,t){try{return new Function(e)}catch(n){return t.push({err:n,code:e}),N}}function Ga(e){var t=Object.create(null);return function(n,r,i){(r=D({},r)).warn;delete r.warn;var o=r.delimiters?String(r.delimiters)+n:n;if(t[o])return t[o];var a=e(n,r);var s={},u=[];return s.render=Ya(a.render,u),s.staticRenderFns=a.staticRenderFns.map((function(e){return Ya(e,u)})),t[o]=s}}var Ja,Za,Qa=(Ja=function(e,t){var n=sa(e.trim(),t);!1!==t.optimize&&xa(n,t);var r=Ia(n,t);return{ast:n,render:r.render,staticRenderFns:r.staticRenderFns}},function(e){function t(t,n){var r=Object.create(e),i=[],o=[];if(n)for(var a in n.modules&&(r.modules=(e.modules||[]).concat(n.modules)),n.directives&&(r.directives=D(Object.create(e.directives||null),n.directives)),n)"modules"!==a&&"directives"!==a&&(r[a]=n[a]);r.warn=function(e,t,n){(n?o:i).push(e)};var s=Ja(t.trim(),r);return s.errors=i,s.tips=o,s}return{compile:t,compileToFunctions:Ga(t)}})(_a),es=(Qa.compile,Qa.compileToFunctions);function ts(e){return(Za=Za||document.createElement("div")).innerHTML=e?'<a href="\n"/>':'<div a="\n"/>',Za.innerHTML.indexOf("&#10;")>0}var ns=!!V&&ts(!1),rs=!!V&&ts(!0),is=x((function(e){var t=er(e);return t&&t.innerHTML})),os=En.prototype.$mount;En.prototype.$mount=function(e,t){if((e=e&&er(e))===document.body||e===document.documentElement)return this;var n=this.$options;if(!n.render){var r=n.template;if(r)if("string"==typeof r)"#"===r.charAt(0)&&(r=is(r));else{if(!r.nodeType)return this;r=r.innerHTML}else e&&(r=function(e){if(e.outerHTML)return e.outerHTML;var t=document.createElement("div");return t.appendChild(e.cloneNode(!0)),t.innerHTML}(e));if(r){0;var i=es(r,{outputSourceRange:!1,shouldDecodeNewlines:ns,shouldDecodeNewlinesForHref:rs,delimiters:n.delimiters,comments:n.comments},this),o=i.render,a=i.staticRenderFns;n.render=o,n.staticRenderFns=a}}return os.call(this,e,t)},En.compile=es,t.a=En}).call(this,n(8),n(20).setImmediate)},function(e,t){(function(){var t=[].slice,n=[].indexOf||function(e){for(var t=0,n=this.length;t<n;t++)if(t in this&&this[t]===e)return t;return-1};e.exports=function(){function e(e,t){this.obj=e,this.file=t,this.startPos=this.file.tell(),this.loaded=!1,this.loadMethod=null,this.loadArgs=[],this.passthru=[]}return e.prototype.now=function(){var e,n;return n=arguments[0],e=2<=arguments.length?t.call(arguments,1):[],this.obj[n].apply(this.obj,e),this},e.prototype.later=function(){var e,n;return n=arguments[0],e=2<=arguments.length?t.call(arguments,1):[],this.loadMethod=n,this.loadArgs=e,this},e.prototype.ignore=function(){var e;return e=1<=arguments.length?t.call(arguments,0):[],this.passthru.concat(e),this},e.prototype.get=function(){var e,t,r,i;for(t in r=this.obj,i=this,e=function(e,t){if(null==i[e])return Object.defineProperty(i,e,{get:function(){return this.loaded||n.call(this.passthru,e)>=0||this.load(),this.obj[e]}})},r)e(t,r[t]);return this},e.prototype.load=function(){var e;return e=this.file.tell(),this.file.seek(this.startPos),this.obj[this.loadMethod].apply(this.obj,this.loadArgs),this.file.seek(e),this.loaded=!0},e}()}).call(this)},function(e,t,n){"use strict";n.r(t),function(e,r,i){
/*!
 * @overview RSVP - a tiny implementation of Promises/A+.
 * @copyright Copyright (c) 2016 Yehuda Katz, Tom Dale, Stefan Penner and contributors
 * @license   Licensed under MIT license
 *            See https://raw.githubusercontent.com/tildeio/rsvp.js/master/LICENSE
 * @version   3.6.2
 */
function o(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1}function a(e){var t=e._promiseCallbacks;return t||(t=e._promiseCallbacks={}),t}n.d(t,"asap",(function(){return he})),n.d(t,"cast",(function(){return De})),n.d(t,"Promise",(function(){return I})),n.d(t,"EventTarget",(function(){return s})),n.d(t,"all",(function(){return V})),n.d(t,"allSettled",(function(){return Y})),n.d(t,"race",(function(){return G})),n.d(t,"hash",(function(){return ee})),n.d(t,"hashSettled",(function(){return ne})),n.d(t,"rethrow",(function(){return re})),n.d(t,"defer",(function(){return ie})),n.d(t,"denodeify",(function(){return U})),n.d(t,"configure",(function(){return c})),n.d(t,"on",(function(){return Ne})),n.d(t,"off",(function(){return je})),n.d(t,"resolve",(function(){return ae})),n.d(t,"reject",(function(){return se})),n.d(t,"map",(function(){return oe})),n.d(t,"async",(function(){return Pe})),n.d(t,"filter",(function(){return ce}));var s={mixin:function(e){return e.on=this.on,e.off=this.off,e.trigger=this.trigger,e._promiseCallbacks=void 0,e},on:function(e,t){if("function"!=typeof t)throw new TypeError("Callback must be a function");var n=a(this),r=void 0;(r=n[e])||(r=n[e]=[]),-1===o(r,t)&&r.push(t)},off:function(e,t){var n,r=a(this),i=void 0;t?-1!==(n=o(i=r[e],t))&&i.splice(n,1):r[e]=[]},trigger:function(e,t,n){var r;if(r=a(this)[e])for(var i=0;i<r.length;i++)(0,r[i])(t,n)}},u={instrument:!1};function c(e,t){if(2!==arguments.length)return u[e];u[e]=t}function l(e){return"function"==typeof e}function f(e){return null!==e&&"object"==typeof e}s.mixin(u);var h=Array.isArray?Array.isArray:function(e){return"[object Array]"===Object.prototype.toString.call(e)},p=Date.now||function(){return(new Date).getTime()},d=[];function v(e,t,n){1===d.push({name:e,payload:{key:t._guidKey,id:t._id,eventName:e,detail:t._result,childId:n&&n._id,label:t._label,timeStamp:p(),error:u["instrument-with-stack"]?new Error(t._label):null}})&&setTimeout((function(){for(var e=0;e<d.length;e++){var t=d[e],n=t.payload;n.guid=n.key+n.id,n.childGuid=n.key+n.childId,n.error&&(n.stack=n.error.stack),u.trigger(t.name,t.payload)}d.length=0}),50)}function g(e,t){if(e&&"object"==typeof e&&e.constructor===this)return e;var n=new this(y,t);return w(n,e),n}function y(){}var m=new S;function b(e){try{return e.then}catch(e){return m.error=e,m}}function _(e,t,n){t.constructor===e.constructor&&n===D&&e.constructor.resolve===g?function(e,t){1===t._state?T(e,t._result):2===t._state?(t._onError=null,C(e,t._result)):E(t,void 0,(function(n){t!==n?w(e,n):T(e,n)}),(function(t){return C(e,t)}))}(e,t):n===m?(C(e,m.error),m.error=null):l(n)?function(e,t,n){u.async((function(e){var r=!1,i=function(e,t,n,r){try{e.call(t,n,r)}catch(e){return e}}(n,t,(function(n){r||(r=!0,t!==n?w(e,n):T(e,n))}),(function(t){r||(r=!0,C(e,t))}),e._label);!r&&i&&(r=!0,C(e,i))}),e)}(e,t,n):T(e,t)}function w(e,t){var n,r;e===t?T(e,t):(r=typeof(n=t),null===n||"object"!==r&&"function"!==r?T(e,t):_(e,t,b(t)))}function x(e){e._onError&&e._onError(e._result),k(e)}function T(e,t){void 0===e._state&&(e._result=t,e._state=1,0===e._subscribers.length?u.instrument&&v("fulfilled",e):u.async(k,e))}function C(e,t){void 0===e._state&&(e._state=2,e._result=t,u.async(x,e))}function E(e,t,n,r){var i=e._subscribers,o=i.length;e._onError=null,i[o]=t,i[o+1]=n,i[o+2]=r,0===o&&e._state&&u.async(k,e)}function k(e){var t=e._subscribers,n=e._state;if(u.instrument&&v(1===n?"fulfilled":"rejected",e),0!==t.length){for(var r=void 0,i=void 0,o=e._result,a=0;a<t.length;a+=3)r=t[a],i=t[a+n],r?O(n,r,i,o):i(o);e._subscribers.length=0}}function S(){this.error=null}var A=new S;function O(e,t,n,r){var i=l(n),o=void 0,a=void 0;if(i){if((o=function(e,t){try{return e(t)}catch(e){return A.error=e,A}}(n,r))===A)a=o.error,o.error=null;else if(o===t)return void C(t,new TypeError("A promises callback cannot return that same promise."))}else o=r;void 0!==t._state||(i&&void 0===a?w(t,o):void 0!==a?C(t,a):1===e?T(t,o):2===e&&C(t,o))}function D(e,t,n){var r=this._state;if(1===r&&!e||2===r&&!t)return u.instrument&&v("chained",this,this),this;this._onError=null;var i=new this.constructor(y,n),o=this._result;if(u.instrument&&v("chained",this,i),void 0===r)E(this,i,e,t);else{var a=1===r?e:t;u.async((function(){return O(r,i,a,o)}))}return i}var P=function(){function e(e,t,n,r){this._instanceConstructor=e,this.promise=new e(y,r),this._abortOnReject=n,this._init.apply(this,arguments)}return e.prototype._init=function(e,t){var n=t.length||0;this.length=n,this._remaining=n,this._result=new Array(n),this._enumerate(t),0===this._remaining&&T(this.promise,this._result)},e.prototype._enumerate=function(e){for(var t=this.length,n=this.promise,r=0;void 0===n._state&&r<t;r++)this._eachEntry(e[r],r)},e.prototype._settleMaybeThenable=function(e,t){var n=this._instanceConstructor,r=n.resolve;if(r===g){var i=b(e);if(i===D&&void 0!==e._state)e._onError=null,this._settledAt(e._state,t,e._result);else if("function"!=typeof i)this._remaining--,this._result[t]=this._makeResult(1,t,e);else if(n===I){var o=new n(y);_(o,e,i),this._willSettleAt(o,t)}else this._willSettleAt(new n((function(t){return t(e)})),t)}else this._willSettleAt(r(e),t)},e.prototype._eachEntry=function(e,t){var n;null!==(n=e)&&"object"==typeof n?this._settleMaybeThenable(e,t):(this._remaining--,this._result[t]=this._makeResult(1,t,e))},e.prototype._settledAt=function(e,t,n){var r=this.promise;void 0===r._state&&(this._abortOnReject&&2===e?C(r,n):(this._remaining--,this._result[t]=this._makeResult(e,t,n),0===this._remaining&&T(r,this._result)))},e.prototype._makeResult=function(e,t,n){return n},e.prototype._willSettleAt=function(e,t){var n=this;E(e,void 0,(function(e){return n._settledAt(1,t,e)}),(function(e){return n._settledAt(2,t,e)}))},e}();function N(e,t,n){return 1===e?{state:"fulfilled",value:n}:{state:"rejected",reason:n}}var j="rsvp_"+p()+"-",L=0;var I=function(){function e(t,n){this._id=L++,this._label=n,this._state=void 0,this._result=void 0,this._subscribers=[],u.instrument&&v("created",this),y!==t&&("function"!=typeof t&&function(){throw new TypeError("You must pass a resolver function as the first argument to the promise constructor")}(),this instanceof e?function(e,t){var n=!1;try{t((function(t){n||(n=!0,w(e,t))}),(function(t){n||(n=!0,C(e,t))}))}catch(t){C(e,t)}}(this,t):function(){throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.")}())}return e.prototype._onError=function(e){var t=this;u.after((function(){t._onError&&u.trigger("error",e,t._label)}))},e.prototype.catch=function(e,t){return this.then(void 0,e,t)},e.prototype.finally=function(e,t){var n=this.constructor;return this.then((function(t){return n.resolve(e()).then((function(){return t}))}),(function(t){return n.resolve(e()).then((function(){throw t}))}),t)},e}();function M(){this.value=void 0}I.cast=g,I.all=function(e,t){return h(e)?new P(this,e,!0,t).promise:this.reject(new TypeError("Promise.all must be called with an array"),t)},I.race=function(e,t){var n=new this(y,t);if(!h(e))return C(n,new TypeError("Promise.race must be called with an array")),n;for(var r=0;void 0===n._state&&r<e.length;r++)E(this.resolve(e[r]),void 0,(function(e){return w(n,e)}),(function(e){return C(n,e)}));return n},I.resolve=g,I.reject=function(e,t){var n=new this(y,t);return C(n,e),n},I.prototype._guidKey=j,I.prototype.then=D;var R=new M,B=new M;function $(e,t,n){try{e.apply(t,n)}catch(e){return R.value=e,R}}function q(e,t){for(var n={},r=e.length,i=new Array(r),o=0;o<r;o++)i[o]=e[o];for(var a=0;a<t.length;a++){n[t[a]]=i[a+1]}return n}function F(e){for(var t=e.length,n=new Array(t-1),r=1;r<t;r++)n[r-1]=e[r];return n}function H(e,t){return{then:function(n,r){return e.call(t,n,r)}}}function U(e,t){var n=function(){for(var n=this,r=arguments.length,i=new Array(r+1),o=!1,a=0;a<r;++a){var s=arguments[a];if(!o){if((o=K(s))===B){var u=new I(y);return C(u,B.value),u}o&&!0!==o&&(s=H(o,s))}i[a]=s}var c=new I(y);return i[r]=function(e,n){e?C(c,e):void 0===t?w(c,n):!0===t?w(c,F(arguments)):h(t)?w(c,q(arguments,t)):w(c,n)},o?z(c,i,e,n):W(c,i,e,n)};return n.__proto__=e,n}function W(e,t,n,r){var i=$(n,r,t);return i===R&&C(e,i.value),e}function z(e,t,n,r){return I.all(t).then((function(t){var i=$(n,r,t);return i===R&&C(e,i.value),e}))}function K(e){return!(!e||"object"!=typeof e)&&(e.constructor===I||function(e){try{return e.then}catch(e){return R.value=e,R}}(e))}function V(e,t){return I.all(e,t)}var X=function(e){function t(t,n,r){return function(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}(this,e.call(this,t,n,!1,r))}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}(t,e),t}(P);function Y(e,t){return h(e)?new X(I,e,t).promise:I.reject(new TypeError("Promise.allSettled must be called with an array"),t)}function G(e,t){return I.race(e,t)}function J(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}X.prototype._makeResult=N;var Z=Object.prototype.hasOwnProperty,Q=function(e){function t(t,n){var r=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],i=arguments[3];return J(this,e.call(this,t,n,r,i))}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}(t,e),t.prototype._init=function(e,t){this._result={},this._enumerate(t),0===this._remaining&&T(this.promise,this._result)},t.prototype._enumerate=function(e){var t=this.promise,n=[];for(var r in e)Z.call(e,r)&&n.push({position:r,entry:e[r]});var i=n.length;this._remaining=i;for(var o=void 0,a=0;void 0===t._state&&a<i;a++)o=n[a],this._eachEntry(o.entry,o.position)},t}(P);function ee(e,t){return f(e)?new Q(I,e,t).promise:I.reject(new TypeError("Promise.hash must be called with an object"),t)}var te=function(e){function t(t,n,r){return function(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}(this,e.call(this,t,n,!1,r))}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}(t,e),t}(Q);function ne(e,t){return f(e)?new te(I,e,!1,t).promise:I.reject(new TypeError("RSVP.hashSettled must be called with an object"),t)}function re(e){throw setTimeout((function(){throw e})),e}function ie(e){var t={resolve:void 0,reject:void 0};return t.promise=new I((function(e,n){t.resolve=e,t.reject=n}),e),t}function oe(e,t,n){return h(e)?l(t)?I.all(e,n).then((function(e){for(var r=e.length,i=new Array(r),o=0;o<r;o++)i[o]=t(e[o]);return I.all(i,n)})):I.reject(new TypeError("RSVP.map expects a function as a second argument"),n):I.reject(new TypeError("RSVP.map must be called with an array"),n)}function ae(e,t){return I.resolve(e,t)}function se(e,t){return I.reject(e,t)}function ue(e,t){return I.all(e,t)}function ce(e,t,n){return h(e)||f(e)&&void 0!==e.then?l(t)?(h(e)?ue(e,n):function(e,t){return I.resolve(e,t).then((function(e){return ue(e,t)}))}(e,n)).then((function(e){for(var r=e.length,i=new Array(r),o=0;o<r;o++)i[o]=t(e[o]);return ue(i,n).then((function(t){for(var n=new Array(r),i=0,o=0;o<r;o++)t[o]&&(n[i]=e[o],i++);return n.length=i,n}))})):I.reject(new TypeError("RSVP.filter expects function as a second argument"),n):I.reject(new TypeError("RSVP.filter must be called with an array or promise"),n)}te.prototype._makeResult=N;var le=0,fe=void 0;function he(e,t){be[le]=e,be[le+1]=t,2===(le+=2)&&Se()}var pe="undefined"!=typeof window?window:void 0,de=pe||{},ve=de.MutationObserver||de.WebKitMutationObserver,ge="undefined"==typeof self&&void 0!==e&&"[object process]"==={}.toString.call(e),ye="undefined"!=typeof Uint8ClampedArray&&"undefined"!=typeof importScripts&&"undefined"!=typeof MessageChannel;function me(){return function(){return setTimeout(_e,1)}}var be=new Array(1e3);function _e(){for(var e=0;e<le;e+=2){(0,be[e])(be[e+1]),be[e]=void 0,be[e+1]=void 0}le=0}var we,xe,Te,Ce,Ee,ke,Se=void 0;ge?(Ee=e.nextTick,ke=e.versions.node.match(/^(?:(\d+)\.)?(?:(\d+)\.)?(\*|\d+)$/),Array.isArray(ke)&&"0"===ke[1]&&"10"===ke[2]&&(Ee=r),Se=function(){return Ee(_e)}):ve?(xe=0,Te=new ve(_e),Ce=document.createTextNode(""),Te.observe(Ce,{characterData:!0}),Se=function(){return Ce.data=xe=++xe%2}):ye?((we=new MessageChannel).port1.onmessage=_e,Se=function(){return we.port2.postMessage(0)}):Se=void 0===pe?function(){try{var e=n(41);return void 0!==(fe=e.runOnLoop||e.runOnContext)?function(){fe(_e)}:me()}catch(e){return me()}}():me();var Ae;if("object"==typeof self)self;else{if("object"!=typeof i)throw new Error("no global: `self` or `global` found");i}function Oe(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}u.async=he,u.after=function(e){return setTimeout(e,0)};var De=ae,Pe=function(e,t){return u.async(e,t)};function Ne(){u.on.apply(u,arguments)}function je(){u.off.apply(u,arguments)}if("undefined"!=typeof window&&"object"==typeof window.__PROMISE_INSTRUMENTATION__){var Le=window.__PROMISE_INSTRUMENTATION__;for(var Ie in c("instrument",!0),Le)Le.hasOwnProperty(Ie)&&Ne(Ie,Le[Ie])}var Me=(Oe(Ae={asap:he,cast:De,Promise:I,EventTarget:s,all:V,allSettled:Y,race:G,hash:ee,hashSettled:ne,rethrow:re,defer:ie,denodeify:U,configure:c,on:Ne,off:je,resolve:ae,reject:se,map:oe},"async",Pe),Oe(Ae,"filter",ce),Ae);t.default=Me}.call(this,n(10),n(20).setImmediate,n(8))},function(e,t,n){"use strict";(function(t){var r=n(9).Buffer,i=n(49),o=e.exports;o.encodings=null,o.defaultCharUnicode="�",o.defaultCharSingleByte="?",o.encode=function(e,t,n){e=""+(e||"");var i=o.getEncoder(t,n),a=i.write(e),s=i.end();return s&&s.length>0?r.concat([a,s]):a},o.decode=function(e,t,n){"string"==typeof e&&(o.skipDecodeWarning||(console.error("Iconv-lite warning: decode()-ing strings is deprecated. Refer to https://github.com/ashtuchkin/iconv-lite/wiki/Use-Buffers-when-decoding"),o.skipDecodeWarning=!0),e=r.from(""+(e||""),"binary"));var i=o.getDecoder(t,n),a=i.write(e),s=i.end();return s?a+s:a},o.encodingExists=function(e){try{return o.getCodec(e),!0}catch(e){return!1}},o.toEncoding=o.encode,o.fromEncoding=o.decode,o._codecDataCache={},o.getCodec=function(e){o.encodings||(o.encodings=n(50));for(var t=o._canonicalizeEncoding(e),r={};;){var i=o._codecDataCache[t];if(i)return i;var a=o.encodings[t];switch(typeof a){case"string":t=a;break;case"object":for(var s in a)r[s]=a[s];r.encodingName||(r.encodingName=t),t=a.type;break;case"function":return r.encodingName||(r.encodingName=t),i=new a(r,o),o._codecDataCache[r.encodingName]=i,i;default:throw new Error("Encoding not recognized: '"+e+"' (searched as: '"+t+"')")}}},o._canonicalizeEncoding=function(e){return(""+e).toLowerCase().replace(/:\d{4}$|[^0-9a-z]/g,"")},o.getEncoder=function(e,t){var n=o.getCodec(e),r=new n.encoder(t,n);return n.bomAware&&t&&t.addBOM&&(r=new i.PrependBOM(r,t)),r},o.getDecoder=function(e,t){var n=o.getCodec(e),r=new n.decoder(t,n);return!n.bomAware||t&&!1===t.stripBOM||(r=new i.StripBOM(r,t)),r};var a=void 0!==t&&t.versions&&t.versions.node;if(a){var s=a.split(".").map(Number);(s[0]>0||s[1]>=10)&&n(66)(o),n(67)(o)}}).call(this,n(10))},function(e){e.exports=JSON.parse('[["0","\\u0000",127,"€"],["8140","丂丄丅丆丏丒丗丟丠両丣並丩丮丯丱丳丵丷丼乀乁乂乄乆乊乑乕乗乚乛乢乣乤乥乧乨乪",5,"乲乴",9,"乿",6,"亇亊"],["8180","亐亖亗亙亜亝亞亣亪亯亰亱亴亶亷亸亹亼亽亾仈仌仏仐仒仚仛仜仠仢仦仧仩仭仮仯仱仴仸仹仺仼仾伀伂",6,"伋伌伒",4,"伜伝伡伣伨伩伬伭伮伱伳伵伷伹伻伾",4,"佄佅佇",5,"佒佔佖佡佢佦佨佪佫佭佮佱佲併佷佸佹佺佽侀侁侂侅來侇侊侌侎侐侒侓侕侖侘侙侚侜侞侟価侢"],["8240","侤侫侭侰",4,"侶",8,"俀俁係俆俇俈俉俋俌俍俒",4,"俙俛俠俢俤俥俧俫俬俰俲俴俵俶俷俹俻俼俽俿",11],["8280","個倎倐們倓倕倖倗倛倝倞倠倢倣値倧倫倯",10,"倻倽倿偀偁偂偄偅偆偉偊偋偍偐",4,"偖偗偘偙偛偝",7,"偦",5,"偭",8,"偸偹偺偼偽傁傂傃傄傆傇傉傊傋傌傎",20,"傤傦傪傫傭",4,"傳",6,"傼"],["8340","傽",17,"僐",5,"僗僘僙僛",10,"僨僩僪僫僯僰僱僲僴僶",4,"僼",9,"儈"],["8380","儉儊儌",5,"儓",13,"儢",28,"兂兇兊兌兎兏児兒兓兗兘兙兛兝",4,"兣兤兦內兩兪兯兲兺兾兿冃冄円冇冊冋冎冏冐冑冓冔冘冚冝冞冟冡冣冦",4,"冭冮冴冸冹冺冾冿凁凂凃凅凈凊凍凎凐凒",5],["8440","凘凙凚凜凞凟凢凣凥",5,"凬凮凱凲凴凷凾刄刅刉刋刌刏刐刓刔刕刜刞刟刡刢刣別刦刧刪刬刯刱刲刴刵刼刾剄",5,"剋剎剏剒剓剕剗剘"],["8480","剙剚剛剝剟剠剢剣剤剦剨剫剬剭剮剰剱剳",9,"剾劀劃",4,"劉",6,"劑劒劔",6,"劜劤劥劦劧劮劯劰労",9,"勀勁勂勄勅勆勈勊勌勍勎勏勑勓勔動勗務",5,"勠勡勢勣勥",10,"勱",7,"勻勼勽匁匂匃匄匇匉匊匋匌匎"],["8540","匑匒匓匔匘匛匜匞匟匢匤匥匧匨匩匫匬匭匯",9,"匼匽區卂卄卆卋卌卍卐協単卙卛卝卥卨卪卬卭卲卶卹卻卼卽卾厀厁厃厇厈厊厎厏"],["8580","厐",4,"厖厗厙厛厜厞厠厡厤厧厪厫厬厭厯",6,"厷厸厹厺厼厽厾叀參",4,"収叏叐叒叓叕叚叜叝叞叡叢叧叴叺叾叿吀吂吅吇吋吔吘吙吚吜吢吤吥吪吰吳吶吷吺吽吿呁呂呄呅呇呉呌呍呎呏呑呚呝",4,"呣呥呧呩",7,"呴呹呺呾呿咁咃咅咇咈咉咊咍咑咓咗咘咜咞咟咠咡"],["8640","咢咥咮咰咲咵咶咷咹咺咼咾哃哅哊哋哖哘哛哠",4,"哫哬哯哰哱哴",5,"哻哾唀唂唃唄唅唈唊",4,"唒唓唕",5,"唜唝唞唟唡唥唦"],["8680","唨唩唫唭唲唴唵唶唸唹唺唻唽啀啂啅啇啈啋",4,"啑啒啓啔啗",4,"啝啞啟啠啢啣啨啩啫啯",5,"啹啺啽啿喅喆喌喍喎喐喒喓喕喖喗喚喛喞喠",6,"喨",8,"喲喴営喸喺喼喿",4,"嗆嗇嗈嗊嗋嗎嗏嗐嗕嗗",4,"嗞嗠嗢嗧嗩嗭嗮嗰嗱嗴嗶嗸",4,"嗿嘂嘃嘄嘅"],["8740","嘆嘇嘊嘋嘍嘐",7,"嘙嘚嘜嘝嘠嘡嘢嘥嘦嘨嘩嘪嘫嘮嘯嘰嘳嘵嘷嘸嘺嘼嘽嘾噀",11,"噏",4,"噕噖噚噛噝",4],["8780","噣噥噦噧噭噮噯噰噲噳噴噵噷噸噹噺噽",7,"嚇",6,"嚐嚑嚒嚔",14,"嚤",10,"嚰",6,"嚸嚹嚺嚻嚽",12,"囋",8,"囕囖囘囙囜団囥",5,"囬囮囯囲図囶囷囸囻囼圀圁圂圅圇國",6],["8840","園",9,"圝圞圠圡圢圤圥圦圧圫圱圲圴",4,"圼圽圿坁坃坄坅坆坈坉坋坒",4,"坘坙坢坣坥坧坬坮坰坱坲坴坵坸坹坺坽坾坿垀"],["8880","垁垇垈垉垊垍",4,"垔",6,"垜垝垞垟垥垨垪垬垯垰垱垳垵垶垷垹",8,"埄",6,"埌埍埐埑埓埖埗埛埜埞埡埢埣埥",7,"埮埰埱埲埳埵埶執埻埼埾埿堁堃堄堅堈堉堊堌堎堏堐堒堓堔堖堗堘堚堛堜堝堟堢堣堥",4,"堫",4,"報堲堳場堶",7],["8940","堾",5,"塅",6,"塎塏塐塒塓塕塖塗塙",4,"塟",5,"塦",4,"塭",16,"塿墂墄墆墇墈墊墋墌"],["8980","墍",4,"墔",4,"墛墜墝墠",7,"墪",17,"墽墾墿壀壂壃壄壆",10,"壒壓壔壖",13,"壥",5,"壭壯壱売壴壵壷壸壺",7,"夃夅夆夈",4,"夎夐夑夒夓夗夘夛夝夞夠夡夢夣夦夨夬夰夲夳夵夶夻"],["8a40","夽夾夿奀奃奅奆奊奌奍奐奒奓奙奛",4,"奡奣奤奦",12,"奵奷奺奻奼奾奿妀妅妉妋妌妎妏妐妑妔妕妘妚妛妜妝妟妠妡妢妦"],["8a80","妧妬妭妰妱妳",5,"妺妼妽妿",6,"姇姈姉姌姍姎姏姕姖姙姛姞",4,"姤姦姧姩姪姫姭",11,"姺姼姽姾娀娂娊娋娍娎娏娐娒娔娕娖娗娙娚娛娝娞娡娢娤娦娧娨娪",6,"娳娵娷",4,"娽娾娿婁",4,"婇婈婋",9,"婖婗婘婙婛",5],["8b40","婡婣婤婥婦婨婩婫",8,"婸婹婻婼婽婾媀",17,"媓",6,"媜",13,"媫媬"],["8b80","媭",4,"媴媶媷媹",4,"媿嫀嫃",5,"嫊嫋嫍",4,"嫓嫕嫗嫙嫚嫛嫝嫞嫟嫢嫤嫥嫧嫨嫪嫬",4,"嫲",22,"嬊",11,"嬘",25,"嬳嬵嬶嬸",7,"孁",6],["8c40","孈",7,"孒孖孞孠孡孧孨孫孭孮孯孲孴孶孷學孹孻孼孾孿宂宆宊宍宎宐宑宒宔宖実宧宨宩宬宭宮宯宱宲宷宺宻宼寀寁寃寈寉寊寋寍寎寏"],["8c80","寑寔",8,"寠寢寣實寧審",4,"寯寱",6,"寽対尀専尃尅將專尋尌對導尐尒尓尗尙尛尞尟尠尡尣尦尨尩尪尫尭尮尯尰尲尳尵尶尷屃屄屆屇屌屍屒屓屔屖屗屘屚屛屜屝屟屢層屧",6,"屰屲",6,"屻屼屽屾岀岃",4,"岉岊岋岎岏岒岓岕岝",4,"岤",4],["8d40","岪岮岯岰岲岴岶岹岺岻岼岾峀峂峃峅",5,"峌",5,"峓",5,"峚",6,"峢峣峧峩峫峬峮峯峱",9,"峼",4],["8d80","崁崄崅崈",5,"崏",4,"崕崗崘崙崚崜崝崟",4,"崥崨崪崫崬崯",4,"崵",7,"崿",7,"嵈嵉嵍",10,"嵙嵚嵜嵞",10,"嵪嵭嵮嵰嵱嵲嵳嵵",12,"嶃",21,"嶚嶛嶜嶞嶟嶠"],["8e40","嶡",21,"嶸",12,"巆",6,"巎",12,"巜巟巠巣巤巪巬巭"],["8e80","巰巵巶巸",4,"巿帀帄帇帉帊帋帍帎帒帓帗帞",7,"帨",4,"帯帰帲",4,"帹帺帾帿幀幁幃幆",5,"幍",6,"幖",4,"幜幝幟幠幣",14,"幵幷幹幾庁庂広庅庈庉庌庍庎庒庘庛庝庡庢庣庤庨",4,"庮",4,"庴庺庻庼庽庿",6],["8f40","廆廇廈廋",5,"廔廕廗廘廙廚廜",11,"廩廫",8,"廵廸廹廻廼廽弅弆弇弉弌弍弎弐弒弔弖弙弚弜弝弞弡弢弣弤"],["8f80","弨弫弬弮弰弲",6,"弻弽弾弿彁",14,"彑彔彙彚彛彜彞彟彠彣彥彧彨彫彮彯彲彴彵彶彸彺彽彾彿徃徆徍徎徏徑従徔徖徚徛徝從徟徠徢",5,"復徫徬徯",5,"徶徸徹徺徻徾",4,"忇忈忊忋忎忓忔忕忚忛応忞忟忢忣忥忦忨忩忬忯忰忲忳忴忶忷忹忺忼怇"],["9040","怈怉怋怌怐怑怓怗怘怚怞怟怢怣怤怬怭怮怰",4,"怶",4,"怽怾恀恄",6,"恌恎恏恑恓恔恖恗恘恛恜恞恟恠恡恥恦恮恱恲恴恵恷恾悀"],["9080","悁悂悅悆悇悈悊悋悎悏悐悑悓悕悗悘悙悜悞悡悢悤悥悧悩悪悮悰悳悵悶悷悹悺悽",7,"惇惈惉惌",4,"惒惓惔惖惗惙惛惞惡",4,"惪惱惲惵惷惸惻",4,"愂愃愄愅愇愊愋愌愐",4,"愖愗愘愙愛愜愝愞愡愢愥愨愩愪愬",18,"慀",6],["9140","慇慉態慍慏慐慒慓慔慖",6,"慞慟慠慡慣慤慥慦慩",6,"慱慲慳慴慶慸",18,"憌憍憏",4,"憕"],["9180","憖",6,"憞",8,"憪憫憭",9,"憸",5,"憿懀懁懃",4,"應懌",4,"懓懕",16,"懧",13,"懶",8,"戀",5,"戇戉戓戔戙戜戝戞戠戣戦戧戨戩戫戭戯戰戱戲戵戶戸",4,"扂扄扅扆扊"],["9240","扏扐払扖扗扙扚扜",6,"扤扥扨扱扲扴扵扷扸扺扻扽抁抂抃抅抆抇抈抋",5,"抔抙抜抝択抣抦抧抩抪抭抮抯抰抲抳抴抶抷抸抺抾拀拁"],["9280","拃拋拏拑拕拝拞拠拡拤拪拫拰拲拵拸拹拺拻挀挃挄挅挆挊挋挌挍挏挐挒挓挔挕挗挘挙挜挦挧挩挬挭挮挰挱挳",5,"挻挼挾挿捀捁捄捇捈捊捑捒捓捔捖",7,"捠捤捥捦捨捪捫捬捯捰捲捳捴捵捸捹捼捽捾捿掁掃掄掅掆掋掍掑掓掔掕掗掙",6,"採掤掦掫掯掱掲掵掶掹掻掽掿揀"],["9340","揁揂揃揅揇揈揊揋揌揑揓揔揕揗",6,"揟揢揤",4,"揫揬揮揯揰揱揳揵揷揹揺揻揼揾搃搄搆",4,"損搎搑搒搕",5,"搝搟搢搣搤"],["9380","搥搧搨搩搫搮",5,"搵",4,"搻搼搾摀摂摃摉摋",6,"摓摕摖摗摙",4,"摟",7,"摨摪摫摬摮",9,"摻",6,"撃撆撈",8,"撓撔撗撘撚撛撜撝撟",4,"撥撦撧撨撪撫撯撱撲撳撴撶撹撻撽撾撿擁擃擄擆",6,"擏擑擓擔擕擖擙據"],["9440","擛擜擝擟擠擡擣擥擧",24,"攁",7,"攊",7,"攓",4,"攙",8],["9480","攢攣攤攦",4,"攬攭攰攱攲攳攷攺攼攽敀",4,"敆敇敊敋敍敎敐敒敓敔敗敘敚敜敟敠敡敤敥敧敨敩敪敭敮敯敱敳敵敶數",14,"斈斉斊斍斎斏斒斔斕斖斘斚斝斞斠斢斣斦斨斪斬斮斱",7,"斺斻斾斿旀旂旇旈旉旊旍旐旑旓旔旕旘",7,"旡旣旤旪旫"],["9540","旲旳旴旵旸旹旻",4,"昁昄昅昇昈昉昋昍昐昑昒昖昗昘昚昛昜昞昡昢昣昤昦昩昪昫昬昮昰昲昳昷",4,"昽昿晀時晄",6,"晍晎晐晑晘"],["9580","晙晛晜晝晞晠晢晣晥晧晩",4,"晱晲晳晵晸晹晻晼晽晿暀暁暃暅暆暈暉暊暋暍暎暏暐暒暓暔暕暘",4,"暞",8,"暩",4,"暯",4,"暵暶暷暸暺暻暼暽暿",25,"曚曞",7,"曧曨曪",5,"曱曵曶書曺曻曽朁朂會"],["9640","朄朅朆朇朌朎朏朑朒朓朖朘朙朚朜朞朠",5,"朧朩朮朰朲朳朶朷朸朹朻朼朾朿杁杄杅杇杊杋杍杒杔杕杗",4,"杝杢杣杤杦杧杫杬杮東杴杶"],["9680","杸杹杺杻杽枀枂枃枅枆枈枊枌枍枎枏枑枒枓枔枖枙枛枟枠枡枤枦枩枬枮枱枲枴枹",7,"柂柅",9,"柕柖柗柛柟柡柣柤柦柧柨柪柫柭柮柲柵",7,"柾栁栂栃栄栆栍栐栒栔栕栘",4,"栞栟栠栢",6,"栫",6,"栴栵栶栺栻栿桇桋桍桏桒桖",5],["9740","桜桝桞桟桪桬",7,"桵桸",8,"梂梄梇",7,"梐梑梒梔梕梖梘",9,"梣梤梥梩梪梫梬梮梱梲梴梶梷梸"],["9780","梹",6,"棁棃",5,"棊棌棎棏棐棑棓棔棖棗棙棛",4,"棡棢棤",9,"棯棲棳棴棶棷棸棻棽棾棿椀椂椃椄椆",4,"椌椏椑椓",11,"椡椢椣椥",7,"椮椯椱椲椳椵椶椷椸椺椻椼椾楀楁楃",16,"楕楖楘楙楛楜楟"],["9840","楡楢楤楥楧楨楩楪楬業楯楰楲",4,"楺楻楽楾楿榁榃榅榊榋榌榎",5,"榖榗榙榚榝",9,"榩榪榬榮榯榰榲榳榵榶榸榹榺榼榽"],["9880","榾榿槀槂",7,"構槍槏槑槒槓槕",5,"槜槝槞槡",11,"槮槯槰槱槳",9,"槾樀",9,"樋",11,"標",5,"樠樢",5,"権樫樬樭樮樰樲樳樴樶",6,"樿",4,"橅橆橈",7,"橑",6,"橚"],["9940","橜",4,"橢橣橤橦",10,"橲",6,"橺橻橽橾橿檁檂檃檅",8,"檏檒",4,"檘",7,"檡",5],["9980","檧檨檪檭",114,"欥欦欨",6],["9a40","欯欰欱欳欴欵欶欸欻欼欽欿歀歁歂歄歅歈歊歋歍",11,"歚",7,"歨歩歫",13,"歺歽歾歿殀殅殈"],["9a80","殌殎殏殐殑殔殕殗殘殙殜",4,"殢",7,"殫",7,"殶殸",6,"毀毃毄毆",4,"毌毎毐毑毘毚毜",4,"毢",7,"毬毭毮毰毱毲毴毶毷毸毺毻毼毾",6,"氈",4,"氎氒気氜氝氞氠氣氥氫氬氭氱氳氶氷氹氺氻氼氾氿汃汄汅汈汋",4,"汑汒汓汖汘"],["9b40","汙汚汢汣汥汦汧汫",4,"汱汳汵汷汸決汻汼汿沀沄沇沊沋沍沎沑沒沕沖沗沘沚沜沝沞沠沢沨沬沯沰沴沵沶沷沺泀況泂泃泆泇泈泋泍泎泏泑泒泘"],["9b80","泙泚泜泝泟泤泦泧泩泬泭泲泴泹泿洀洂洃洅洆洈洉洊洍洏洐洑洓洔洕洖洘洜洝洟",5,"洦洨洩洬洭洯洰洴洶洷洸洺洿浀浂浄浉浌浐浕浖浗浘浛浝浟浡浢浤浥浧浨浫浬浭浰浱浲浳浵浶浹浺浻浽",4,"涃涄涆涇涊涋涍涏涐涒涖",4,"涜涢涥涬涭涰涱涳涴涶涷涹",5,"淁淂淃淈淉淊"],["9c40","淍淎淏淐淒淓淔淕淗淚淛淜淟淢淣淥淧淨淩淪淭淯淰淲淴淵淶淸淺淽",7,"渆渇済渉渋渏渒渓渕渘渙減渜渞渟渢渦渧渨渪測渮渰渱渳渵"],["9c80","渶渷渹渻",7,"湅",7,"湏湐湑湒湕湗湙湚湜湝湞湠",10,"湬湭湯",14,"満溁溂溄溇溈溊",4,"溑",6,"溙溚溛溝溞溠溡溣溤溦溨溩溫溬溭溮溰溳溵溸溹溼溾溿滀滃滄滅滆滈滉滊滌滍滎滐滒滖滘滙滛滜滝滣滧滪",5],["9d40","滰滱滲滳滵滶滷滸滺",7,"漃漄漅漇漈漊",4,"漐漑漒漖",9,"漡漢漣漥漦漧漨漬漮漰漲漴漵漷",6,"漿潀潁潂"],["9d80","潃潄潅潈潉潊潌潎",9,"潙潚潛潝潟潠潡潣潤潥潧",5,"潯潰潱潳潵潶潷潹潻潽",6,"澅澆澇澊澋澏",12,"澝澞澟澠澢",4,"澨",10,"澴澵澷澸澺",5,"濁濃",5,"濊",6,"濓",10,"濟濢濣濤濥"],["9e40","濦",7,"濰",32,"瀒",7,"瀜",6,"瀤",6],["9e80","瀫",9,"瀶瀷瀸瀺",17,"灍灎灐",13,"灟",11,"灮灱灲灳灴灷灹灺灻災炁炂炃炄炆炇炈炋炌炍炏炐炑炓炗炘炚炛炞",12,"炰炲炴炵炶為炾炿烄烅烆烇烉烋",12,"烚"],["9f40","烜烝烞烠烡烢烣烥烪烮烰",6,"烸烺烻烼烾",10,"焋",4,"焑焒焔焗焛",10,"焧",7,"焲焳焴"],["9f80","焵焷",13,"煆煇煈煉煋煍煏",12,"煝煟",4,"煥煩",4,"煯煰煱煴煵煶煷煹煻煼煾",5,"熅",4,"熋熌熍熎熐熑熒熓熕熖熗熚",4,"熡",6,"熩熪熫熭",5,"熴熶熷熸熺",8,"燄",9,"燏",4],["a040","燖",9,"燡燢燣燤燦燨",5,"燯",9,"燺",11,"爇",19],["a080","爛爜爞",9,"爩爫爭爮爯爲爳爴爺爼爾牀",6,"牉牊牋牎牏牐牑牓牔牕牗牘牚牜牞牠牣牤牥牨牪牫牬牭牰牱牳牴牶牷牸牻牼牽犂犃犅",4,"犌犎犐犑犓",11,"犠",11,"犮犱犲犳犵犺",6,"狅狆狇狉狊狋狌狏狑狓狔狕狖狘狚狛"],["a1a1","　、。·ˉˇ¨〃々—～‖…‘’“”〔〕〈",7,"〖〗【】±×÷∶∧∨∑∏∪∩∈∷√⊥∥∠⌒⊙∫∮≡≌≈∽∝≠≮≯≤≥∞∵∴♂♀°′″℃＄¤￠￡‰§№☆★○●◎◇◆□■△▲※→←↑↓〓"],["a2a1","ⅰ",9],["a2b1","⒈",19,"⑴",19,"①",9],["a2e5","㈠",9],["a2f1","Ⅰ",11],["a3a1","！＂＃￥％",88,"￣"],["a4a1","ぁ",82],["a5a1","ァ",85],["a6a1","Α",16,"Σ",6],["a6c1","α",16,"σ",6],["a6e0","︵︶︹︺︿﹀︽︾﹁﹂﹃﹄"],["a6ee","︻︼︷︸︱"],["a6f4","︳︴"],["a7a1","А",5,"ЁЖ",25],["a7d1","а",5,"ёж",25],["a840","ˊˋ˙–―‥‵℅℉↖↗↘↙∕∟∣≒≦≧⊿═",35,"▁",6],["a880","█",7,"▓▔▕▼▽◢◣◤◥☉⊕〒〝〞"],["a8a1","āáǎàēéěèīíǐìōóǒòūúǔùǖǘǚǜüêɑ"],["a8bd","ńň"],["a8c0","ɡ"],["a8c5","ㄅ",36],["a940","〡",8,"㊣㎎㎏㎜㎝㎞㎡㏄㏎㏑㏒㏕︰￢￤"],["a959","℡㈱"],["a95c","‐"],["a960","ー゛゜ヽヾ〆ゝゞ﹉",9,"﹔﹕﹖﹗﹙",8],["a980","﹢",4,"﹨﹩﹪﹫"],["a996","〇"],["a9a4","─",75],["aa40","狜狝狟狢",5,"狪狫狵狶狹狽狾狿猀猂猄",5,"猋猌猍猏猐猑猒猔猘猙猚猟猠猣猤猦猧猨猭猯猰猲猳猵猶猺猻猼猽獀",8],["aa80","獉獊獋獌獎獏獑獓獔獕獖獘",7,"獡",10,"獮獰獱"],["ab40","獲",11,"獿",4,"玅玆玈玊玌玍玏玐玒玓玔玕玗玘玙玚玜玝玞玠玡玣",5,"玪玬玭玱玴玵玶玸玹玼玽玾玿珁珃",4],["ab80","珋珌珎珒",6,"珚珛珜珝珟珡珢珣珤珦珨珪珫珬珮珯珰珱珳",4],["ac40","珸",10,"琄琇琈琋琌琍琎琑",8,"琜",5,"琣琤琧琩琫琭琯琱琲琷",4,"琽琾琿瑀瑂",11],["ac80","瑎",6,"瑖瑘瑝瑠",12,"瑮瑯瑱",4,"瑸瑹瑺"],["ad40","瑻瑼瑽瑿璂璄璅璆璈璉璊璌璍璏璑",10,"璝璟",7,"璪",15,"璻",12],["ad80","瓈",9,"瓓",8,"瓝瓟瓡瓥瓧",6,"瓰瓱瓲"],["ae40","瓳瓵瓸",6,"甀甁甂甃甅",7,"甎甐甒甔甕甖甗甛甝甞甠",4,"甦甧甪甮甴甶甹甼甽甿畁畂畃畄畆畇畉畊畍畐畑畒畓畕畖畗畘"],["ae80","畝",7,"畧畨畩畫",6,"畳畵當畷畺",4,"疀疁疂疄疅疇"],["af40","疈疉疊疌疍疎疐疓疕疘疛疜疞疢疦",4,"疭疶疷疺疻疿痀痁痆痋痌痎痏痐痑痓痗痙痚痜痝痟痠痡痥痩痬痭痮痯痲痳痵痶痷痸痺痻痽痾瘂瘄瘆瘇"],["af80","瘈瘉瘋瘍瘎瘏瘑瘒瘓瘔瘖瘚瘜瘝瘞瘡瘣瘧瘨瘬瘮瘯瘱瘲瘶瘷瘹瘺瘻瘽癁療癄"],["b040","癅",6,"癎",5,"癕癗",4,"癝癟癠癡癢癤",6,"癬癭癮癰",7,"癹発發癿皀皁皃皅皉皊皌皍皏皐皒皔皕皗皘皚皛"],["b080","皜",7,"皥",8,"皯皰皳皵",9,"盀盁盃啊阿埃挨哎唉哀皑癌蔼矮艾碍爱隘鞍氨安俺按暗岸胺案肮昂盎凹敖熬翱袄傲奥懊澳芭捌扒叭吧笆八疤巴拔跋靶把耙坝霸罢爸白柏百摆佰败拜稗斑班搬扳般颁板版扮拌伴瓣半办绊邦帮梆榜膀绑棒磅蚌镑傍谤苞胞包褒剥"],["b140","盄盇盉盋盌盓盕盙盚盜盝盞盠",4,"盦",7,"盰盳盵盶盷盺盻盽盿眀眂眃眅眆眊県眎",10,"眛眜眝眞眡眣眤眥眧眪眫"],["b180","眬眮眰",4,"眹眻眽眾眿睂睄睅睆睈",7,"睒",7,"睜薄雹保堡饱宝抱报暴豹鲍爆杯碑悲卑北辈背贝钡倍狈备惫焙被奔苯本笨崩绷甭泵蹦迸逼鼻比鄙笔彼碧蓖蔽毕毙毖币庇痹闭敝弊必辟壁臂避陛鞭边编贬扁便变卞辨辩辫遍标彪膘表鳖憋别瘪彬斌濒滨宾摈兵冰柄丙秉饼炳"],["b240","睝睞睟睠睤睧睩睪睭",11,"睺睻睼瞁瞂瞃瞆",5,"瞏瞐瞓",11,"瞡瞣瞤瞦瞨瞫瞭瞮瞯瞱瞲瞴瞶",4],["b280","瞼瞾矀",12,"矎",8,"矘矙矚矝",4,"矤病并玻菠播拨钵波博勃搏铂箔伯帛舶脖膊渤泊驳捕卜哺补埠不布步簿部怖擦猜裁材才财睬踩采彩菜蔡餐参蚕残惭惨灿苍舱仓沧藏操糙槽曹草厕策侧册测层蹭插叉茬茶查碴搽察岔差诧拆柴豺搀掺蝉馋谗缠铲产阐颤昌猖"],["b340","矦矨矪矯矰矱矲矴矵矷矹矺矻矼砃",5,"砊砋砎砏砐砓砕砙砛砞砠砡砢砤砨砪砫砮砯砱砲砳砵砶砽砿硁硂硃硄硆硈硉硊硋硍硏硑硓硔硘硙硚"],["b380","硛硜硞",11,"硯",7,"硸硹硺硻硽",6,"场尝常长偿肠厂敞畅唱倡超抄钞朝嘲潮巢吵炒车扯撤掣彻澈郴臣辰尘晨忱沉陈趁衬撑称城橙成呈乘程惩澄诚承逞骋秤吃痴持匙池迟弛驰耻齿侈尺赤翅斥炽充冲虫崇宠抽酬畴踌稠愁筹仇绸瞅丑臭初出橱厨躇锄雏滁除楚"],["b440","碄碅碆碈碊碋碏碐碒碔碕碖碙碝碞碠碢碤碦碨",7,"碵碶碷碸確碻碼碽碿磀磂磃磄磆磇磈磌磍磎磏磑磒磓磖磗磘磚",9],["b480","磤磥磦磧磩磪磫磭",4,"磳磵磶磸磹磻",5,"礂礃礄礆",6,"础储矗搐触处揣川穿椽传船喘串疮窗幢床闯创吹炊捶锤垂春椿醇唇淳纯蠢戳绰疵茨磁雌辞慈瓷词此刺赐次聪葱囱匆从丛凑粗醋簇促蹿篡窜摧崔催脆瘁粹淬翠村存寸磋撮搓措挫错搭达答瘩打大呆歹傣戴带殆代贷袋待逮"],["b540","礍",5,"礔",9,"礟",4,"礥",14,"礵",4,"礽礿祂祃祄祅祇祊",8,"祔祕祘祙祡祣"],["b580","祤祦祩祪祫祬祮祰",6,"祹祻",4,"禂禃禆禇禈禉禋禌禍禎禐禑禒怠耽担丹单郸掸胆旦氮但惮淡诞弹蛋当挡党荡档刀捣蹈倒岛祷导到稻悼道盗德得的蹬灯登等瞪凳邓堤低滴迪敌笛狄涤翟嫡抵底地蒂第帝弟递缔颠掂滇碘点典靛垫电佃甸店惦奠淀殿碉叼雕凋刁掉吊钓调跌爹碟蝶迭谍叠"],["b640","禓",6,"禛",11,"禨",10,"禴",4,"禼禿秂秄秅秇秈秊秌秎秏秐秓秔秖秗秙",5,"秠秡秢秥秨秪"],["b680","秬秮秱",6,"秹秺秼秾秿稁稄稅稇稈稉稊稌稏",4,"稕稖稘稙稛稜丁盯叮钉顶鼎锭定订丢东冬董懂动栋侗恫冻洞兜抖斗陡豆逗痘都督毒犊独读堵睹赌杜镀肚度渡妒端短锻段断缎堆兑队对墩吨蹲敦顿囤钝盾遁掇哆多夺垛躲朵跺舵剁惰堕蛾峨鹅俄额讹娥恶厄扼遏鄂饿恩而儿耳尔饵洱二"],["b740","稝稟稡稢稤",14,"稴稵稶稸稺稾穀",5,"穇",9,"穒",4,"穘",16],["b780","穩",6,"穱穲穳穵穻穼穽穾窂窅窇窉窊窋窌窎窏窐窓窔窙窚窛窞窡窢贰发罚筏伐乏阀法珐藩帆番翻樊矾钒繁凡烦反返范贩犯饭泛坊芳方肪房防妨仿访纺放菲非啡飞肥匪诽吠肺废沸费芬酚吩氛分纷坟焚汾粉奋份忿愤粪丰封枫蜂峰锋风疯烽逢冯缝讽奉凤佛否夫敷肤孵扶拂辐幅氟符伏俘服"],["b840","窣窤窧窩窪窫窮",4,"窴",10,"竀",10,"竌",9,"竗竘竚竛竜竝竡竢竤竧",5,"竮竰竱竲竳"],["b880","竴",4,"竻竼竾笀笁笂笅笇笉笌笍笎笐笒笓笖笗笘笚笜笝笟笡笢笣笧笩笭浮涪福袱弗甫抚辅俯釜斧脯腑府腐赴副覆赋复傅付阜父腹负富讣附妇缚咐噶嘎该改概钙盖溉干甘杆柑竿肝赶感秆敢赣冈刚钢缸肛纲岗港杠篙皋高膏羔糕搞镐稿告哥歌搁戈鸽胳疙割革葛格蛤阁隔铬个各给根跟耕更庚羹"],["b940","笯笰笲笴笵笶笷笹笻笽笿",5,"筆筈筊筍筎筓筕筗筙筜筞筟筡筣",10,"筯筰筳筴筶筸筺筼筽筿箁箂箃箄箆",6,"箎箏"],["b980","箑箒箓箖箘箙箚箛箞箟箠箣箤箥箮箯箰箲箳箵箶箷箹",7,"篂篃範埂耿梗工攻功恭龚供躬公宫弓巩汞拱贡共钩勾沟苟狗垢构购够辜菇咕箍估沽孤姑鼓古蛊骨谷股故顾固雇刮瓜剐寡挂褂乖拐怪棺关官冠观管馆罐惯灌贯光广逛瑰规圭硅归龟闺轨鬼诡癸桂柜跪贵刽辊滚棍锅郭国果裹过哈"],["ba40","篅篈築篊篋篍篎篏篐篒篔",4,"篛篜篞篟篠篢篣篤篧篨篩篫篬篭篯篰篲",4,"篸篹篺篻篽篿",7,"簈簉簊簍簎簐",5,"簗簘簙"],["ba80","簚",4,"簠",5,"簨簩簫",12,"簹",5,"籂骸孩海氦亥害骇酣憨邯韩含涵寒函喊罕翰撼捍旱憾悍焊汗汉夯杭航壕嚎豪毫郝好耗号浩呵喝荷菏核禾和何合盒貉阂河涸赫褐鹤贺嘿黑痕很狠恨哼亨横衡恒轰哄烘虹鸿洪宏弘红喉侯猴吼厚候后呼乎忽瑚壶葫胡蝴狐糊湖"],["bb40","籃",9,"籎",36,"籵",5,"籾",9],["bb80","粈粊",6,"粓粔粖粙粚粛粠粡粣粦粧粨粩粫粬粭粯粰粴",4,"粺粻弧虎唬护互沪户花哗华猾滑画划化话槐徊怀淮坏欢环桓还缓换患唤痪豢焕涣宦幻荒慌黄磺蝗簧皇凰惶煌晃幌恍谎灰挥辉徽恢蛔回毁悔慧卉惠晦贿秽会烩汇讳诲绘荤昏婚魂浑混豁活伙火获或惑霍货祸击圾基机畸稽积箕"],["bc40","粿糀糂糃糄糆糉糋糎",6,"糘糚糛糝糞糡",6,"糩",5,"糰",7,"糹糺糼",13,"紋",5],["bc80","紑",14,"紡紣紤紥紦紨紩紪紬紭紮細",6,"肌饥迹激讥鸡姬绩缉吉极棘辑籍集及急疾汲即嫉级挤几脊己蓟技冀季伎祭剂悸济寄寂计记既忌际妓继纪嘉枷夹佳家加荚颊贾甲钾假稼价架驾嫁歼监坚尖笺间煎兼肩艰奸缄茧检柬碱硷拣捡简俭剪减荐槛鉴践贱见键箭件"],["bd40","紷",54,"絯",7],["bd80","絸",32,"健舰剑饯渐溅涧建僵姜将浆江疆蒋桨奖讲匠酱降蕉椒礁焦胶交郊浇骄娇嚼搅铰矫侥脚狡角饺缴绞剿教酵轿较叫窖揭接皆秸街阶截劫节桔杰捷睫竭洁结解姐戒藉芥界借介疥诫届巾筋斤金今津襟紧锦仅谨进靳晋禁近烬浸"],["be40","継",12,"綧",6,"綯",42],["be80","線",32,"尽劲荆兢茎睛晶鲸京惊精粳经井警景颈静境敬镜径痉靖竟竞净炯窘揪究纠玖韭久灸九酒厩救旧臼舅咎就疚鞠拘狙疽居驹菊局咀矩举沮聚拒据巨具距踞锯俱句惧炬剧捐鹃娟倦眷卷绢撅攫抉掘倔爵觉决诀绝均菌钧军君峻"],["bf40","緻",62],["bf80","縺縼",4,"繂",4,"繈",21,"俊竣浚郡骏喀咖卡咯开揩楷凯慨刊堪勘坎砍看康慷糠扛抗亢炕考拷烤靠坷苛柯棵磕颗科壳咳可渴克刻客课肯啃垦恳坑吭空恐孔控抠口扣寇枯哭窟苦酷库裤夸垮挎跨胯块筷侩快宽款匡筐狂框矿眶旷况亏盔岿窥葵奎魁傀"],["c040","繞",35,"纃",23,"纜纝纞"],["c080","纮纴纻纼绖绤绬绹缊缐缞缷缹缻",6,"罃罆",9,"罒罓馈愧溃坤昆捆困括扩廓阔垃拉喇蜡腊辣啦莱来赖蓝婪栏拦篮阑兰澜谰揽览懒缆烂滥琅榔狼廊郎朗浪捞劳牢老佬姥酪烙涝勒乐雷镭蕾磊累儡垒擂肋类泪棱楞冷厘梨犁黎篱狸离漓理李里鲤礼莉荔吏栗丽厉励砾历利傈例俐"],["c140","罖罙罛罜罝罞罠罣",4,"罫罬罭罯罰罳罵罶罷罸罺罻罼罽罿羀羂",7,"羋羍羏",4,"羕",4,"羛羜羠羢羣羥羦羨",6,"羱"],["c180","羳",4,"羺羻羾翀翂翃翄翆翇翈翉翋翍翏",4,"翖翗翙",5,"翢翣痢立粒沥隶力璃哩俩联莲连镰廉怜涟帘敛脸链恋炼练粮凉梁粱良两辆量晾亮谅撩聊僚疗燎寥辽潦了撂镣廖料列裂烈劣猎琳林磷霖临邻鳞淋凛赁吝拎玲菱零龄铃伶羚凌灵陵岭领另令溜琉榴硫馏留刘瘤流柳六龙聋咙笼窿"],["c240","翤翧翨翪翫翬翭翯翲翴",6,"翽翾翿耂耇耈耉耊耎耏耑耓耚耛耝耞耟耡耣耤耫",5,"耲耴耹耺耼耾聀聁聄聅聇聈聉聎聏聐聑聓聕聖聗"],["c280","聙聛",13,"聫",5,"聲",11,"隆垄拢陇楼娄搂篓漏陋芦卢颅庐炉掳卤虏鲁麓碌露路赂鹿潞禄录陆戮驴吕铝侣旅履屡缕虑氯律率滤绿峦挛孪滦卵乱掠略抡轮伦仑沦纶论萝螺罗逻锣箩骡裸落洛骆络妈麻玛码蚂马骂嘛吗埋买麦卖迈脉瞒馒蛮满蔓曼慢漫"],["c340","聾肁肂肅肈肊肍",5,"肔肕肗肙肞肣肦肧肨肬肰肳肵肶肸肹肻胅胇",4,"胏",6,"胘胟胠胢胣胦胮胵胷胹胻胾胿脀脁脃脄脅脇脈脋"],["c380","脌脕脗脙脛脜脝脟",12,"脭脮脰脳脴脵脷脹",4,"脿谩芒茫盲氓忙莽猫茅锚毛矛铆卯茂冒帽貌贸么玫枚梅酶霉煤没眉媒镁每美昧寐妹媚门闷们萌蒙檬盟锰猛梦孟眯醚靡糜迷谜弥米秘觅泌蜜密幂棉眠绵冕免勉娩缅面苗描瞄藐秒渺庙妙蔑灭民抿皿敏悯闽明螟鸣铭名命谬摸"],["c440","腀",5,"腇腉腍腎腏腒腖腗腘腛",4,"腡腢腣腤腦腨腪腫腬腯腲腳腵腶腷腸膁膃",4,"膉膋膌膍膎膐膒",5,"膙膚膞",4,"膤膥"],["c480","膧膩膫",7,"膴",5,"膼膽膾膿臄臅臇臈臉臋臍",6,"摹蘑模膜磨摩魔抹末莫墨默沫漠寞陌谋牟某拇牡亩姆母墓暮幕募慕木目睦牧穆拿哪呐钠那娜纳氖乃奶耐奈南男难囊挠脑恼闹淖呢馁内嫩能妮霓倪泥尼拟你匿腻逆溺蔫拈年碾撵捻念娘酿鸟尿捏聂孽啮镊镍涅您柠狞凝宁"],["c540","臔",14,"臤臥臦臨臩臫臮",4,"臵",5,"臽臿舃與",4,"舎舏舑舓舕",5,"舝舠舤舥舦舧舩舮舲舺舼舽舿"],["c580","艀艁艂艃艅艆艈艊艌艍艎艐",7,"艙艛艜艝艞艠",7,"艩拧泞牛扭钮纽脓浓农弄奴努怒女暖虐疟挪懦糯诺哦欧鸥殴藕呕偶沤啪趴爬帕怕琶拍排牌徘湃派攀潘盘磐盼畔判叛乓庞旁耪胖抛咆刨炮袍跑泡呸胚培裴赔陪配佩沛喷盆砰抨烹澎彭蓬棚硼篷膨朋鹏捧碰坯砒霹批披劈琵毗"],["c640","艪艫艬艭艱艵艶艷艸艻艼芀芁芃芅芆芇芉芌芐芓芔芕芖芚芛芞芠芢芣芧芲芵芶芺芻芼芿苀苂苃苅苆苉苐苖苙苚苝苢苧苨苩苪苬苭苮苰苲苳苵苶苸"],["c680","苺苼",4,"茊茋茍茐茒茓茖茘茙茝",9,"茩茪茮茰茲茷茻茽啤脾疲皮匹痞僻屁譬篇偏片骗飘漂瓢票撇瞥拼频贫品聘乒坪苹萍平凭瓶评屏坡泼颇婆破魄迫粕剖扑铺仆莆葡菩蒲埔朴圃普浦谱曝瀑期欺栖戚妻七凄漆柒沏其棋奇歧畦崎脐齐旗祈祁骑起岂乞企启契砌器气迄弃汽泣讫掐"],["c740","茾茿荁荂荄荅荈荊",4,"荓荕",4,"荝荢荰",6,"荹荺荾",6,"莇莈莊莋莌莍莏莐莑莔莕莖莗莙莚莝莟莡",6,"莬莭莮"],["c780","莯莵莻莾莿菂菃菄菆菈菉菋菍菎菐菑菒菓菕菗菙菚菛菞菢菣菤菦菧菨菫菬菭恰洽牵扦钎铅千迁签仟谦乾黔钱钳前潜遣浅谴堑嵌欠歉枪呛腔羌墙蔷强抢橇锹敲悄桥瞧乔侨巧鞘撬翘峭俏窍切茄且怯窃钦侵亲秦琴勤芹擒禽寝沁青轻氢倾卿清擎晴氰情顷请庆琼穷秋丘邱球求囚酋泅趋区蛆曲躯屈驱渠"],["c840","菮華菳",4,"菺菻菼菾菿萀萂萅萇萈萉萊萐萒",5,"萙萚萛萞",5,"萩",7,"萲",5,"萹萺萻萾",7,"葇葈葉"],["c880","葊",6,"葒",4,"葘葝葞葟葠葢葤",4,"葪葮葯葰葲葴葷葹葻葼取娶龋趣去圈颧权醛泉全痊拳犬券劝缺炔瘸却鹊榷确雀裙群然燃冉染瓤壤攘嚷让饶扰绕惹热壬仁人忍韧任认刃妊纫扔仍日戎茸蓉荣融熔溶容绒冗揉柔肉茹蠕儒孺如辱乳汝入褥软阮蕊瑞锐闰润若弱撒洒萨腮鳃塞赛三叁"],["c940","葽",4,"蒃蒄蒅蒆蒊蒍蒏",7,"蒘蒚蒛蒝蒞蒟蒠蒢",12,"蒰蒱蒳蒵蒶蒷蒻蒼蒾蓀蓂蓃蓅蓆蓇蓈蓋蓌蓎蓏蓒蓔蓕蓗"],["c980","蓘",4,"蓞蓡蓢蓤蓧",4,"蓭蓮蓯蓱",10,"蓽蓾蔀蔁蔂伞散桑嗓丧搔骚扫嫂瑟色涩森僧莎砂杀刹沙纱傻啥煞筛晒珊苫杉山删煽衫闪陕擅赡膳善汕扇缮墒伤商赏晌上尚裳梢捎稍烧芍勺韶少哨邵绍奢赊蛇舌舍赦摄射慑涉社设砷申呻伸身深娠绅神沈审婶甚肾慎渗声生甥牲升绳"],["ca40","蔃",8,"蔍蔎蔏蔐蔒蔔蔕蔖蔘蔙蔛蔜蔝蔞蔠蔢",8,"蔭",9,"蔾",4,"蕄蕅蕆蕇蕋",10],["ca80","蕗蕘蕚蕛蕜蕝蕟",4,"蕥蕦蕧蕩",8,"蕳蕵蕶蕷蕸蕼蕽蕿薀薁省盛剩胜圣师失狮施湿诗尸虱十石拾时什食蚀实识史矢使屎驶始式示士世柿事拭誓逝势是嗜噬适仕侍释饰氏市恃室视试收手首守寿授售受瘦兽蔬枢梳殊抒输叔舒淑疏书赎孰熟薯暑曙署蜀黍鼠属术述树束戍竖墅庶数漱"],["cb40","薂薃薆薈",6,"薐",10,"薝",6,"薥薦薧薩薫薬薭薱",5,"薸薺",6,"藂",6,"藊",4,"藑藒"],["cb80","藔藖",5,"藝",6,"藥藦藧藨藪",14,"恕刷耍摔衰甩帅栓拴霜双爽谁水睡税吮瞬顺舜说硕朔烁斯撕嘶思私司丝死肆寺嗣四伺似饲巳松耸怂颂送宋讼诵搜艘擞嗽苏酥俗素速粟僳塑溯宿诉肃酸蒜算虽隋随绥髓碎岁穗遂隧祟孙损笋蓑梭唆缩琐索锁所塌他它她塔"],["cc40","藹藺藼藽藾蘀",4,"蘆",10,"蘒蘓蘔蘕蘗",15,"蘨蘪",13,"蘹蘺蘻蘽蘾蘿虀"],["cc80","虁",11,"虒虓處",4,"虛虜虝號虠虡虣",7,"獭挞蹋踏胎苔抬台泰酞太态汰坍摊贪瘫滩坛檀痰潭谭谈坦毯袒碳探叹炭汤塘搪堂棠膛唐糖倘躺淌趟烫掏涛滔绦萄桃逃淘陶讨套特藤腾疼誊梯剔踢锑提题蹄啼体替嚏惕涕剃屉天添填田甜恬舔腆挑条迢眺跳贴铁帖厅听烃"],["cd40","虭虯虰虲",6,"蚃",6,"蚎",4,"蚔蚖",5,"蚞",4,"蚥蚦蚫蚭蚮蚲蚳蚷蚸蚹蚻",4,"蛁蛂蛃蛅蛈蛌蛍蛒蛓蛕蛖蛗蛚蛜"],["cd80","蛝蛠蛡蛢蛣蛥蛦蛧蛨蛪蛫蛬蛯蛵蛶蛷蛺蛻蛼蛽蛿蜁蜄蜅蜆蜋蜌蜎蜏蜐蜑蜔蜖汀廷停亭庭挺艇通桐酮瞳同铜彤童桶捅筒统痛偷投头透凸秃突图徒途涂屠土吐兔湍团推颓腿蜕褪退吞屯臀拖托脱鸵陀驮驼椭妥拓唾挖哇蛙洼娃瓦袜歪外豌弯湾玩顽丸烷完碗挽晚皖惋宛婉万腕汪王亡枉网往旺望忘妄威"],["ce40","蜙蜛蜝蜟蜠蜤蜦蜧蜨蜪蜫蜬蜭蜯蜰蜲蜳蜵蜶蜸蜹蜺蜼蜽蝀",6,"蝊蝋蝍蝏蝐蝑蝒蝔蝕蝖蝘蝚",5,"蝡蝢蝦",7,"蝯蝱蝲蝳蝵"],["ce80","蝷蝸蝹蝺蝿螀螁螄螆螇螉螊螌螎",4,"螔螕螖螘",6,"螠",4,"巍微危韦违桅围唯惟为潍维苇萎委伟伪尾纬未蔚味畏胃喂魏位渭谓尉慰卫瘟温蚊文闻纹吻稳紊问嗡翁瓮挝蜗涡窝我斡卧握沃巫呜钨乌污诬屋无芜梧吾吴毋武五捂午舞伍侮坞戊雾晤物勿务悟误昔熙析西硒矽晰嘻吸锡牺"],["cf40","螥螦螧螩螪螮螰螱螲螴螶螷螸螹螻螼螾螿蟁",4,"蟇蟈蟉蟌",4,"蟔",6,"蟜蟝蟞蟟蟡蟢蟣蟤蟦蟧蟨蟩蟫蟬蟭蟯",9],["cf80","蟺蟻蟼蟽蟿蠀蠁蠂蠄",5,"蠋",7,"蠔蠗蠘蠙蠚蠜",4,"蠣稀息希悉膝夕惜熄烯溪汐犀檄袭席习媳喜铣洗系隙戏细瞎虾匣霞辖暇峡侠狭下厦夏吓掀锨先仙鲜纤咸贤衔舷闲涎弦嫌显险现献县腺馅羡宪陷限线相厢镶香箱襄湘乡翔祥详想响享项巷橡像向象萧硝霄削哮嚣销消宵淆晓"],["d040","蠤",13,"蠳",5,"蠺蠻蠽蠾蠿衁衂衃衆",5,"衎",5,"衕衖衘衚",6,"衦衧衪衭衯衱衳衴衵衶衸衹衺"],["d080","衻衼袀袃袆袇袉袊袌袎袏袐袑袓袔袕袗",4,"袝",4,"袣袥",5,"小孝校肖啸笑效楔些歇蝎鞋协挟携邪斜胁谐写械卸蟹懈泄泻谢屑薪芯锌欣辛新忻心信衅星腥猩惺兴刑型形邢行醒幸杏性姓兄凶胸匈汹雄熊休修羞朽嗅锈秀袖绣墟戌需虚嘘须徐许蓄酗叙旭序畜恤絮婿绪续轩喧宣悬旋玄"],["d140","袬袮袯袰袲",4,"袸袹袺袻袽袾袿裀裃裄裇裈裊裋裌裍裏裐裑裓裖裗裚",4,"裠裡裦裧裩",6,"裲裵裶裷裺裻製裿褀褁褃",5],["d180","褉褋",4,"褑褔",4,"褜",4,"褢褣褤褦褧褨褩褬褭褮褯褱褲褳褵褷选癣眩绚靴薛学穴雪血勋熏循旬询寻驯巡殉汛训讯逊迅压押鸦鸭呀丫芽牙蚜崖衙涯雅哑亚讶焉咽阉烟淹盐严研蜒岩延言颜阎炎沿奄掩眼衍演艳堰燕厌砚雁唁彦焰宴谚验殃央鸯秧杨扬佯疡羊洋阳氧仰痒养样漾邀腰妖瑶"],["d240","褸",8,"襂襃襅",24,"襠",5,"襧",19,"襼"],["d280","襽襾覀覂覄覅覇",26,"摇尧遥窑谣姚咬舀药要耀椰噎耶爷野冶也页掖业叶曳腋夜液一壹医揖铱依伊衣颐夷遗移仪胰疑沂宜姨彝椅蚁倚已乙矣以艺抑易邑屹亿役臆逸肄疫亦裔意毅忆义益溢诣议谊译异翼翌绎茵荫因殷音阴姻吟银淫寅饮尹引隐"],["d340","覢",30,"觃觍觓觔觕觗觘觙觛觝觟觠觡觢觤觧觨觩觪觬觭觮觰觱觲觴",6],["d380","觻",4,"訁",5,"計",21,"印英樱婴鹰应缨莹萤营荧蝇迎赢盈影颖硬映哟拥佣臃痈庸雍踊蛹咏泳涌永恿勇用幽优悠忧尤由邮铀犹油游酉有友右佑釉诱又幼迂淤于盂榆虞愚舆余俞逾鱼愉渝渔隅予娱雨与屿禹宇语羽玉域芋郁吁遇喻峪御愈欲狱育誉"],["d440","訞",31,"訿",8,"詉",21],["d480","詟",25,"詺",6,"浴寓裕预豫驭鸳渊冤元垣袁原援辕园员圆猿源缘远苑愿怨院曰约越跃钥岳粤月悦阅耘云郧匀陨允运蕴酝晕韵孕匝砸杂栽哉灾宰载再在咱攒暂赞赃脏葬遭糟凿藻枣早澡蚤躁噪造皂灶燥责择则泽贼怎增憎曾赠扎喳渣札轧"],["d540","誁",7,"誋",7,"誔",46],["d580","諃",32,"铡闸眨栅榨咋乍炸诈摘斋宅窄债寨瞻毡詹粘沾盏斩辗崭展蘸栈占战站湛绽樟章彰漳张掌涨杖丈帐账仗胀瘴障招昭找沼赵照罩兆肇召遮折哲蛰辙者锗蔗这浙珍斟真甄砧臻贞针侦枕疹诊震振镇阵蒸挣睁征狰争怔整拯正政"],["d640","諤",34,"謈",27],["d680","謤謥謧",30,"帧症郑证芝枝支吱蜘知肢脂汁之织职直植殖执值侄址指止趾只旨纸志挚掷至致置帜峙制智秩稚质炙痔滞治窒中盅忠钟衷终种肿重仲众舟周州洲诌粥轴肘帚咒皱宙昼骤珠株蛛朱猪诸诛逐竹烛煮拄瞩嘱主著柱助蛀贮铸筑"],["d740","譆",31,"譧",4,"譭",25],["d780","讇",24,"讬讱讻诇诐诪谉谞住注祝驻抓爪拽专砖转撰赚篆桩庄装妆撞壮状椎锥追赘坠缀谆准捉拙卓桌琢茁酌啄着灼浊兹咨资姿滋淄孜紫仔籽滓子自渍字鬃棕踪宗综总纵邹走奏揍租足卒族祖诅阻组钻纂嘴醉最罪尊遵昨左佐柞做作坐座"],["d840","谸",8,"豂豃豄豅豈豊豋豍",7,"豖豗豘豙豛",5,"豣",6,"豬",6,"豴豵豶豷豻",6,"貃貄貆貇"],["d880","貈貋貍",6,"貕貖貗貙",20,"亍丌兀丐廿卅丕亘丞鬲孬噩丨禺丿匕乇夭爻卮氐囟胤馗毓睾鼗丶亟鼐乜乩亓芈孛啬嘏仄厍厝厣厥厮靥赝匚叵匦匮匾赜卦卣刂刈刎刭刳刿剀剌剞剡剜蒯剽劂劁劐劓冂罔亻仃仉仂仨仡仫仞伛仳伢佤仵伥伧伉伫佞佧攸佚佝"],["d940","貮",62],["d980","賭",32,"佟佗伲伽佶佴侑侉侃侏佾佻侪佼侬侔俦俨俪俅俚俣俜俑俟俸倩偌俳倬倏倮倭俾倜倌倥倨偾偃偕偈偎偬偻傥傧傩傺僖儆僭僬僦僮儇儋仝氽佘佥俎龠汆籴兮巽黉馘冁夔勹匍訇匐凫夙兕亠兖亳衮袤亵脔裒禀嬴蠃羸冫冱冽冼"],["da40","贎",14,"贠赑赒赗赟赥赨赩赪赬赮赯赱赲赸",8,"趂趃趆趇趈趉趌",4,"趒趓趕",9,"趠趡"],["da80","趢趤",12,"趲趶趷趹趻趽跀跁跂跅跇跈跉跊跍跐跒跓跔凇冖冢冥讠讦讧讪讴讵讷诂诃诋诏诎诒诓诔诖诘诙诜诟诠诤诨诩诮诰诳诶诹诼诿谀谂谄谇谌谏谑谒谔谕谖谙谛谘谝谟谠谡谥谧谪谫谮谯谲谳谵谶卩卺阝阢阡阱阪阽阼陂陉陔陟陧陬陲陴隈隍隗隰邗邛邝邙邬邡邴邳邶邺"],["db40","跕跘跙跜跠跡跢跥跦跧跩跭跮跰跱跲跴跶跼跾",6,"踆踇踈踋踍踎踐踑踒踓踕",7,"踠踡踤",4,"踫踭踰踲踳踴踶踷踸踻踼踾"],["db80","踿蹃蹅蹆蹌",4,"蹓",5,"蹚",11,"蹧蹨蹪蹫蹮蹱邸邰郏郅邾郐郄郇郓郦郢郜郗郛郫郯郾鄄鄢鄞鄣鄱鄯鄹酃酆刍奂劢劬劭劾哿勐勖勰叟燮矍廴凵凼鬯厶弁畚巯坌垩垡塾墼壅壑圩圬圪圳圹圮圯坜圻坂坩垅坫垆坼坻坨坭坶坳垭垤垌垲埏垧垴垓垠埕埘埚埙埒垸埴埯埸埤埝"],["dc40","蹳蹵蹷",4,"蹽蹾躀躂躃躄躆躈",6,"躑躒躓躕",6,"躝躟",11,"躭躮躰躱躳",6,"躻",7],["dc80","軃",10,"軏",21,"堋堍埽埭堀堞堙塄堠塥塬墁墉墚墀馨鼙懿艹艽艿芏芊芨芄芎芑芗芙芫芸芾芰苈苊苣芘芷芮苋苌苁芩芴芡芪芟苄苎芤苡茉苷苤茏茇苜苴苒苘茌苻苓茑茚茆茔茕苠苕茜荑荛荜茈莒茼茴茱莛荞茯荏荇荃荟荀茗荠茭茺茳荦荥"],["dd40","軥",62],["dd80","輤",32,"荨茛荩荬荪荭荮莰荸莳莴莠莪莓莜莅荼莶莩荽莸荻莘莞莨莺莼菁萁菥菘堇萘萋菝菽菖萜萸萑萆菔菟萏萃菸菹菪菅菀萦菰菡葜葑葚葙葳蒇蒈葺蒉葸萼葆葩葶蒌蒎萱葭蓁蓍蓐蓦蒽蓓蓊蒿蒺蓠蒡蒹蒴蒗蓥蓣蔌甍蔸蓰蔹蔟蔺"],["de40","轅",32,"轪辀辌辒辝辠辡辢辤辥辦辧辪辬辭辮辯農辳辴辵辷辸辺辻込辿迀迃迆"],["de80","迉",4,"迏迒迖迗迚迠迡迣迧迬迯迱迲迴迵迶迺迻迼迾迿逇逈逌逎逓逕逘蕖蔻蓿蓼蕙蕈蕨蕤蕞蕺瞢蕃蕲蕻薤薨薇薏蕹薮薜薅薹薷薰藓藁藜藿蘧蘅蘩蘖蘼廾弈夼奁耷奕奚奘匏尢尥尬尴扌扪抟抻拊拚拗拮挢拶挹捋捃掭揶捱捺掎掴捭掬掊捩掮掼揲揸揠揿揄揞揎摒揆掾摅摁搋搛搠搌搦搡摞撄摭撖"],["df40","這逜連逤逥逧",5,"逰",4,"逷逹逺逽逿遀遃遅遆遈",4,"過達違遖遙遚遜",5,"遤遦遧適遪遫遬遯",4,"遶",6,"遾邁"],["df80","還邅邆邇邉邊邌",4,"邒邔邖邘邚邜邞邟邠邤邥邧邨邩邫邭邲邷邼邽邿郀摺撷撸撙撺擀擐擗擤擢攉攥攮弋忒甙弑卟叱叽叩叨叻吒吖吆呋呒呓呔呖呃吡呗呙吣吲咂咔呷呱呤咚咛咄呶呦咝哐咭哂咴哒咧咦哓哔呲咣哕咻咿哌哙哚哜咩咪咤哝哏哞唛哧唠哽唔哳唢唣唏唑唧唪啧喏喵啉啭啁啕唿啐唼"],["e040","郂郃郆郈郉郋郌郍郒郔郕郖郘郙郚郞郟郠郣郤郥郩郪郬郮郰郱郲郳郵郶郷郹郺郻郼郿鄀鄁鄃鄅",19,"鄚鄛鄜"],["e080","鄝鄟鄠鄡鄤",10,"鄰鄲",6,"鄺",8,"酄唷啖啵啶啷唳唰啜喋嗒喃喱喹喈喁喟啾嗖喑啻嗟喽喾喔喙嗪嗷嗉嘟嗑嗫嗬嗔嗦嗝嗄嗯嗥嗲嗳嗌嗍嗨嗵嗤辔嘞嘈嘌嘁嘤嘣嗾嘀嘧嘭噘嘹噗嘬噍噢噙噜噌噔嚆噤噱噫噻噼嚅嚓嚯囔囗囝囡囵囫囹囿圄圊圉圜帏帙帔帑帱帻帼"],["e140","酅酇酈酑酓酔酕酖酘酙酛酜酟酠酦酧酨酫酭酳酺酻酼醀",4,"醆醈醊醎醏醓",6,"醜",5,"醤",5,"醫醬醰醱醲醳醶醷醸醹醻"],["e180","醼",10,"釈釋釐釒",9,"針",8,"帷幄幔幛幞幡岌屺岍岐岖岈岘岙岑岚岜岵岢岽岬岫岱岣峁岷峄峒峤峋峥崂崃崧崦崮崤崞崆崛嵘崾崴崽嵬嵛嵯嵝嵫嵋嵊嵩嵴嶂嶙嶝豳嶷巅彳彷徂徇徉後徕徙徜徨徭徵徼衢彡犭犰犴犷犸狃狁狎狍狒狨狯狩狲狴狷猁狳猃狺"],["e240","釦",62],["e280","鈥",32,"狻猗猓猡猊猞猝猕猢猹猥猬猸猱獐獍獗獠獬獯獾舛夥飧夤夂饣饧",5,"饴饷饽馀馄馇馊馍馐馑馓馔馕庀庑庋庖庥庠庹庵庾庳赓廒廑廛廨廪膺忄忉忖忏怃忮怄忡忤忾怅怆忪忭忸怙怵怦怛怏怍怩怫怊怿怡恸恹恻恺恂"],["e340","鉆",45,"鉵",16],["e380","銆",7,"銏",24,"恪恽悖悚悭悝悃悒悌悛惬悻悱惝惘惆惚悴愠愦愕愣惴愀愎愫慊慵憬憔憧憷懔懵忝隳闩闫闱闳闵闶闼闾阃阄阆阈阊阋阌阍阏阒阕阖阗阙阚丬爿戕氵汔汜汊沣沅沐沔沌汨汩汴汶沆沩泐泔沭泷泸泱泗沲泠泖泺泫泮沱泓泯泾"],["e440","銨",5,"銯",24,"鋉",31],["e480","鋩",32,"洹洧洌浃浈洇洄洙洎洫浍洮洵洚浏浒浔洳涑浯涞涠浞涓涔浜浠浼浣渚淇淅淞渎涿淠渑淦淝淙渖涫渌涮渫湮湎湫溲湟溆湓湔渲渥湄滟溱溘滠漭滢溥溧溽溻溷滗溴滏溏滂溟潢潆潇漤漕滹漯漶潋潴漪漉漩澉澍澌潸潲潼潺濑"],["e540","錊",51,"錿",10],["e580","鍊",31,"鍫濉澧澹澶濂濡濮濞濠濯瀚瀣瀛瀹瀵灏灞宀宄宕宓宥宸甯骞搴寤寮褰寰蹇謇辶迓迕迥迮迤迩迦迳迨逅逄逋逦逑逍逖逡逵逶逭逯遄遑遒遐遨遘遢遛暹遴遽邂邈邃邋彐彗彖彘尻咫屐屙孱屣屦羼弪弩弭艴弼鬻屮妁妃妍妩妪妣"],["e640","鍬",34,"鎐",27],["e680","鎬",29,"鏋鏌鏍妗姊妫妞妤姒妲妯姗妾娅娆姝娈姣姘姹娌娉娲娴娑娣娓婀婧婊婕娼婢婵胬媪媛婷婺媾嫫媲嫒嫔媸嫠嫣嫱嫖嫦嫘嫜嬉嬗嬖嬲嬷孀尕尜孚孥孳孑孓孢驵驷驸驺驿驽骀骁骅骈骊骐骒骓骖骘骛骜骝骟骠骢骣骥骧纟纡纣纥纨纩"],["e740","鏎",7,"鏗",54],["e780","鐎",32,"纭纰纾绀绁绂绉绋绌绐绔绗绛绠绡绨绫绮绯绱绲缍绶绺绻绾缁缂缃缇缈缋缌缏缑缒缗缙缜缛缟缡",6,"缪缫缬缭缯",4,"缵幺畿巛甾邕玎玑玮玢玟珏珂珑玷玳珀珉珈珥珙顼琊珩珧珞玺珲琏琪瑛琦琥琨琰琮琬"],["e840","鐯",14,"鐿",43,"鑬鑭鑮鑯"],["e880","鑰",20,"钑钖钘铇铏铓铔铚铦铻锜锠琛琚瑁瑜瑗瑕瑙瑷瑭瑾璜璎璀璁璇璋璞璨璩璐璧瓒璺韪韫韬杌杓杞杈杩枥枇杪杳枘枧杵枨枞枭枋杷杼柰栉柘栊柩枰栌柙枵柚枳柝栀柃枸柢栎柁柽栲栳桠桡桎桢桄桤梃栝桕桦桁桧桀栾桊桉栩梵梏桴桷梓桫棂楮棼椟椠棹"],["e940","锧锳锽镃镈镋镕镚镠镮镴镵長",7,"門",42],["e980","閫",32,"椤棰椋椁楗棣椐楱椹楠楂楝榄楫榀榘楸椴槌榇榈槎榉楦楣楹榛榧榻榫榭槔榱槁槊槟榕槠榍槿樯槭樗樘橥槲橄樾檠橐橛樵檎橹樽樨橘橼檑檐檩檗檫猷獒殁殂殇殄殒殓殍殚殛殡殪轫轭轱轲轳轵轶轸轷轹轺轼轾辁辂辄辇辋"],["ea40","闌",27,"闬闿阇阓阘阛阞阠阣",6,"阫阬阭阯阰阷阸阹阺阾陁陃陊陎陏陑陒陓陖陗"],["ea80","陘陙陚陜陝陞陠陣陥陦陫陭",4,"陳陸",12,"隇隉隊辍辎辏辘辚軎戋戗戛戟戢戡戥戤戬臧瓯瓴瓿甏甑甓攴旮旯旰昊昙杲昃昕昀炅曷昝昴昱昶昵耆晟晔晁晏晖晡晗晷暄暌暧暝暾曛曜曦曩贲贳贶贻贽赀赅赆赈赉赇赍赕赙觇觊觋觌觎觏觐觑牮犟牝牦牯牾牿犄犋犍犏犒挈挲掰"],["eb40","隌階隑隒隓隕隖隚際隝",9,"隨",7,"隱隲隴隵隷隸隺隻隿雂雃雈雊雋雐雑雓雔雖",9,"雡",6,"雫"],["eb80","雬雭雮雰雱雲雴雵雸雺電雼雽雿霂霃霅霊霋霌霐霑霒霔霕霗",4,"霝霟霠搿擘耄毪毳毽毵毹氅氇氆氍氕氘氙氚氡氩氤氪氲攵敕敫牍牒牖爰虢刖肟肜肓肼朊肽肱肫肭肴肷胧胨胩胪胛胂胄胙胍胗朐胝胫胱胴胭脍脎胲胼朕脒豚脶脞脬脘脲腈腌腓腴腙腚腱腠腩腼腽腭腧塍媵膈膂膑滕膣膪臌朦臊膻"],["ec40","霡",8,"霫霬霮霯霱霳",4,"霺霻霼霽霿",18,"靔靕靗靘靚靜靝靟靣靤靦靧靨靪",7],["ec80","靲靵靷",4,"靽",7,"鞆",4,"鞌鞎鞏鞐鞓鞕鞖鞗鞙",4,"臁膦欤欷欹歃歆歙飑飒飓飕飙飚殳彀毂觳斐齑斓於旆旄旃旌旎旒旖炀炜炖炝炻烀炷炫炱烨烊焐焓焖焯焱煳煜煨煅煲煊煸煺熘熳熵熨熠燠燔燧燹爝爨灬焘煦熹戾戽扃扈扉礻祀祆祉祛祜祓祚祢祗祠祯祧祺禅禊禚禧禳忑忐"],["ed40","鞞鞟鞡鞢鞤",6,"鞬鞮鞰鞱鞳鞵",46],["ed80","韤韥韨韮",4,"韴韷",23,"怼恝恚恧恁恙恣悫愆愍慝憩憝懋懑戆肀聿沓泶淼矶矸砀砉砗砘砑斫砭砜砝砹砺砻砟砼砥砬砣砩硎硭硖硗砦硐硇硌硪碛碓碚碇碜碡碣碲碹碥磔磙磉磬磲礅磴礓礤礞礴龛黹黻黼盱眄眍盹眇眈眚眢眙眭眦眵眸睐睑睇睃睚睨"],["ee40","頏",62],["ee80","顎",32,"睢睥睿瞍睽瞀瞌瞑瞟瞠瞰瞵瞽町畀畎畋畈畛畲畹疃罘罡罟詈罨罴罱罹羁罾盍盥蠲钅钆钇钋钊钌钍钏钐钔钗钕钚钛钜钣钤钫钪钭钬钯钰钲钴钶",4,"钼钽钿铄铈",6,"铐铑铒铕铖铗铙铘铛铞铟铠铢铤铥铧铨铪"],["ef40","顯",5,"颋颎颒颕颙颣風",37,"飏飐飔飖飗飛飜飝飠",4],["ef80","飥飦飩",30,"铩铫铮铯铳铴铵铷铹铼铽铿锃锂锆锇锉锊锍锎锏锒",4,"锘锛锝锞锟锢锪锫锩锬锱锲锴锶锷锸锼锾锿镂锵镄镅镆镉镌镎镏镒镓镔镖镗镘镙镛镞镟镝镡镢镤",8,"镯镱镲镳锺矧矬雉秕秭秣秫稆嵇稃稂稞稔"],["f040","餈",4,"餎餏餑",28,"餯",26],["f080","饊",9,"饖",12,"饤饦饳饸饹饻饾馂馃馉稹稷穑黏馥穰皈皎皓皙皤瓞瓠甬鸠鸢鸨",4,"鸲鸱鸶鸸鸷鸹鸺鸾鹁鹂鹄鹆鹇鹈鹉鹋鹌鹎鹑鹕鹗鹚鹛鹜鹞鹣鹦",6,"鹱鹭鹳疒疔疖疠疝疬疣疳疴疸痄疱疰痃痂痖痍痣痨痦痤痫痧瘃痱痼痿瘐瘀瘅瘌瘗瘊瘥瘘瘕瘙"],["f140","馌馎馚",10,"馦馧馩",47],["f180","駙",32,"瘛瘼瘢瘠癀瘭瘰瘿瘵癃瘾瘳癍癞癔癜癖癫癯翊竦穸穹窀窆窈窕窦窠窬窨窭窳衤衩衲衽衿袂袢裆袷袼裉裢裎裣裥裱褚裼裨裾裰褡褙褓褛褊褴褫褶襁襦襻疋胥皲皴矜耒耔耖耜耠耢耥耦耧耩耨耱耋耵聃聆聍聒聩聱覃顸颀颃"],["f240","駺",62],["f280","騹",32,"颉颌颍颏颔颚颛颞颟颡颢颥颦虍虔虬虮虿虺虼虻蚨蚍蚋蚬蚝蚧蚣蚪蚓蚩蚶蛄蚵蛎蚰蚺蚱蚯蛉蛏蚴蛩蛱蛲蛭蛳蛐蜓蛞蛴蛟蛘蛑蜃蜇蛸蜈蜊蜍蜉蜣蜻蜞蜥蜮蜚蜾蝈蜴蜱蜩蜷蜿螂蜢蝽蝾蝻蝠蝰蝌蝮螋蝓蝣蝼蝤蝙蝥螓螯螨蟒"],["f340","驚",17,"驲骃骉骍骎骔骕骙骦骩",6,"骲骳骴骵骹骻骽骾骿髃髄髆",4,"髍髎髏髐髒體髕髖髗髙髚髛髜"],["f380","髝髞髠髢髣髤髥髧髨髩髪髬髮髰",8,"髺髼",6,"鬄鬅鬆蟆螈螅螭螗螃螫蟥螬螵螳蟋蟓螽蟑蟀蟊蟛蟪蟠蟮蠖蠓蟾蠊蠛蠡蠹蠼缶罂罄罅舐竺竽笈笃笄笕笊笫笏筇笸笪笙笮笱笠笥笤笳笾笞筘筚筅筵筌筝筠筮筻筢筲筱箐箦箧箸箬箝箨箅箪箜箢箫箴篑篁篌篝篚篥篦篪簌篾篼簏簖簋"],["f440","鬇鬉",5,"鬐鬑鬒鬔",10,"鬠鬡鬢鬤",10,"鬰鬱鬳",7,"鬽鬾鬿魀魆魊魋魌魎魐魒魓魕",5],["f480","魛",32,"簟簪簦簸籁籀臾舁舂舄臬衄舡舢舣舭舯舨舫舸舻舳舴舾艄艉艋艏艚艟艨衾袅袈裘裟襞羝羟羧羯羰羲籼敉粑粝粜粞粢粲粼粽糁糇糌糍糈糅糗糨艮暨羿翎翕翥翡翦翩翮翳糸絷綦綮繇纛麸麴赳趄趔趑趱赧赭豇豉酊酐酎酏酤"],["f540","魼",62],["f580","鮻",32,"酢酡酰酩酯酽酾酲酴酹醌醅醐醍醑醢醣醪醭醮醯醵醴醺豕鹾趸跫踅蹙蹩趵趿趼趺跄跖跗跚跞跎跏跛跆跬跷跸跣跹跻跤踉跽踔踝踟踬踮踣踯踺蹀踹踵踽踱蹉蹁蹂蹑蹒蹊蹰蹶蹼蹯蹴躅躏躔躐躜躞豸貂貊貅貘貔斛觖觞觚觜"],["f640","鯜",62],["f680","鰛",32,"觥觫觯訾謦靓雩雳雯霆霁霈霏霎霪霭霰霾龀龃龅",5,"龌黾鼋鼍隹隼隽雎雒瞿雠銎銮鋈錾鍪鏊鎏鐾鑫鱿鲂鲅鲆鲇鲈稣鲋鲎鲐鲑鲒鲔鲕鲚鲛鲞",5,"鲥",4,"鲫鲭鲮鲰",7,"鲺鲻鲼鲽鳄鳅鳆鳇鳊鳋"],["f740","鰼",62],["f780","鱻鱽鱾鲀鲃鲄鲉鲊鲌鲏鲓鲖鲗鲘鲙鲝鲪鲬鲯鲹鲾",4,"鳈鳉鳑鳒鳚鳛鳠鳡鳌",4,"鳓鳔鳕鳗鳘鳙鳜鳝鳟鳢靼鞅鞑鞒鞔鞯鞫鞣鞲鞴骱骰骷鹘骶骺骼髁髀髅髂髋髌髑魅魃魇魉魈魍魑飨餍餮饕饔髟髡髦髯髫髻髭髹鬈鬏鬓鬟鬣麽麾縻麂麇麈麋麒鏖麝麟黛黜黝黠黟黢黩黧黥黪黯鼢鼬鼯鼹鼷鼽鼾齄"],["f840","鳣",62],["f880","鴢",32],["f940","鵃",62],["f980","鶂",32],["fa40","鶣",62],["fa80","鷢",32],["fb40","鸃",27,"鸤鸧鸮鸰鸴鸻鸼鹀鹍鹐鹒鹓鹔鹖鹙鹝鹟鹠鹡鹢鹥鹮鹯鹲鹴",9,"麀"],["fb80","麁麃麄麅麆麉麊麌",5,"麔",8,"麞麠",5,"麧麨麩麪"],["fc40","麫",8,"麵麶麷麹麺麼麿",4,"黅黆黇黈黊黋黌黐黒黓黕黖黗黙黚點黡黣黤黦黨黫黬黭黮黰",8,"黺黽黿",6],["fc80","鼆",4,"鼌鼏鼑鼒鼔鼕鼖鼘鼚",5,"鼡鼣",8,"鼭鼮鼰鼱"],["fd40","鼲",4,"鼸鼺鼼鼿",4,"齅",10,"齒",38],["fd80","齹",5,"龁龂龍",11,"龜龝龞龡",4,"郎凉秊裏隣"],["fe40","兀嗀﨎﨏﨑﨓﨔礼﨟蘒﨡﨣﨤﨧﨨﨩"]]')},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(4),t=n(7).Module,e.exports=function(e){function t(e,t){this.layer=e,this.parent=null!=t?t:null,this.layer.node=this,this._children=[],this.name=this.layer.name,this.forceVisible=null,this.coords={top:this.layer.top,bottom:this.layer.bottom,left:this.layer.left,right:this.layer.right},this.topOffset=0,this.leftOffset=0,this.createProperties()}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.includes(n(130)),t.includes(n(131)),t.includes(n(132)),t.PROPERTIES=["name","left","right","top","bottom","height","width"],t.prototype.type="node",t.prototype.createProperties=function(){return Object.defineProperty(this,"top",{get:function(){return this.coords.top+this.topOffset},set:function(e){return this.coords.top=e}}),Object.defineProperty(this,"right",{get:function(){return this.coords.right+this.leftOffset},set:function(e){return this.coords.right=e}}),Object.defineProperty(this,"bottom",{get:function(){return this.coords.bottom+this.topOffset},set:function(e){return this.coords.bottom=e}}),Object.defineProperty(this,"left",{get:function(){return this.coords.left+this.leftOffset},set:function(e){return this.coords.left=e}}),Object.defineProperty(this,"width",{get:function(){return this.right-this.left}}),Object.defineProperty(this,"height",{get:function(){return this.bottom-this.top}})},t.prototype.get=function(e){var t;return"function"==typeof(t=null!=this[e]?this[e]:this.layer[e])?t():t},t.prototype.visible=function(){return!(this.layer.clipped&&!this.clippingMask().visible())&&(null!=this.forceVisible?this.forceVisible:this.layer.visible)},t.prototype.hidden=function(){return!this.visible()},t.prototype.isLayer=function(){return"layer"===this.type},t.prototype.isGroup=function(){return"group"===this.type},t.prototype.isRoot=function(){return"root"===this.type},t.prototype.clippingMask=function(){var e;return this.layer.clipped?this.clippingMaskCached||(this.clippingMaskCached=function(){for(e=this.nextSibling();e.clipped;)e=e.nextSibling();return e}.call(this)):null},t.prototype.clippedBy=function(){return this.clippingMask()},t.prototype.export=function(){var e,n,r,i,o;for(e={type:null,visible:this.visible(),opacity:this.layer.opacity/255,blendingMode:this.layer.blendingMode()},n=0,r=(o=t.PROPERTIES).length;n<r;n++)e[i=o[n]]=this[i];return e},t.prototype.updateDimensions=function(){var e,t,n,i;if(!this.isLayer()){for(e=0,t=(i=this._children).length;e<t;e++)i[e].updateDimensions();if(!this.isRoot())return n=this._children.filter((function(e){return!e.isEmpty()})),this.left=r.min(n.map((function(e){return e.left})))||0,this.top=r.min(n.map((function(e){return e.top})))||0,this.bottom=r.max(n.map((function(e){return e.bottom})))||0,this.right=r.max(n.map((function(e){return e.right})))||0}},t}(t)}).call(this)},function(e,t,n){"use strict";var r,i,o,a=n(31),s=n.n(a);r={},i={},o={},t.a={"獲取圖層":async function(e,t){var n,o,a;return r[e]||(r[e]=await s.a.fromURL(e)),o=r[e],n=[e,t].toString(),i[n]||(a=o.tree().childrenAtPath(t)[0],i[n]={"位置":a.coords,img:a.layer.image.toPng()}),i[n]},"獲取圖層組":async function(e,t){var n,r;return await async function(){var i;for(n in i=[],t)r=t[n],i.push(await this.獲取圖層(e,r));return i}.call(this)},"圖層融合":function(e){var t,n,r,i,o,a,s,u,c,l,f;for(0,l=Math.max.apply(Math,function(){var t,n,r;for(r=[],t=0,n=e.length;t<n;t++)c=e[t],r.push(c.位置.right);return r}()),f=Math.max.apply(Math,function(){var t,n,r;for(r=[],t=0,n=e.length;t<n;t++)c=e[t],r.push(c.位置.bottom);return r}()),(n=document.createElement("canvas")).width=l,n.height=f,r=n.getContext("2d"),i=0,a=e.length;i<a;i++)c=e[i],({left:o,top:u,bottom:t,right:s}=c.位置),r.drawImage(c.img,o,u);return[l,f,n.toDataURL("image/png")]},"融合到div":function(e,t,n,r,i){var o;return(o=document.getElementById(i)).style.transition=`background ${r}s, width ${r}s, height ${r}s`,o.style.width=t,o.style.height=n,o.style.backgroundImage=`url(${e})`},"渲染圖層組到div":async function(e,t,n){var r,i,a,s,u;return a=[e,t].toString(),o[a]||(u=await this.獲取圖層組(e,t),o[a]=this.圖層融合(u)),[s,i,r]=o[a],this.融合到div(r,s,i,.5,n)},"渲染png到div":function(e,t){var n;return(n=new Image).setAttribute("crossOrigin","Anonymous"),n.src=e,n.onload=()=>{var e,r,i;return[i,r,e]=this.圖層融合([{"位置":{top:0,left:0,bottom:n.height,right:n.width},img:n}]),this.融合到div(e,i,r,.5,t)}}}},function(e,t,n){(function(e){var r=void 0!==e&&e||"undefined"!=typeof self&&self||window,i=Function.prototype.apply;function o(e,t){this._id=e,this._clearFn=t}t.setTimeout=function(){return new o(i.call(setTimeout,r,arguments),clearTimeout)},t.setInterval=function(){return new o(i.call(setInterval,r,arguments),clearInterval)},t.clearTimeout=t.clearInterval=function(e){e&&e.close()},o.prototype.unref=o.prototype.ref=function(){},o.prototype.close=function(){this._clearFn.call(r,this._id)},t.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},t.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},t._unrefActive=t.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout((function(){e._onTimeout&&e._onTimeout()}),t))},n(40),t.setImmediate="undefined"!=typeof self&&self.setImmediate||void 0!==e&&e.setImmediate||this&&this.setImmediate,t.clearImmediate="undefined"!=typeof self&&self.clearImmediate||void 0!==e&&e.clearImmediate||this&&this.clearImmediate}).call(this,n(8))},function(e){e.exports=JSON.parse('[["a140","",62],["a180","",32],["a240","",62],["a280","",32],["a2ab","",5],["a2e3","€"],["a2ef",""],["a2fd",""],["a340","",62],["a380","",31,"　"],["a440","",62],["a480","",32],["a4f4","",10],["a540","",62],["a580","",32],["a5f7","",7],["a640","",62],["a680","",32],["a6b9","",7],["a6d9","",6],["a6ec",""],["a6f3",""],["a6f6","",8],["a740","",62],["a780","",32],["a7c2","",14],["a7f2","",12],["a896","",10],["a8bc",""],["a8bf","ǹ"],["a8c1",""],["a8ea","",20],["a958",""],["a95b",""],["a95d",""],["a989","〾⿰",11],["a997","",12],["a9f0","",14],["aaa1","",93],["aba1","",93],["aca1","",93],["ada1","",93],["aea1","",93],["afa1","",93],["d7fa","",4],["f8a1","",93],["f9a1","",93],["faa1","",93],["fba1","",93],["fca1","",93],["fda1","",93],["fe50","⺁⺄㑳㑇⺈⺋㖞㘚㘎⺌⺗㥮㤘㧏㧟㩳㧐㭎㱮㳠⺧⺪䁖䅟⺮䌷⺳⺶⺷䎱䎬⺻䏝䓖䙡䙌"],["fe80","䜣䜩䝼䞍⻊䥇䥺䥽䦂䦃䦅䦆䦟䦛䦷䦶䲣䲟䲠䲡䱷䲢䴓",6,"䶮",93]]')},function(e){e.exports=JSON.parse('[["0","\\u0000",127],["a140","　，、。．‧；：？！︰…‥﹐﹑﹒·﹔﹕﹖﹗｜–︱—︳╴︴﹏（）︵︶｛｝︷︸〔〕︹︺【】︻︼《》︽︾〈〉︿﹀「」﹁﹂『』﹃﹄﹙﹚"],["a1a1","﹛﹜﹝﹞‘’“”〝〞‵′＃＆＊※§〃○●△▲◎☆★◇◆□■▽▼㊣℅¯￣＿ˍ﹉﹊﹍﹎﹋﹌﹟﹠﹡＋－×÷±√＜＞＝≦≧≠∞≒≡﹢",4,"～∩∪⊥∠∟⊿㏒㏑∫∮∵∴♀♂⊕⊙↑↓←→↖↗↙↘∥∣／"],["a240","＼∕﹨＄￥〒￠￡％＠℃℉﹩﹪﹫㏕㎜㎝㎞㏎㎡㎎㎏㏄°兙兛兞兝兡兣嗧瓩糎▁",7,"▏▎▍▌▋▊▉┼┴┬┤├▔─│▕┌┐└┘╭"],["a2a1","╮╰╯═╞╪╡◢◣◥◤╱╲╳０",9,"Ⅰ",9,"〡",8,"十卄卅Ａ",25,"ａ",21],["a340","ｗｘｙｚΑ",16,"Σ",6,"α",16,"σ",6,"ㄅ",10],["a3a1","ㄐ",25,"˙ˉˊˇˋ"],["a3e1","€"],["a440","一乙丁七乃九了二人儿入八几刀刁力匕十卜又三下丈上丫丸凡久么也乞于亡兀刃勺千叉口土士夕大女子孑孓寸小尢尸山川工己已巳巾干廾弋弓才"],["a4a1","丑丐不中丰丹之尹予云井互五亢仁什仃仆仇仍今介仄元允內六兮公冗凶分切刈勻勾勿化匹午升卅卞厄友及反壬天夫太夭孔少尤尺屯巴幻廿弔引心戈戶手扎支文斗斤方日曰月木欠止歹毋比毛氏水火爪父爻片牙牛犬王丙"],["a540","世丕且丘主乍乏乎以付仔仕他仗代令仙仞充兄冉冊冬凹出凸刊加功包匆北匝仟半卉卡占卯卮去可古右召叮叩叨叼司叵叫另只史叱台句叭叻四囚外"],["a5a1","央失奴奶孕它尼巨巧左市布平幼弁弘弗必戊打扔扒扑斥旦朮本未末札正母民氐永汁汀氾犯玄玉瓜瓦甘生用甩田由甲申疋白皮皿目矛矢石示禾穴立丞丟乒乓乩亙交亦亥仿伉伙伊伕伍伐休伏仲件任仰仳份企伋光兇兆先全"],["a640","共再冰列刑划刎刖劣匈匡匠印危吉吏同吊吐吁吋各向名合吃后吆吒因回囝圳地在圭圬圯圩夙多夷夸妄奸妃好她如妁字存宇守宅安寺尖屹州帆并年"],["a6a1","式弛忙忖戎戌戍成扣扛托收早旨旬旭曲曳有朽朴朱朵次此死氖汝汗汙江池汐汕污汛汍汎灰牟牝百竹米糸缶羊羽老考而耒耳聿肉肋肌臣自至臼舌舛舟艮色艾虫血行衣西阡串亨位住佇佗佞伴佛何估佐佑伽伺伸佃佔似但佣"],["a740","作你伯低伶余佝佈佚兌克免兵冶冷別判利刪刨劫助努劬匣即卵吝吭吞吾否呎吧呆呃吳呈呂君吩告吹吻吸吮吵吶吠吼呀吱含吟听囪困囤囫坊坑址坍"],["a7a1","均坎圾坐坏圻壯夾妝妒妨妞妣妙妖妍妤妓妊妥孝孜孚孛完宋宏尬局屁尿尾岐岑岔岌巫希序庇床廷弄弟彤形彷役忘忌志忍忱快忸忪戒我抄抗抖技扶抉扭把扼找批扳抒扯折扮投抓抑抆改攻攸旱更束李杏材村杜杖杞杉杆杠"],["a840","杓杗步每求汞沙沁沈沉沅沛汪決沐汰沌汨沖沒汽沃汲汾汴沆汶沍沔沘沂灶灼災灸牢牡牠狄狂玖甬甫男甸皂盯矣私秀禿究系罕肖肓肝肘肛肚育良芒"],["a8a1","芋芍見角言谷豆豕貝赤走足身車辛辰迂迆迅迄巡邑邢邪邦那酉釆里防阮阱阪阬並乖乳事些亞享京佯依侍佳使佬供例來侃佰併侈佩佻侖佾侏侑佺兔兒兕兩具其典冽函刻券刷刺到刮制剁劾劻卒協卓卑卦卷卸卹取叔受味呵"],["a940","咖呸咕咀呻呷咄咒咆呼咐呱呶和咚呢周咋命咎固垃坷坪坩坡坦坤坼夜奉奇奈奄奔妾妻委妹妮姑姆姐姍始姓姊妯妳姒姅孟孤季宗定官宜宙宛尚屈居"],["a9a1","屆岷岡岸岩岫岱岳帘帚帖帕帛帑幸庚店府底庖延弦弧弩往征彿彼忝忠忽念忿怏怔怯怵怖怪怕怡性怩怫怛或戕房戾所承拉拌拄抿拂抹拒招披拓拔拋拈抨抽押拐拙拇拍抵拚抱拘拖拗拆抬拎放斧於旺昔易昌昆昂明昀昏昕昊"],["aa40","昇服朋杭枋枕東果杳杷枇枝林杯杰板枉松析杵枚枓杼杪杲欣武歧歿氓氛泣注泳沱泌泥河沽沾沼波沫法泓沸泄油況沮泗泅泱沿治泡泛泊沬泯泜泖泠"],["aaa1","炕炎炒炊炙爬爭爸版牧物狀狎狙狗狐玩玨玟玫玥甽疝疙疚的盂盲直知矽社祀祁秉秈空穹竺糾罔羌羋者肺肥肢肱股肫肩肴肪肯臥臾舍芳芝芙芭芽芟芹花芬芥芯芸芣芰芾芷虎虱初表軋迎返近邵邸邱邶采金長門阜陀阿阻附"],["ab40","陂隹雨青非亟亭亮信侵侯便俠俑俏保促侶俘俟俊俗侮俐俄係俚俎俞侷兗冒冑冠剎剃削前剌剋則勇勉勃勁匍南卻厚叛咬哀咨哎哉咸咦咳哇哂咽咪品"],["aba1","哄哈咯咫咱咻咩咧咿囿垂型垠垣垢城垮垓奕契奏奎奐姜姘姿姣姨娃姥姪姚姦威姻孩宣宦室客宥封屎屏屍屋峙峒巷帝帥帟幽庠度建弈弭彥很待徊律徇後徉怒思怠急怎怨恍恰恨恢恆恃恬恫恪恤扁拜挖按拼拭持拮拽指拱拷"],["ac40","拯括拾拴挑挂政故斫施既春昭映昧是星昨昱昤曷柿染柱柔某柬架枯柵柩柯柄柑枴柚查枸柏柞柳枰柙柢柝柒歪殃殆段毒毗氟泉洋洲洪流津洌洱洞洗"],["aca1","活洽派洶洛泵洹洧洸洩洮洵洎洫炫為炳炬炯炭炸炮炤爰牲牯牴狩狠狡玷珊玻玲珍珀玳甚甭畏界畎畋疫疤疥疢疣癸皆皇皈盈盆盃盅省盹相眉看盾盼眇矜砂研砌砍祆祉祈祇禹禺科秒秋穿突竿竽籽紂紅紀紉紇約紆缸美羿耄"],["ad40","耐耍耑耶胖胥胚胃胄背胡胛胎胞胤胝致舢苧范茅苣苛苦茄若茂茉苒苗英茁苜苔苑苞苓苟苯茆虐虹虻虺衍衫要觔計訂訃貞負赴赳趴軍軌述迦迢迪迥"],["ada1","迭迫迤迨郊郎郁郃酋酊重閂限陋陌降面革韋韭音頁風飛食首香乘亳倌倍倣俯倦倥俸倩倖倆值借倚倒們俺倀倔倨俱倡個候倘俳修倭倪俾倫倉兼冤冥冢凍凌准凋剖剜剔剛剝匪卿原厝叟哨唐唁唷哼哥哲唆哺唔哩哭員唉哮哪"],["ae40","哦唧唇哽唏圃圄埂埔埋埃堉夏套奘奚娑娘娜娟娛娓姬娠娣娩娥娌娉孫屘宰害家宴宮宵容宸射屑展屐峭峽峻峪峨峰島崁峴差席師庫庭座弱徒徑徐恙"],["aea1","恣恥恐恕恭恩息悄悟悚悍悔悌悅悖扇拳挈拿捎挾振捕捂捆捏捉挺捐挽挪挫挨捍捌效敉料旁旅時晉晏晃晒晌晅晁書朔朕朗校核案框桓根桂桔栩梳栗桌桑栽柴桐桀格桃株桅栓栘桁殊殉殷氣氧氨氦氤泰浪涕消涇浦浸海浙涓"],["af40","浬涉浮浚浴浩涌涊浹涅浥涔烊烘烤烙烈烏爹特狼狹狽狸狷玆班琉珮珠珪珞畔畝畜畚留疾病症疲疳疽疼疹痂疸皋皰益盍盎眩真眠眨矩砰砧砸砝破砷"],["afa1","砥砭砠砟砲祕祐祠祟祖神祝祗祚秤秣秧租秦秩秘窄窈站笆笑粉紡紗紋紊素索純紐紕級紜納紙紛缺罟羔翅翁耆耘耕耙耗耽耿胱脂胰脅胭胴脆胸胳脈能脊胼胯臭臬舀舐航舫舨般芻茫荒荔荊茸荐草茵茴荏茲茹茶茗荀茱茨荃"],["b040","虔蚊蚪蚓蚤蚩蚌蚣蚜衰衷袁袂衽衹記訐討訌訕訊託訓訖訏訑豈豺豹財貢起躬軒軔軏辱送逆迷退迺迴逃追逅迸邕郡郝郢酒配酌釘針釗釜釙閃院陣陡"],["b0a1","陛陝除陘陞隻飢馬骨高鬥鬲鬼乾偺偽停假偃偌做偉健偶偎偕偵側偷偏倏偯偭兜冕凰剪副勒務勘動匐匏匙匿區匾參曼商啪啦啄啞啡啃啊唱啖問啕唯啤唸售啜唬啣唳啁啗圈國圉域堅堊堆埠埤基堂堵執培夠奢娶婁婉婦婪婀"],["b140","娼婢婚婆婊孰寇寅寄寂宿密尉專將屠屜屝崇崆崎崛崖崢崑崩崔崙崤崧崗巢常帶帳帷康庸庶庵庾張強彗彬彩彫得徙從徘御徠徜恿患悉悠您惋悴惦悽"],["b1a1","情悻悵惜悼惘惕惆惟悸惚惇戚戛扈掠控捲掖探接捷捧掘措捱掩掉掃掛捫推掄授掙採掬排掏掀捻捩捨捺敝敖救教敗啟敏敘敕敔斜斛斬族旋旌旎晝晚晤晨晦晞曹勗望梁梯梢梓梵桿桶梱梧梗械梃棄梭梆梅梔條梨梟梡梂欲殺"],["b240","毫毬氫涎涼淳淙液淡淌淤添淺清淇淋涯淑涮淞淹涸混淵淅淒渚涵淚淫淘淪深淮淨淆淄涪淬涿淦烹焉焊烽烯爽牽犁猜猛猖猓猙率琅琊球理現琍瓠瓶"],["b2a1","瓷甜產略畦畢異疏痔痕疵痊痍皎盔盒盛眷眾眼眶眸眺硫硃硎祥票祭移窒窕笠笨笛第符笙笞笮粒粗粕絆絃統紮紹紼絀細紳組累終紲紱缽羞羚翌翎習耜聊聆脯脖脣脫脩脰脤舂舵舷舶船莎莞莘荸莢莖莽莫莒莊莓莉莠荷荻荼"],["b340","莆莧處彪蛇蛀蚶蛄蚵蛆蛋蚱蚯蛉術袞袈被袒袖袍袋覓規訪訝訣訥許設訟訛訢豉豚販責貫貨貪貧赧赦趾趺軛軟這逍通逗連速逝逐逕逞造透逢逖逛途"],["b3a1","部郭都酗野釵釦釣釧釭釩閉陪陵陳陸陰陴陶陷陬雀雪雩章竟頂頃魚鳥鹵鹿麥麻傢傍傅備傑傀傖傘傚最凱割剴創剩勞勝勛博厥啻喀喧啼喊喝喘喂喜喪喔喇喋喃喳單喟唾喲喚喻喬喱啾喉喫喙圍堯堪場堤堰報堡堝堠壹壺奠"],["b440","婷媚婿媒媛媧孳孱寒富寓寐尊尋就嵌嵐崴嵇巽幅帽幀幃幾廊廁廂廄弼彭復循徨惑惡悲悶惠愜愣惺愕惰惻惴慨惱愎惶愉愀愒戟扉掣掌描揀揩揉揆揍"],["b4a1","插揣提握揖揭揮捶援揪換摒揚揹敞敦敢散斑斐斯普晰晴晶景暑智晾晷曾替期朝棺棕棠棘棗椅棟棵森棧棹棒棲棣棋棍植椒椎棉棚楮棻款欺欽殘殖殼毯氮氯氬港游湔渡渲湧湊渠渥渣減湛湘渤湖湮渭渦湯渴湍渺測湃渝渾滋"],["b540","溉渙湎湣湄湲湩湟焙焚焦焰無然煮焜牌犄犀猶猥猴猩琺琪琳琢琥琵琶琴琯琛琦琨甥甦畫番痢痛痣痙痘痞痠登發皖皓皴盜睏短硝硬硯稍稈程稅稀窘"],["b5a1","窗窖童竣等策筆筐筒答筍筋筏筑粟粥絞結絨絕紫絮絲絡給絢絰絳善翔翕耋聒肅腕腔腋腑腎脹腆脾腌腓腴舒舜菩萃菸萍菠菅萋菁華菱菴著萊菰萌菌菽菲菊萸萎萄菜萇菔菟虛蛟蛙蛭蛔蛛蛤蛐蛞街裁裂袱覃視註詠評詞証詁"],["b640","詔詛詐詆訴診訶詖象貂貯貼貳貽賁費賀貴買貶貿貸越超趁跎距跋跚跑跌跛跆軻軸軼辜逮逵週逸進逶鄂郵鄉郾酣酥量鈔鈕鈣鈉鈞鈍鈐鈇鈑閔閏開閑"],["b6a1","間閒閎隊階隋陽隅隆隍陲隄雁雅雄集雇雯雲韌項順須飧飪飯飩飲飭馮馭黃黍黑亂傭債傲傳僅傾催傷傻傯僇剿剷剽募勦勤勢勣匯嗟嗨嗓嗦嗎嗜嗇嗑嗣嗤嗯嗚嗡嗅嗆嗥嗉園圓塞塑塘塗塚塔填塌塭塊塢塒塋奧嫁嫉嫌媾媽媼"],["b740","媳嫂媲嵩嵯幌幹廉廈弒彙徬微愚意慈感想愛惹愁愈慎慌慄慍愾愴愧愍愆愷戡戢搓搾搞搪搭搽搬搏搜搔損搶搖搗搆敬斟新暗暉暇暈暖暄暘暍會榔業"],["b7a1","楚楷楠楔極椰概楊楨楫楞楓楹榆楝楣楛歇歲毀殿毓毽溢溯滓溶滂源溝滇滅溥溘溼溺溫滑準溜滄滔溪溧溴煎煙煩煤煉照煜煬煦煌煥煞煆煨煖爺牒猷獅猿猾瑯瑚瑕瑟瑞瑁琿瑙瑛瑜當畸瘀痰瘁痲痱痺痿痴痳盞盟睛睫睦睞督"],["b840","睹睪睬睜睥睨睢矮碎碰碗碘碌碉硼碑碓硿祺祿禁萬禽稜稚稠稔稟稞窟窠筷節筠筮筧粱粳粵經絹綑綁綏絛置罩罪署義羨群聖聘肆肄腱腰腸腥腮腳腫"],["b8a1","腹腺腦舅艇蒂葷落萱葵葦葫葉葬葛萼萵葡董葩葭葆虞虜號蛹蜓蜈蜇蜀蛾蛻蜂蜃蜆蜊衙裟裔裙補裘裝裡裊裕裒覜解詫該詳試詩詰誇詼詣誠話誅詭詢詮詬詹詻訾詨豢貊貉賊資賈賄貲賃賂賅跡跟跨路跳跺跪跤跦躲較載軾輊"],["b940","辟農運遊道遂達逼違遐遇遏過遍遑逾遁鄒鄗酬酪酩釉鈷鉗鈸鈽鉀鈾鉛鉋鉤鉑鈴鉉鉍鉅鈹鈿鉚閘隘隔隕雍雋雉雊雷電雹零靖靴靶預頑頓頊頒頌飼飴"],["b9a1","飽飾馳馱馴髡鳩麂鼎鼓鼠僧僮僥僖僭僚僕像僑僱僎僩兢凳劃劂匱厭嗾嘀嘛嘗嗽嘔嘆嘉嘍嘎嗷嘖嘟嘈嘐嗶團圖塵塾境墓墊塹墅塽壽夥夢夤奪奩嫡嫦嫩嫗嫖嫘嫣孵寞寧寡寥實寨寢寤察對屢嶄嶇幛幣幕幗幔廓廖弊彆彰徹慇"],["ba40","愿態慷慢慣慟慚慘慵截撇摘摔撤摸摟摺摑摧搴摭摻敲斡旗旖暢暨暝榜榨榕槁榮槓構榛榷榻榫榴槐槍榭槌榦槃榣歉歌氳漳演滾漓滴漩漾漠漬漏漂漢"],["baa1","滿滯漆漱漸漲漣漕漫漯澈漪滬漁滲滌滷熔熙煽熊熄熒爾犒犖獄獐瑤瑣瑪瑰瑭甄疑瘧瘍瘋瘉瘓盡監瞄睽睿睡磁碟碧碳碩碣禎福禍種稱窪窩竭端管箕箋筵算箝箔箏箸箇箄粹粽精綻綰綜綽綾綠緊綴網綱綺綢綿綵綸維緒緇綬"],["bb40","罰翠翡翟聞聚肇腐膀膏膈膊腿膂臧臺與舔舞艋蓉蒿蓆蓄蒙蒞蒲蒜蓋蒸蓀蓓蒐蒼蓑蓊蜿蜜蜻蜢蜥蜴蜘蝕蜷蜩裳褂裴裹裸製裨褚裯誦誌語誣認誡誓誤"],["bba1","說誥誨誘誑誚誧豪貍貌賓賑賒赫趙趕跼輔輒輕輓辣遠遘遜遣遙遞遢遝遛鄙鄘鄞酵酸酷酴鉸銀銅銘銖鉻銓銜銨鉼銑閡閨閩閣閥閤隙障際雌雒需靼鞅韶頗領颯颱餃餅餌餉駁骯骰髦魁魂鳴鳶鳳麼鼻齊億儀僻僵價儂儈儉儅凜"],["bc40","劇劈劉劍劊勰厲嘮嘻嘹嘲嘿嘴嘩噓噎噗噴嘶嘯嘰墀墟增墳墜墮墩墦奭嬉嫻嬋嫵嬌嬈寮寬審寫層履嶝嶔幢幟幡廢廚廟廝廣廠彈影德徵慶慧慮慝慕憂"],["bca1","慼慰慫慾憧憐憫憎憬憚憤憔憮戮摩摯摹撞撲撈撐撰撥撓撕撩撒撮播撫撚撬撙撢撳敵敷數暮暫暴暱樣樟槨樁樞標槽模樓樊槳樂樅槭樑歐歎殤毅毆漿潼澄潑潦潔澆潭潛潸潮澎潺潰潤澗潘滕潯潠潟熟熬熱熨牖犛獎獗瑩璋璃"],["bd40","瑾璀畿瘠瘩瘟瘤瘦瘡瘢皚皺盤瞎瞇瞌瞑瞋磋磅確磊碾磕碼磐稿稼穀稽稷稻窯窮箭箱範箴篆篇篁箠篌糊締練緯緻緘緬緝編緣線緞緩綞緙緲緹罵罷羯"],["bda1","翩耦膛膜膝膠膚膘蔗蔽蔚蓮蔬蔭蔓蔑蔣蔡蔔蓬蔥蓿蔆螂蝴蝶蝠蝦蝸蝨蝙蝗蝌蝓衛衝褐複褒褓褕褊誼諒談諄誕請諸課諉諂調誰論諍誶誹諛豌豎豬賠賞賦賤賬賭賢賣賜質賡赭趟趣踫踐踝踢踏踩踟踡踞躺輝輛輟輩輦輪輜輞"],["be40","輥適遮遨遭遷鄰鄭鄧鄱醇醉醋醃鋅銻銷鋪銬鋤鋁銳銼鋒鋇鋰銲閭閱霄霆震霉靠鞍鞋鞏頡頫頜颳養餓餒餘駝駐駟駛駑駕駒駙骷髮髯鬧魅魄魷魯鴆鴉"],["bea1","鴃麩麾黎墨齒儒儘儔儐儕冀冪凝劑劓勳噙噫噹噩噤噸噪器噥噱噯噬噢噶壁墾壇壅奮嬝嬴學寰導彊憲憑憩憊懍憶憾懊懈戰擅擁擋撻撼據擄擇擂操撿擒擔撾整曆曉暹曄曇暸樽樸樺橙橫橘樹橄橢橡橋橇樵機橈歙歷氅濂澱澡"],["bf40","濃澤濁澧澳激澹澶澦澠澴熾燉燐燒燈燕熹燎燙燜燃燄獨璜璣璘璟璞瓢甌甍瘴瘸瘺盧盥瞠瞞瞟瞥磨磚磬磧禦積穎穆穌穋窺篙簑築篤篛篡篩篦糕糖縊"],["bfa1","縑縈縛縣縞縝縉縐罹羲翰翱翮耨膳膩膨臻興艘艙蕊蕙蕈蕨蕩蕃蕉蕭蕪蕞螃螟螞螢融衡褪褲褥褫褡親覦諦諺諫諱謀諜諧諮諾謁謂諷諭諳諶諼豫豭貓賴蹄踱踴蹂踹踵輻輯輸輳辨辦遵遴選遲遼遺鄴醒錠錶鋸錳錯錢鋼錫錄錚"],["c040","錐錦錡錕錮錙閻隧隨險雕霎霑霖霍霓霏靛靜靦鞘頰頸頻頷頭頹頤餐館餞餛餡餚駭駢駱骸骼髻髭鬨鮑鴕鴣鴦鴨鴒鴛默黔龍龜優償儡儲勵嚎嚀嚐嚅嚇"],["c0a1","嚏壕壓壑壎嬰嬪嬤孺尷屨嶼嶺嶽嶸幫彌徽應懂懇懦懋戲戴擎擊擘擠擰擦擬擱擢擭斂斃曙曖檀檔檄檢檜櫛檣橾檗檐檠歜殮毚氈濘濱濟濠濛濤濫濯澀濬濡濩濕濮濰燧營燮燦燥燭燬燴燠爵牆獰獲璩環璦璨癆療癌盪瞳瞪瞰瞬"],["c140","瞧瞭矯磷磺磴磯礁禧禪穗窿簇簍篾篷簌篠糠糜糞糢糟糙糝縮績繆縷縲繃縫總縱繅繁縴縹繈縵縿縯罄翳翼聱聲聰聯聳臆臃膺臂臀膿膽臉膾臨舉艱薪"],["c1a1","薄蕾薜薑薔薯薛薇薨薊虧蟀蟑螳蟒蟆螫螻螺蟈蟋褻褶襄褸褽覬謎謗謙講謊謠謝謄謐豁谿豳賺賽購賸賻趨蹉蹋蹈蹊轄輾轂轅輿避遽還邁邂邀鄹醣醞醜鍍鎂錨鍵鍊鍥鍋錘鍾鍬鍛鍰鍚鍔闊闋闌闈闆隱隸雖霜霞鞠韓顆颶餵騁"],["c240","駿鮮鮫鮪鮭鴻鴿麋黏點黜黝黛鼾齋叢嚕嚮壙壘嬸彝懣戳擴擲擾攆擺擻擷斷曜朦檳檬櫃檻檸櫂檮檯歟歸殯瀉瀋濾瀆濺瀑瀏燻燼燾燸獷獵璧璿甕癖癘"],["c2a1","癒瞽瞿瞻瞼礎禮穡穢穠竄竅簫簧簪簞簣簡糧織繕繞繚繡繒繙罈翹翻職聶臍臏舊藏薩藍藐藉薰薺薹薦蟯蟬蟲蟠覆覲觴謨謹謬謫豐贅蹙蹣蹦蹤蹟蹕軀轉轍邇邃邈醫醬釐鎔鎊鎖鎢鎳鎮鎬鎰鎘鎚鎗闔闖闐闕離雜雙雛雞霤鞣鞦"],["c340","鞭韹額顏題顎顓颺餾餿餽餮馥騎髁鬃鬆魏魎魍鯊鯉鯽鯈鯀鵑鵝鵠黠鼕鼬儳嚥壞壟壢寵龐廬懲懷懶懵攀攏曠曝櫥櫝櫚櫓瀛瀟瀨瀚瀝瀕瀘爆爍牘犢獸"],["c3a1","獺璽瓊瓣疇疆癟癡矇礙禱穫穩簾簿簸簽簷籀繫繭繹繩繪羅繳羶羹羸臘藩藝藪藕藤藥藷蟻蠅蠍蟹蟾襠襟襖襞譁譜識證譚譎譏譆譙贈贊蹼蹲躇蹶蹬蹺蹴轔轎辭邊邋醱醮鏡鏑鏟鏃鏈鏜鏝鏖鏢鏍鏘鏤鏗鏨關隴難霪霧靡韜韻類"],["c440","願顛颼饅饉騖騙鬍鯨鯧鯖鯛鶉鵡鵲鵪鵬麒麗麓麴勸嚨嚷嚶嚴嚼壤孀孃孽寶巉懸懺攘攔攙曦朧櫬瀾瀰瀲爐獻瓏癢癥礦礪礬礫竇競籌籃籍糯糰辮繽繼"],["c4a1","纂罌耀臚艦藻藹蘑藺蘆蘋蘇蘊蠔蠕襤覺觸議譬警譯譟譫贏贍躉躁躅躂醴釋鐘鐃鏽闡霰飄饒饑馨騫騰騷騵鰓鰍鹹麵黨鼯齟齣齡儷儸囁囀囂夔屬巍懼懾攝攜斕曩櫻欄櫺殲灌爛犧瓖瓔癩矓籐纏續羼蘗蘭蘚蠣蠢蠡蠟襪襬覽譴"],["c540","護譽贓躊躍躋轟辯醺鐮鐳鐵鐺鐸鐲鐫闢霸霹露響顧顥饗驅驃驀騾髏魔魑鰭鰥鶯鶴鷂鶸麝黯鼙齜齦齧儼儻囈囊囉孿巔巒彎懿攤權歡灑灘玀瓤疊癮癬"],["c5a1","禳籠籟聾聽臟襲襯觼讀贖贗躑躓轡酈鑄鑑鑒霽霾韃韁顫饕驕驍髒鬚鱉鰱鰾鰻鷓鷗鼴齬齪龔囌巖戀攣攫攪曬欐瓚竊籤籣籥纓纖纔臢蘸蘿蠱變邐邏鑣鑠鑤靨顯饜驚驛驗髓體髑鱔鱗鱖鷥麟黴囑壩攬灞癱癲矗罐羈蠶蠹衢讓讒"],["c640","讖艷贛釀鑪靂靈靄韆顰驟鬢魘鱟鷹鷺鹼鹽鼇齷齲廳欖灣籬籮蠻觀躡釁鑲鑰顱饞髖鬣黌灤矚讚鑷韉驢驥纜讜躪釅鑽鑾鑼鱷鱸黷豔鑿鸚爨驪鬱鸛鸞籲"],["c940","乂乜凵匚厂万丌乇亍囗兀屮彳丏冇与丮亓仂仉仈冘勼卬厹圠夃夬尐巿旡殳毌气爿丱丼仨仜仩仡仝仚刌匜卌圢圣夗夯宁宄尒尻屴屳帄庀庂忉戉扐氕"],["c9a1","氶汃氿氻犮犰玊禸肊阞伎优伬仵伔仱伀价伈伝伂伅伢伓伄仴伒冱刓刉刐劦匢匟卍厊吇囡囟圮圪圴夼妀奼妅奻奾奷奿孖尕尥屼屺屻屾巟幵庄异弚彴忕忔忏扜扞扤扡扦扢扙扠扚扥旯旮朾朹朸朻机朿朼朳氘汆汒汜汏汊汔汋"],["ca40","汌灱牞犴犵玎甪癿穵网艸艼芀艽艿虍襾邙邗邘邛邔阢阤阠阣佖伻佢佉体佤伾佧佒佟佁佘伭伳伿佡冏冹刜刞刡劭劮匉卣卲厎厏吰吷吪呔呅吙吜吥吘"],["caa1","吽呏呁吨吤呇囮囧囥坁坅坌坉坋坒夆奀妦妘妠妗妎妢妐妏妧妡宎宒尨尪岍岏岈岋岉岒岊岆岓岕巠帊帎庋庉庌庈庍弅弝彸彶忒忑忐忭忨忮忳忡忤忣忺忯忷忻怀忴戺抃抌抎抏抔抇扱扻扺扰抁抈扷扽扲扴攷旰旴旳旲旵杅杇"],["cb40","杙杕杌杈杝杍杚杋毐氙氚汸汧汫沄沋沏汱汯汩沚汭沇沕沜汦汳汥汻沎灴灺牣犿犽狃狆狁犺狅玕玗玓玔玒町甹疔疕皁礽耴肕肙肐肒肜芐芏芅芎芑芓"],["cba1","芊芃芄豸迉辿邟邡邥邞邧邠阰阨阯阭丳侘佼侅佽侀侇佶佴侉侄佷佌侗佪侚佹侁佸侐侜侔侞侒侂侕佫佮冞冼冾刵刲刳剆刱劼匊匋匼厒厔咇呿咁咑咂咈呫呺呾呥呬呴呦咍呯呡呠咘呣呧呤囷囹坯坲坭坫坱坰坶垀坵坻坳坴坢"],["cc40","坨坽夌奅妵妺姏姎妲姌姁妶妼姃姖妱妽姀姈妴姇孢孥宓宕屄屇岮岤岠岵岯岨岬岟岣岭岢岪岧岝岥岶岰岦帗帔帙弨弢弣弤彔徂彾彽忞忥怭怦怙怲怋"],["cca1","怴怊怗怳怚怞怬怢怍怐怮怓怑怌怉怜戔戽抭抴拑抾抪抶拊抮抳抯抻抩抰抸攽斨斻昉旼昄昒昈旻昃昋昍昅旽昑昐曶朊枅杬枎枒杶杻枘枆构杴枍枌杺枟枑枙枃杽极杸杹枔欥殀歾毞氝沓泬泫泮泙沶泔沭泧沷泐泂沺泃泆泭泲"],["cd40","泒泝沴沊沝沀泞泀洰泍泇沰泹泏泩泑炔炘炅炓炆炄炑炖炂炚炃牪狖狋狘狉狜狒狔狚狌狑玤玡玭玦玢玠玬玝瓝瓨甿畀甾疌疘皯盳盱盰盵矸矼矹矻矺"],["cda1","矷祂礿秅穸穻竻籵糽耵肏肮肣肸肵肭舠芠苀芫芚芘芛芵芧芮芼芞芺芴芨芡芩苂芤苃芶芢虰虯虭虮豖迒迋迓迍迖迕迗邲邴邯邳邰阹阽阼阺陃俍俅俓侲俉俋俁俔俜俙侻侳俛俇俖侺俀侹俬剄剉勀勂匽卼厗厖厙厘咺咡咭咥哏"],["ce40","哃茍咷咮哖咶哅哆咠呰咼咢咾呲哞咰垵垞垟垤垌垗垝垛垔垘垏垙垥垚垕壴复奓姡姞姮娀姱姝姺姽姼姶姤姲姷姛姩姳姵姠姾姴姭宨屌峐峘峌峗峋峛"],["cea1","峞峚峉峇峊峖峓峔峏峈峆峎峟峸巹帡帢帣帠帤庰庤庢庛庣庥弇弮彖徆怷怹恔恲恞恅恓恇恉恛恌恀恂恟怤恄恘恦恮扂扃拏挍挋拵挎挃拫拹挏挌拸拶挀挓挔拺挕拻拰敁敃斪斿昶昡昲昵昜昦昢昳昫昺昝昴昹昮朏朐柁柲柈枺"],["cf40","柜枻柸柘柀枷柅柫柤柟枵柍枳柷柶柮柣柂枹柎柧柰枲柼柆柭柌枮柦柛柺柉柊柃柪柋欨殂殄殶毖毘毠氠氡洨洴洭洟洼洿洒洊泚洳洄洙洺洚洑洀洝浂"],["cfa1","洁洘洷洃洏浀洇洠洬洈洢洉洐炷炟炾炱炰炡炴炵炩牁牉牊牬牰牳牮狊狤狨狫狟狪狦狣玅珌珂珈珅玹玶玵玴珫玿珇玾珃珆玸珋瓬瓮甮畇畈疧疪癹盄眈眃眄眅眊盷盻盺矧矨砆砑砒砅砐砏砎砉砃砓祊祌祋祅祄秕种秏秖秎窀"],["d040","穾竑笀笁籺籸籹籿粀粁紃紈紁罘羑羍羾耇耎耏耔耷胘胇胠胑胈胂胐胅胣胙胜胊胕胉胏胗胦胍臿舡芔苙苾苹茇苨茀苕茺苫苖苴苬苡苲苵茌苻苶苰苪"],["d0a1","苤苠苺苳苭虷虴虼虳衁衎衧衪衩觓訄訇赲迣迡迮迠郱邽邿郕郅邾郇郋郈釔釓陔陏陑陓陊陎倞倅倇倓倢倰倛俵俴倳倷倬俶俷倗倜倠倧倵倯倱倎党冔冓凊凄凅凈凎剡剚剒剞剟剕剢勍匎厞唦哢唗唒哧哳哤唚哿唄唈哫唑唅哱"],["d140","唊哻哷哸哠唎唃唋圁圂埌堲埕埒垺埆垽垼垸垶垿埇埐垹埁夎奊娙娖娭娮娕娏娗娊娞娳孬宧宭宬尃屖屔峬峿峮峱峷崀峹帩帨庨庮庪庬弳弰彧恝恚恧"],["d1a1","恁悢悈悀悒悁悝悃悕悛悗悇悜悎戙扆拲挐捖挬捄捅挶捃揤挹捋捊挼挩捁挴捘捔捙挭捇挳捚捑挸捗捀捈敊敆旆旃旄旂晊晟晇晑朒朓栟栚桉栲栳栻桋桏栖栱栜栵栫栭栯桎桄栴栝栒栔栦栨栮桍栺栥栠欬欯欭欱欴歭肂殈毦毤"],["d240","毨毣毢毧氥浺浣浤浶洍浡涒浘浢浭浯涑涍淯浿涆浞浧浠涗浰浼浟涂涘洯浨涋浾涀涄洖涃浻浽浵涐烜烓烑烝烋缹烢烗烒烞烠烔烍烅烆烇烚烎烡牂牸"],["d2a1","牷牶猀狺狴狾狶狳狻猁珓珙珥珖玼珧珣珩珜珒珛珔珝珚珗珘珨瓞瓟瓴瓵甡畛畟疰痁疻痄痀疿疶疺皊盉眝眛眐眓眒眣眑眕眙眚眢眧砣砬砢砵砯砨砮砫砡砩砳砪砱祔祛祏祜祓祒祑秫秬秠秮秭秪秜秞秝窆窉窅窋窌窊窇竘笐"],["d340","笄笓笅笏笈笊笎笉笒粄粑粊粌粈粍粅紞紝紑紎紘紖紓紟紒紏紌罜罡罞罠罝罛羖羒翃翂翀耖耾耹胺胲胹胵脁胻脀舁舯舥茳茭荄茙荑茥荖茿荁茦茜茢"],["d3a1","荂荎茛茪茈茼荍茖茤茠茷茯茩荇荅荌荓茞茬荋茧荈虓虒蚢蚨蚖蚍蚑蚞蚇蚗蚆蚋蚚蚅蚥蚙蚡蚧蚕蚘蚎蚝蚐蚔衃衄衭衵衶衲袀衱衿衯袃衾衴衼訒豇豗豻貤貣赶赸趵趷趶軑軓迾迵适迿迻逄迼迶郖郠郙郚郣郟郥郘郛郗郜郤酐"],["d440","酎酏釕釢釚陜陟隼飣髟鬯乿偰偪偡偞偠偓偋偝偲偈偍偁偛偊偢倕偅偟偩偫偣偤偆偀偮偳偗偑凐剫剭剬剮勖勓匭厜啵啶唼啍啐唴唪啑啢唶唵唰啒啅"],["d4a1","唌唲啥啎唹啈唭唻啀啋圊圇埻堔埢埶埜埴堀埭埽堈埸堋埳埏堇埮埣埲埥埬埡堎埼堐埧堁堌埱埩埰堍堄奜婠婘婕婧婞娸娵婭婐婟婥婬婓婤婗婃婝婒婄婛婈媎娾婍娹婌婰婩婇婑婖婂婜孲孮寁寀屙崞崋崝崚崠崌崨崍崦崥崏"],["d540","崰崒崣崟崮帾帴庱庴庹庲庳弶弸徛徖徟悊悐悆悾悰悺惓惔惏惤惙惝惈悱惛悷惊悿惃惍惀挲捥掊掂捽掽掞掭掝掗掫掎捯掇掐据掯捵掜捭掮捼掤挻掟"],["d5a1","捸掅掁掑掍捰敓旍晥晡晛晙晜晢朘桹梇梐梜桭桮梮梫楖桯梣梬梩桵桴梲梏桷梒桼桫桲梪梀桱桾梛梖梋梠梉梤桸桻梑梌梊桽欶欳欷欸殑殏殍殎殌氪淀涫涴涳湴涬淩淢涷淶淔渀淈淠淟淖涾淥淜淝淛淴淊涽淭淰涺淕淂淏淉"],["d640","淐淲淓淽淗淍淣涻烺焍烷焗烴焌烰焄烳焐烼烿焆焓焀烸烶焋焂焎牾牻牼牿猝猗猇猑猘猊猈狿猏猞玈珶珸珵琄琁珽琇琀珺珼珿琌琋珴琈畤畣痎痒痏"],["d6a1","痋痌痑痐皏皉盓眹眯眭眱眲眴眳眽眥眻眵硈硒硉硍硊硌砦硅硐祤祧祩祪祣祫祡离秺秸秶秷窏窔窐笵筇笴笥笰笢笤笳笘笪笝笱笫笭笯笲笸笚笣粔粘粖粣紵紽紸紶紺絅紬紩絁絇紾紿絊紻紨罣羕羜羝羛翊翋翍翐翑翇翏翉耟"],["d740","耞耛聇聃聈脘脥脙脛脭脟脬脞脡脕脧脝脢舑舸舳舺舴舲艴莐莣莨莍荺荳莤荴莏莁莕莙荵莔莩荽莃莌莝莛莪莋荾莥莯莈莗莰荿莦莇莮荶莚虙虖蚿蚷"],["d7a1","蛂蛁蛅蚺蚰蛈蚹蚳蚸蛌蚴蚻蚼蛃蚽蚾衒袉袕袨袢袪袚袑袡袟袘袧袙袛袗袤袬袌袓袎覂觖觙觕訰訧訬訞谹谻豜豝豽貥赽赻赹趼跂趹趿跁軘軞軝軜軗軠軡逤逋逑逜逌逡郯郪郰郴郲郳郔郫郬郩酖酘酚酓酕釬釴釱釳釸釤釹釪"],["d840","釫釷釨釮镺閆閈陼陭陫陱陯隿靪頄飥馗傛傕傔傞傋傣傃傌傎傝偨傜傒傂傇兟凔匒匑厤厧喑喨喥喭啷噅喢喓喈喏喵喁喣喒喤啽喌喦啿喕喡喎圌堩堷"],["d8a1","堙堞堧堣堨埵塈堥堜堛堳堿堶堮堹堸堭堬堻奡媯媔媟婺媢媞婸媦婼媥媬媕媮娷媄媊媗媃媋媩婻婽媌媜媏媓媝寪寍寋寔寑寊寎尌尰崷嵃嵫嵁嵋崿崵嵑嵎嵕崳崺嵒崽崱嵙嵂崹嵉崸崼崲崶嵀嵅幄幁彘徦徥徫惉悹惌惢惎惄愔"],["d940","惲愊愖愅惵愓惸惼惾惁愃愘愝愐惿愄愋扊掔掱掰揎揥揨揯揃撝揳揊揠揶揕揲揵摡揟掾揝揜揄揘揓揂揇揌揋揈揰揗揙攲敧敪敤敜敨敥斌斝斞斮旐旒"],["d9a1","晼晬晻暀晱晹晪晲朁椌棓椄棜椪棬棪棱椏棖棷棫棤棶椓椐棳棡椇棌椈楰梴椑棯棆椔棸棐棽棼棨椋椊椗棎棈棝棞棦棴棑椆棔棩椕椥棇欹欻欿欼殔殗殙殕殽毰毲毳氰淼湆湇渟湉溈渼渽湅湢渫渿湁湝湳渜渳湋湀湑渻渃渮湞"],["da40","湨湜湡渱渨湠湱湫渹渢渰湓湥渧湸湤湷湕湹湒湦渵渶湚焠焞焯烻焮焱焣焥焢焲焟焨焺焛牋牚犈犉犆犅犋猒猋猰猢猱猳猧猲猭猦猣猵猌琮琬琰琫琖"],["daa1","琚琡琭琱琤琣琝琩琠琲瓻甯畯畬痧痚痡痦痝痟痤痗皕皒盚睆睇睄睍睅睊睎睋睌矞矬硠硤硥硜硭硱硪确硰硩硨硞硢祴祳祲祰稂稊稃稌稄窙竦竤筊笻筄筈筌筎筀筘筅粢粞粨粡絘絯絣絓絖絧絪絏絭絜絫絒絔絩絑絟絎缾缿罥"],["db40","罦羢羠羡翗聑聏聐胾胔腃腊腒腏腇脽腍脺臦臮臷臸臹舄舼舽舿艵茻菏菹萣菀菨萒菧菤菼菶萐菆菈菫菣莿萁菝菥菘菿菡菋菎菖菵菉萉萏菞萑萆菂菳"],["dba1","菕菺菇菑菪萓菃菬菮菄菻菗菢萛菛菾蛘蛢蛦蛓蛣蛚蛪蛝蛫蛜蛬蛩蛗蛨蛑衈衖衕袺裗袹袸裀袾袶袼袷袽袲褁裉覕覘覗觝觚觛詎詍訹詙詀詗詘詄詅詒詈詑詊詌詏豟貁貀貺貾貰貹貵趄趀趉跘跓跍跇跖跜跏跕跙跈跗跅軯軷軺"],["dc40","軹軦軮軥軵軧軨軶軫軱軬軴軩逭逴逯鄆鄬鄄郿郼鄈郹郻鄁鄀鄇鄅鄃酡酤酟酢酠鈁鈊鈥鈃鈚鈦鈏鈌鈀鈒釿釽鈆鈄鈧鈂鈜鈤鈙鈗鈅鈖镻閍閌閐隇陾隈"],["dca1","隉隃隀雂雈雃雱雰靬靰靮頇颩飫鳦黹亃亄亶傽傿僆傮僄僊傴僈僂傰僁傺傱僋僉傶傸凗剺剸剻剼嗃嗛嗌嗐嗋嗊嗝嗀嗔嗄嗩喿嗒喍嗏嗕嗢嗖嗈嗲嗍嗙嗂圔塓塨塤塏塍塉塯塕塎塝塙塥塛堽塣塱壼嫇嫄嫋媺媸媱媵媰媿嫈媻嫆"],["dd40","媷嫀嫊媴媶嫍媹媐寖寘寙尟尳嵱嵣嵊嵥嵲嵬嵞嵨嵧嵢巰幏幎幊幍幋廅廌廆廋廇彀徯徭惷慉慊愫慅愶愲愮慆愯慏愩慀戠酨戣戥戤揅揱揫搐搒搉搠搤"],["dda1","搳摃搟搕搘搹搷搢搣搌搦搰搨摁搵搯搊搚摀搥搧搋揧搛搮搡搎敯斒旓暆暌暕暐暋暊暙暔晸朠楦楟椸楎楢楱椿楅楪椹楂楗楙楺楈楉椵楬椳椽楥棰楸椴楩楀楯楄楶楘楁楴楌椻楋椷楜楏楑椲楒椯楻椼歆歅歃歂歈歁殛嗀毻毼"],["de40","毹毷毸溛滖滈溏滀溟溓溔溠溱溹滆滒溽滁溞滉溷溰滍溦滏溲溾滃滜滘溙溒溎溍溤溡溿溳滐滊溗溮溣煇煔煒煣煠煁煝煢煲煸煪煡煂煘煃煋煰煟煐煓"],["dea1","煄煍煚牏犍犌犑犐犎猼獂猻猺獀獊獉瑄瑊瑋瑒瑑瑗瑀瑏瑐瑎瑂瑆瑍瑔瓡瓿瓾瓽甝畹畷榃痯瘏瘃痷痾痼痹痸瘐痻痶痭痵痽皙皵盝睕睟睠睒睖睚睩睧睔睙睭矠碇碚碔碏碄碕碅碆碡碃硹碙碀碖硻祼禂祽祹稑稘稙稒稗稕稢稓"],["df40","稛稐窣窢窞竫筦筤筭筴筩筲筥筳筱筰筡筸筶筣粲粴粯綈綆綀綍絿綅絺綎絻綃絼綌綔綄絽綒罭罫罧罨罬羦羥羧翛翜耡腤腠腷腜腩腛腢腲朡腞腶腧腯"],["dfa1","腄腡舝艉艄艀艂艅蓱萿葖葶葹蒏蒍葥葑葀蒆葧萰葍葽葚葙葴葳葝蔇葞萷萺萴葺葃葸萲葅萩菙葋萯葂萭葟葰萹葎葌葒葯蓅蒎萻葇萶萳葨葾葄萫葠葔葮葐蜋蜄蛷蜌蛺蛖蛵蝍蛸蜎蜉蜁蛶蜍蜅裖裋裍裎裞裛裚裌裐覅覛觟觥觤"],["e040","觡觠觢觜触詶誆詿詡訿詷誂誄詵誃誁詴詺谼豋豊豥豤豦貆貄貅賌赨赩趑趌趎趏趍趓趔趐趒跰跠跬跱跮跐跩跣跢跧跲跫跴輆軿輁輀輅輇輈輂輋遒逿"],["e0a1","遄遉逽鄐鄍鄏鄑鄖鄔鄋鄎酮酯鉈鉒鈰鈺鉦鈳鉥鉞銃鈮鉊鉆鉭鉬鉏鉠鉧鉯鈶鉡鉰鈱鉔鉣鉐鉲鉎鉓鉌鉖鈲閟閜閞閛隒隓隑隗雎雺雽雸雵靳靷靸靲頏頍頎颬飶飹馯馲馰馵骭骫魛鳪鳭鳧麀黽僦僔僗僨僳僛僪僝僤僓僬僰僯僣僠"],["e140","凘劀劁勩勫匰厬嘧嘕嘌嘒嗼嘏嘜嘁嘓嘂嗺嘝嘄嗿嗹墉塼墐墘墆墁塿塴墋塺墇墑墎塶墂墈塻墔墏壾奫嫜嫮嫥嫕嫪嫚嫭嫫嫳嫢嫠嫛嫬嫞嫝嫙嫨嫟孷寠"],["e1a1","寣屣嶂嶀嵽嶆嵺嶁嵷嶊嶉嶈嵾嵼嶍嵹嵿幘幙幓廘廑廗廎廜廕廙廒廔彄彃彯徶愬愨慁慞慱慳慒慓慲慬憀慴慔慺慛慥愻慪慡慖戩戧戫搫摍摛摝摴摶摲摳摽摵摦撦摎撂摞摜摋摓摠摐摿搿摬摫摙摥摷敳斠暡暠暟朅朄朢榱榶槉"],["e240","榠槎榖榰榬榼榑榙榎榧榍榩榾榯榿槄榽榤槔榹槊榚槏榳榓榪榡榞槙榗榐槂榵榥槆歊歍歋殞殟殠毃毄毾滎滵滱漃漥滸漷滻漮漉潎漙漚漧漘漻漒滭漊"],["e2a1","漶潳滹滮漭潀漰漼漵滫漇漎潃漅滽滶漹漜滼漺漟漍漞漈漡熇熐熉熀熅熂熏煻熆熁熗牄牓犗犕犓獃獍獑獌瑢瑳瑱瑵瑲瑧瑮甀甂甃畽疐瘖瘈瘌瘕瘑瘊瘔皸瞁睼瞅瞂睮瞀睯睾瞃碲碪碴碭碨硾碫碞碥碠碬碢碤禘禊禋禖禕禔禓"],["e340","禗禈禒禐稫穊稰稯稨稦窨窫窬竮箈箜箊箑箐箖箍箌箛箎箅箘劄箙箤箂粻粿粼粺綧綷緂綣綪緁緀緅綝緎緄緆緋緌綯綹綖綼綟綦綮綩綡緉罳翢翣翥翞"],["e3a1","耤聝聜膉膆膃膇膍膌膋舕蒗蒤蒡蒟蒺蓎蓂蒬蒮蒫蒹蒴蓁蓍蒪蒚蒱蓐蒝蒧蒻蒢蒔蓇蓌蒛蒩蒯蒨蓖蒘蒶蓏蒠蓗蓔蓒蓛蒰蒑虡蜳蜣蜨蝫蝀蜮蜞蜡蜙蜛蝃蜬蝁蜾蝆蜠蜲蜪蜭蜼蜒蜺蜱蜵蝂蜦蜧蜸蜤蜚蜰蜑裷裧裱裲裺裾裮裼裶裻"],["e440","裰裬裫覝覡覟覞觩觫觨誫誙誋誒誏誖谽豨豩賕賏賗趖踉踂跿踍跽踊踃踇踆踅跾踀踄輐輑輎輍鄣鄜鄠鄢鄟鄝鄚鄤鄡鄛酺酲酹酳銥銤鉶銛鉺銠銔銪銍"],["e4a1","銦銚銫鉹銗鉿銣鋮銎銂銕銢鉽銈銡銊銆銌銙銧鉾銇銩銝銋鈭隞隡雿靘靽靺靾鞃鞀鞂靻鞄鞁靿韎韍頖颭颮餂餀餇馝馜駃馹馻馺駂馽駇骱髣髧鬾鬿魠魡魟鳱鳲鳵麧僿儃儰僸儆儇僶僾儋儌僽儊劋劌勱勯噈噂噌嘵噁噊噉噆噘"],["e540","噚噀嘳嘽嘬嘾嘸嘪嘺圚墫墝墱墠墣墯墬墥墡壿嫿嫴嫽嫷嫶嬃嫸嬂嫹嬁嬇嬅嬏屧嶙嶗嶟嶒嶢嶓嶕嶠嶜嶡嶚嶞幩幝幠幜緳廛廞廡彉徲憋憃慹憱憰憢憉"],["e5a1","憛憓憯憭憟憒憪憡憍慦憳戭摮摰撖撠撅撗撜撏撋撊撌撣撟摨撱撘敶敺敹敻斲斳暵暰暩暲暷暪暯樀樆樗槥槸樕槱槤樠槿槬槢樛樝槾樧槲槮樔槷槧橀樈槦槻樍槼槫樉樄樘樥樏槶樦樇槴樖歑殥殣殢殦氁氀毿氂潁漦潾澇濆澒"],["e640","澍澉澌潢潏澅潚澖潶潬澂潕潲潒潐潗澔澓潝漀潡潫潽潧澐潓澋潩潿澕潣潷潪潻熲熯熛熰熠熚熩熵熝熥熞熤熡熪熜熧熳犘犚獘獒獞獟獠獝獛獡獚獙"],["e6a1","獢璇璉璊璆璁瑽璅璈瑼瑹甈甇畾瘥瘞瘙瘝瘜瘣瘚瘨瘛皜皝皞皛瞍瞏瞉瞈磍碻磏磌磑磎磔磈磃磄磉禚禡禠禜禢禛歶稹窲窴窳箷篋箾箬篎箯箹篊箵糅糈糌糋緷緛緪緧緗緡縃緺緦緶緱緰緮緟罶羬羰羭翭翫翪翬翦翨聤聧膣膟"],["e740","膞膕膢膙膗舖艏艓艒艐艎艑蔤蔻蔏蔀蔩蔎蔉蔍蔟蔊蔧蔜蓻蔫蓺蔈蔌蓴蔪蓲蔕蓷蓫蓳蓼蔒蓪蓩蔖蓾蔨蔝蔮蔂蓽蔞蓶蔱蔦蓧蓨蓰蓯蓹蔘蔠蔰蔋蔙蔯虢"],["e7a1","蝖蝣蝤蝷蟡蝳蝘蝔蝛蝒蝡蝚蝑蝞蝭蝪蝐蝎蝟蝝蝯蝬蝺蝮蝜蝥蝏蝻蝵蝢蝧蝩衚褅褌褔褋褗褘褙褆褖褑褎褉覢覤覣觭觰觬諏諆誸諓諑諔諕誻諗誾諀諅諘諃誺誽諙谾豍貏賥賟賙賨賚賝賧趠趜趡趛踠踣踥踤踮踕踛踖踑踙踦踧"],["e840","踔踒踘踓踜踗踚輬輤輘輚輠輣輖輗遳遰遯遧遫鄯鄫鄩鄪鄲鄦鄮醅醆醊醁醂醄醀鋐鋃鋄鋀鋙銶鋏鋱鋟鋘鋩鋗鋝鋌鋯鋂鋨鋊鋈鋎鋦鋍鋕鋉鋠鋞鋧鋑鋓"],["e8a1","銵鋡鋆銴镼閬閫閮閰隤隢雓霅霈霂靚鞊鞎鞈韐韏頞頝頦頩頨頠頛頧颲餈飺餑餔餖餗餕駜駍駏駓駔駎駉駖駘駋駗駌骳髬髫髳髲髱魆魃魧魴魱魦魶魵魰魨魤魬鳼鳺鳽鳿鳷鴇鴀鳹鳻鴈鴅鴄麃黓鼏鼐儜儓儗儚儑凞匴叡噰噠噮"],["e940","噳噦噣噭噲噞噷圜圛壈墽壉墿墺壂墼壆嬗嬙嬛嬡嬔嬓嬐嬖嬨嬚嬠嬞寯嶬嶱嶩嶧嶵嶰嶮嶪嶨嶲嶭嶯嶴幧幨幦幯廩廧廦廨廥彋徼憝憨憖懅憴懆懁懌憺"],["e9a1","憿憸憌擗擖擐擏擉撽撉擃擛擳擙攳敿敼斢曈暾曀曊曋曏暽暻暺曌朣樴橦橉橧樲橨樾橝橭橶橛橑樨橚樻樿橁橪橤橐橏橔橯橩橠樼橞橖橕橍橎橆歕歔歖殧殪殫毈毇氄氃氆澭濋澣濇澼濎濈潞濄澽澞濊澨瀄澥澮澺澬澪濏澿澸"],["ea40","澢濉澫濍澯澲澰燅燂熿熸燖燀燁燋燔燊燇燏熽燘熼燆燚燛犝犞獩獦獧獬獥獫獪瑿璚璠璔璒璕璡甋疀瘯瘭瘱瘽瘳瘼瘵瘲瘰皻盦瞚瞝瞡瞜瞛瞢瞣瞕瞙"],["eaa1","瞗磝磩磥磪磞磣磛磡磢磭磟磠禤穄穈穇窶窸窵窱窷篞篣篧篝篕篥篚篨篹篔篪篢篜篫篘篟糒糔糗糐糑縒縡縗縌縟縠縓縎縜縕縚縢縋縏縖縍縔縥縤罃罻罼罺羱翯耪耩聬膱膦膮膹膵膫膰膬膴膲膷膧臲艕艖艗蕖蕅蕫蕍蕓蕡蕘"],["eb40","蕀蕆蕤蕁蕢蕄蕑蕇蕣蔾蕛蕱蕎蕮蕵蕕蕧蕠薌蕦蕝蕔蕥蕬虣虥虤螛螏螗螓螒螈螁螖螘蝹螇螣螅螐螑螝螄螔螜螚螉褞褦褰褭褮褧褱褢褩褣褯褬褟觱諠"],["eba1","諢諲諴諵諝謔諤諟諰諈諞諡諨諿諯諻貑貒貐賵賮賱賰賳赬赮趥趧踳踾踸蹀蹅踶踼踽蹁踰踿躽輶輮輵輲輹輷輴遶遹遻邆郺鄳鄵鄶醓醐醑醍醏錧錞錈錟錆錏鍺錸錼錛錣錒錁鍆錭錎錍鋋錝鋺錥錓鋹鋷錴錂錤鋿錩錹錵錪錔錌"],["ec40","錋鋾錉錀鋻錖閼闍閾閹閺閶閿閵閽隩雔霋霒霐鞙鞗鞔韰韸頵頯頲餤餟餧餩馞駮駬駥駤駰駣駪駩駧骹骿骴骻髶髺髹髷鬳鮀鮅鮇魼魾魻鮂鮓鮒鮐魺鮕"],["eca1","魽鮈鴥鴗鴠鴞鴔鴩鴝鴘鴢鴐鴙鴟麈麆麇麮麭黕黖黺鼒鼽儦儥儢儤儠儩勴嚓嚌嚍嚆嚄嚃噾嚂噿嚁壖壔壏壒嬭嬥嬲嬣嬬嬧嬦嬯嬮孻寱寲嶷幬幪徾徻懃憵憼懧懠懥懤懨懞擯擩擣擫擤擨斁斀斶旚曒檍檖檁檥檉檟檛檡檞檇檓檎"],["ed40","檕檃檨檤檑橿檦檚檅檌檒歛殭氉濌澩濴濔濣濜濭濧濦濞濲濝濢濨燡燱燨燲燤燰燢獳獮獯璗璲璫璐璪璭璱璥璯甐甑甒甏疄癃癈癉癇皤盩瞵瞫瞲瞷瞶"],["eda1","瞴瞱瞨矰磳磽礂磻磼磲礅磹磾礄禫禨穜穛穖穘穔穚窾竀竁簅簏篲簀篿篻簎篴簋篳簂簉簃簁篸篽簆篰篱簐簊糨縭縼繂縳顈縸縪繉繀繇縩繌縰縻縶繄縺罅罿罾罽翴翲耬膻臄臌臊臅臇膼臩艛艚艜薃薀薏薧薕薠薋薣蕻薤薚薞"],["ee40","蕷蕼薉薡蕺蕸蕗薎薖薆薍薙薝薁薢薂薈薅蕹蕶薘薐薟虨螾螪螭蟅螰螬螹螵螼螮蟉蟃蟂蟌螷螯蟄蟊螴螶螿螸螽蟞螲褵褳褼褾襁襒褷襂覭覯覮觲觳謞"],["eea1","謘謖謑謅謋謢謏謒謕謇謍謈謆謜謓謚豏豰豲豱豯貕貔賹赯蹎蹍蹓蹐蹌蹇轃轀邅遾鄸醚醢醛醙醟醡醝醠鎡鎃鎯鍤鍖鍇鍼鍘鍜鍶鍉鍐鍑鍠鍭鎏鍌鍪鍹鍗鍕鍒鍏鍱鍷鍻鍡鍞鍣鍧鎀鍎鍙闇闀闉闃闅閷隮隰隬霠霟霘霝霙鞚鞡鞜"],["ef40","鞞鞝韕韔韱顁顄顊顉顅顃餥餫餬餪餳餲餯餭餱餰馘馣馡騂駺駴駷駹駸駶駻駽駾駼騃骾髾髽鬁髼魈鮚鮨鮞鮛鮦鮡鮥鮤鮆鮢鮠鮯鴳鵁鵧鴶鴮鴯鴱鴸鴰"],["efa1","鵅鵂鵃鴾鴷鵀鴽翵鴭麊麉麍麰黈黚黻黿鼤鼣鼢齔龠儱儭儮嚘嚜嚗嚚嚝嚙奰嬼屩屪巀幭幮懘懟懭懮懱懪懰懫懖懩擿攄擽擸攁攃擼斔旛曚曛曘櫅檹檽櫡櫆檺檶檷櫇檴檭歞毉氋瀇瀌瀍瀁瀅瀔瀎濿瀀濻瀦濼濷瀊爁燿燹爃燽獶"],["f040","璸瓀璵瓁璾璶璻瓂甔甓癜癤癙癐癓癗癚皦皽盬矂瞺磿礌礓礔礉礐礒礑禭禬穟簜簩簙簠簟簭簝簦簨簢簥簰繜繐繖繣繘繢繟繑繠繗繓羵羳翷翸聵臑臒"],["f0a1","臐艟艞薴藆藀藃藂薳薵薽藇藄薿藋藎藈藅薱薶藒蘤薸薷薾虩蟧蟦蟢蟛蟫蟪蟥蟟蟳蟤蟔蟜蟓蟭蟘蟣螤蟗蟙蠁蟴蟨蟝襓襋襏襌襆襐襑襉謪謧謣謳謰謵譇謯謼謾謱謥謷謦謶謮謤謻謽謺豂豵貙貘貗賾贄贂贀蹜蹢蹠蹗蹖蹞蹥蹧"],["f140","蹛蹚蹡蹝蹩蹔轆轇轈轋鄨鄺鄻鄾醨醥醧醯醪鎵鎌鎒鎷鎛鎝鎉鎧鎎鎪鎞鎦鎕鎈鎙鎟鎍鎱鎑鎲鎤鎨鎴鎣鎥闒闓闑隳雗雚巂雟雘雝霣霢霥鞬鞮鞨鞫鞤鞪"],["f1a1","鞢鞥韗韙韖韘韺顐顑顒颸饁餼餺騏騋騉騍騄騑騊騅騇騆髀髜鬈鬄鬅鬩鬵魊魌魋鯇鯆鯃鮿鯁鮵鮸鯓鮶鯄鮹鮽鵜鵓鵏鵊鵛鵋鵙鵖鵌鵗鵒鵔鵟鵘鵚麎麌黟鼁鼀鼖鼥鼫鼪鼩鼨齌齕儴儵劖勷厴嚫嚭嚦嚧嚪嚬壚壝壛夒嬽嬾嬿巃幰"],["f240","徿懻攇攐攍攉攌攎斄旞旝曞櫧櫠櫌櫑櫙櫋櫟櫜櫐櫫櫏櫍櫞歠殰氌瀙瀧瀠瀖瀫瀡瀢瀣瀩瀗瀤瀜瀪爌爊爇爂爅犥犦犤犣犡瓋瓅璷瓃甖癠矉矊矄矱礝礛"],["f2a1","礡礜礗礞禰穧穨簳簼簹簬簻糬糪繶繵繸繰繷繯繺繲繴繨罋罊羃羆羷翽翾聸臗臕艤艡艣藫藱藭藙藡藨藚藗藬藲藸藘藟藣藜藑藰藦藯藞藢蠀蟺蠃蟶蟷蠉蠌蠋蠆蟼蠈蟿蠊蠂襢襚襛襗襡襜襘襝襙覈覷覶觶譐譈譊譀譓譖譔譋譕"],["f340","譑譂譒譗豃豷豶貚贆贇贉趬趪趭趫蹭蹸蹳蹪蹯蹻軂轒轑轏轐轓辴酀鄿醰醭鏞鏇鏏鏂鏚鏐鏹鏬鏌鏙鎩鏦鏊鏔鏮鏣鏕鏄鏎鏀鏒鏧镽闚闛雡霩霫霬霨霦"],["f3a1","鞳鞷鞶韝韞韟顜顙顝顗颿颽颻颾饈饇饃馦馧騚騕騥騝騤騛騢騠騧騣騞騜騔髂鬋鬊鬎鬌鬷鯪鯫鯠鯞鯤鯦鯢鯰鯔鯗鯬鯜鯙鯥鯕鯡鯚鵷鶁鶊鶄鶈鵱鶀鵸鶆鶋鶌鵽鵫鵴鵵鵰鵩鶅鵳鵻鶂鵯鵹鵿鶇鵨麔麑黀黼鼭齀齁齍齖齗齘匷嚲"],["f440","嚵嚳壣孅巆巇廮廯忀忁懹攗攖攕攓旟曨曣曤櫳櫰櫪櫨櫹櫱櫮櫯瀼瀵瀯瀷瀴瀱灂瀸瀿瀺瀹灀瀻瀳灁爓爔犨獽獼璺皫皪皾盭矌矎矏矍矲礥礣礧礨礤礩"],["f4a1","禲穮穬穭竷籉籈籊籇籅糮繻繾纁纀羺翿聹臛臙舋艨艩蘢藿蘁藾蘛蘀藶蘄蘉蘅蘌藽蠙蠐蠑蠗蠓蠖襣襦覹觷譠譪譝譨譣譥譧譭趮躆躈躄轙轖轗轕轘轚邍酃酁醷醵醲醳鐋鐓鏻鐠鐏鐔鏾鐕鐐鐨鐙鐍鏵鐀鏷鐇鐎鐖鐒鏺鐉鏸鐊鏿"],["f540","鏼鐌鏶鐑鐆闞闠闟霮霯鞹鞻韽韾顠顢顣顟飁飂饐饎饙饌饋饓騲騴騱騬騪騶騩騮騸騭髇髊髆鬐鬒鬑鰋鰈鯷鰅鰒鯸鱀鰇鰎鰆鰗鰔鰉鶟鶙鶤鶝鶒鶘鶐鶛"],["f5a1","鶠鶔鶜鶪鶗鶡鶚鶢鶨鶞鶣鶿鶩鶖鶦鶧麙麛麚黥黤黧黦鼰鼮齛齠齞齝齙龑儺儹劘劗囃嚽嚾孈孇巋巏廱懽攛欂櫼欃櫸欀灃灄灊灈灉灅灆爝爚爙獾甗癪矐礭礱礯籔籓糲纊纇纈纋纆纍罍羻耰臝蘘蘪蘦蘟蘣蘜蘙蘧蘮蘡蘠蘩蘞蘥"],["f640","蠩蠝蠛蠠蠤蠜蠫衊襭襩襮襫觺譹譸譅譺譻贐贔趯躎躌轞轛轝酆酄酅醹鐿鐻鐶鐩鐽鐼鐰鐹鐪鐷鐬鑀鐱闥闤闣霵霺鞿韡顤飉飆飀饘饖騹騽驆驄驂驁騺"],["f6a1","騿髍鬕鬗鬘鬖鬺魒鰫鰝鰜鰬鰣鰨鰩鰤鰡鶷鶶鶼鷁鷇鷊鷏鶾鷅鷃鶻鶵鷎鶹鶺鶬鷈鶱鶭鷌鶳鷍鶲鹺麜黫黮黭鼛鼘鼚鼱齎齥齤龒亹囆囅囋奱孋孌巕巑廲攡攠攦攢欋欈欉氍灕灖灗灒爞爟犩獿瓘瓕瓙瓗癭皭礵禴穰穱籗籜籙籛籚"],["f740","糴糱纑罏羇臞艫蘴蘵蘳蘬蘲蘶蠬蠨蠦蠪蠥襱覿覾觻譾讄讂讆讅譿贕躕躔躚躒躐躖躗轠轢酇鑌鑐鑊鑋鑏鑇鑅鑈鑉鑆霿韣顪顩飋饔饛驎驓驔驌驏驈驊"],["f7a1","驉驒驐髐鬙鬫鬻魖魕鱆鱈鰿鱄鰹鰳鱁鰼鰷鰴鰲鰽鰶鷛鷒鷞鷚鷋鷐鷜鷑鷟鷩鷙鷘鷖鷵鷕鷝麶黰鼵鼳鼲齂齫龕龢儽劙壨壧奲孍巘蠯彏戁戃戄攩攥斖曫欑欒欏毊灛灚爢玂玁玃癰矔籧籦纕艬蘺虀蘹蘼蘱蘻蘾蠰蠲蠮蠳襶襴襳觾"],["f840","讌讎讋讈豅贙躘轤轣醼鑢鑕鑝鑗鑞韄韅頀驖驙鬞鬟鬠鱒鱘鱐鱊鱍鱋鱕鱙鱌鱎鷻鷷鷯鷣鷫鷸鷤鷶鷡鷮鷦鷲鷰鷢鷬鷴鷳鷨鷭黂黐黲黳鼆鼜鼸鼷鼶齃齏"],["f8a1","齱齰齮齯囓囍孎屭攭曭曮欓灟灡灝灠爣瓛瓥矕礸禷禶籪纗羉艭虃蠸蠷蠵衋讔讕躞躟躠躝醾醽釂鑫鑨鑩雥靆靃靇韇韥驞髕魙鱣鱧鱦鱢鱞鱠鸂鷾鸇鸃鸆鸅鸀鸁鸉鷿鷽鸄麠鼞齆齴齵齶囔攮斸欘欙欗欚灢爦犪矘矙礹籩籫糶纚"],["f940","纘纛纙臠臡虆虇虈襹襺襼襻觿讘讙躥躤躣鑮鑭鑯鑱鑳靉顲饟鱨鱮鱭鸋鸍鸐鸏鸒鸑麡黵鼉齇齸齻齺齹圞灦籯蠼趲躦釃鑴鑸鑶鑵驠鱴鱳鱱鱵鸔鸓黶鼊"],["f9a1","龤灨灥糷虪蠾蠽蠿讞貜躩軉靋顳顴飌饡馫驤驦驧鬤鸕鸗齈戇欞爧虌躨钂钀钁驩驨鬮鸙爩虋讟钃鱹麷癵驫鱺鸝灩灪麤齾齉龘碁銹裏墻恒粧嫺╔╦╗╠╬╣╚╩╝╒╤╕╞╪╡╘╧╛╓╥╖╟╫╢╙╨╜║═╭╮╰╯▓"]]')},function(e,t,n){(function(){var t;t=n(6),e.exports={cmykToRgb:function(e,n,r,i){return[t.clamp(65535-(e*(255-i)+(i<<8))>>8,0,255),t.clamp(65535-(n*(255-i)+(i<<8))>>8,0,255),t.clamp(65535-(r*(255-i)+(i<<8))>>8,0,255)]}}}).call(this)},function(e,t,n){(function(){var t;t=n(4),e.exports=function(){function e(e){this.file=e,this.recordType=null}return e.prototype.parse=function(){switch(this.recordType=this.file.readShort(),this.recordType){case 0:case 3:return this._readPathRecord();case 1:case 2:case 4:case 5:return this._readBezierPoint();case 7:return this._readClipboardRecord();case 8:return this._readInitialFill();default:return this.file.seek(24,!0)}},e.prototype.export=function(){return t.merge({recordType:this.recordType},function(){var e;switch(this.recordType){case 0:case 3:return{numPoints:this.numPoints,operation:this.operation};case 1:case 2:case 4:case 5:return{linked:this.linked,closed:1===(e=this.recordType)||2===e,preceding:{vert:this.precedingVert,horiz:this.precedingHoriz},anchor:{vert:this.anchorVert,horiz:this.anchorHoriz},leaving:{vert:this.leavingVert,horiz:this.leavingHoriz}};case 7:return{clipboard:{top:this.clipboardTop,left:this.clipboardLeft,bottom:this.clipboardBottom,right:this.clipboardRight,resolution:this.clipboardResolution}};case 8:return{initialFill:this.initialFill};default:return{}}}.call(this))},e.prototype.isBezierPoint=function(){var e;return 1===(e=this.recordType)||2===e||4===e||5===e},e.prototype._readPathRecord=function(){return this.numPoints=this.file.readShort(),this.operation=this.file.readShort(),this.file.seek(20,!0)},e.prototype._readBezierPoint=function(){var e;return this.linked=1===(e=this.recordType)||4===e,this.precedingVert=this.file.readPathNumber(),this.precedingHoriz=this.file.readPathNumber(),this.anchorVert=this.file.readPathNumber(),this.anchorHoriz=this.file.readPathNumber(),this.leavingVert=this.file.readPathNumber(),this.leavingHoriz=this.file.readPathNumber()},e.prototype._readClipboardRecord=function(){return this.clipboardTop=this.file.readPathNumber(),this.clipboardLeft=this.file.readPathNumber(),this.clipboardBottom=this.file.readPathNumber(),this.clipboardRight=this.file.readPathNumber(),this.clipboardResolution=this.file.readPathNumber(),this.file.seek(4,!0)},e.prototype._readInitialFill=function(){return this.initialFill=this.file.readShort(),this.file.seek(22,!0)},e}()}).call(this)},function(e,t,n){(function(){var t,r,i,o,a={}.hasOwnProperty;i=n(14),o=n(6),r={artboard:n(90),blendClippingElements:n(91),blendInteriorElements:n(92),fillOpacity:n(93),gradientFill:n(94),layerId:n(95),layerNameSource:n(96),legacyTypetool:n(97),locked:n(99),metadata:n(100),name:n(101),nestedSectionDivider:n(102),objectEffects:n(103),sectionDivider:n(104),solidColor:n(105),typeTool:n(26),vectorMask:n(106),vectorOrigination:n(107),vectorStroke:n(108),vectorStrokeContent:n(109),placedLayer:n(110),linkedLayer:n(27),smartObject:n(111)},t=["LMsk","Lr16","Lr32","Layr","Mt16","Mt32","Mtrn","Alph","FMsk","Ink2","FEid","FXid","PxSD"],e.exports={parseLayerInfo:function(){var e,n,s,u,c,l,f;for(f=[];this.file.tell()<this.layerEnd;)if(this.file.seek(4,!0),n=this.file.readString(4),c=2===this.header.version&&t.includes(n)?o.pad2(this.file.readLongLong()):o.pad2(this.file.readInt()),this.file.tell(),!(c<=0)){for(l in s=!1,r)if(a.call(r,l)&&(u=r[l]).shouldParse(n)){if(e=new u(this,c),this.externalFiles&&"lnk2"===n){this.externalFiles.push(e.parse());break}this.adjustments[l]=new i(e,this.file).now("skip").later("parse").get(),null==this[l]&&function(e){return function(t){return e[t]=function(){return e.adjustments[t]}}}(this)(l),this.infoKeys.push(n),s=!0;break}s?f.push(void 0):f.push(this.file.seek(c,!0))}return f}}}).call(this)},function(e,t,n){(function(){var t,r,i,o,a={}.hasOwnProperty;i=n(4),o=n(98),r=n(1),t=n(3),e.exports=function(e){var n,r;function s(e,t){s.__super__.constructor.call(this,e,t),this.version=null,this.transform={},this.textVersion=null,this.descriptorVersion=null,this.textData=null,this.engineData=null,this.textValue=null,this.warpVersion=null,this.descriptorVersion=null,this.warpData=null,this.coords={}}return function(e,t){for(var n in t)a.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(s,e),s.shouldParse=function(e){return"TySh"===e},r=["xx","xy","yx","yy","tx","ty"],n=["left","top","right","bottom"],s.prototype.parse=function(){var e,r,i,a,s;for(this.version=this.file.readShort(),this.parseTransformInfo(),this.textVersion=this.file.readShort(),this.descriptorVersion=this.file.readInt(),this.textData=new t(this.file).parse(),this.textValue=this.textData["Txt "],this.engineData=o(this.textData.EngineData),this.warpVersion=this.file.readShort(),this.descriptorVersion=this.file.readInt(),this.warpData=new t(this.file).parse(),s=[],r=e=0,i=n.length;e<i;r=++e)a=n[r],s.push(this.coords[a]=this.file.readInt());return s},s.prototype.parseTransformInfo=function(){var e,t,n,i,o;for(o=[],t=e=0,n=r.length;e<n;t=++e)i=r[t],o.push(this.transform[i]=this.file.readDouble());return o},s.prototype.fonts=function(){return null==this.engineData?[]:this.engineData.ResourceDict.FontSet.map((function(e){return e.Name}))},s.prototype.lengthArray=function(){var e;return e=this.engineData.EngineDict.StyleRun.RunLengthArray,i.reduce(e,(function(e,t){return e+t}))-this.textValue.length==1&&(e[e.length-1]=e[e.length-1]-1),e},s.prototype.fontStyles=function(){return this.engineData.EngineDict.StyleRun.RunArray.map((function(e){return e.StyleSheet.StyleSheetData})).map((function(e){return e.FauxItalic?"italic":"normal"}))},s.prototype.fontWeights=function(){return this.engineData.EngineDict.StyleRun.RunArray.map((function(e){return e.StyleSheet.StyleSheetData})).map((function(e){return e.FauxBold?"bold":"normal"}))},s.prototype.textDecoration=function(){return this.engineData.EngineDict.StyleRun.RunArray.map((function(e){return e.StyleSheet.StyleSheetData})).map((function(e){return e.Underline?"underline":"none"}))},s.prototype.leading=function(){return this.engineData.EngineDict.StyleRun.RunArray.map((function(e){return e.StyleSheet.StyleSheetData})).map((function(e){return e.Leading?e.Leading:"auto"}))},s.prototype.sizes=function(){return null==this.engineData&&null==this.styles().FontSize?[]:this.styles().FontSize},s.prototype.alignment=function(){var e;return null==this.engineData?[]:(e=["left","right","center","justify"],this.engineData.EngineDict.ParagraphRun.RunArray.map((function(t){return e[Math.min(parseInt(t.ParagraphSheet.Properties.Justification,10),3)]})))},s.prototype.colors=function(){return null==this.engineData||null==this.styles().FillColor?[[0,0,0,255]]:this.styles().FillColor.map((function(e){var t;return(t=e.Values.map((function(e){return Math.round(255*e)}))).push(t.shift()),t}))},s.prototype.styles=function(){var e;return null==this.engineData?{}:null!=this._styles?this._styles:(e=this.engineData.EngineDict.StyleRun.RunArray.map((function(e){return e.StyleSheet.StyleSheetData})),this._styles=i.reduce(e,(function(e,t){var n,r;for(n in t)a.call(t,n)&&(r=t[n],e[n]||(e[n]=[]),e[n].push(r));return e}),{}))},s.prototype.toCSS=function(){var e,t,n,r;for(n in e=[],t={"font-family":this.fonts().join(", "),"font-size":this.sizes()[0]+"pt",color:"rgba("+this.colors()[0].join(", ")+")","text-align":this.alignment()[0]})null!=(r=t[n])&&e.push(n+": "+r+";");return e.join("\n")},s.prototype.export=function(){return{value:this.textValue,font:{lengthArray:this.lengthArray(),styles:this.fontStyles(),weights:this.fontWeights(),names:this.fonts(),sizes:this.sizes(),colors:this.colors(),alignment:this.alignment(),textDecoration:this.textDecoration(),leading:this.leading()},left:this.coords.left,top:this.coords.top,right:this.coords.right,bottom:this.coords.bottom,transform:this.transform}},s}(r)}).call(this)},function(e,t,n){(function(){var t,r,i,o={}.hasOwnProperty;r=n(1),t=n(3),i=n(6),e.exports=function(e){function n(e,t){n.__super__.constructor.call(this,e,t)}return function(e,t){for(var n in t)o.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"lnk2"===e},n.prototype.parse=function(){var e,n,r,o,a;for(e=this.file.tell()+this.length,this.files=[];this.file.tell()<e;)o={},this.file.seek(4,!0),n=1+i.pad4(this.file.readInt())+this.file.tell(),r=this.file.readString(4),a=this.file.readInt(),o.uuid=this.file.readString(this.file.readByte()),o.fileName=this.file.readUnicodeString(),o.fileType=this.file.readString(4),this.file.readString(4),this.file.seek(4,!0),o.datasize=this.file.readInt(),o.openFile=this.file.readBoolean(),!0===o.openFile&&(this.file.seek(4,!0),o.openFile=new t(this.file).parse()),"liFD"===r&&(o.fileData=this.file.read(o.datasize)),a>=5&&(o.childId=this.file.readUnicodeString()),a>=6&&(o.modTime=this.file.readDouble()),a>=7&&(o.lockedState=this.file.readBoolean()),this.files.push(o),this.file.seek(n);return this.file.seek(e),this.files},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i,o,a={}.hasOwnProperty;o=n(7).Module,r=n(29),i=n(119),t=n(123),e.exports=function(e){var n,o,s,u;function c(e,t){this.file=e,this.header=t,this.numPixels=this.width()*this.height(),16===this.depth()&&(this.numPixels*=2),this.calculateLength(),this.pixelData=new Uint8Array(4*this.channelLength),this.maskData=new Uint8Array(4*this.maskLength),this.channelData=new Uint8Array(this.length+this.maskLength),this.opacity=1,this.hasMask=!1,this.startPos=this.file.tell(),this.endPos=this.startPos+this.length,this.setChannelsInfo()}for(function(e,t){for(var n in t)a.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(c,e),c.includes(r.RAW),c.includes(r.RLE),c.includes(i.Greyscale),c.includes(i.RGB),c.includes(i.CMYK),c.includes(t.PNG),["Raw","RLE","ZIP","ZIPPrediction"],n=function(e){return c.prototype[e]=function(){return this.header[e]}},o=0,s=(u=["width","height","channels","depth","mode"]).length;o<s;o++)n(u[o]);return c.prototype.setChannelsInfo=function(){switch(this.mode()){case 1:return this.setGreyscaleChannels();case 3:return this.setRgbChannels();case 4:return this.setCmykChannels()}},c.prototype.calculateLength=function(){return this.length=function(){switch(this.depth()){case 1:return(this.width()+7)/8*this.height();case 16:return this.width()*this.height()*2;default:return this.width()*this.height()}}.call(this),this.channelLength=this.length,this.length*=this.channels(),this.layer&&this.layer.mask.size?this.maskLength=this.layer.mask.width*this.layer.mask.height:this.maskLength=0},c.prototype.parse=function(){var e;if(this.compression=this.parseCompression(),2!==(e=this.compression)&&3!==e)return this.parseImageData();this.file.seek(this.endPos)},c.prototype.parseCompression=function(){return this.file.readShort()},c.prototype.parseImageData=function(){switch(this.compression){case 0:this.parseRaw();break;case 1:this.parseRLE();break;case 2:case 3:this.parseZip();break;default:this.file.seek(this.endPos)}return this.processImageData()},c.prototype.processImageData=function(){switch(this.mode()){case 1:this.combineGreyscaleChannel();break;case 3:this.combineRgbChannel();break;case 4:this.combineCmykChannel()}return this.channelData=null},c}(o)}).call(this)},function(e,t,n){(function(){e.exports={RAW:n(115),RLE:n(116),LayerRLE:n(117),LayerRAW:n(118)}}).call(this)},function(e,t,n){"use strict";n(33),n(34);const r=n(35),i={};function o(e,t={}){const{reverse:n}=t;let o=n?"R_"+e:e;return i[o]||(i[o]=r[e].reduce((e,n)=>{const r=t.reverse?1:0;return e[n[r]]=n[1-r],e},{}))}function a(e,t){return t.reduce((e,t)=>{const n=t.slice();return n.splice(0,0,{}),function(e,t){const n=Object.keys(t).reduce((e,t)=>Math.max(e,t.length),0),r=[];for(let i=0,{length:o}=e;i<o;i++){let o;for(let a=n;a>0;a--){const n=e.substr(i,a);if(Object.hasOwnProperty.call(t,n)){i+=a-1,r.push(t[n]),o=1;break}}!o&&r.push(e[i])}return r.join("")}(e,Object.assign.apply(null,n))},e)}t.hongKongToSimplified=function(e){return a(e,[[o("HKVariantsRevPhrases"),o("HKVariants",{reverse:!0})],[o("TSPhrases"),o("TSCharacters")]])},t.simplifiedToHongKong=function(e){return a(e,[[o("STPhrases"),o("STCharacters")],[o("HKVariantsPhrases"),o("HKVariants")]])},t.simplifiedToTraditional=function(e){return a(e,[[o("STPhrases"),o("STCharacters")]])},t.simplifiedToTaiwan=function(e){return a(e,[[o("STPhrases"),o("STCharacters")],[o("TWVariants")]])},t.simplifiedToTaiwanWithPhrases=function(e){return a(e,[[o("STPhrases"),o("STCharacters")],[o("TWPhrasesIT"),o("TWPhrasesName"),o("TWPhrasesOther"),o("TWVariants")]])},t.traditionalToHongKong=function(e){return a(e,[[o("HKVariants")]])},t.traditionalToSimplified=function(e){return a(e,[[o("TSPhrases"),o("TSCharacters")]])},t.traditionalToTaiwan=function(e){return a(e,[[o("TWVariants")]])},t.taiwanToSimplified=function(e){return a(e,[[o("TWVariantsRevPhrases"),o("TWVariants",{reverse:!0})],[o("TSPhrases"),o("TSCharacters")]])},t.taiwanToSimplifiedWithPhrases=function(e){return a(e,[[o("TWVariantsRevPhrases"),o("TWVariants",{reverse:!0})],[o("TWPhrasesIT",{reverse:!0}),o("TWPhrasesName",{reverse:!0}),o("TWPhrasesOther",{reverse:!0})],[o("TSPhrases"),o("TSCharacters")]])}},function(e,t,n){e.exports=n(39)},function(e,t,n){"use strict";n.r(t);var r,i,o,a=n(13),s=n(0),u=n.n(s),c=n(2),l=n(12),f=n(5);n(136);window._py演出=c.a,window.onload=function(){var e;return e={},new URLSearchParams(window.location.search).forEach((function(t,n){return e[n]=t})),window.山彥?(console.log("在本地演出"),o(e["入口"])):(console.log("在瀏覽器上演出"),r()),l.a.控制初始化()},o=function(e){return window.v=new a.a({el:"#總畫面",data:{"本地運行":!0,"圖片文件夾":"","音樂文件夾":"","視頻文件夾":"","psd立繪路徑":"","自定css":"","主題css":"","解析度":"","邊界":"","翻譯":!1,"存檔讀檔":{"啓動功能":"？？？","檔表":[]},"用戶設置":{"文字速度":{"類型":"number","值":35,"範圍":[0,100],"提示":["須臾","永恆"]},"對話框背景透明度":{"類型":"number","值":.8,"範圍":[0,1],"提示":["通透","固實"]},"總體音量":{"類型":"number","值":1,"範圍":[0,1],"提示":["小聲","大聲(沒用)"]},"自動收起控制面板":{"類型":"boolean","值":!1}}},watch:{$data:{handler:function(e,t){return 山彥.vue更新(e)},deep:!0}}}),山彥.vue連接初始化((function(e){var t,n,r;for(t in r=[],e)n=e[t],r.push(v[t]=n);return r})),"讀檔"===e?山彥.初始化((function(){return c.a.準備工作(),f.a.讀檔準備()})):山彥.初始化((function(){return c.a.準備工作(),c.a.更新()}))},i=function(e){var t,n,r,i,o,a,s,u,c,l;for(l={},r=0,o=(c=JSON.parse(JSON.stringify(e.演出步))).length;r<o;r++)for((t=c[r]).背景&&(l[`${v.圖片文件夾}/${t.背景[0]}`]=!0),t.cg&&(l[`${v.圖片文件夾}/${t.cg[0]}`]=!0),t.插入圖&&(l[`${v.圖片文件夾}/${t.插入圖}`]=!0),i=0,a=(s=t.立繪).length;i<a;i++)u=s[i],l[`${v.psd立繪路徑}/${u.名字}.psd`]=!0;return function(){var e;for(n in e=[],l)e.push(n);return e}()},window.加載完成的初始化=function(){return u()("#加載畫面").fadeOut(),山彥.初始化((function(){return c.a.準備工作(),c.a.更新()}))},r=function(){var e,t,n,r;if("undefined"!=typeof 虛擬核心){if(window.navigator.userAgent.indexOf("Chrome")&&window.chrome){for(u()("#加載畫面").css("display","flex"),window.山彥={n:0,"步進":function(){return this.n+=1},"更新":function(){return c.a.改變演出狀態(虛擬核心.演出步[this.n])},"狀態回調":function(e,t){return e&&this.步進(),t(虛擬核心.演出步[this.n])},"初始化":function(e){return e()},"切換全屏":function(){var e,t,n,r;return r=(n=(t=window.document).documentElement).requestFullscreen||n.mozRequestFullScreen||n.webkitRequestFullScreen||n.msRequestFullscreen,e=t.exitFullscreen||t.mozCancelFullScreen||t.webkitExitFullscreen||t.msExitFullscreen,t.fullscreenElement||t.mozFullScreenElement||t.webkitFullscreenElement||t.msFullscreenElement?e.call(t):r.call(n)}},window.v=new a.a({el:"#總畫面",data:{"本地運行":!1,"圖片文件夾":虛擬核心.圖片文件夾,"音樂文件夾":虛擬核心.音樂文件夾,"視頻文件夾":虛擬核心.視頻文件夾,"psd立繪路徑":虛擬核心.psd立繪路徑,"自定css":虛擬核心.自定css,"主題css":虛擬核心.主題css,"解析度":虛擬核心.解析度,"邊界":虛擬核心.邊界,"翻譯":!1,"用戶設置":{"文字速度":{"類型":"number","值":35,"範圍":[0,100],"提示":["須臾","永恆"]},"對話框背景透明度":{"類型":"number","值":.8,"範圍":[0,1],"提示":["通透","固實"]},"總體音量":{"類型":"number","值":1,"範圍":[0,1],"提示":["小聲","大聲(沒用)"]},"自動收起控制面板":{"類型":"boolean","值":!1}}}}),r=i(虛擬核心),window.v加載=new a.a({el:"#加載畫面",data:{"最大值":r.length,"計數":0}}),e=0,t=r.length;e<t;e++)n=r[e],console.log(n),u.a.get(n,(function(){return v加載.計數+=1}));return u()("title").html(虛擬核心.作品名)}alert("只有chrome能用。")}else alert("無法加載虛擬核心。")}},function(e,t){},function(e,t,n){(function(e){function n(e,t){for(var n=0,r=e.length-1;r>=0;r--){var i=e[r];"."===i?e.splice(r,1):".."===i?(e.splice(r,1),n++):n&&(e.splice(r,1),n--)}if(t)for(;n--;n)e.unshift("..");return e}function r(e,t){if(e.filter)return e.filter(t);for(var n=[],r=0;r<e.length;r++)t(e[r],r,e)&&n.push(e[r]);return n}t.resolve=function(){for(var t="",i=!1,o=arguments.length-1;o>=-1&&!i;o--){var a=o>=0?arguments[o]:e.cwd();if("string"!=typeof a)throw new TypeError("Arguments to path.resolve must be strings");a&&(t=a+"/"+t,i="/"===a.charAt(0))}return(i?"/":"")+(t=n(r(t.split("/"),(function(e){return!!e})),!i).join("/"))||"."},t.normalize=function(e){var o=t.isAbsolute(e),a="/"===i(e,-1);return(e=n(r(e.split("/"),(function(e){return!!e})),!o).join("/"))||o||(e="."),e&&a&&(e+="/"),(o?"/":"")+e},t.isAbsolute=function(e){return"/"===e.charAt(0)},t.join=function(){var e=Array.prototype.slice.call(arguments,0);return t.normalize(r(e,(function(e,t){if("string"!=typeof e)throw new TypeError("Arguments to path.join must be strings");return e})).join("/"))},t.relative=function(e,n){function r(e){for(var t=0;t<e.length&&""===e[t];t++);for(var n=e.length-1;n>=0&&""===e[n];n--);return t>n?[]:e.slice(t,n-t+1)}e=t.resolve(e).substr(1),n=t.resolve(n).substr(1);for(var i=r(e.split("/")),o=r(n.split("/")),a=Math.min(i.length,o.length),s=a,u=0;u<a;u++)if(i[u]!==o[u]){s=u;break}var c=[];for(u=s;u<i.length;u++)c.push("..");return(c=c.concat(o.slice(s))).join("/")},t.sep="/",t.delimiter=":",t.dirname=function(e){if("string"!=typeof e&&(e+=""),0===e.length)return".";for(var t=e.charCodeAt(0),n=47===t,r=-1,i=!0,o=e.length-1;o>=1;--o)if(47===(t=e.charCodeAt(o))){if(!i){r=o;break}}else i=!1;return-1===r?n?"/":".":n&&1===r?"/":e.slice(0,r)},t.basename=function(e,t){var n=function(e){"string"!=typeof e&&(e+="");var t,n=0,r=-1,i=!0;for(t=e.length-1;t>=0;--t)if(47===e.charCodeAt(t)){if(!i){n=t+1;break}}else-1===r&&(i=!1,r=t+1);return-1===r?"":e.slice(n,r)}(e);return t&&n.substr(-1*t.length)===t&&(n=n.substr(0,n.length-t.length)),n},t.extname=function(e){"string"!=typeof e&&(e+="");for(var t=-1,n=0,r=-1,i=!0,o=0,a=e.length-1;a>=0;--a){var s=e.charCodeAt(a);if(47!==s)-1===r&&(i=!1,r=a+1),46===s?-1===t?t=a:1!==o&&(o=1):-1!==t&&(o=-1);else if(!i){n=a+1;break}}return-1===t||-1===r||0===o||1===o&&t===r-1&&t===n+1?"":e.slice(t,r)};var i="b"==="ab".substr(-1)?function(e,t,n){return e.substr(t,n)}:function(e,t,n){return t<0&&(t=e.length+t),e.substr(t,n)}}).call(this,n(10))},function(e){e.exports=JSON.parse('{"HKVariants":[["僞","偽"],["兌","兑"],["冑","胄"],["冗","宂"],["勳","勛"],["叄","叁"],["啓","啟"],["嘆","歎"],["囪","囱"],["妝","粧"],["媼","媪"],["嫋","裊"],["嫺","嫻"],["嬀","媯"],["岩","巖"],["悅","悦"],["慍","愠"],["戶","户"],["挩","捝"],["搵","揾"],["擡","抬"],["敓","敚"],["敘","敍"],["柺","枴"],["梲","棁"],["棱","稜"],["榲","榅"],["檯","枱"],["氳","氲"],["涌","湧"],["涗","涚"],["溫","温"],["溼","濕"],["潙","溈"],["潨","潀"],["熅","煴"],["爲","為"],["痹","痺"],["癡","痴"],["皁","皂"],["稅","税"],["竈","灶"],["糉","粽"],["縕","緼"],["繮","韁"],["纔","才"],["脫","脱"],["膃","腽"],["臥","卧"],["臺","台"],["菸","煙"],["蒕","蒀"],["蔥","葱"],["蔿","蒍"],["蘊","藴"],["蛻","蜕"],["衆","眾"],["衛","衞"],["覈","核"],["說","説"],["贗","贋"],["踊","踴"],["轀","輼"],["醞","醖"],["鉢","缽"],["鉤","鈎"],["銳","鋭"],["閱","閲"],["鰮","鰛"],["鱉","鼈"]],"HKVariantsPhrases":[["南涌","南涌"],["大欖涌","大欖涌"],["大涌","大涌"],["東涌","東涌"],["沙河涌","沙河涌"],["沙魚涌","沙魚涌"],["河涌","河涌"],["泥涌","泥涌"],["涌尾","涌尾"],["深涌","深涌"],["溪涌","溪涌"],["葵涌","葵涌"],["蠔涌","蠔涌"],["西涌","西涌"],["鰂魚涌","鰂魚涌"],["麻涌","麻涌"],["黎涌","黎涌"]],"HKVariantsRevPhrases":[["七星巖","七星巖"],["世胄","世胄"],["介胄","介冑"],["傅巖","傅巖"],["免胄","免冑"],["冠胄","冠冑"],["千巖競秀","千巖競秀"],["千巖萬壑","千巖萬壑"],["千巖萬谷","千巖萬谷"],["台山","台山"],["台州","台州"],["台州地區","台州地區"],["台州市","台州市"],["名胄","名胄"],["國胄","國胄"],["圍巖","圍巖"],["地胄","地胄"],["壓胄子","壓冑子"],["士胄","士胄"],["大巖桐","大巖桐"],["天台女","天台女"],["天台宗","天台宗"],["天台山","天台山"],["天台縣","天台縣"],["天潢貴胄","天潢貴胄"],["奇巖","奇巖"],["寶胄","寶胄"],["小巖洞","小巖洞"],["岫巖縣","岫巖縣"],["峯巖","峯巖"],["嵌巖","嵌巖"],["巉巖","巉巖"],["巖壁","巖壁"],["巖居","巖居"],["巖居穴處","巖居穴處"],["巖居谷飲","巖居谷飲"],["巖岸","巖岸"],["巖巉","巖巉"],["巖巖","巖巖"],["巖徼","巖徼"],["巖手縣","巖手縣"],["巖村","巖村"],["巖洞","巖洞"],["巖流圈","巖流圈"],["巖牆","巖牆"],["巖牆之下","巖牆之下"],["巖畫","巖畫"],["巖穴","巖穴"],["巖穴之士","巖穴之士"],["巖薔薇","巖薔薇"],["巖邑","巖邑"],["巖郎","巖郎"],["巖阻","巖阻"],["巖陛","巖陛"],["帝胄","帝胄"],["幽巖","幽巖"],["幽棲巖谷","幽棲巖谷"],["懸巖","懸巖"],["懸巖峭壁","懸巖峭壁"],["懸胄","懸冑"],["攀巖","攀巖"],["支胄","支胄"],["教胄","教胄"],["景胄","景胄"],["望胄","望胄"],["末胄","末胄"],["村胄","村胄"],["枕巖漱流","枕巖漱流"],["枝胄","枝胄"],["氏胄","氏胄"],["洪胄","洪胄"],["浙江天台縣","浙江天台縣"],["清胄","清胄"],["灰巖殘丘","灰巖殘丘"],["玄胄","玄胄"],["甲胄","甲冑"],["甲胄魚類","甲冑魚類"],["皇胄","皇胄"],["石灰巖洞","石灰巖洞"],["神胄","神胄"],["簪纓世胄","簪纓世胄"],["系胄","系胄"],["紅巖","紅巖"],["絕巖","絕巖"],["緒胄","緒胄"],["纂胄","纂胄"],["胄嗣","胄嗣"],["胄子","胄子"],["胄序","胄序"],["胄族","胄族"],["胄甲","冑甲"],["胄監","胄監"],["胄科","冑科"],["胄緒","胄緒"],["胄胤","胄胤"],["胄裔","胄裔"],["胄裔繁衍","胄裔繁衍"],["胄閥","胄閥"],["胡雪巖","胡雪巖"],["胤胄","胤胄"],["苗胄","苗胄"],["英胄","英胄"],["華胄","華胄"],["血胄","血胄"],["裔胄","裔胄"],["訓胄","訓胄"],["試胄","試胄"],["豪門貴胄","豪門貴胄"],["貝胄","貝冑"],["貴胄","貴胄"],["賢胄","賢胄"],["躬擐甲胄","躬擐甲冑"],["遐胄","遐胄"],["遙胄","遙胄"],["遙遙華胄","遙遙華胄"],["遠胄","遠胄"],["遺胄","遺胄"],["重巖疊嶂","重巖疊嶂"],["金胄","金胄"],["鎧胄","鎧冑"],["鑿巖","鑿巖"],["門胄","門胄"],["雲巖區","雲巖區"],["非層巖","非層巖"],["韓侂胄","韓侂冑"],["飮胄","飮冑"],["骨巖巖","骨巖巖"],["高胄","高胄"],["魚胄","魚冑"],["鮮胄","鮮胄"],["鴻胄","鴻胄"],["黃巖區","黃巖區"],["黃巖島","黃巖島"],["黃炎貴胄","黃炎貴胄"],["齒胄","齒胄"],["龍巖","龍巖"],["龍巖市","龍巖市"],["龍巖村","龍巖村"],["龍胄","龍胄"]],"JPVariants":[["乘","乗"],["亂","乱"],["亙","亘"],["亞","亜"],["佛","仏"],["來","来"],["倂","併"],["假","仮"],["傳","伝"],["僞","偽"],["價","価"],["儉","倹"],["兒","児"],["兩","両"],["剩","剰"],["劍","剣"],["劑","剤"],["勞","労"],["勳","勲"],["勵","励"],["勸","勧"],["區","区"],["卷","巻"],["卽","即"],["參","参"],["啞","唖"],["單","単"],["嚙","噛"],["嚴","厳"],["囑","嘱"],["圈","圏"],["國","国"],["圍","囲"],["圓","円"],["圖","図"],["團","団"],["增","増"],["墮","堕"],["壓","圧"],["壘","塁"],["壞","壊"],["壤","壌"],["壯","壮"],["壹","壱"],["壽","寿"],["奧","奥"],["奬","奨"],["孃","嬢"],["學","学"],["寢","寝"],["實","実"],["寫","写"],["寬","寛"],["寶","宝"],["將","将"],["專","専"],["對","対"],["屆","届"],["屛","屏"],["屬","属"],["峽","峡"],["嶽","岳"],["巖","巌"],["巢","巣"],["帶","帯"],["幷","并"],["廢","廃"],["廣","広"],["廳","庁"],["彈","弾"],["彌","弥"],["彎","弯"],["徑","径"],["從","従"],["徵","徴"],["德","徳"],["恆","恒"],["惠","恵"],["惡","悪"],["惱","悩"],["愼","慎"],["慘","惨"],["應","応"],["懷","懐"],["戀","恋"],["戰","戦"],["戲","戯"],["戾","戻"],["拂","払"],["拔","抜"],["拜","拝"],["挾","挟"],["插","挿"],["揭","掲"],["搔","掻"],["搖","揺"],["搜","捜"],["擇","択"],["擊","撃"],["擔","担"],["據","拠"],["擧","挙"],["擴","拡"],["攝","摂"],["攪","撹"],["收","収"],["效","効"],["敍","叙"],["敕","勅"],["數","数"],["斷","断"],["晚","晩"],["晝","昼"],["曆","暦"],["曉","暁"],["曾","曽"],["會","会"],["枡","桝"],["條","条"],["棧","桟"],["榮","栄"],["槪","概"],["樂","楽"],["樓","楼"],["樞","枢"],["樣","様"],["橫","横"],["檢","検"],["櫻","桜"],["權","権"],["歐","欧"],["歡","歓"],["步","歩"],["歷","歴"],["歸","帰"],["殘","残"],["殼","殻"],["毆","殴"],["每","毎"],["氣","気"],["涉","渉"],["淚","涙"],["淨","浄"],["淺","浅"],["渴","渇"],["溪","渓"],["溫","温"],["滯","滞"],["滿","満"],["潛","潜"],["澁","渋"],["澤","沢"],["濕","湿"],["濟","済"],["濱","浜"],["濾","沪"],["瀧","滝"],["瀨","瀬"],["灣","湾"],["燈","灯"],["燒","焼"],["營","営"],["爐","炉"],["爭","争"],["爲","為"],["犧","犠"],["狀","状"],["狹","狭"],["獨","独"],["獵","猟"],["獸","獣"],["獻","献"],["瓣","弁"],["甁","瓶"],["畫","画"],["當","当"],["疊","畳"],["瘦","痩"],["癡","痴"],["發","発"],["盜","盗"],["盡","尽"],["眞","真"],["硏","研"],["碎","砕"],["祕","秘"],["祿","禄"],["禪","禅"],["禮","礼"],["禱","祷"],["稱","称"],["稻","稲"],["穎","頴"],["穗","穂"],["穩","穏"],["穰","穣"],["竊","窃"],["竝","並"],["粹","粋"],["絲","糸"],["經","経"],["綠","緑"],["緖","緒"],["緣","縁"],["縣","県"],["縱","縦"],["總","総"],["繡","繍"],["繩","縄"],["繪","絵"],["繼","継"],["續","続"],["纖","繊"],["缺","欠"],["罐","缶"],["聲","声"],["聽","聴"],["肅","粛"],["腦","脳"],["膽","胆"],["臟","臓"],["臺","台"],["與","与"],["舊","旧"],["莊","荘"],["莖","茎"],["萬","万"],["蔣","蒋"],["薰","薫"],["藏","蔵"],["藝","芸"],["藥","薬"],["蘆","芦"],["處","処"],["虛","虚"],["號","号"],["螢","蛍"],["蟲","虫"],["蠟","蝋"],["蠶","蚕"],["蠻","蛮"],["衞","衛"],["裝","装"],["襃","褒"],["覺","覚"],["覽","覧"],["觀","観"],["觸","触"],["謠","謡"],["證","証"],["譯","訳"],["譽","誉"],["讀","読"],["變","変"],["讓","譲"],["豐","豊"],["豫","予"],["貳","弐"],["賣","売"],["賴","頼"],["贊","賛"],["踐","践"],["輕","軽"],["轉","転"],["辨","弁"],["辭","辞"],["辯","弁"],["遞","逓"],["遲","遅"],["邊","辺"],["郞","郎"],["鄕","郷"],["醉","酔"],["醫","医"],["醬","醤"],["釀","醸"],["釋","釈"],["錄","録"],["錢","銭"],["鍊","錬"],["鎭","鎮"],["鐵","鉄"],["鑄","鋳"],["鑛","鉱"],["關","関"],["陷","陥"],["隨","随"],["險","険"],["隱","隠"],["雙","双"],["雜","雑"],["霸","覇"],["靈","霊"],["靜","静"],["顯","顕"],["飜","翻"],["餘","余"],["騷","騒"],["驅","駆"],["驗","験"],["驛","駅"],["髓","髄"],["體","体"],["髮","髪"],["鬪","闘"],["鷄","鶏"],["鷗","鴎"],["鹼","鹸"],["鹽","塩"],["麥","麦"],["麴","麹"],["麵","麺"],["黃","黄"],["黑","黒"],["默","黙"],["點","点"],["黨","党"],["齊","斉"],["齋","斎"],["齒","歯"],["齡","齢"],["龍","竜"],["欄","欄"],["廊","廊"],["朗","朗"],["虜","虜"],["殺","殺"],["類","類"],["隆","隆"],["塚","塚"],["猪","猪"],["神","神"],["祥","祥"],["福","福"],["諸","諸"],["都","都"],["侮","侮"],["僧","僧"],["免","免"],["勉","勉"],["勤","勤"],["卑","卑"],["喝","喝"],["嘆","嘆"],["器","器"],["塀","塀"],["墨","墨"],["層","層"],["悔","悔"],["慨","慨"],["憎","憎"],["懲","懲"],["敏","敏"],["暑","暑"],["梅","梅"],["海","海"],["渚","渚"],["漢","漢"],["煮","煮"],["琢","琢"],["碑","碑"],["社","社"],["祉","祉"],["祈","祈"],["祐","祐"],["祖","祖"],["祝","祝"],["禍","禍"],["禎","禎"],["穀","穀"],["突","突"],["節","節"],["練","練"],["繁","繁"],["署","署"],["者","者"],["臭","臭"],["著","著"],["褐","褐"],["視","視"],["謁","謁"],["謹","謹"],["賓","賓"],["贈","贈"],["逸","逸"],["難","難"],["響","響"],["頻","頻"]],"STCharacters":[["㐷","傌"],["㐹","㑶","㐹"],["㐽","偑"],["㑇","㑳"],["㑈","倲"],["㑔","㑯"],["㑩","儸"],["㓆","𠗣"],["㓥","劏"],["㓰","劃"],["㔉","劚"],["㖊","噚"],["㖞","喎"],["㗷","㘔"],["㘎","㘚"],["㚯","㜄"],["㛀","媰"],["㛟","𡞵"],["㛠","𡢃"],["㛣","㜏"],["㛤","孋"],["㛿","𡠹"],["㟆","㠏"],["㟜","𡾱"],["㟥","嵾"],["㡎","幓"],["㤘","㥮"],["㤽","懤"],["㥪","慺"],["㧏","掆"],["㧐","㩳"],["㧑","撝"],["㧟","擓"],["㧰","擽"],["㨫","㩜"],["㭎","棡"],["㭏","椲"],["㭣","𣙎"],["㭤","樢"],["㭴","樫"],["㱩","殰"],["㱮","殨"],["㲿","瀇"],["㳔","濧"],["㳕","灡"],["㳠","澾"],["㳡","濄"],["㳢","𣾷"],["㳽","瀰"],["㴋","潚"],["㶉","鸂"],["㶶","燶"],["㶽","煱"],["㺍","獱"],["㻅","璯"],["㻏","𤫩"],["㻘","𤪺"],["䀥","䁻"],["䁖","瞜"],["䂵","碽"],["䃅","磾"],["䅉","稏"],["䅟","穇"],["䅪","𥢢"],["䇲","筴"],["䉤","籔"],["䌶","䊷"],["䌷","紬"],["䌸","縳"],["䌹","絅"],["䌺","䋙"],["䌻","䋚"],["䌼","綐"],["䌽","綵"],["䌾","䋻"],["䌿","䋹"],["䍀","繿"],["䍁","繸"],["䍠","䍦"],["䎬","䎱"],["䏝","膞"],["䑽","𦪙"],["䓓","薵"],["䓕","薳"],["䓖","藭"],["䓨","罃"],["䗖","螮"],["䘛","𧝞"],["䘞","𧜗"],["䙊","𧜵"],["䙌","䙡"],["䙓","襬"],["䜣","訢"],["䜤","鿁"],["䜥","𧩙"],["䜧","䜀"],["䜩","讌"],["䝙","貙"],["䞌","𧵳"],["䞍","䝼"],["䞎","𧶧"],["䞐","賰"],["䟢","躎"],["䢀","𨊰"],["䢁","𨊸"],["䢂","𨋢"],["䥺","釾"],["䥽","鏺"],["䥾","䥱"],["䥿","𨯅"],["䦀","𨦫"],["䦁","𨧜"],["䦂","䥇"],["䦃","鐯"],["䦅","鐥"],["䦆","钁"],["䦶","䦛"],["䦷","䦟"],["䩄","靦"],["䭪","𩞯"],["䯃","𩣑"],["䯄","騧"],["䯅","䯀"],["䲝","䱽"],["䲞","𩶘"],["䲟","鮣"],["䲠","鰆"],["䲡","鰌"],["䲢","鰧"],["䲣","䱷"],["䴓","鳾"],["䴔","鵁"],["䴕","鴷"],["䴖","鶄"],["䴗","鶪"],["䴘","鷈","鷉"],["䴙","鷿","鸊"],["䶮","龑"],["万","萬","万"],["与","與"],["丑","醜","丑"],["专","專"],["业","業"],["丛","叢"],["东","東"],["丝","絲"],["丢","丟"],["两","兩"],["严","嚴"],["丧","喪"],["个","個","箇"],["丰","豐","丰"],["临","臨"],["为","爲"],["丽","麗"],["举","舉"],["么","麼"],["义","義"],["乌","烏"],["乐","樂"],["乔","喬"],["习","習"],["乡","鄉"],["书","書"],["买","買"],["乱","亂"],["了","了","瞭"],["争","爭"],["于","於","于"],["亏","虧"],["云","雲","云"],["亘","亙","亘"],["亚","亞"],["产","產"],["亩","畝"],["亲","親"],["亵","褻"],["亸","嚲"],["亿","億"],["仅","僅"],["仆","僕","仆"],["仇","仇","讎"],["从","從"],["仑","侖","崙"],["仓","倉"],["仪","儀"],["们","們"],["价","價","价"],["仿","仿","彷"],["众","衆"],["优","優"],["伙","夥","伙"],["会","會"],["伛","傴"],["伞","傘"],["伟","偉"],["传","傳"],["伡","俥"],["伣","俔"],["伤","傷"],["伥","倀"],["伦","倫"],["伧","傖"],["伪","僞"],["伫","佇"],["体","體"],["余","餘","余"],["佛","佛","彿"],["佣","傭","佣"],["佥","僉"],["侠","俠"],["侣","侶"],["侥","僥"],["侦","偵"],["侧","側"],["侨","僑"],["侩","儈"],["侪","儕"],["侬","儂"],["侭","儘"],["俊","俊","儁"],["俣","俁"],["俦","儔"],["俨","儼"],["俩","倆"],["俪","儷"],["俫","倈"],["俭","儉"],["修","修","脩"],["借","借","藉"],["债","債"],["倾","傾"],["偬","傯"],["偻","僂"],["偾","僨"],["偿","償"],["傤","儎"],["傥","儻"],["傧","儐"],["储","儲"],["傩","儺"],["僵","僵","殭"],["儿","兒"],["克","克","剋"],["兑","兌"],["兖","兗"],["党","黨","党"],["兰","蘭"],["关","關"],["兴","興"],["兹","茲"],["养","養"],["兽","獸"],["冁","囅"],["内","內"],["冈","岡"],["册","冊"],["写","寫"],["军","軍"],["农","農"],["冬","冬","鼕"],["冯","馮"],["冲","衝","沖"],["决","決"],["况","況"],["冻","凍"],["净","淨"],["凄","悽","淒"],["准","準","准"],["凉","涼"],["凌","凌","淩"],["减","減"],["凑","湊"],["凛","凜"],["几","幾","几","機"],["凤","鳳"],["凫","鳧"],["凭","憑"],["凯","凱"],["凶","兇","凶"],["出","出","齣"],["击","擊"],["凿","鑿"],["刍","芻"],["划","劃","划"],["刘","劉"],["则","則"],["刚","剛"],["创","創"],["删","刪"],["别","別","彆"],["刬","剗"],["刭","剄"],["刮","刮","颳"],["制","制","製"],["刹","剎"],["刽","劊"],["刾","㓨"],["刿","劌"],["剀","剴"],["剂","劑"],["剐","剮"],["剑","劍"],["剥","剝"],["剧","劇"],["劝","勸"],["办","辦"],["务","務"],["劢","勱"],["动","動"],["励","勵"],["劲","勁"],["劳","勞"],["势","勢"],["勋","勳","勛"],["勚","勩"],["匀","勻"],["匦","匭"],["匮","匱"],["区","區"],["医","醫"],["千","千","韆"],["升","升","昇"],["华","華"],["协","協"],["单","單"],["卖","賣"],["卜","卜","蔔"],["占","佔","占"],["卢","盧"],["卤","滷","鹵"],["卧","臥"],["卫","衛"],["却","卻"],["卷","卷","捲"],["卺","巹"],["厂","廠","厂"],["厅","廳"],["历","歷","曆"],["厉","厲"],["压","壓"],["厌","厭"],["厍","厙"],["厐","龎"],["厕","廁"],["厘","釐","厘"],["厢","廂"],["厣","厴"],["厦","廈"],["厨","廚"],["厩","廄"],["厮","廝"],["县","縣"],["叁","叄"],["参","參","蔘"],["叆","靉"],["叇","靆"],["双","雙"],["发","發","髮"],["变","變"],["叙","敘"],["叠","疊"],["只","只","隻","祇"],["台","臺","檯","颱","台"],["叶","葉","叶"],["号","號"],["叹","嘆","歎"],["叽","嘰"],["吁","籲","吁"],["合","合","閤"],["吊","吊","弔"],["同","同","衕"],["后","後","后"],["向","向","嚮","曏"],["吓","嚇"],["吕","呂"],["吗","嗎"],["吣","唚"],["吨","噸"],["听","聽"],["启","啓"],["吴","吳"],["呐","吶"],["呒","嘸"],["呓","囈"],["呕","嘔"],["呖","嚦"],["呗","唄"],["员","員"],["呙","咼"],["呛","嗆"],["呜","嗚"],["周","周","週","賙"],["咏","詠"],["咙","嚨"],["咛","嚀"],["咝","噝"],["咤","吒"],["咨","諮","咨"],["咸","鹹","咸"],["咽","咽","嚥"],["哄","哄","鬨"],["响","響"],["哑","啞"],["哒","噠"],["哓","嘵"],["哔","嗶"],["哕","噦"],["哗","譁","嘩"],["哙","噲"],["哜","嚌"],["哝","噥"],["哟","喲"],["唇","脣"],["唛","嘜"],["唝","嗊"],["唠","嘮"],["唡","啢"],["唢","嗩"],["唤","喚"],["啧","嘖"],["啬","嗇"],["啭","囀"],["啮","齧","嚙"],["啯","嘓"],["啰","囉"],["啴","嘽"],["啸","嘯"],["喂","喂","餵"],["喷","噴"],["喽","嘍"],["喾","嚳"],["嗫","囁"],["嗳","噯"],["嘘","噓"],["嘤","嚶"],["嘱","囑"],["噜","嚕"],["噪","噪","譟"],["嚣","囂"],["回","回","迴"],["团","團","糰"],["园","園"],["困","困","睏"],["囱","囪"],["围","圍"],["囵","圇"],["国","國"],["图","圖"],["圆","圓"],["圣","聖"],["圹","壙"],["场","場"],["坂","阪"],["坏","壞"],["坐","坐","座"],["块","塊"],["坚","堅"],["坛","壇","罈"],["坜","壢"],["坝","壩"],["坞","塢"],["坟","墳"],["坠","墜"],["垄","壟"],["垅","壠"],["垆","壚"],["垒","壘"],["垦","墾"],["垩","堊"],["垫","墊"],["垭","埡"],["垯","墶"],["垱","壋"],["垲","塏"],["垴","堖"],["埘","塒"],["埙","壎","塤"],["埚","堝"],["埯","垵"],["堑","塹"],["堕","墮"],["塆","壪"],["墙","牆"],["壮","壯"],["声","聲"],["壳","殼"],["壶","壺"],["壸","壼"],["处","處"],["备","備"],["复","復","複","覆"],["够","夠"],["夫","夫","伕"],["头","頭"],["夸","誇","夸"],["夹","夾"],["夺","奪"],["奁","奩"],["奂","奐"],["奋","奮"],["奖","獎"],["奥","奧"],["奸","奸","姦"],["妆","妝"],["妇","婦"],["妈","媽"],["妩","嫵"],["妪","嫗"],["妫","嬀"],["姗","姍"],["姜","姜","薑"],["姹","奼"],["娄","婁"],["娅","婭"],["娆","嬈"],["娇","嬌"],["娈","孌"],["娘","娘","孃"],["娱","娛"],["娲","媧"],["娴","嫺","嫻"],["婳","嫿"],["婴","嬰"],["婵","嬋"],["婶","嬸"],["媪","媼"],["媭","嬃"],["嫒","嬡"],["嫔","嬪"],["嫱","嬙"],["嬷","嬤"],["孙","孫"],["学","學"],["孪","孿"],["宁","寧","甯"],["宝","寶"],["实","實"],["宠","寵"],["审","審"],["宪","憲"],["宫","宮"],["家","家","傢"],["宽","寬"],["宾","賓"],["寝","寢"],["对","對"],["寻","尋"],["导","導"],["寿","壽"],["将","將"],["尔","爾"],["尘","塵"],["尝","嘗","嚐"],["尧","堯"],["尴","尷"],["尸","屍","尸"],["尽","盡","儘"],["局","局","侷"],["层","層"],["屃","屓"],["屉","屜"],["届","屆"],["属","屬"],["屡","屢"],["屦","屨"],["屿","嶼"],["岁","歲"],["岂","豈"],["岖","嶇"],["岗","崗"],["岘","峴"],["岙","嶴"],["岚","嵐"],["岛","島"],["岩","巖","岩"],["岭","嶺"],["岳","嶽","岳"],["岽","崬"],["岿","巋"],["峃","嶨"],["峄","嶧"],["峡","峽"],["峣","嶢"],["峤","嶠"],["峥","崢"],["峦","巒"],["峰","峯"],["崂","嶗"],["崃","崍"],["崄","嶮"],["崭","嶄"],["嵘","嶸"],["嵚","嶔"],["嵝","嶁"],["巅","巔"],["巨","巨","鉅"],["巩","鞏"],["巯","巰"],["币","幣"],["布","布","佈"],["帅","帥"],["师","師"],["帏","幃"],["帐","帳"],["帘","簾","帘"],["帜","幟"],["带","帶"],["帧","幀"],["席","席","蓆"],["帮","幫"],["帱","幬"],["帻","幘"],["帼","幗"],["幂","冪"],["幞","襆"],["干","幹","乾","干"],["并","並","併"],["幸","幸","倖"],["广","廣","广"],["庄","莊"],["庆","慶"],["床","牀"],["庐","廬"],["庑","廡"],["库","庫"],["应","應"],["庙","廟"],["庞","龐"],["废","廢"],["庵","庵","菴"],["庼","廎"],["廪","廩"],["开","開"],["异","異"],["弃","棄"],["弑","弒"],["张","張"],["弥","彌","瀰"],["弦","弦","絃"],["弪","弳"],["弯","彎"],["弹","彈"],["强","強"],["归","歸"],["当","當","噹"],["录","錄","彔"],["彝","彝"],["彟","彠"],["彦","彥"],["彨","彲"],["彩","彩","綵"],["彻","徹"],["征","徵","征"],["径","徑"],["徕","徠"],["御","御","禦"],["忆","憶"],["忏","懺"],["志","志","誌"],["忧","憂"],["念","念","唸"],["忾","愾"],["怀","懷"],["态","態"],["怂","慫"],["怃","憮"],["怄","慪"],["怅","悵"],["怆","愴"],["怜","憐"],["总","總"],["怼","懟"],["怿","懌"],["恋","戀"],["恒","恆"],["恤","恤","卹"],["恳","懇"],["恶","惡","噁"],["恸","慟"],["恹","懨"],["恺","愷"],["恻","惻"],["恼","惱"],["恽","惲"],["悦","悅"],["悫","愨"],["悬","懸"],["悭","慳"],["悮","悞"],["悯","憫"],["惊","驚"],["惧","懼"],["惨","慘"],["惩","懲"],["惫","憊"],["惬","愜"],["惭","慚"],["惮","憚"],["惯","慣"],["愈","愈","癒"],["愠","慍"],["愤","憤"],["愦","憒"],["愿","願","愿"],["慑","懾"],["慭","憖"],["懑","懣"],["懒","懶"],["懔","懍"],["戆","戇"],["戋","戔"],["戏","戲"],["戗","戧"],["战","戰"],["戚","戚","慼","鏚"],["戬","戩"],["戯","戱"],["户","戶"],["才","才","纔"],["扎","扎","紮"],["扑","撲"],["托","託","托"],["扣","扣","釦"],["执","執"],["扩","擴"],["扪","捫"],["扫","掃"],["扬","揚"],["扰","擾"],["折","折","摺"],["抚","撫"],["抛","拋"],["抟","摶"],["抠","摳"],["抡","掄"],["抢","搶"],["护","護"],["报","報"],["抬","擡"],["抵","抵","牴"],["担","擔"],["拐","拐","柺"],["拟","擬"],["拢","攏"],["拣","揀"],["拥","擁"],["拦","攔"],["拧","擰"],["拨","撥"],["择","擇"],["挂","掛","挂"],["挚","摯"],["挛","攣"],["挜","掗"],["挝","撾"],["挞","撻"],["挟","挾"],["挠","撓"],["挡","擋"],["挢","撟"],["挣","掙"],["挤","擠"],["挥","揮"],["挦","撏"],["挨","挨","捱"],["挽","挽","輓"],["捝","挩"],["捞","撈"],["损","損"],["捡","撿"],["换","換"],["捣","搗"],["据","據","据"],["掳","擄"],["掴","摑"],["掷","擲"],["掸","撣"],["掺","摻"],["掼","摜"],["揽","攬"],["揾","搵"],["揿","撳"],["搀","攙"],["搁","擱"],["搂","摟"],["搄","揯"],["搅","攪"],["搜","搜","蒐"],["携","攜"],["摄","攝"],["摅","攄"],["摆","擺","襬"],["摇","搖"],["摈","擯"],["摊","攤"],["撄","攖"],["撑","撐"],["撵","攆"],["撷","擷"],["撸","擼"],["撺","攛"],["擜","㩵"],["擞","擻"],["攒","攢"],["敌","敵"],["教","教"],["敚","敓"],["敛","斂"],["敩","斆"],["数","數"],["斋","齋"],["斓","斕"],["斗","鬥","斗"],["斩","斬"],["断","斷"],["无","無"],["旧","舊"],["时","時"],["旷","曠"],["旸","暘"],["昆","昆","崑"],["昙","曇"],["昵","暱"],["昼","晝"],["昽","曨"],["显","顯"],["晋","晉"],["晒","曬"],["晓","曉"],["晔","曄"],["晕","暈"],["晖","暉"],["暂","暫"],["暅","𣈶"],["暗","暗","闇"],["暧","曖"],["曲","曲","麴"],["术","術","朮"],["朱","朱","硃"],["朴","樸","朴"],["机","機"],["杀","殺"],["杂","雜"],["权","權"],["杆","杆","桿"],["杠","槓","杠"],["条","條"],["来","來"],["杨","楊"],["杩","榪"],["杯","杯","盃"],["杰","傑","杰"],["松","鬆","松"],["板","板","闆"],["极","極","极"],["构","構"],["枞","樅"],["枢","樞"],["枣","棗"],["枥","櫪"],["枧","梘"],["枨","棖"],["枪","槍"],["枫","楓"],["枭","梟"],["柜","櫃","柜"],["柠","檸"],["查","查"],["柽","檉"],["栀","梔"],["栅","柵"],["标","標"],["栈","棧"],["栉","櫛"],["栊","櫳"],["栋","棟"],["栌","櫨"],["栎","櫟"],["栏","欄"],["树","樹"],["栖","棲"],["栗","慄","栗"],["样","樣"],["核","核","覈"],["栾","欒"],["桠","椏"],["桡","橈"],["桢","楨"],["档","檔"],["桤","榿"],["桥","橋"],["桦","樺"],["桧","檜"],["桨","槳"],["桩","樁"],["桪","樳"],["梁","樑","梁"],["梦","夢"],["梼","檮"],["梾","棶"],["梿","槤"],["检","檢"],["棁","梲"],["棂","櫺","欞"],["棱","棱"],["椁","槨"],["椝","槼"],["椟","櫝"],["椠","槧"],["椢","槶"],["椤","欏"],["椫","樿"],["椭","橢"],["椮","槮"],["楼","樓"],["榄","欖"],["榅","榲"],["榇","櫬"],["榈","櫚"],["榉","櫸"],["榝","樧"],["槚","檟"],["槛","檻"],["槟","檳"],["槠","櫧"],["横","橫"],["樯","檣"],["樱","櫻"],["橥","櫫"],["橱","櫥"],["橹","櫓"],["橼","櫞"],["檩","檁"],["欢","歡"],["欤","歟"],["欧","歐"],["欲","欲","慾"],["歼","殲"],["殁","歿"],["殇","殤"],["残","殘"],["殒","殞"],["殓","殮"],["殚","殫"],["殡","殯"],["殴","毆"],["毁","毀","燬","譭"],["毂","轂"],["毕","畢"],["毙","斃"],["毡","氈"],["毵","毿"],["毶","毿","𣯶"],["氇","氌"],["气","氣"],["氢","氫"],["氩","氬"],["氲","氳"],["汇","匯","彙"],["汉","漢"],["污","污"],["汤","湯"],["汹","洶"],["沈","沈","瀋"],["沟","溝"],["没","沒"],["沣","灃"],["沤","漚"],["沥","瀝"],["沦","淪"],["沧","滄"],["沨","渢"],["沩","潙"],["沪","滬"],["泛","泛","氾","汎"],["泞","濘"],["注","注","註"],["泪","淚"],["泶","澩"],["泷","瀧"],["泸","瀘"],["泺","濼"],["泻","瀉"],["泼","潑"],["泽","澤"],["泾","涇"],["洁","潔"],["洒","灑"],["洼","窪"],["浃","浹"],["浅","淺"],["浆","漿"],["浇","澆"],["浈","湞"],["浉","溮"],["浊","濁"],["测","測"],["浍","澮"],["济","濟"],["浏","瀏"],["浐","滻"],["浑","渾"],["浒","滸"],["浓","濃"],["浔","潯"],["浕","濜"],["涂","塗","涂"],["涌","涌"],["涚","涗"],["涛","濤"],["涝","澇"],["涞","淶"],["涟","漣"],["涠","潿"],["涡","渦"],["涢","溳"],["涣","渙"],["涤","滌"],["润","潤"],["涧","澗"],["涨","漲"],["涩","澀"],["淀","澱","淀"],["渊","淵"],["渌","淥"],["渍","漬"],["渎","瀆"],["渐","漸"],["渑","澠"],["渔","漁"],["渖","瀋"],["渗","滲"],["温","溫"],["游","遊","游"],["湾","灣"],["湿","溼"],["溁","濚"],["溃","潰"],["溅","濺"],["溆","漵"],["溇","漊"],["滗","潷"],["滚","滾"],["滞","滯"],["滟","灩","灧"],["滠","灄"],["满","滿"],["滢","瀅"],["滤","濾"],["滥","濫"],["滦","灤"],["滨","濱"],["滩","灘"],["滪","澦"],["漓","漓","灕"],["潆","瀠"],["潇","瀟"],["潋","瀲"],["潍","濰"],["潜","潛"],["潴","瀦"],["澛","瀂"],["澜","瀾"],["濑","瀨"],["濒","瀕"],["灏","灝"],["灭","滅"],["灯","燈"],["灵","靈"],["灶","竈"],["灾","災"],["灿","燦"],["炀","煬"],["炉","爐"],["炖","燉"],["炜","煒"],["炝","熗"],["点","點"],["炼","煉","鍊"],["炽","熾"],["烁","爍"],["烂","爛"],["烃","烴"],["烛","燭"],["烟","煙","菸"],["烦","煩"],["烧","燒"],["烨","燁"],["烩","燴"],["烫","燙"],["烬","燼"],["热","熱"],["焕","煥"],["焖","燜"],["焘","燾"],["煴","熅"],["熏","薰","燻"],["爱","愛"],["爷","爺"],["牍","牘"],["牦","犛"],["牵","牽"],["牺","犧"],["犊","犢"],["状","狀"],["犷","獷"],["犸","獁"],["犹","猶"],["狈","狽"],["狝","獮"],["狞","獰"],["独","獨"],["狭","狹"],["狮","獅"],["狯","獪"],["狰","猙"],["狱","獄"],["狲","猻"],["猃","獫"],["猎","獵"],["猕","獼"],["猡","玀"],["猪","豬"],["猫","貓"],["猬","蝟"],["献","獻"],["獭","獺"],["玑","璣"],["玙","璵"],["玚","瑒"],["玛","瑪"],["玮","瑋"],["环","環"],["现","現"],["玱","瑲"],["玺","璽"],["珐","琺"],["珑","瓏"],["珰","璫"],["珲","琿"],["琎","璡"],["琏","璉"],["琐","瑣"],["琼","瓊"],["瑶","瑤"],["瑷","璦"],["瑸","璸"],["璎","瓔"],["瓒","瓚"],["瓮","甕"],["瓯","甌"],["电","電"],["画","畫"],["畅","暢"],["畴","疇"],["疖","癤"],["疗","療"],["疟","瘧"],["疠","癘"],["疡","瘍"],["疬","癧"],["疭","瘲"],["疮","瘡"],["疯","瘋"],["疱","皰"],["疴","痾"],["症","症","癥"],["痈","癰"],["痉","痙"],["痒","癢"],["痖","瘂"],["痨","癆"],["痪","瘓"],["痫","癇"],["痴","癡"],["瘅","癉"],["瘆","瘮"],["瘗","瘞"],["瘘","瘻"],["瘪","癟"],["瘫","癱"],["瘾","癮"],["瘿","癭"],["癞","癩"],["癣","癬"],["癫","癲"],["皂","皁","皂"],["皑","皚"],["皱","皺"],["皲","皸"],["盏","盞"],["盐","鹽"],["监","監"],["盖","蓋"],["盗","盜"],["盘","盤"],["眍","瞘"],["眦","眥"],["眬","矓"],["睁","睜"],["睐","睞"],["睑","瞼"],["瞆","瞶"],["瞒","瞞"],["瞩","矚"],["矩","矩","榘"],["矫","矯"],["矶","磯"],["矾","礬"],["矿","礦"],["砀","碭"],["码","碼"],["砖","磚"],["砗","硨"],["砚","硯"],["砜","碸"],["砺","礪"],["砻","礱"],["砾","礫"],["础","礎"],["硁","硜"],["硕","碩"],["硖","硤"],["硗","磽"],["硙","磑"],["硚","礄"],["确","確","确"],["硵","磠"],["硷","礆"],["碍","礙"],["碛","磧"],["碜","磣"],["碱","鹼"],["礼","禮"],["祃","禡"],["祎","禕"],["祢","禰"],["祯","禎"],["祷","禱"],["祸","禍"],["禀","稟"],["禄","祿"],["禅","禪"],["离","離"],["私","私","俬"],["秃","禿"],["秆","稈"],["秋","秋","鞦"],["种","種","种"],["秘","祕"],["积","積"],["称","稱"],["秽","穢"],["秾","穠"],["稆","穭"],["税","稅"],["稣","穌"],["稳","穩"],["穑","穡"],["穗","穗","繐"],["穞","穭"],["穷","窮"],["窃","竊"],["窍","竅"],["窎","窵"],["窑","窯"],["窜","竄"],["窝","窩"],["窥","窺"],["窦","竇"],["窭","窶"],["竖","豎"],["竞","競"],["笃","篤"],["笋","筍"],["笔","筆"],["笕","筧"],["笺","箋"],["笼","籠"],["笾","籩"],["筑","築","筑"],["筚","篳"],["筛","篩"],["筜","簹"],["筝","箏"],["筹","籌"],["筼","篔"],["签","籤","簽"],["筿","篠"],["简","簡"],["箓","籙"],["箦","簀"],["箧","篋"],["箨","籜"],["箩","籮"],["箪","簞"],["箫","簫"],["篑","簣"],["篓","簍"],["篮","籃"],["篯","籛"],["篱","籬"],["簖","籪"],["籁","籟"],["籴","糴"],["类","類"],["籼","秈"],["粜","糶"],["粝","糲"],["粤","粵"],["粪","糞"],["粮","糧"],["粽","糉"],["糁","糝"],["糇","餱"],["糍","餈"],["系","系","係","繫"],["紧","緊"],["累","累"],["絷","縶"],["緼","縕"],["縆","緪"],["纟","糹"],["纠","糾"],["纡","紆"],["红","紅"],["纣","紂"],["纤","纖","縴"],["纥","紇"],["约","約"],["级","級"],["纨","紈"],["纩","纊"],["纪","紀"],["纫","紉"],["纬","緯"],["纭","紜"],["纮","紘"],["纯","純"],["纰","紕"],["纱","紗"],["纲","綱"],["纳","納"],["纴","紝"],["纵","縱"],["纶","綸"],["纷","紛"],["纸","紙"],["纹","紋"],["纺","紡"],["纻","紵"],["纼","紖"],["纽","紐","鈕"],["纾","紓"],["线","線"],["绀","紺"],["绁","紲"],["绂","紱"],["练","練"],["组","組"],["绅","紳"],["细","細"],["织","織"],["终","終"],["绉","縐"],["绊","絆"],["绋","紼"],["绌","絀"],["绍","紹"],["绎","繹"],["经","經"],["绐","紿"],["绑","綁"],["绒","絨"],["结","結"],["绔","絝"],["绕","繞"],["绖","絰"],["绗","絎"],["绘","繪"],["给","給"],["绚","絢"],["绛","絳"],["络","絡"],["绝","絕"],["绞","絞"],["统","統"],["绠","綆"],["绡","綃"],["绢","絹"],["绣","繡"],["绤","綌"],["绥","綏"],["绦","絛"],["继","繼"],["绨","綈"],["绩","績"],["绪","緒"],["绫","綾"],["绬","緓"],["续","續"],["绮","綺"],["绯","緋"],["绰","綽"],["绱","鞝","緔"],["绲","緄"],["绳","繩"],["维","維"],["绵","綿"],["绶","綬"],["绷","繃","綳"],["绸","綢"],["绹","綯"],["绺","綹"],["绻","綣"],["综","綜"],["绽","綻"],["绾","綰"],["绿","綠"],["缀","綴"],["缁","緇"],["缂","緙"],["缃","緗"],["缄","緘"],["缅","緬"],["缆","纜"],["缇","緹"],["缈","緲"],["缉","緝"],["缊","縕"],["缋","繢"],["缌","緦"],["缍","綞"],["缎","緞"],["缏","緶"],["缐","線"],["缑","緱"],["缒","縋"],["缓","緩"],["缔","締"],["缕","縷"],["编","編"],["缗","緡"],["缘","緣"],["缙","縉"],["缚","縛"],["缛","縟"],["缜","縝"],["缝","縫"],["缞","縗"],["缟","縞"],["缠","纏"],["缡","縭"],["缢","縊"],["缣","縑"],["缤","繽"],["缥","縹"],["缦","縵"],["缧","縲"],["缨","纓"],["缩","縮"],["缪","繆"],["缫","繅"],["缬","纈"],["缭","繚"],["缮","繕"],["缯","繒"],["缰","繮"],["缱","繾"],["缲","繰"],["缳","繯"],["缴","繳"],["缵","纘"],["罂","罌"],["网","網"],["罗","羅"],["罚","罰"],["罢","罷"],["罴","羆"],["羁","羈"],["羟","羥"],["羡","羨"],["群","羣"],["翘","翹"],["翙","翽"],["翚","翬"],["耢","耮"],["耧","耬"],["耸","聳"],["耻","恥"],["聂","聶"],["聋","聾"],["职","職"],["聍","聹"],["联","聯"],["聩","聵"],["聪","聰"],["肃","肅"],["肠","腸"],["肤","膚"],["肮","骯"],["肴","餚"],["肾","腎"],["肿","腫"],["胀","脹"],["胁","脅"],["胄","胄","冑"],["胆","膽"],["背","背","揹"],["胜","勝","胜"],["胡","胡","鬍","衚"],["胧","朧"],["胨","腖"],["胪","臚"],["胫","脛"],["胶","膠"],["脉","脈"],["脍","膾"],["脏","髒","臟"],["脐","臍"],["脑","腦"],["脓","膿"],["脔","臠"],["脚","腳"],["脱","脫"],["脶","腡"],["脸","臉"],["腊","臘","腊"],["腌","醃","腌"],["腘","膕"],["腭","齶"],["腻","膩"],["腼","靦"],["腽","膃"],["腾","騰"],["膑","臏"],["膻","羶","膻"],["臜","臢"],["致","致","緻"],["舆","輿"],["舍","舍","捨"],["舣","艤"],["舰","艦"],["舱","艙"],["舻","艫"],["艰","艱"],["艳","豔","艷"],["艺","藝"],["节","節"],["芈","羋"],["芗","薌"],["芜","蕪"],["芦","蘆"],["芲","芲","菕"],["芸","芸","蕓"],["苁","蓯"],["苇","葦"],["苈","藶"],["苋","莧"],["苌","萇"],["苍","蒼"],["苎","苧"],["苏","蘇","甦","囌"],["苔","苔","薹"],["苘","檾"],["苧","薴"],["苹","蘋","苹"],["范","範","范"],["茎","莖"],["茏","蘢"],["茑","蔦"],["茔","塋"],["茕","煢"],["茧","繭"],["荆","荊"],["荐","薦","荐"],["荙","薘"],["荚","莢"],["荛","蕘"],["荜","蓽"],["荝","萴"],["荞","蕎"],["荟","薈"],["荠","薺"],["荡","蕩","盪"],["荣","榮"],["荤","葷"],["荥","滎"],["荦","犖"],["荧","熒"],["荨","蕁"],["荩","藎"],["荪","蓀"],["荫","蔭","廕"],["荬","蕒"],["荭","葒"],["荮","葤"],["药","藥","葯"],["莅","蒞"],["莱","萊"],["莲","蓮"],["莳","蒔"],["莴","萵"],["莶","薟"],["获","獲","穫"],["莸","蕕"],["莹","瑩"],["莺","鶯"],["莼","蓴"],["萚","蘀"],["萝","蘿"],["萤","螢"],["营","營"],["萦","縈"],["萧","蕭"],["萨","薩"],["葱","蔥"],["蒀","蒕"],["蒇","蕆"],["蒉","蕢"],["蒋","蔣"],["蒌","蔞"],["蒏","醟"],["蒙","蒙","矇","濛","懞"],["蓝","藍"],["蓟","薊"],["蓠","蘺"],["蓣","蕷"],["蓥","鎣"],["蓦","驀"],["蔂","虆"],["蔑","蔑","衊"],["蔷","薔"],["蔹","蘞"],["蔺","藺"],["蔼","藹"],["蕰","薀"],["蕲","蘄"],["蕴","蘊"],["薮","藪"],["藓","蘚"],["藴","蘊"],["蘖","櫱"],["虏","虜"],["虑","慮"],["虚","虛"],["虫","蟲","虫"],["虬","虯"],["虮","蟣"],["虱","蝨"],["虽","雖"],["虾","蝦"],["虿","蠆"],["蚀","蝕"],["蚁","蟻"],["蚂","螞"],["蚃","蠁"],["蚕","蠶"],["蚝","蠔","蚝"],["蚬","蜆"],["蛊","蠱"],["蛎","蠣"],["蛏","蟶"],["蛮","蠻"],["蛰","蟄"],["蛱","蛺"],["蛲","蟯"],["蛳","螄"],["蛴","蠐"],["蜕","蛻"],["蜗","蝸"],["蜡","蠟","蜡"],["蝇","蠅"],["蝈","蟈"],["蝉","蟬"],["蝎","蠍"],["蝼","螻"],["蝾","蠑"],["螀","螿"],["螨","蟎"],["蟏","蠨"],["衅","釁"],["衔","銜"],["补","補"],["表","表","錶"],["衬","襯"],["衮","袞"],["袄","襖"],["袅","嫋","裊"],["袆","褘"],["袜","襪"],["袭","襲"],["袯","襏"],["装","裝"],["裆","襠"],["裈","褌"],["裢","褳"],["裣","襝"],["裤","褲"],["裥","襉","襇"],["褛","褸"],["褴","襤"],["襕","襴"],["见","見"],["观","觀"],["觃","覎"],["规","規"],["觅","覓"],["视","視"],["觇","覘"],["览","覽"],["觉","覺"],["觊","覬"],["觋","覡"],["觌","覿"],["觍","覥"],["觎","覦"],["觏","覯"],["觐","覲"],["觑","覷"],["觞","觴"],["触","觸"],["觯","觶"],["訚","誾"],["詟","讋"],["誉","譽"],["誊","謄"],["讠","訁"],["计","計"],["订","訂"],["讣","訃"],["认","認"],["讥","譏"],["讦","訐"],["讧","訌"],["讨","討"],["让","讓"],["讪","訕"],["讫","訖"],["讬","託"],["训","訓"],["议","議"],["讯","訊"],["记","記"],["讱","訒"],["讲","講"],["讳","諱"],["讴","謳"],["讵","詎"],["讶","訝"],["讷","訥"],["许","許"],["讹","訛"],["论","論"],["讻","訩"],["讼","訟"],["讽","諷"],["设","設"],["访","訪"],["诀","訣"],["证","證","証"],["诂","詁"],["诃","訶"],["评","評"],["诅","詛"],["识","識"],["诇","詗"],["诈","詐"],["诉","訴"],["诊","診"],["诋","詆"],["诌","謅"],["词","詞"],["诎","詘"],["诏","詔"],["诐","詖"],["译","譯"],["诒","詒"],["诓","誆"],["诔","誄"],["试","試"],["诖","詿"],["诗","詩"],["诘","詰"],["诙","詼"],["诚","誠"],["诛","誅"],["诜","詵"],["话","話"],["诞","誕"],["诟","詬"],["诠","詮"],["诡","詭"],["询","詢"],["诣","詣"],["诤","諍"],["该","該"],["详","詳"],["诧","詫"],["诨","諢"],["诩","詡"],["诪","譸"],["诫","誡"],["诬","誣"],["语","語"],["诮","誚"],["误","誤"],["诰","誥"],["诱","誘"],["诲","誨"],["诳","誑"],["说","說"],["诵","誦"],["诶","誒"],["请","請"],["诸","諸"],["诹","諏"],["诺","諾"],["读","讀"],["诼","諑"],["诽","誹"],["课","課"],["诿","諉"],["谀","諛"],["谁","誰"],["谂","諗"],["调","調"],["谄","諂"],["谅","諒"],["谆","諄"],["谇","誶"],["谈","談"],["谉","讅"],["谊","誼"],["谋","謀"],["谌","諶"],["谍","諜"],["谎","謊"],["谏","諫"],["谐","諧"],["谑","謔"],["谒","謁"],["谓","謂"],["谔","諤"],["谕","諭"],["谖","諼"],["谗","讒"],["谘","諮"],["谙","諳"],["谚","諺"],["谛","諦"],["谜","謎"],["谝","諞"],["谞","諝"],["谟","謨"],["谠","讜"],["谡","謖"],["谢","謝"],["谣","謠"],["谤","謗"],["谥","諡","謚"],["谦","謙"],["谧","謐"],["谨","謹"],["谩","謾"],["谪","謫"],["谫","譾"],["谬","謬"],["谭","譚"],["谮","譖"],["谯","譙"],["谰","讕"],["谱","譜"],["谲","譎"],["谳","讞"],["谴","譴"],["谵","譫"],["谶","讖"],["谷","谷","穀"],["豮","豶"],["贝","貝"],["贞","貞"],["负","負"],["贠","貟"],["贡","貢"],["财","財"],["责","責"],["贤","賢"],["败","敗"],["账","賬"],["货","貨"],["质","質"],["贩","販"],["贪","貪"],["贫","貧"],["贬","貶"],["购","購"],["贮","貯"],["贯","貫"],["贰","貳"],["贱","賤"],["贲","賁"],["贳","貰"],["贴","貼"],["贵","貴"],["贶","貺"],["贷","貸"],["贸","貿"],["费","費"],["贺","賀"],["贻","貽"],["贼","賊"],["贽","贄"],["贾","賈"],["贿","賄"],["赀","貲"],["赁","賃"],["赂","賂"],["赃","贓"],["资","資"],["赅","賅"],["赆","贐"],["赇","賕"],["赈","賑"],["赉","賚"],["赊","賒"],["赋","賦"],["赌","賭"],["赍","齎"],["赎","贖"],["赏","賞"],["赐","賜"],["赑","贔"],["赒","賙"],["赓","賡"],["赔","賠"],["赕","賧"],["赖","賴"],["赗","賵"],["赘","贅"],["赙","賻"],["赚","賺"],["赛","賽"],["赜","賾"],["赝","贗","贋"],["赞","贊","讚"],["赟","贇"],["赠","贈"],["赡","贍"],["赢","贏"],["赣","贛"],["赪","赬"],["赵","趙"],["赶","趕"],["趋","趨"],["趱","趲"],["趸","躉"],["跃","躍"],["跄","蹌"],["跞","躒"],["践","踐"],["跶","躂"],["跷","蹺"],["跸","蹕"],["跹","躚"],["跻","躋"],["踊","踊"],["踌","躊"],["踪","蹤"],["踬","躓"],["踯","躑"],["蹑","躡"],["蹒","蹣"],["蹰","躕"],["蹿","躥"],["躏","躪"],["躜","躦"],["躯","軀"],["輼","轀"],["车","車"],["轧","軋"],["轨","軌"],["轩","軒"],["轪","軑"],["轫","軔"],["转","轉"],["轭","軛"],["轮","輪"],["软","軟"],["轰","轟"],["轱","軲"],["轲","軻"],["轳","轤"],["轴","軸"],["轵","軹"],["轶","軼"],["轷","軤"],["轸","軫"],["轹","轢"],["轺","軺"],["轻","輕"],["轼","軾"],["载","載"],["轾","輊"],["轿","轎"],["辀","輈"],["辁","輇"],["辂","輅"],["较","較"],["辄","輒"],["辅","輔"],["辆","輛"],["辇","輦"],["辈","輩"],["辉","輝"],["辊","輥"],["辋","輞"],["辌","輬"],["辍","輟"],["辎","輜"],["辏","輳"],["辐","輻"],["辑","輯"],["辒","轀"],["输","輸"],["辔","轡"],["辕","轅"],["辖","轄"],["辗","輾"],["辘","轆"],["辙","轍"],["辚","轔"],["辞","辭"],["辟","闢","辟"],["辩","辯"],["辫","辮"],["边","邊"],["辽","遼"],["达","達"],["迁","遷"],["过","過"],["迈","邁"],["运","運"],["还","還"],["这","這"],["进","進"],["远","遠"],["违","違"],["连","連"],["迟","遲"],["迩","邇"],["迳","逕"],["迹","跡","蹟"],["适","適","适"],["选","選"],["逊","遜"],["递","遞"],["逦","邐"],["逻","邏"],["遗","遺"],["遥","遙"],["邓","鄧"],["邝","鄺"],["邬","鄔"],["邮","郵"],["邹","鄒"],["邺","鄴"],["邻","鄰"],["郁","鬱","郁"],["郏","郟"],["郐","鄶"],["郑","鄭"],["郓","鄆"],["郦","酈"],["郧","鄖"],["郸","鄲"],["酂","酇"],["酝","醞"],["酦","醱"],["酱","醬"],["酸","酸","痠"],["酽","釅"],["酾","釃"],["酿","釀"],["醖","醞"],["采","採","采","寀"],["释","釋"],["里","裏","里"],["鉴","鑑","鑒"],["銮","鑾"],["錾","鏨"],["钅","釒"],["钆","釓"],["钇","釔"],["针","針","鍼"],["钉","釘"],["钊","釗"],["钋","釙"],["钌","釕"],["钍","釷"],["钎","釺"],["钏","釧"],["钐","釤"],["钑","鈒"],["钒","釩"],["钓","釣"],["钔","鍆"],["钕","釹"],["钖","鍚"],["钗","釵"],["钘","鈃"],["钙","鈣"],["钚","鈈"],["钛","鈦"],["钜","鉅"],["钝","鈍"],["钞","鈔"],["钟","鍾","鐘","鈡"],["钠","鈉"],["钡","鋇"],["钢","鋼"],["钣","鈑"],["钤","鈐"],["钥","鑰","鈅"],["钦","欽"],["钧","鈞"],["钨","鎢"],["钩","鉤"],["钪","鈧"],["钫","鈁","鍅"],["钬","鈥"],["钭","鈄"],["钮","鈕"],["钯","鈀"],["钰","鈺"],["钱","錢"],["钲","鉦"],["钳","鉗"],["钴","鈷"],["钵","鉢"],["钶","鈳"],["钷","鉕"],["钸","鈽"],["钹","鈸"],["钺","鉞"],["钻","鑽","鉆"],["钼","鉬"],["钽","鉭"],["钾","鉀"],["钿","鈿"],["铀","鈾"],["铁","鐵"],["铂","鉑"],["铃","鈴"],["铄","鑠"],["铅","鉛"],["铆","鉚"],["铇","鉋"],["铈","鈰"],["铉","鉉"],["铊","鉈"],["铋","鉍"],["铌","鈮"],["铍","鈹"],["铎","鐸"],["铏","鉶"],["铐","銬"],["铑","銠"],["铒","鉺"],["铓","鋩"],["铔","錏"],["铕","銪"],["铖","鋮"],["铗","鋏"],["铘","鋣"],["铙","鐃"],["铚","銍"],["铛","鐺"],["铜","銅"],["铝","鋁"],["铞","銱"],["铟","銦"],["铠","鎧"],["铡","鍘"],["铢","銖"],["铣","銑"],["铤","鋌"],["铥","銩"],["铦","銛"],["铧","鏵"],["铨","銓"],["铩","鎩"],["铪","鉿"],["铫","銚"],["铬","鉻"],["铭","銘"],["铮","錚"],["铯","銫"],["铰","鉸"],["铱","銥"],["铲","鏟","剷"],["铳","銃"],["铴","鐋"],["铵","銨"],["银","銀"],["铷","銣"],["铸","鑄"],["铹","鐒"],["铺","鋪"],["铻","鋙"],["铼","錸"],["铽","鋱"],["链","鏈","鍊"],["铿","鏗"],["销","銷"],["锁","鎖"],["锂","鋰"],["锃","鋥"],["锄","鋤"],["锅","鍋"],["锆","鋯"],["锇","鋨"],["锈","鏽"],["锉","銼"],["锊","鋝"],["锋","鋒"],["锌","鋅"],["锍","鋶"],["锎","鐦"],["锏","鐗","鐧"],["锐","銳"],["锑","銻"],["锒","鋃"],["锓","鋟"],["锔","鋦"],["锕","錒"],["锖","錆"],["锗","鍺"],["锘","鍩"],["错","錯"],["锚","錨"],["锛","錛"],["锜","錡"],["锝","鍀"],["锞","錁"],["锟","錕"],["锠","錩"],["锡","錫"],["锢","錮"],["锣","鑼"],["锤","錘"],["锥","錐"],["锦","錦"],["锧","鑕"],["锨","杴","鍁"],["锩","錈"],["锪","鍃"],["锫","錇","鉳"],["锬","錟"],["锭","錠"],["键","鍵"],["锯","鋸"],["锰","錳"],["锱","錙"],["锲","鍥"],["锳","鍈"],["锴","鍇"],["锵","鏘"],["锶","鍶"],["锷","鍔"],["锸","鍤"],["锹","鍬"],["锺","鍾"],["锻","鍛"],["锼","鎪"],["锽","鍠"],["锾","鍰"],["锿","鎄","鑀"],["镀","鍍"],["镁","鎂"],["镂","鏤"],["镃","鎡"],["镄","鐨"],["镅","鎇","鋂"],["镆","鏌"],["镇","鎮"],["镈","鎛"],["镉","鎘"],["镊","鑷"],["镋","钂","鎲"],["镌","鐫"],["镍","鎳"],["镎","鎿","錼"],["镏","鎦"],["镐","鎬"],["镑","鎊"],["镒","鎰"],["镓","鎵"],["镔","鑌"],["镕","鎔"],["镖","鏢"],["镗","鏜"],["镘","鏝"],["镙","鏍"],["镚","鏰"],["镛","鏞"],["镜","鏡"],["镝","鏑"],["镞","鏃"],["镟","鏇"],["镠","鏐"],["镡","鐔"],["镢","钁","鐝"],["镣","鐐"],["镤","鏷"],["镥","鑥"],["镦","鐓"],["镧","鑭"],["镨","鐠"],["镩","鑹"],["镪","鏹"],["镫","鐙"],["镬","鑊"],["镭","鐳"],["镮","鐶"],["镯","鐲"],["镰","鐮","鎌"],["镱","鐿"],["镲","鑔"],["镳","鑣"],["镴","鑞"],["镵","鑱"],["镶","鑲"],["长","長"],["门","門"],["闩","閂"],["闪","閃"],["闫","閆"],["闬","閈"],["闭","閉"],["问","問"],["闯","闖"],["闰","閏"],["闱","闈"],["闲","閒","閑"],["闳","閎"],["间","間"],["闵","閔"],["闶","閌"],["闷","悶"],["闸","閘"],["闹","鬧"],["闺","閨"],["闻","聞"],["闼","闥"],["闽","閩"],["闾","閭"],["闿","闓"],["阀","閥"],["阁","閣"],["阂","閡"],["阃","閫"],["阄","鬮"],["阅","閱"],["阆","閬"],["阇","闍"],["阈","閾"],["阉","閹"],["阊","閶"],["阋","鬩"],["阌","閿"],["阍","閽"],["阎","閻"],["阏","閼"],["阐","闡"],["阑","闌"],["阒","闃"],["阓","闠"],["阔","闊"],["阕","闋"],["阖","闔"],["阗","闐"],["阘","闒"],["阙","闕"],["阚","闞"],["阛","闤"],["队","隊"],["阳","陽"],["阴","陰"],["阵","陣"],["阶","階"],["际","際"],["陆","陸"],["陇","隴"],["陈","陳"],["陉","陘"],["陕","陝"],["陦","隯"],["陧","隉"],["陨","隕"],["险","險"],["随","隨"],["隐","隱"],["隶","隸"],["隽","雋"],["难","難"],["雇","僱"],["雏","雛"],["雕","雕","鵰"],["雠","讎"],["雳","靂"],["雾","霧"],["霁","霽"],["霉","黴"],["霡","霢"],["霭","靄"],["靓","靚"],["靔","靝"],["静","靜"],["面","面","麪"],["靥","靨"],["鞑","韃"],["鞒","鞽"],["鞯","韉"],["鞲","韝"],["韦","韋"],["韧","韌"],["韨","韍"],["韩","韓"],["韪","韙"],["韫","韞"],["韬","韜"],["韵","韻"],["页","頁"],["顶","頂"],["顷","頃"],["顸","頇"],["项","項"],["顺","順"],["须","須","鬚"],["顼","頊"],["顽","頑"],["顾","顧"],["顿","頓"],["颀","頎"],["颁","頒"],["颂","頌"],["颃","頏"],["预","預"],["颅","顱"],["领","領"],["颇","頗"],["颈","頸"],["颉","頡"],["颊","頰"],["颋","頲"],["颌","頜"],["颍","潁"],["颎","熲"],["颏","頦"],["颐","頤"],["频","頻"],["颒","頮"],["颓","頹"],["颔","頷"],["颕","頴"],["颖","穎"],["颗","顆"],["题","題"],["颙","顒"],["颚","顎"],["颛","顓"],["颜","顏"],["额","額"],["颞","顳"],["颟","顢"],["颠","顛"],["颡","顙"],["颢","顥"],["颣","纇"],["颤","顫"],["颥","顬"],["颦","顰"],["颧","顴"],["风","風"],["飏","颺"],["飐","颭"],["飑","颮"],["飒","颯"],["飓","颶"],["飔","颸"],["飕","颼"],["飖","颻"],["飗","飀"],["飘","飄"],["飙","飆"],["飚","飈"],["飞","飛"],["飨","饗"],["餍","饜"],["饣","飠"],["饤","飣"],["饥","飢","饑"],["饦","飥"],["饧","餳"],["饨","飩"],["饩","餼"],["饪","飪"],["饫","飫"],["饬","飭"],["饭","飯"],["饮","飲"],["饯","餞"],["饰","飾"],["饱","飽"],["饲","飼"],["饳","飿"],["饴","飴"],["饵","餌"],["饶","饒"],["饷","餉"],["饸","餄"],["饹","餎"],["饺","餃"],["饻","餏"],["饼","餅"],["饽","餑"],["饾","餖"],["饿","餓"],["馀","餘"],["馁","餒"],["馂","餕"],["馃","餜"],["馄","餛"],["馅","餡"],["馆","館"],["馇","餷"],["馈","饋"],["馉","餶"],["馊","餿"],["馋","饞"],["馌","饁"],["馍","饃"],["馎","餺"],["馏","餾"],["馐","饈"],["馑","饉"],["馒","饅"],["馓","饊"],["馔","饌"],["馕","饢"],["马","馬"],["驭","馭"],["驮","馱"],["驯","馴"],["驰","馳"],["驱","驅"],["驲","馹"],["驳","駁"],["驴","驢"],["驵","駔"],["驶","駛"],["驷","駟"],["驸","駙"],["驹","駒"],["驺","騶"],["驻","駐"],["驼","駝"],["驽","駑"],["驾","駕"],["驿","驛"],["骀","駘"],["骁","驍"],["骂","罵"],["骃","駰"],["骄","驕"],["骅","驊"],["骆","駱"],["骇","駭"],["骈","駢"],["骉","驫"],["骊","驪"],["骋","騁"],["验","驗"],["骍","騂"],["骎","駸"],["骏","駿"],["骐","騏"],["骑","騎"],["骒","騍"],["骓","騅"],["骔","騌"],["骕","驌"],["骖","驂"],["骗","騙"],["骘","騭"],["骙","騤"],["骚","騷"],["骛","騖"],["骜","驁"],["骝","騮"],["骞","騫"],["骟","騸"],["骠","驃"],["骡","騾"],["骢","驄"],["骣","驏"],["骤","驟"],["骥","驥"],["骦","驦"],["骧","驤"],["髅","髏"],["髋","髖"],["髌","髕"],["鬓","鬢"],["鬶","鬹"],["魇","魘"],["魉","魎"],["鱼","魚"],["鱽","魛"],["鱾","魢"],["鱿","魷"],["鲀","魨"],["鲁","魯"],["鲂","魴"],["鲃","䰾"],["鲄","魺"],["鲅","鮁"],["鲆","鮃"],["鲇","鮎"],["鲈","鱸"],["鲉","鮋"],["鲊","鮓"],["鲋","鮒"],["鲌","鮊"],["鲍","鮑"],["鲎","鱟"],["鲏","鮍"],["鲐","鮐"],["鲑","鮭"],["鲒","鮚"],["鲓","鮳"],["鲔","鮪"],["鲕","鮞"],["鲖","鮦"],["鲗","鰂"],["鲘","鮜"],["鲙","鱠"],["鲚","鱭"],["鲛","鮫"],["鲜","鮮"],["鲝","鮺"],["鲞","鯗"],["鲟","鱘"],["鲠","鯁"],["鲡","鱺"],["鲢","鰱"],["鲣","鰹"],["鲤","鯉"],["鲥","鰣"],["鲦","鰷"],["鲧","鯀"],["鲨","鯊"],["鲩","鯇"],["鲪","鮶"],["鲫","鯽"],["鲬","鯒"],["鲭","鯖"],["鲮","鯪"],["鲯","鯕"],["鲰","鯫"],["鲱","鯡"],["鲲","鯤"],["鲳","鯧"],["鲴","鯝"],["鲵","鯢"],["鲶","鮎","鯰"],["鲷","鯛"],["鲸","鯨"],["鲹","鰺"],["鲺","鯴"],["鲻","鯔"],["鲼","鱝"],["鲽","鰈"],["鲾","鰏"],["鲿","鱨"],["鳀","鯷"],["鳁","鰮","鰛"],["鳂","鰃"],["鳃","鰓"],["鳄","鱷"],["鳅","鰍"],["鳆","鰒"],["鳇","鰉"],["鳈","鰁"],["鳉","鱂"],["鳊","鯿"],["鳋","鰠"],["鳌","鰲"],["鳍","鰭"],["鳎","鰨"],["鳏","鰥"],["鳐","鰩"],["鳑","鰟"],["鳒","鰜"],["鳓","鰳"],["鳔","鰾"],["鳕","鱈"],["鳖","鱉"],["鳗","鰻"],["鳘","鰵"],["鳙","鱅"],["鳚","䲁"],["鳛","鰼"],["鳜","鱖"],["鳝","鱔"],["鳞","鱗"],["鳟","鱒"],["鳠","鱯"],["鳡","鱤"],["鳢","鱧"],["鳣","鱣"],["鳤","䲘"],["鸟","鳥"],["鸠","鳩"],["鸡","雞"],["鸢","鳶"],["鸣","鳴"],["鸤","鳲"],["鸥","鷗"],["鸦","鴉"],["鸧","鶬"],["鸨","鴇"],["鸩","鴆"],["鸪","鴣"],["鸫","鶇"],["鸬","鸕"],["鸭","鴨"],["鸮","鴞"],["鸯","鴦"],["鸰","鴒"],["鸱","鴟"],["鸲","鴝"],["鸳","鴛"],["鸴","鷽"],["鸵","鴕"],["鸶","鷥"],["鸷","鷙"],["鸸","鴯"],["鸹","鴰"],["鸺","鵂"],["鸻","鴴"],["鸼","鵃"],["鸽","鴿"],["鸾","鸞"],["鸿","鴻"],["鹀","鵐"],["鹁","鵓"],["鹂","鸝"],["鹃","鵑"],["鹄","鵠"],["鹅","鵝"],["鹆","鵒"],["鹇","鷳","鷴"],["鹈","鵜"],["鹉","鵡"],["鹊","鵲"],["鹋","鶓"],["鹌","鵪"],["鹍","鵾"],["鹎","鵯"],["鹏","鵬"],["鹐","鵮"],["鹑","鶉"],["鹒","鶊"],["鹓","鵷"],["鹔","鷫"],["鹕","鶘"],["鹖","鶡"],["鹗","鶚"],["鹘","鶻"],["鹙","鶖"],["鹚","鶿"],["鹛","鶥"],["鹜","鶩"],["鹝","鷊"],["鹞","鷂"],["鹟","鶲"],["鹠","鶹"],["鹡","鶺"],["鹢","鷁"],["鹣","鶼"],["鹤","鶴"],["鹥","鷖"],["鹦","鸚"],["鹧","鷓"],["鹨","鷚"],["鹩","鷯"],["鹪","鷦"],["鹫","鷲"],["鹬","鷸"],["鹭","鷺"],["鹮","䴉"],["鹯","鸇"],["鹰","鷹"],["鹱","鸌"],["鹲","鸏"],["鹳","鸛"],["鹴","鸘"],["鹾","鹺"],["麦","麥"],["麸","麩"],["麹","麴"],["麺","麪"],["麽","麼"],["黄","黃"],["黉","黌"],["黡","黶"],["黩","黷"],["黪","黲"],["黾","黽"],["鼋","黿"],["鼌","鼂"],["鼍","鼉"],["鼗","鞀"],["鼹","鼴"],["齄","齇"],["齐","齊"],["齑","齏"],["齿","齒"],["龀","齔"],["龁","齕"],["龂","齗"],["龃","齟"],["龄","齡"],["龅","齙"],["龆","齠"],["龇","齜"],["龈","齦"],["龉","齬"],["龊","齪"],["龋","齲"],["龌","齷"],["龙","龍"],["龚","龔"],["龛","龕"],["龟","龜"],["鿎","䃮"],["鿏","䥑"],["鿒","鿓"],["鿔","鎶"],["𠀾","𠁞"],["𠆲","儣"],["𠆿","𠌥"],["𠇹","俓"],["𠉂","㒓"],["𠉗","𠏢"],["𠊉","𣍐"],["𠋆","儭"],["𠚳","𠠎"],["𠛅","剾"],["𠛆","𠞆"],["𠛾","𪟖"],["𠡠","勑"],["𠮶","嗰"],["𠯟","哯"],["𠯠","噅"],["𠰱","㘉"],["𠰷","嚧"],["𠱞","囃"],["𠲥","𡅏"],["𠴛","𡃕"],["𠴢","𡄔"],["𠵸","𡄣"],["𠵾","㗲"],["𡋀","𡓾"],["𡋗","𡑭"],["𡋤","壗"],["𡍣","𡔖"],["𡒄","壈"],["𡝠","㜷"],["𡞋","㜗"],["𡞱","㜢"],["𡠟","孎"],["𡥧","孻"],["𡭜","𡮉"],["𡭬","𡮣"],["𡳃","𡳳"],["𡳒","𦘧"],["𡶴","嵼"],["𡸃","𡽗"],["𡺃","嶈"],["𡺄","嶘"],["𢋈","㢝"],["𢗓","㦛"],["𢘙","𢤱"],["𢘝","𢣚"],["𢘞","𢣭"],["𢙏","愻"],["𢙐","憹"],["𢙑","𢠼"],["𢙒","憢"],["𢙓","懀"],["𢛯","㦎"],["𢠁","懎"],["𢢐","𤢻"],["𢧐","戰"],["𢫊","𢷮"],["𢫞","𢶫"],["𢫬","摋"],["𢬍","擫"],["𢬦","𢹿"],["𢭏","擣"],["𢽾","斅"],["𣃁","斸"],["𣆐","曥"],["𣈣","𣋋"],["𣍨","𦢈"],["𣍯","腪"],["𣍰","脥"],["𣎑","臗"],["𣏢","槫"],["𣐕","桱"],["𣐤","欍"],["𣑶","𣠲"],["𣒌","楇"],["𣓿","橯"],["𣔌","樤"],["𣗊","樠"],["𣗋","欓"],["𣗙","㰙"],["𣘐","㯤"],["𣘓","𣞻"],["𣘴","檭"],["𣘷","𣝕"],["𣚚","欘"],["𣞎","𣠩"],["𣨼","殢"],["𣭤","𣯴"],["𣯣","𣯩"],["𣱝","氭"],["𣲗","湋"],["𣲘","潕"],["𣳆","㵗"],["𣶩","澅"],["𣶫","𣿉"],["𣶭","𪷓"],["𣷷","𤅶"],["𣸣","濆"],["𣺼","灙"],["𣺽","𤁣"],["𣽷","瀃"],["𤆡","熓"],["𤆢","㷍"],["𤇃","爄"],["𤇄","熌"],["𤇭","爖"],["𤇹","熚"],["𤈶","熉"],["𤈷","㷿"],["𤊀","𤒎"],["𤊰","𤓩"],["𤋏","熡"],["𤎺","㸇"],["𤎻","𤑳"],["𤙯","𤛮"],["𤝢","𤢟"],["𤞃","獩"],["𤞤","玁"],["𤠋","㺏"],["𤦀","瓕"],["𤩽","瓛"],["𤳄","𤳸"],["𤶊","癐"],["𤶧","𤸫"],["𤻊","㿗"],["𤽯","㿧"],["𤾀","皟"],["𤿲","麬"],["𥁢","䀉"],["𥅘","𥌃"],["𥅴","䀹"],["𥅿","𥊝"],["𥆧","瞤"],["𥇢","䁪"],["𥎝","䂎"],["𥐟","礒"],["𥐯","𥖅"],["𥐰","𥕥"],["𥐻","碙"],["𥞦","𥞵"],["𥧂","𥨐"],["𥩟","竚"],["𥩺","𥪂"],["𥫣","籅"],["𥬀","䉙"],["𥬞","籋"],["𥬠","篘"],["𥭉","𥵊"],["𥮋","𥸠"],["𥮜","䉲"],["𥮾","篸"],["𥱔","𥵃"],["𥹥","𥼽"],["𥺅","䊭"],["𥺇","𥽖"],["𦈈","𥿊"],["𦈉","緷"],["𦈋","綇"],["𦈌","綀"],["𦈎","繟"],["𦈏","緍"],["𦈐","縺"],["𦈑","緸"],["𦈒","𦂅"],["𦈓","䋿"],["𦈔","縎"],["𦈕","緰"],["𦈖","䌈"],["𦈗","𦃄"],["𦈘","䌋"],["𦈙","䌰"],["𦈚","縬"],["𦈛","繓"],["𦈜","䌖"],["𦈝","繏"],["𦈞","䌟"],["𦈟","䌝"],["𦈠","䌥"],["𦈡","繻"],["𦍠","䍽"],["𦛨","朥"],["𦝼","膢"],["𦟗","𦣎"],["𦨩","𦪽"],["𦰏","蓧"],["𦰴","䕳"],["𦶟","爇"],["𦶻","𦾟"],["𦻕","蘟"],["𦼖","檾"],["𧉐","𧕟"],["𧉞","䗿"],["𧌥","𧎈"],["𧏖","蠙"],["𧏗","蠀"],["𧑏","蠾"],["𧒭","𧔥"],["𧜭","䙱"],["𧝝","襰"],["𧝧","𧟀"],["𧮪","詀"],["𧳕","𧳟"],["𧹑","䞈"],["𧹒","買"],["𧹓","𧶔"],["𧹔","賬"],["𧹕","䝻"],["𧹖","賟"],["𧹗","贃"],["𧿈","𨇁"],["𨀁","躘"],["𨀱","𨄣"],["𨁴","𨅍"],["𨂺","𨈊"],["𨄄","𨈌"],["𨅛","䠱"],["𨅫","𨇞"],["𨅬","躝"],["𨉗","軉"],["𨐅","軗"],["𨐆","𨊻"],["𨐇","𨏠"],["𨐈","輄"],["𨐉","𨎮"],["𨐊","𨏥"],["𨑹","䢨"],["𨟳","𨣞"],["𨠨","𨣧"],["𨡙","𨢿"],["𨡺","𨣈"],["𨤰","𨤻"],["𨰾","鎷"],["𨰿","釳"],["𨱀","𨥛"],["𨱁","鈠"],["𨱂","鈋"],["𨱃","鈲"],["𨱄","鈯"],["𨱅","鉁"],["𨱆","龯"],["𨱇","銶"],["𨱈","鋉"],["𨱉","鍄"],["𨱊","𨧱"],["𨱋","錂"],["𨱌","鏆"],["𨱍","鎯"],["𨱎","鍮"],["𨱏","鎝"],["𨱐","𨫒"],["𨱑","鐄"],["𨱒","鏉"],["𨱓","鐎"],["𨱔","鐏"],["𨱕","𨮂"],["𨱖","䥩"],["𨷿","䦳"],["𨸀","𨳕"],["𨸁","𨳑"],["𨸂","閍"],["𨸃","閐"],["𨸄","䦘"],["𨸅","𨴗"],["𨸆","𨵩"],["𨸇","𨵸"],["𨸉","𨶀"],["𨸊","𨶏"],["𨸋","𨶲"],["𨸌","𨶮"],["𨸎","𨷲"],["𨸘","𨽏"],["𨸟","䧢"],["𩏼","䪏"],["𩏽","𩏪"],["𩏾","𩎢"],["𩏿","䪘"],["𩐀","䪗"],["𩓋","顂"],["𩖕","𩓣"],["𩖖","顃"],["𩖗","䫴"],["𩙥","颰"],["𩙦","𩗀"],["𩙧","䬞"],["𩙨","𩘹"],["𩙩","𩘀"],["𩙪","颷"],["𩙫","颾"],["𩙬","𩘺"],["𩙭","𩘝"],["𩙮","䬘"],["𩙯","䬝"],["𩙰","𩙈"],["𩟿","𩚛"],["𩠀","𩚥"],["𩠁","𩚵"],["𩠂","𩛆"],["𩠃","𩛩"],["𩠅","𩟐"],["𩠆","𩜦"],["𩠇","䭀"],["𩠈","䭃"],["𩠉","𩜇"],["𩠊","𩜵"],["𩠋","𩝔"],["𩠌","餸"],["𩠎","𩞄"],["𩠏","𩞦"],["𩠠","𩠴"],["𩡖","𩡣"],["𩧦","𩡺"],["𩧨","駎"],["𩧩","𩤊"],["𩧪","䮾"],["𩧫","駚"],["𩧬","𩢡"],["𩧭","䭿"],["𩧮","𩢾"],["𩧯","驋"],["𩧰","䮝"],["𩧱","𩥉"],["𩧲","駧"],["𩧳","𩢸"],["𩧴","駩"],["𩧵","𩢴"],["𩧶","𩣏"],["𩧸","𩣫"],["𩧺","駶"],["𩧻","𩣵"],["𩧼","𩣺"],["𩧿","䮠"],["𩨀","騔"],["𩨁","䮞"],["𩨂","驄"],["𩨃","騝"],["𩨄","騪"],["𩨅","𩤸"],["𩨆","𩤙"],["𩨇","䮫"],["𩨈","騟"],["𩨉","𩤲"],["𩨊","騚"],["𩨋","𩥄"],["𩨌","𩥑"],["𩨍","𩥇"],["𩨎","龭"],["𩨏","䮳"],["𩨐","𩧆"],["𩩈","䯤"],["𩬣","𩭙"],["𩬤","𩰀"],["𩭹","鬖"],["𩯒","𩯳"],["𩰰","𩰹"],["𩲒","𩳤"],["𩴌","𩴵"],["𩽹","魥"],["𩽺","𩵩"],["𩽻","𩵹"],["𩽼","鯶"],["𩽽","𩶱"],["𩽾","鮟"],["𩽿","𩶰"],["𩾀","鮕"],["𩾁","鯄"],["𩾂","䲖"],["𩾃","鮸"],["𩾄","𩷰"],["𩾅","𩸃"],["𩾆","𩸦"],["𩾇","鯱"],["𩾈","䱙"],["𩾊","䱬"],["𩾋","䱰"],["𩾌","鱇"],["𩾎","𩽇"],["𪉂","䲰"],["𪉃","鳼"],["𪉄","𩿪"],["𪉅","𪀦"],["𪉆","鴲"],["𪉈","鴜"],["𪉉","𪁈"],["𪉊","鷨"],["𪉋","𪀾"],["𪉌","𪁖"],["𪉍","鵚"],["𪉎","𪂆"],["𪉏","𪃏"],["𪉐","𪃍"],["𪉑","鷔"],["𪉒","𪄕"],["𪉓","𪈼"],["𪉔","𪄆"],["𪉕","𪇳"],["𪎈","䴬"],["𪎉","麲"],["𪎊","麨"],["𪎋","䴴"],["𪎌","麳"],["𪎍","𪋿"],["𪑅","䵳"],["𪔭","𪔵"],["𪚏","𪘀"],["𪚐","𪘯"],["𪜎","𠿕"],["𪞝","凙"],["𪟎","㔋"],["𪟝","勣"],["𪠀","𧷎"],["𪠟","㓄"],["𪠡","𠬙"],["𪠳","唓"],["𪠵","㖮"],["𪠸","嚛"],["𪠺","𠽃"],["𪠽","噹"],["𪡀","嘺"],["𪡃","嘪"],["𪡋","噞"],["𪡏","嗹"],["𪡛","㗿"],["𪡞","嘳"],["𪡺","𡃄"],["𪢌","㘓"],["𪢐","𡃤"],["𪢒","𡂡"],["𪢕","嚽"],["𪢖","𡅯"],["𪢠","囒"],["𪢮","圞"],["𪢸","墲"],["𪣆","埬"],["𪣒","堚"],["𪣻","塿"],["𪤄","𡓁"],["𪤚","壣"],["𪥠","𧹈"],["𪥫","孇"],["𪥰","嬣"],["𪥿","嬻"],["𪧀","孾"],["𪧘","寠"],["𪨊","㞞"],["𪨗","屩"],["𪨧","崙"],["𪨩","𡸗"],["𪨶","輋"],["𪨷","巗"],["𪨹","𡹬"],["𪩇","㟺"],["𪩎","巊"],["𪩘","巘"],["𪩛","𡿖"],["𪩷","幝"],["𪩸","幩"],["𪪏","廬"],["𪪑","㢗"],["𪪞","廧"],["𪪴","𢍰"],["𪪼","彃"],["𪫌","徿"],["𪫡","𢤩"],["𪫷","㦞"],["𪫺","憸"],["𪬚","𢣐"],["𪬯","𢤿"],["𪭝","𢯷"],["𪭢","摐"],["𪭧","擟"],["𪭯","𢶒"],["𪭵","掚"],["𪭾","撊"],["𪮃","㨻"],["𪮋","㩋"],["𪮖","撧"],["𪮳","𢺳"],["𪮶","攋"],["𪯋","㪎"],["𪰶","曊"],["𪱥","膹"],["𪱷","梖"],["𪲎","櫅"],["𪲔","欐"],["𪲛","檵"],["𪲮","櫠"],["𪳍","欇"],["𪳗","𣜬"],["𪴙","欑"],["𪵑","毊"],["𪵣","霼"],["𪵱","濿"],["𪶄","溡"],["𪶒","𤄷"],["𪶮","𣽏"],["𪷍","㵾"],["𪷽","灒"],["𪸕","熂"],["𪸩","煇"],["𪹀","𤑹"],["𪹠","𤓌"],["𪹳","爥"],["𪹹","𤒻"],["𪺣","𤘀"],["𪺪","𤜆"],["𪺭","犞"],["𪺷","獊"],["𪺸","𤠮"],["𪺻","㺜"],["𪺽","猌"],["𪻐","瑽"],["𪻨","瓄"],["𪻲","瑻"],["𪻺","璝"],["𪼋","㻶"],["𪼴","𤬅"],["𪽈","畼"],["𪽝","𤳷"],["𪽪","痮"],["𪽭","𤷃"],["𪽮","㿖"],["𪽴","𤺔"],["𪽷","瘱"],["𪾔","盨"],["𪾢","睍"],["𪾣","眝"],["𪾦","矑"],["𪾸","矉"],["𪿊","𥏝"],["𪿞","𥖲"],["𪿫","礮"],["𪿵","𥗇"],["𫀌","𥜰"],["𫀓","𥜐"],["𫀨","䅐"],["𫀬","䅳"],["𫀮","𥢷"],["𫁂","䆉"],["𫁟","竱"],["𫁡","鴗"],["𫁱","𥶽"],["𫁲","䉑"],["𫁳","𥯤"],["𫁷","䉶"],["𫁺","𥴼"],["𫂃","簢"],["𫂆","簂"],["𫂈","䉬"],["𫂖","𥴨"],["𫂿","𥻦"],["𫃗","𩏷"],["𫄙","糺"],["𫄚","䊺"],["𫄛","紟"],["𫄜","䋃"],["𫄝","𥾯"],["𫄞","䋔"],["𫄟","絁"],["𫄠","絙"],["𫄡","絧"],["𫄢","絥"],["𫄣","繷"],["𫄤","繨"],["𫄥","纚"],["𫄦","𦀖"],["𫄧","綖"],["𫄨","絺"],["𫄩","䋦"],["𫄪","𦅇"],["𫄫","綟"],["𫄬","緤"],["𫄭","緮"],["𫄮","䋼"],["𫄯","𦃩"],["𫄰","縍"],["𫄱","繬"],["𫄲","縸"],["𫄳","縰"],["𫄴","繂"],["𫄵","𦅈"],["𫄶","繈"],["𫄷","繶"],["𫄸","纁"],["𫄹","纗"],["𫅅","䍤"],["𫅗","羵"],["𫅥","𦒀"],["𫅭","䎙"],["𫅼","𦔖"],["𫆏","聻"],["𫆝","𦟼"],["𫆫","𦡝"],["𫇘","𦧺"],["𫇛","艣"],["𫇪","𦱌"],["𫇭","蔿"],["𫇴","蒭"],["𫇽","蕽"],["𫈉","蕳"],["𫈎","葝"],["𫈟","蔯"],["𫈵","蕝"],["𫉁","薆"],["𫉄","藷"],["𫊪","䗅"],["𫊮","蠦"],["𫊸","蟜"],["𫊹","𧒯"],["𫊻","蟳"],["𫋇","蟂"],["𫋌","蟘"],["𫋲","䙔"],["𫋷","襗"],["𫋹","襓"],["𫋻","襘"],["𫌀","襀"],["𫌇","襵"],["𫌋","𧞫"],["𫌨","覼"],["𫌪","覛"],["𫌫","𧡴"],["𫌬","𧢄"],["𫌭","覹"],["𫌯","䚩"],["𫍐","𧭹"],["𫍙","訑"],["𫍚","訞"],["𫍛","訜"],["𫍜","詓"],["𫍝","諫"],["𫍞","𧦝"],["𫍟","𧦧"],["𫍠","䛄"],["𫍡","詑"],["𫍢","譊"],["𫍣","詷"],["𫍤","譑"],["𫍥","誂"],["𫍦","譨"],["𫍧","誺"],["𫍨","誫"],["𫍩","諣"],["𫍪","誋"],["𫍫","䛳"],["𫍬","誷"],["𫍭","𧩕"],["𫍮","誳"],["𫍯","諴"],["𫍰","諰"],["𫍱","諯"],["𫍲","謏"],["𫍳","諥"],["𫍴","謱"],["𫍵","謸"],["𫍶","𧩼"],["𫍷","謉"],["𫍸","謆"],["𫍹","謯"],["𫍺","𧫝"],["𫍻","譆"],["𫍼","𧬤"],["𫍽","譞"],["𫍾","𧭈"],["𫍿","譾"],["𫎆","豵"],["𫎌","貗"],["𫎦","贚"],["𫎧","䝭"],["𫎨","𧸘"],["𫎩","賝"],["𫎪","䞋"],["𫎫","贉"],["𫎬","贑"],["𫎭","䞓"],["𫎱","䟐"],["𫎳","䟆"],["𫎸","𧽯"],["𫎺","䟃"],["𫏃","䠆"],["𫏆","蹳"],["𫏋","蹻"],["𫏌","𨂐"],["𫏐","蹔"],["𫏑","𨇽"],["𫏕","𨆪"],["𫏞","𨇰"],["𫏨","𨇤"],["𫐄","軏"],["𫐅","軕"],["𫐆","轣"],["𫐇","軜"],["𫐈","軷"],["𫐉","軨"],["𫐊","軬"],["𫐋","𨎌"],["𫐌","軿"],["𫐍","𨌈"],["𫐎","輢"],["𫐏","輖"],["𫐐","輗"],["𫐑","輨"],["𫐒","輷"],["𫐓","輮"],["𫐔","𨍰"],["𫐕","轊"],["𫐖","轇"],["𫐗","轐"],["𫐘","轗"],["𫐙","轠"],["𫐷","遱"],["𫑘","鄟"],["𫑡","鄳"],["𫑷","醶"],["𫓥","釟"],["𫓦","釨"],["𫓧","鈇"],["𫓨","鈛"],["𫓩","鏦"],["𫓪","鈆"],["𫓫","𨥟"],["𫓬","鉔"],["𫓭","鉠"],["𫓮","𨪕"],["𫓯","銈"],["𫓰","銊"],["𫓱","鐈"],["𫓲","銁"],["𫓳","𨰋"],["𫓴","鉾"],["𫓵","鋠"],["𫓶","鋗"],["𫓷","𫒡"],["𫓸","錽"],["𫓹","錤"],["𫓺","鐪"],["𫓻","錜"],["𫓼","𨨛"],["𫓽","錝"],["𫓾","錥"],["𫓿","𨨢"],["𫔀","鍊"],["𫔁","鐼"],["𫔂","鍉"],["𫔃","𨰲"],["𫔄","鍒"],["𫔅","鎍"],["𫔆","䥯"],["𫔇","鎞"],["𫔈","鎙"],["𫔉","𨰃"],["𫔊","鏥"],["𫔋","䥗"],["𫔌","鏾"],["𫔍","鐇"],["𫔎","鐍"],["𫔏","𨬖"],["𫔐","𨭸"],["𫔑","𨭖"],["𫔒","𨮳"],["𫔓","𨯟"],["𫔔","鑴"],["𫔕","𨰥"],["𫔖","𨲳"],["𫔭","開"],["𫔮","閒"],["𫔯","閗"],["𫔰","閞"],["𫔲","𨴹"],["𫔴","閵"],["𫔵","䦯"],["𫔶","闑"],["𫔽","𨼳"],["𫕚","𩀨"],["𫕥","霣"],["𫕨","𩅙"],["𫖃","靧"],["𫖅","䪊"],["𫖇","鞾"],["𫖑","𩎖"],["𫖒","韠"],["𫖓","𩏂"],["𫖔","韛"],["𫖕","韝"],["𫖖","𩏠"],["𫖪","𩑔"],["𫖫","䪴"],["𫖬","䪾"],["𫖭","𩒎"],["𫖮","顗"],["𫖯","頫"],["𫖰","䫂"],["𫖱","䫀"],["𫖲","䫟"],["𫖳","頵"],["𫖴","𩔳"],["𫖵","𩓥"],["𫖶","顅"],["𫖷","𩔑"],["𫖸","願"],["𫖹","顣"],["𫖺","䫶"],["𫗇","䫻"],["𫗈","𩗓"],["𫗉","𩗴"],["𫗊","䬓"],["𫗋","飋"],["𫗚","𩟗"],["𫗞","飦"],["𫗟","䬧"],["𫗠","餦"],["𫗡","𩚩"],["𫗢","飵"],["𫗣","飶"],["𫗤","𩛌"],["𫗥","餫"],["𫗦","餔"],["𫗧","餗"],["𫗨","𩛡"],["𫗩","饠"],["𫗪","餧"],["𫗫","餬"],["𫗬","餪"],["𫗭","餵"],["𫗮","餭"],["𫗯","餱"],["𫗰","䭔"],["𫗱","䭑"],["𫗳","𩝽"],["𫗴","饘"],["𫗵","饟"],["𫘛","馯"],["𫘜","馼"],["𫘝","駃"],["𫘞","駞"],["𫘟","駊"],["𫘠","駤"],["𫘡","駫"],["𫘣","駻"],["𫘤","騃"],["𫘥","騉"],["𫘦","騊"],["𫘧","騄"],["𫘨","騠"],["𫘩","騜"],["𫘪","騵"],["𫘫","騴"],["𫘬","騱"],["𫘭","騻"],["𫘮","䮰"],["𫘯","驓"],["𫘰","驙"],["𫘱","驨"],["𫘽","鬠"],["𫙂","𩯁"],["𫚈","鱮"],["𫚉","魟"],["𫚊","鰑"],["𫚋","鱄"],["𫚌","魦"],["𫚍","魵"],["𫚎","𩶁"],["𫚏","䱁"],["𫚐","䱀"],["𫚑","鮅"],["𫚒","鮄"],["𫚓","鮤"],["𫚔","鮰"],["𫚕","鰤"],["𫚖","鮆"],["𫚗","鮯"],["𫚘","𩻮"],["𫚙","鯆"],["𫚚","鮿"],["𫚛","鮵"],["𫚜","䲅"],["𫚝","𩸄"],["𫚞","鯬"],["𫚟","𩸡"],["𫚠","䱧"],["𫚡","鯞"],["𫚢","鰋"],["𫚣","鯾"],["𫚤","鰦"],["𫚥","鰕"],["𫚦","鰫"],["𫚧","鰽"],["𫚨","𩻗"],["𫚩","𩻬"],["𫚪","鱊"],["𫚫","鱢"],["𫚬","𩼶"],["𫚭","鱲"],["𫛚","鳽"],["𫛛","鳷"],["𫛜","鴀"],["𫛝","鴅"],["𫛞","鴃"],["𫛟","鸗"],["𫛠","𩿤"],["𫛡","鴔"],["𫛢","鸋"],["𫛣","鴥"],["𫛤","鴐"],["𫛥","鵊"],["𫛦","鴮"],["𫛧","𪀖"],["𫛨","鵧"],["𫛩","鴳"],["𫛪","鴽"],["𫛫","鶰"],["𫛬","䳜"],["𫛭","鵟"],["𫛮","䳤"],["𫛯","鶭"],["𫛰","䳢"],["𫛱","鵫"],["𫛲","鵰"],["𫛳","鵩"],["𫛴","鷤"],["𫛵","鶌"],["𫛶","鶒"],["𫛷","鶦"],["𫛸","鶗"],["𫛹","𪃧"],["𫛺","䳧"],["𫛻","𪃒"],["𫛼","䳫"],["𫛽","鷅"],["𫛾","𪆷"],["𫜀","鷐"],["𫜁","鷩"],["𫜂","𪅂"],["𫜃","鷣"],["𫜄","鷷"],["𫜅","䴋"],["𫜊","𪉸"],["𫜑","麷"],["𫜒","䴱"],["𫜓","𪌭"],["𫜔","䴽"],["𫜕","𪍠"],["𫜙","䵴"],["𫜟","𪓰"],["𫜨","䶕"],["𫜩","齧"],["𫜪","齩"],["𫜫","𫜦"],["𫜬","齰"],["𫜭","齭"],["𫜮","齴"],["𫜯","𪙏"],["𫜰","齾"],["𫜲","龓"],["𫜳","䶲"],["𫝈","㑮"],["𫝋","𠐊"],["𫝦","㛝"],["𫝧","㜐"],["𫝨","媈"],["𫝩","嬦"],["𫝪","𡟫"],["𫝫","婡"],["𫝬","嬇"],["𫝭","孆"],["𫝮","孄"],["𫝵","嶹"],["𫞅","𦠅"],["𫞗","潣"],["𫞚","澬"],["𫞛","㶆"],["𫞝","灍"],["𫞠","爧"],["𫞡","爃"],["𫞢","𤛱"],["𫞣","㹽"],["𫞥","珼"],["𫞦","璾"],["𫞧","𤩂"],["𫞨","璼"],["𫞩","璊"],["𫞷","𥢶"],["𫟃","絍"],["𫟄","綋"],["𫟅","綡"],["𫟆","緟"],["𫟇","𦆲"],["𫟑","䖅"],["𫟕","䕤"],["𫟞","訨"],["𫟟","詊"],["𫟠","譂"],["𫟡","誴"],["𫟢","䜖"],["𫟤","䡐"],["𫟥","䡩"],["𫟦","䡵"],["𫟫","𨞺"],["𫟬","𨟊"],["𫟲","釚"],["𫟳","釲"],["𫟴","鈖"],["𫟵","鈗"],["𫟶","銏"],["𫟷","鉝"],["𫟸","鉽"],["𫟹","鉷"],["𫟺","䤤"],["𫟻","銂"],["𫟼","鐽"],["𫟽","𨧰"],["𫟾","𨩰"],["𫟿","鎈"],["𫠀","䥄"],["𫠁","鑉"],["𫠂","閝"],["𫠅","韚"],["𫠆","頍"],["𫠇","𩖰"],["𫠈","䫾"],["𫠊","䮄"],["𫠋","騼"],["𫠌","𩦠"],["𫠏","𩵦"],["𫠐","魽"],["𫠑","䱸"],["𫠒","鱆"],["𫠖","𩿅"],["𫠜","齯"],["𫢸","僤"],["𫮃","墠"],["𫰛","娙"],["𫶇","嵽"],["𫷷","廞"],["𫸩","彄"],["𬀩","暐"],["𬬭","錀"],["𬬻","鑪"],["𬭊","𨧀"],["𬭛","𨨏"],["𬭳","𨭎"],["𬭶","𨭆"],["𬶋","鮈"],["𬶍","鮀"],["𬶏","鮠"],["𬶟","鯻"],["𬸪","鷭"]],"STPhrases":[["㓦划","㓦劃"],["一丝不挂","一絲不掛"],["一了心愿","一了心願"],["一了百了","一了百了"],["一了百当","一了百當"],["一争两丑","一爭兩醜"],["一伙","一夥"],["一伙人","一夥人"],["一伙头","一夥頭"],["一偿宿愿","一償宿願"],["一元复始","一元復始"],["一克","一克"],["一党","一黨"],["一冲性子","一沖性子"],["一准","一準"],["一出剧","一齣劇"],["一出去","一出去"],["一出场","一出場"],["一出子","一齣子"],["一出戏","一齣戲"],["一出来","一出來"],["一出生","一出生"],["一出祁山","一出祁山"],["一分收获","一分收穫"],["一分耕耘","一分耕耘"],["一分钟","一分鐘"],["一划","一劃"],["一别","一別"],["一别多年","一別多年"],["一别头","一彆頭"],["一刻千金","一刻千金"],["一前一后","一前一後"],["一力承当","一力承當"],["一卷","一卷"],["一厘一毫","一釐一毫"],["一厢情愿","一廂情願"],["一去不回","一去不回"],["一去不复","一去不復"],["一去不复返","一去不復返"],["一发","一發"],["一发之差","一髮之差"],["一发之间","一髮之間"],["一发千钧","一髮千鈞"],["一口钟","一口鐘"],["一只","一隻"],["一台","一臺"],["一台台","一臺臺"],["一叶","一葉"],["一叶兰","一葉蘭"],["一叶扁舟","一葉扁舟"],["一叶知秋","一葉知秋"],["一号木杆","一號木桿"],["一吊","一吊"],["一吊钱","一吊錢"],["一同","一同"],["一向","一向"],["一周","一週"],["一周天","一週天"],["一周年","一週年"],["一周遭","一周遭"],["一哄","一鬨"],["一哄而上","一哄而上"],["一哄而散","一鬨而散"],["一哄而起","一哄而起"],["一哄而集","一哄而集"],["一喊出","一喊出"],["一回","一回"],["一回事","一回事"],["一团","一團"],["一团和气","一團和氣"],["一团团","一團團"],["一团漆黑","一團漆黑"],["一团火","一團火"],["一团糟","一團糟"],["一国两制","一國兩制"],["一地胡拿","一地胡拿"],["一地里","一地裏"],["一块面","一塊麪"],["一坛","一罈"],["一坛坛","一罈罈"],["一坛死水","一壇死水"],["一塌糊涂","一塌糊塗"],["一壶千金","一壺千金"],["一夜致富","一夜致富"],["一大伙","一大夥"],["一天后","一天後"],["一天星斗","一天星斗"],["一天钟","一天鐘"],["一夫一妻","一夫一妻"],["一夫当关","一夫當關"],["一妻制","一妻制"],["一妻多夫","一妻多夫"],["一孔出气","一孔出氣"],["一字一板","一字一板"],["一字千金","一字千金"],["一寸秋波","一寸秋波"],["一将功成","一將功成"],["一展长才","一展長才"],["一干","一干"],["一干二净","一乾二淨"],["一干人","一干人"],["一干家中","一干家中"],["一干弟兄","一干弟兄"],["一干弟子","一干弟子"],["一干而尽","一乾而盡"],["一干部下","一干部下"],["一并","一併"],["一开出来","一開出來"],["一弦","一弦"],["一当","一當"],["一心向上","一心向上"],["一念","一念"],["一念三千","一念三千"],["一扎","一紮"],["一托头","一托頭"],["一托气","一托氣"],["一扣","一扣"],["一折","一折"],["一折一磨","一折一磨"],["一折两段","一折兩段"],["一折八扣","一折八扣"],["一拍即合","一拍即合"],["一挂","一掛"],["一挂之下","一掛之下"],["一掷千金","一擲千金"],["一掷百万","一擲百萬"],["一搜","一搜"],["一摇一摆","一搖一擺"],["一摇三摆","一搖三擺"],["一播出","一播出"],["一斗","一斗"],["一斗再斗","一鬥再鬥"],["一斗斗","一斗斗"],["一方面","一方面"],["一无所获","一無所獲"],["一日万机","一日萬機"],["一日三秋","一日三秋"],["一日千里","一日千里"],["一日叫娘","一日叫孃"],["一早起了","一早起了"],["一时糊涂","一時糊塗"],["一曲","一曲"],["一曲千金","一曲千金"],["一曲阳关","一曲陽關"],["一本万利","一本萬利"],["一杆","一杆"],["一杆进洞","一桿進洞"],["一杠","一槓"],["一杯","一杯"],["一杯杯","一杯杯"],["一杯羹","一杯羹"],["一松","一鬆"],["一板","一板"],["一板一眼","一板一眼"],["一板三眼","一板三眼"],["一柜","一櫃"],["一树百获","一樹百穫"],["一根烟","一根菸"],["一死了之","一死了之"],["一毫一发","一毫一髮"],["一池秋水","一池秋水"],["一沐三捉发","一沐三捉髮"],["一沐三握发","一沐三握髮"],["一波三折","一波三折"],["一泻千里","一瀉千里"],["一派胡言","一派胡言"],["一流人才","一流人才"],["一涂","一塗"],["一游","一遊"],["一溜烟","一溜煙"],["一点钟","一點鐘"],["一物一制","一物一制"],["一物克一物","一物剋一物"],["一百多万","一百多萬"],["一百廿万","一百廿萬"],["一目了然","一目瞭然"],["一相情愿","一相情願"],["一看出","一看出"],["一碗面","一碗麪"],["一碧万顷","一碧萬頃"],["一禾九穗","一禾九穗"],["一种","一種"],["一秒钟","一秒鐘"],["一穗三秀","一穗三秀"],["一笑了之","一笑了之"],["一笑千金","一笑千金"],["一笔划","一筆劃"],["一答一合","一答一合"],["一签","一簽"],["一箭之仇","一箭之仇"],["一箭双雕","一箭雙鵰"],["一系","一系"],["一系列","一系列"],["一统志","一統志"],["一网打尽","一網打盡"],["一翻出","一翻出"],["一胎制","一胎制"],["一至于此","一至於此"],["一致","一致"],["一致字","一致字"],["一致性","一致性"],["一致百虑","一致百慮"],["一般等价","一般等價"],["一落千丈","一落千丈"],["一表","一表"],["一表人才","一表人才"],["一表人材","一表人材"],["一表人物","一表人物"],["一表非俗","一表非俗"],["一表非凡","一表非凡"],["一见钟情","一見鍾情"],["一见面","一見面"],["一视同仁","一視同仁"],["一览表","一覽表"],["一触即发","一觸即發"],["一言不发","一言不發"],["一言不合","一言不合"],["一言千金","一言千金"],["一言已定千金不移","一言已定千金不移"],["一言既出","一言既出"],["一言既出驷马难追","一言既出駟馬難追"],["一言难尽","一言難盡"],["一讲出","一講出"],["一语不发","一語不發"],["一说出","一說出"],["一诺值千金","一諾值千金"],["一诺千金","一諾千金"],["一败涂地","一敗塗地"],["一赞","一讚"],["一走了之","一走了之"],["一起干","一起幹"],["一蹴可几","一蹴可幾"],["一身作事一身当","一身作事一身當"],["一轨同风","一軌同風"],["一辞莫赞","一辭莫贊"],["一递里","一遞裏"],["一逞兽欲","一逞獸慾"],["一道烟","一道煙"],["一醉解千愁","一醉解千愁"],["一里","一里"],["一里一外","一裏一外"],["一针","一針"],["一针见血","一針見血"],["一锅面","一鍋麪"],["一锹掘个井","一鍬掘個井"],["一院制","一院制"],["一雨成秋","一雨成秋"],["一面","一面"],["一面之交","一面之交"],["一面之缘","一面之緣"],["一面之识","一面之識"],["一面之词","一面之詞"],["一面之辞","一面之辭"],["一面之雅","一面之雅"],["一面倒","一面倒"],["一面儿官司","一面兒官司"],["一面如旧","一面如舊"],["一面点","一面點"],["一飞冲天","一飛沖天"],["一食万钱","一食萬錢"],["一饭千金","一飯千金"],["一饮而尽","一飲而盡"],["一马当先","一馬當先"],["一麾出守","一麾出守"],["一鼓一板","一鼓一板"],["一鼻孔出气","一鼻孔出氣"],["一龙生九种种种各别","一龍生九種種種各別"],["丁一确二","丁一確二"],["丁丁冬冬","丁丁冬冬"],["丁丁当当","丁丁當當"],["丁丁炒面","丁丁炒面"],["丁丑","丁丑"],["丁伯升","丁伯升"],["丁克","丁克"],["丁冬","丁冬"],["丁固生松","丁固生松"],["丁娘十索","丁娘十索"],["丁字梁","丁字梁"],["丁当","丁當"],["丁柏升","丁柏升"],["丁种","丁種"],["丁种维生素","丁種維生素"],["丁铃当啷","丁鈴噹啷"],["丁零当啷","丁零當啷"],["丁鸿志","丁鴻志"],["七万","七萬"],["七万三千","七萬三千"],["七万五千","七萬五千"],["七万八千","七萬八千"],["七万六千","七萬六千"],["七万四千","七萬四千"],["七个","七個"],["七个八个","七個八個"],["七了八当","七了八當"],["七余","七餘"],["七八下里","七八下裏"],["七出","七出"],["七出祁山","七出祁山"],["七分钟","七分鐘"],["七划","七劃"],["七十七万","七十七萬"],["七十七国集团","七十七國集團"],["七十五万","七十五萬"],["七千","七千"],["七千两百","七千兩百"],["七发","七發"],["七只","七隻"],["七台","七臺"],["七台河","七臺河"],["七台河市","七臺河市"],["七叶胆","七葉膽"],["七周","七週"],["七回","七回"],["七团","七團"],["七国集团","七國集團"],["七坛","七罈"],["七天后","七天後"],["七娘","七娘"],["七娘妈","七孃媽"],["七孔生烟","七孔生煙"],["七巧板","七巧板"],["七弦","七絃"],["七彩","七彩"],["七彩缤纷","七彩繽紛"],["七彩虹","七彩虹"],["七情六欲","七情六慾"],["七扎","七紮"],["七折","七折"],["七折八扣","七折八扣"],["七政四余","七政四餘"],["七星坛","七星壇"],["七星岩","七星巖"],["七星板","七星板"],["七星瓢虫","七星瓢蟲"],["七杯","七杯"],["七步之才","七步之才"],["七步奇才","七步奇才"],["七点钟","七點鐘"],["七百万","七百萬"],["七百多万","七百多萬"],["七种","七種"],["七秒钟","七秒鐘"],["七窍冒烟","七竅冒煙"],["七窍生烟","七竅生煙"],["七色板","七色板"],["七里河","七里河"],["七里河区","七里河區"],["七里香","七里香"],["万一","萬一"],["万一只","萬一只"],["万万","萬萬"],["万万不可","萬萬不可"],["万万千千","萬萬千千"],["万万岁","萬萬歲"],["万丈","萬丈"],["万丈光芒","萬丈光芒"],["万丈深渊","萬丈深淵"],["万丈竿头","萬丈竿頭"],["万丈红尘","萬丈紅塵"],["万丈高楼平地起","萬丈高樓平地起"],["万不及一","萬不及一"],["万不可失","萬不可失"],["万不失一","萬不失一"],["万不得已","萬不得已"],["万世","萬世"],["万世一时","萬世一時"],["万世师表","萬世師表"],["万个","萬個"],["万丰","萬豐"],["万丹","萬丹"],["万丹乡","萬丹鄉"],["万乘","萬乘"],["万乘之国","萬乘之國"],["万乘之尊","萬乘之尊"],["万事","萬事"],["万事亨通","萬事亨通"],["万事俱备只欠东风","萬事俱備只欠東風"],["万事具备","萬事具備"],["万事大吉","萬事大吉"],["万事如意","萬事如意"],["万事得","萬事得"],["万事皆从急中错","萬事皆從急中錯"],["万事皆休","萬事皆休"],["万事皆备","萬事皆備"],["万事起头难","萬事起頭難"],["万事达","萬事達"],["万事达卡","萬事達卡"],["万事通","萬事通"],["万人","萬人"],["万人之敌","萬人之敵"],["万人之敵","萬人之敵"],["万人坑","萬人坑"],["万人敌","萬人敵"],["万人空巷","萬人空巷"],["万人迷","萬人迷"],["万仞","萬仞"],["万代","萬代"],["万代一时","萬代一時"],["万代兰","萬代蘭"],["万代千秋","萬代千秋"],["万份","萬份"],["万众","萬衆"],["万众一心","萬衆一心"],["万众欢腾","萬衆歡騰"],["万众瞩目","萬衆矚目"],["万位","萬位"],["万余","萬餘"],["万余只","萬餘隻"],["万余里","萬餘里"],["万俟","万俟"],["万倍","萬倍"],["万儿","萬兒"],["万儿八千","萬兒八千"],["万元","萬元"],["万元户","萬元戶"],["万全","萬全"],["万全之策","萬全之策"],["万全之计","萬全之計"],["万全县","萬全縣"],["万全街","萬全街"],["万兽之王","萬獸之王"],["万几","萬幾"],["万分","萬分"],["万分之一","萬分之一"],["万分感激","萬分感激"],["万分痛苦","萬分痛苦"],["万别千差","萬別千差"],["万剐千刀","萬剮千刀"],["万劫","萬劫"],["万劫不复","萬劫不復"],["万千","萬千"],["万华","萬華"],["万华区","萬華區"],["万华站","萬華站"],["万博宣伟","萬博宣偉"],["万博省","萬博省"],["万卷","萬卷"],["万卷书","萬卷書"],["万历","萬曆"],["万县","萬縣"],["万县地区","萬縣地區"],["万县市","萬縣市"],["万县港","萬縣港"],["万变不离其宗","萬變不離其宗"],["万古","萬古"],["万古不灭","萬古不滅"],["万古千秋","萬古千秋"],["万古流芳","萬古流芳"],["万古留芳","萬古留芳"],["万古长新","萬古長新"],["万古长春","萬古長春"],["万古长青","萬古長青"],["万只","萬隻"],["万叶","萬葉"],["万名","萬名"],["万向节","萬向節"],["万国","萬國"],["万国公报","萬國公報"],["万国公法","萬國公法"],["万国宫","萬國宮"],["万国旗","萬國旗"],["万国码","萬國碼"],["万国邮联","萬國郵聯"],["万国音标","萬國音標"],["万圆","萬圓"],["万圣节","萬聖節"],["万坛","萬罈"],["万境归空","萬境歸空"],["万壑","萬壑"],["万壑争流","萬壑爭流"],["万天后","萬天後"],["万夫","萬夫"],["万夫不当","萬夫不當"],["万夫莫当","萬夫莫當"],["万夫莫敌","萬夫莫敵"],["万头攒动","萬頭攢動"],["万姓","萬姓"],["万姓统谱","萬姓統譜"],["万字","萬字"],["万宁市","萬寧市"],["万安","萬安"],["万安县","萬安縣"],["万宝华","萬寶華"],["万宝囊","萬寶囊"],["万宝常","萬寶常"],["万宝路","萬寶路"],["万家","萬家"],["万家乐","萬家樂"],["万家灯火","萬家燈火"],["万家生佛","萬家生佛"],["万家香","萬家香"],["万寿","萬壽"],["万寿千秋","萬壽千秋"],["万寿山","萬壽山"],["万寿无疆","萬壽無疆"],["万寿果","萬壽果"],["万寿菊","萬壽菊"],["万山","萬山"],["万山特区","萬山特區"],["万山镇","萬山鎮"],["万岁","萬歲"],["万岁千秋","萬歲千秋"],["万岁爷","萬歲爺"],["万峦","萬巒"],["万峦乡","萬巒鄉"],["万州区","萬州區"],["万年","萬年"],["万年历","萬年曆"],["万年历表","萬年曆錶"],["万年县","萬年縣"],["万年青","萬年青"],["万幸","萬幸"],["万念","萬念"],["万念俱灰","萬念俱灰"],["万急","萬急"],["万恩市","萬恩市"],["万恶","萬惡"],["万恶之源","萬惡之源"],["万恶之首","萬惡之首"],["万恶淫为首","萬惡淫爲首"],["万恶滔天","萬惡滔天"],["万户","萬戶"],["万户侯","萬戶侯"],["万户千门","萬戶千門"],["万扎","萬紮"],["万把","萬把"],["万把块","萬把塊"],["万斛泉源","萬斛泉源"],["万斤","萬斤"],["万斯同","萬斯同"],["万方","萬方"],["万旗","万旗"],["万无","萬無"],["万无一失","萬無一失"],["万无失一","萬無失一"],["万智牌","萬智牌"],["万有","萬有"],["万有引力","萬有引力"],["万有引力定律","萬有引力定律"],["万望","萬望"],["万机","萬機"],["万杞良","萬杞良"],["万柏林","萬柏林"],["万柏林区","萬柏林區"],["万桶","萬桶"],["万步","萬步"],["万步表","萬步表"],["万死","萬死"],["万死一生","萬死一生"],["万死不辞","萬死不辭"],["万段","萬段"],["万毒枯","萬毒枯"],["万民伞","萬民傘"],["万水千山","萬水千山"],["万沙浪","萬沙浪"],["万泉河","萬泉河"],["万法唯识","萬法唯識"],["万泰银","萬泰銀"],["万洋山","萬洋山"],["万源市","萬源市"],["万灵丹","萬靈丹"],["万灵节","萬靈節"],["万灵药","萬靈藥"],["万点","萬點"],["万点大关","萬點大關"],["万物","萬物"],["万物之灵","萬物之靈"],["万状","萬狀"],["万用","萬用"],["万用字元","萬用字元"],["万用手冊","萬用手冊"],["万用电表","萬用電表"],["万用表","萬用表"],["万盛","萬盛"],["万盛区","萬盛區"],["万盛溪","萬盛溪"],["万目睽睽","萬目睽睽"],["万石","萬石"],["万福","萬福"],["万福玛丽亚","萬福瑪麗亞"],["万秀区","萬秀區"],["万种","萬種"],["万种风情","萬種風情"],["万窍","萬竅"],["万端","萬端"],["万签插架","萬籤插架"],["万箭攒心","萬箭攢心"],["万箭穿心","萬箭穿心"],["万箭穿身","萬箭穿身"],["万箱","萬箱"],["万籁","萬籟"],["万籁俱寂","萬籟俱寂"],["万籁无声","萬籟無聲"],["万籤插架","萬籤插架"],["万米","萬米"],["万米长跑","萬米長跑"],["万紫千红","萬紫千紅"],["万红千紫","萬紅千紫"],["万绪千头","萬緒千頭"],["万绪千端","萬緒千端"],["万维网","萬維網"],["万绿丛中","萬綠叢中"],["万缕千丝","萬縷千絲"],["万缘","萬緣"],["万能","萬能"],["万能工专","萬能工專"],["万能曲尺","萬能曲尺"],["万能梗","萬能梗"],["万能梗犬","萬能梗犬"],["万能胶","萬能膠"],["万能选手","萬能選手"],["万能钥匙","萬能鑰匙"],["万能锅","萬能鍋"],["万般","萬般"],["万般皆下品","萬般皆下品"],["万般皆是命","萬般皆是命"],["万艾可","萬艾可"],["万花争艳","萬花爭豔"],["万花筒","萬花筒"],["万苦千辛","萬苦千辛"],["万荣乡","萬榮鄉"],["万荣县","萬榮縣"],["万虑俱清","萬慮俱清"],["万言","萬言"],["万言书","萬言書"],["万语千言","萬語千言"],["万象","萬象"],["万象包罗","萬象包羅"],["万象更新","萬象更新"],["万象森罗","萬象森羅"],["万贯","萬貫"],["万贯家产","萬貫家產"],["万贯家私","萬貫家私"],["万贯家财","萬貫家財"],["万载千秋","萬載千秋"],["万载县","萬載縣"],["万道","萬道"],["万那杜","萬那杜"],["万邦","萬邦"],["万部","萬部"],["万里","萬里"],["万里之望","萬里之望"],["万里乡","萬里鄉"],["万里侯","萬里侯"],["万里同风","萬里同風"],["万里封侯","萬里封侯"],["万里无云","萬里無雲"],["万里春愁直","萬裏春愁直"],["万里晴空","萬里晴空"],["万里江山","萬里江山"],["万里迢迢","萬里迢迢"],["万里追踪","萬里追蹤"],["万里长城","萬里長城"],["万里长征","萬里長征"],["万里长江","萬里長江"],["万里长空","萬里長空"],["万里鹏程","萬里鵬程"],["万里鹏翼","萬里鵬翼"],["万重","萬重"],["万重山","萬重山"],["万金","萬金"],["万金不换","萬金不換"],["万金之躯","萬金之軀"],["万金油","萬金油"],["万钧","萬鈞"],["万钧之力","萬鈞之力"],["万锺","萬鍾"],["万难","萬難"],["万顷","萬頃"],["万顷琉璃","萬頃琉璃"],["万顷碧波","萬頃碧波"],["万馀","萬餘"],["万马","萬馬"],["万马千军","萬馬千軍"],["万马奔腾","萬馬奔騰"],["万马皆瘖","萬馬皆瘖"],["万马齐喑","萬馬齊喑"],["万马齐瘖","萬馬齊瘖"],["万鸦老","萬鴉老"],["万齐融","萬齊融"],["丈余","丈餘"],["丈八灯台","丈八燈臺"],["丈母娘","丈母孃"],["三万","三萬"],["三个","三個"],["三个鼻子管","三個鼻子管"],["三丰","三豐"],["三仙台","三仙臺"],["三代同堂","三代同堂"],["三余","三餘"],["三元合金","三元合金"],["三元里","三元里"],["三克","三克"],["三党","三黨"],["三八制","三八制"],["三冬","三冬"],["三冬两夏","三冬兩夏"],["三准","三準"],["三出祁山","三出祁山"],["三分钟","三分鐘"],["三只","三隻"],["三只手","三隻手"],["三台","三臺"],["三台县","三臺縣"],["三台联播","三臺聯播"],["三叶期","三葉期"],["三叶松","三葉松"],["三叶草","三葉草"],["三叶虫","三葉蟲"],["三叹","三嘆"],["三合会","三合會"],["三合土","三合土"],["三合房","三合房"],["三合星","三合星"],["三合板","三合板"],["三合院","三合院"],["三同","三同"],["三向","三向"],["三周","三週"],["三周年","三週年"],["三呼万岁","三呼萬歲"],["三回两转","三回兩轉"],["三回九曲","三回九曲"],["三回九转","三回九轉"],["三回五次","三回五次"],["三回五转","三回五轉"],["三国志","三國志"],["三坛大戒","三壇大戒"],["三复","三複"],["三复斯言","三復斯言"],["三复白圭","三復白圭"],["三大发明","三大發明"],["三大差别","三大差別"],["三天后","三天後"],["三头两面","三頭兩面"],["三头马车制","三頭馬車制"],["三夹板","三夾板"],["三娘教子","三孃教子"],["三对三斗牛","三對三鬥牛"],["三对六面","三對六面"],["三尸","三尸"],["三尸神","三尸神"],["三年制","三年制"],["三弦","三絃"],["三征七辟","三徵七辟"],["三思台","三思臺"],["三思而后","三思而後"],["三思而后行","三思而後行"],["三恶道","三惡道"],["三战两胜","三戰兩勝"],["三才","三才"],["三才图会","三才圖會"],["三扎","三紮"],["三折肱","三折肱"],["三折肱为良医","三折肱爲良醫"],["三振出局","三振出局"],["三方面","三方面"],["三日不读书面目可憎","三日不讀書面目可憎"],["三星集团","三星集團"],["三月里的桃花","三月裏的桃花"],["三杆","三杆"],["三杠","三槓"],["三杯","三杯"],["三杯和万事","三杯和萬事"],["三杯鸡","三杯雞"],["三板","三板"],["三极","三極"],["三极真空","三極真空"],["三极管","三極管"],["三次曲线","三次曲線"],["三段制","三段制"],["三江并流","三江並流"],["三浴三熏","三浴三熏"],["三涂","三塗"],["三点钟","三點鐘"],["三熏三沐","三熏三沐"],["三班制","三班制"],["三瓦两舍","三瓦兩舍"],["三瓦四舍","三瓦四舍"],["三生有幸","三生有幸"],["三用表","三用表"],["三番四复","三番四復"],["三百万","三百萬"],["三百个","三百個"],["三百千千","三百千千"],["三百多万","三百多萬"],["三百馀万","三百餘萬"],["三秋","三秋"],["三秒钟","三秒鐘"],["三穗","三穗"],["三穗县","三穗縣"],["三级三审制","三級三審制"],["三结合","三結合"],["三统历","三統曆"],["三统历史","三統歷史"],["三胜制","三勝制"],["三脚采茶戏","三腳採茶戲"],["三舍","三舍"],["三苏","三蘇"],["三表","三表"],["三角关系","三角關係"],["三角套汇","三角套匯"],["三角巾包扎法","三角巾包紮法"],["三角板","三角板"],["三角表","三角表"],["三辟","三辟"],["三连胜","三連勝"],["三部合唱","三部合唱"],["三部曲","三部曲"],["三里屯","三里屯"],["三里河","三里河"],["三针","三針"],["三长制","三長制"],["三门干部","三門幹部"],["三青团","三青團"],["三面","三面"],["三面亚当","三面亞當"],["三面体","三面體"],["三面夏娃","三面夏娃"],["三面红旗","三面紅旗"],["三面网","三面網"],["三面角","三面角"],["三马同槽","三馬同槽"],["三鹿集团","三鹿集團"],["上一个","上一個"],["上万","上萬"],["上上个月","上上個月"],["上下五千年","上下五千年"],["上下交困","上下交困"],["上下同心","上下同心"],["上下游","上下游"],["上不了","上不了"],["上不了台面","上不了檯面"],["上不得台盘","上不得檯盤"],["上个星期","上個星期"],["上个月","上個月"],["上中下游","上中下游"],["上了","上了"],["上了岁数","上了歲數"],["上了年纪","上了年紀"],["上党","上黨"],["上党梆子","上黨梆子"],["上冲","上衝"],["上冲下洗","上沖下洗"],["上千","上千"],["上千万","上千萬"],["上千人","上千人"],["上升","上升"],["上升为","上升爲"],["上升趋势","上升趨勢"],["上半叶","上半葉"],["上发条","上發條"],["上台","上臺"],["上台演唱","上臺演唱"],["上台演奏","上臺演奏"],["上台演讲","上臺演講"],["上叶","上葉"],["上合屋","上閤屋"],["上合组织","上合組織"],["上吊","上吊"],["上吊自杀","上吊自殺"],["上同调","上同調"],["上周","上週"],["上回","上回"],["上复","上覆"],["上夸克","上夸克"],["上层建筑","上層建築"],["上市柜","上市櫃"],["上弦","上弦"],["上当","上當"],["上彩","上彩"],["上搜","上搜"],["上杠","上槓"],["上柜","上櫃"],["上栗县","上栗縣"],["上梁","上樑"],["上梁不正","上樑不正"],["上梁不正下梁歪","上樑不正下樑歪"],["上梁山","上梁山"],["上梁文","上梁文"],["上游","上游"],["上游工业","上游工業"],["上百万","上百萬"],["上确界","上確界"],["上签","上籤"],["上签写","上簽寫"],["上签名","上簽名"],["上签字","上簽字"],["上签收","上簽收"],["上舍","上舍"],["上花台","上花臺"],["上药","上藥"],["上药膏","上藥膏"],["上蜡","上蠟"],["上表","上表"],["上课钟","上課鐘"],["上野树里","上野樹里"],["上链","上鍊"],["上面","上面"],["上马杯","上馬杯"],["下一个","下一個"],["下三面","下三面"],["下下个月","下下個月"],["下不了","下不了"],["下不了台","下不了臺"],["下不来台","下不來臺"],["下个星期","下個星期"],["下个月","下個月"],["下了","下了"],["下于","下於"],["下仑路","下崙路"],["下冲","下衝"],["下出","下出"],["下划线","下劃線"],["下厂","下廠"],["下发","下發"],["下台","下臺"],["下台阶","下臺階"],["下叶","下葉"],["下同","下同"],["下向","下向"],["下周","下週"],["下咽","下嚥"],["下回","下回"],["下城里","下城裏"],["下夸克","下夸克"],["下弦","下弦"],["下彩","下彩"],["下得了","下得了"],["下手干","下手幹"],["下才","下才"],["下摆","下襬"],["下有苏杭","下有蘇杭"],["下板儿","下板兒"],["下梁","下樑"],["下水道系统","下水道系統"],["下注","下注"],["下注解","下註解"],["下游","下游"],["下游工业","下游工業"],["下确界","下確界"],["下种","下種"],["下笔千言","下筆千言"],["下签","下籤"],["下签写","下簽寫"],["下签名","下簽名"],["下签字","下簽字"],["下签收","下簽收"],["下药","下藥"],["下表","下表"],["下课后","下課後"],["下课钟","下課鐘"],["下采","下采"],["下里","下里"],["下里巴人","下里巴人"],["下面","下面","下麪"],["下面请看","下面請看"],["下风方向","下風方向"],["下马杯","下馬杯"],["不一致","不一致"],["不一致字","不一致字"],["不上台盘","不上檯盤"],["不下于","不下於"],["不丑","不醜"],["不世出","不世出"],["不中于款","不中於款"],["不丰不杀","不豐不殺"],["不为牛后","不爲牛後"],["不为米折腰","不爲米折腰"],["不乐于","不樂於"],["不了","不了"],["不了之局","不了之局"],["不了了之","不了了之"],["不了了当","不了了當"],["不了情","不了情"],["不了汉","不了漢"],["不了解","不瞭解"],["不以词害志","不以詞害志"],["不以辞害志","不以辭害志"],["不体面","不體面"],["不作准","不作準"],["不侮暗室","不侮暗室"],["不修","不修"],["不修小节","不修小節"],["不修帷薄","不修帷薄"],["不修边幅","不修邊幅"],["不借","不借"],["不值当","不值當"],["不假外出","不假外出"],["不偏极","不偏極"],["不停当","不停當"],["不光彩","不光彩"],["不克","不克"],["不克制","不剋制"],["不克自制","不克自制"],["不全症","不全症"],["不再出版","不再出版"],["不准","不準","不准"],["不准他","不准他"],["不准你","不准你"],["不准备","不準備"],["不准她","不准她"],["不准它","不准它"],["不准我","不准我"],["不准没","不准沒"],["不准确","不準確"],["不准翻印","不准翻印"],["不准许","不准許"],["不准谁","不准誰"],["不准问","不准問"],["不减当年","不減當年"],["不出","不出"],["不出去","不出去"],["不出所料","不出所料"],["不出材","不出材"],["不出来","不出來"],["不分胜负","不分勝負"],["不分胜败","不分勝敗"],["不分青红皂白","不分青紅皁白"],["不切合实际","不切合實際"],["不划算","不划算"],["不利于","不利於"],["不前不后","不前不後"],["不加修饰","不加修飾"],["不加区别","不加區別"],["不加自制","不加自制"],["不劳无获","不勞無獲"],["不劳而获","不勞而獲"],["不升","不升"],["不升反降","不升反降"],["不单只是","不單只是"],["不卜可知","不卜可知"],["不占","不佔"],["不占凶吉","不占凶吉"],["不占卜","不占卜"],["不占吉凶","不占吉凶"],["不占算","不占算"],["不发心","不發心"],["不变价格","不變價格"],["不只","不只"],["不只是","不只是"],["不可以道里计","不可以道里計"],["不可同年而语","不可同年而語"],["不可同日","不可同日"],["不可同日而语","不可同日而語"],["不可向迩","不可向邇"],["不可当","不可當"],["不可战胜","不可戰勝"],["不可挽回","不可挽回"],["不可救药","不可救藥"],["不可胜书","不可勝書"],["不可胜原","不可勝原"],["不可胜数","不可勝數"],["不可胜纪","不可勝紀"],["不可胜言","不可勝言"],["不可胜计","不可勝計"],["不可胜记","不可勝記"],["不吃烟火食","不吃煙火食"],["不合","不合"],["不合体统","不合體統"],["不合作","不合作"],["不合作运动","不合作運動"],["不合式","不合式"],["不合时宜","不合時宜"],["不合标准","不合標準"],["不合格","不合格"],["不合法","不合法"],["不合理","不合理"],["不合算","不合算"],["不合群","不合羣"],["不合节","不合節"],["不合规定","不合規定"],["不合适","不合適"],["不合逻辑","不合邏輯"],["不吊","不弔"],["不同","不同"],["不同于","不同於"],["不同人","不同人"],["不同以往","不同以往"],["不同凡响","不同凡響"],["不同印本","不同印本"],["不同处","不同處"],["不同意","不同意"],["不同日月","不同日月"],["不同点","不同點"],["不同调","不同調"],["不向","不向"],["不告而别","不告而別"],["不周","不周"],["不周到","不周到"],["不周山","不周山"],["不周延","不周延"],["不周风","不周風"],["不善于","不善於"],["不图打点只图混水","不圖打點只圖混水"],["不在了","不在了"],["不堪回首","不堪回首"],["不复","不復"],["不复存在","不復存在"],["不外借","不外借"],["不多于","不多於"],["不多几日","不多幾日"],["不大合时","不大合時"],["不大精采","不大精采"],["不好了","不好了"],["不好干涉","不好干涉"],["不好干預","不好干預"],["不好干预","不好干預"],["不嫌母丑","不嫌母醜"],["不孕症","不孕症"],["不孝有三无后为大","不孝有三無後爲大"],["不学亡术","不學亡術"],["不学无术","不學無術"],["不安于位","不安於位"],["不安于室","不安於室"],["不完全叶","不完全葉"],["不寒而栗","不寒而慄"],["不对腔板","不對腔板"],["不小于","不小於"],["不少于","不少於"],["不尽","不盡"],["不尽年","不盡年"],["不尽心","不盡心"],["不尽木","不盡木"],["不尽根","不盡根"],["不尽然","不盡然"],["不尽相同","不盡相同"],["不尽道理","不盡道理"],["不屑于","不屑於"],["不属于","不屬於"],["不差毫厘","不差毫釐"],["不差毫发","不差毫髮"],["不干","不幹","不乾"],["不干不净","不乾不淨"],["不干不淨吃了没病","不乾不淨吃了沒病"],["不干了","不幹了"],["不干事","不幹事"],["不干他","不干他"],["不干休","不干休"],["不干你","不干你"],["不干净","不乾淨"],["不干她","不干她"],["不干它","不干它"],["不干己事","不干己事"],["不干性","不乾性"],["不干我","不干我"],["不干扰","不干擾"],["不干杯","不乾杯"],["不干涉","不干涉"],["不干涉主义","不干涉主義"],["不干渴","不乾渴"],["不干犯","不干犯"],["不干着急","不乾着急"],["不干胶","不乾膠"],["不干脆","不乾脆"],["不干裂","不乾裂"],["不干预","不干預"],["不并","不併"],["不幸","不幸"],["不幸之事","不幸之事"],["不幸之幸","不幸之幸"],["不幸受害","不幸受害"],["不幸的是","不幸的是"],["不当","不當"],["不当一回事","不當一回事"],["不当不对","不當不對"],["不当不正","不當不正"],["不当事","不當事"],["不当人","不當人"],["不当人化化","不當人化化"],["不当人子","不當人子"],["不当党","不當黨"],["不当党产","不當黨產"],["不当准","不當準"],["不当官","不當官"],["不当家","不當家"],["不当家化化","不當家化化"],["不当家花拉","不當家花拉"],["不当家花花","不當家花花"],["不当家豁拉","不當家豁拉"],["不当得利","不當得利"],["不当数","不當數"],["不当稳便","不當穩便"],["不当紧","不當緊"],["不当耍处","不當耍處"],["不当道","不當道"],["不形于色","不形於色"],["不彩","不彩"],["不徇颜面","不徇顏面"],["不得了","不得了"],["不得台盘","不得檯盤"],["不得志","不得志"],["不得闲","不得閒"],["不念","不念"],["不念旧恶","不念舊惡"],["不恶而严","不惡而嚴"],["不情不愿","不情不願"],["不情愿","不情願"],["不惮强御","不憚強禦"],["不愿","不願"],["不愿意","不願意"],["不成才","不成才"],["不战而胜","不戰而勝"],["不才","不才"],["不打不成才","不打不成才"],["不托","不託"],["不扣","不扣"],["不折","不折"],["不折不扣","不折不扣"],["不挂","不掛"],["不挂眼","不掛眼"],["不放松","不放鬆"],["不敢出声","不敢出聲"],["不敢出气","不敢出氣"],["不敢后人","不敢後人"],["不敢当","不敢當"],["不整合","不整合"],["不斗","不鬥"],["不断电系统","不斷電系統"],["不早了","不早了"],["不时之须","不時之須"],["不明就里","不明就裏"],["不明确","不明確"],["不是个儿","不是個兒"],["不是了处","不是了處"],["不是别人","不是別人"],["不松下","不鬆下"],["不极","不極"],["不极不反","不極不反"],["不染纤尘","不染纖塵"],["不标准","不標準"],["不欲","不欲"],["不欺暗室","不欺暗室"],["不止于此","不止於此"],["不正当","不正當"],["不正当关系","不正當關係"],["不正当竞争","不正當競爭"],["不正确","不正確"],["不死药","不死藥"],["不毒不发","不毒不發"],["不气干","不氣干"],["不求收获","不求收獲"],["不治之症","不治之症"],["不注意","不注意"],["不测风云","不測風雲"],["不涂","不塗"],["不消几日","不消幾日"],["不甘于","不甘於"],["不甘后人","不甘後人"],["不甚了了","不甚了了"],["不甚合意","不甚合意"],["不用干","不用幹"],["不用斗了","不用鬥了"],["不畏强御","不畏強禦"],["不畏彊御","不畏彊禦"],["不留情面","不留情面"],["不相同","不相同"],["不相干","不相干"],["不知凡几","不知凡幾"],["不知去向","不知去向"],["不知所云","不知所云"],["不确","不確"],["不确定","不確定"],["不确定性","不確定性"],["不确定性原理","不確定性原理"],["不确定感","不確定感"],["不确定故意","不確定故意"],["不确实","不確實"],["不符合","不符合"],["不等于","不等於"],["不等价交换","不等價交換"],["不管闲事","不管閒事"],["不系","不繫"],["不系舟","不繫舟"],["不约而合","不約而合"],["不约而同","不約而同"],["不织布","不織布"],["不结汇进口","不結匯進口"],["不绝于耳","不絕於耳"],["不老药","不老藥"],["不肯干休","不肯干休"],["不育症","不育症"],["不胜","不勝"],["不胜之态","不勝之態"],["不胜其扰","不勝其擾"],["不胜其烦","不勝其煩"],["不胜其苦","不勝其苦"],["不胜唏嘘","不勝唏噓"],["不胜感喟","不勝感喟"],["不胜感激","不勝感激"],["不胜春","不勝春"],["不胜枚举","不勝枚舉"],["不胜衣","不勝衣"],["不胜负荷","不勝負荷"],["不胜酒力","不勝酒力"],["不能出口","不能出口"],["不能尽数","不能盡數"],["不能胜数","不能勝數"],["不能自制","不能自制"],["不能赞一辞","不能贊一辭"],["不至于","不至於"],["不致","不致"],["不致于","不致於"],["不舍","不捨"],["不舍得","不捨得"],["不舍昼夜","不捨晝夜"],["不舒适","不舒適"],["不良于行","不良於行"],["不良倾向","不良傾向"],["不良才","不良才"],["不良适应","不良適應"],["不药而愈","不藥而癒"],["不药而癒","不藥而癒"],["不获","不獲"],["不落人后","不落人後"],["不虚发","不虛發"],["不行了","不行了"],["不表","不表"],["不见世面","不見世面"],["不见了","不見了"],["不见识面","不見識面"],["不见面","不見面"],["不规范","不規範"],["不解之仇","不解之仇"],["不讨采","不討采"],["不让须眉","不讓鬚眉"],["不讲情面","不講情面"],["不识局面","不識局面"],["不识闲","不識閒"],["不说价","不說價"],["不说出","不說出"],["不谈别的","不談別的"],["不谋而合","不謀而合"],["不谋而同","不謀而同"],["不谐当","不諧當"],["不谷","不穀"],["不负所托","不負所托"],["不赞","不讚"],["不赞一词","不讚一詞"],["不赞一辞","不讚一辭"],["不赞同","不贊同"],["不赞成","不贊成"],["不足为据","不足爲據"],["不足之症","不足之症"],["不足回旋","不足回旋"],["不足挂齿","不足掛齒"],["不足采信","不足採信"],["不辞而别","不辭而別"],["不远万里","不遠萬里"],["不远千里","不遠千里"],["不连续面","不連續面"],["不适","不適"],["不适合","不適合"],["不适当","不適當"],["不适感","不適感"],["不适用","不適用"],["不逊于","不遜於"],["不透明水彩画","不透明水彩畫"],["不通吊庆","不通弔慶"],["不遗余力","不遺餘力"],["不避彊御","不避彊禦"],["不采","不採"],["不采声","不采聲"],["不锈钢","不鏽鋼"],["不锈钢板","不鏽鋼板"],["不问前因后果","不問前因後果"],["不问是非曲直","不問是非曲直"],["不降反升","不降反升"],["不限于","不限於"],["不须","不須"],["不顾前后","不顧前後"],["不顾后果","不顧後果"],["不顾曲直","不顧曲直"],["不顾闲野","不顧閒野"],["不食人间烟火","不食人間煙火"],["不食周粟","不食周粟"],["不食干腊","不食乾腊"],["不食烟火","不食煙火"],["不龟手药","不龜手藥"],["不龟药","不龜藥"],["与他一斗","與他一鬥"],["与众不同","與衆不同"],["与克制","與剋制"],["与党","與黨"],["与君一席话胜读十年书","與君一席話勝讀十年書"],["与国同休","與國同休"],["与她一斗","與她一鬥"],["与子同袍","與子同袍"],["与日同辉","與日同輝"],["与此同时","與此同時"],["与民同乐","與民同樂"],["与民同忧","與民同憂"],["丑三","丑三"],["丑丑","醜醜"],["丑丫头","醜丫頭"],["丑事","醜事"],["丑于","醜於"],["丑人","醜人"],["丑人多作怪","醜人多作怪"],["丑侪","醜儕"],["丑八怪","醜八怪"],["丑剌剌","醜剌剌"],["丑剧","醜劇"],["丑化","醜化"],["丑史","醜史"],["丑名","醜名"],["丑咤","醜吒"],["丑地","醜地"],["丑声","醜聲"],["丑声四溢","醜聲四溢"],["丑声远播","醜聲遠播"],["丑头怪脸","醜頭怪臉"],["丑夷","醜夷"],["丑女","醜女"],["丑女人","醜女人"],["丑女效颦","醜女效顰"],["丑奴儿","醜奴兒"],["丑妇","醜婦"],["丑媳","醜媳"],["丑媳妇","醜媳婦"],["丑媳妇总得要见公婆","醜媳婦總得要見公婆"],["丑小鸭","醜小鴨"],["丑巴怪","醜巴怪"],["丑年","丑年"],["丑徒","醜徒"],["丑态","醜態"],["丑态毕露","醜態畢露"],["丑态百出","醜態百出"],["丑怪","醜怪"],["丑恶","醜惡"],["丑日","丑日"],["丑旦","丑旦"],["丑时","丑時"],["丑月","丑月"],["丑末","醜末"],["丑杂","醜雜"],["丑样","醜樣"],["丑死","醜死"],["丑比","醜比"],["丑毙了","醜斃了"],["丑沮","醜沮"],["丑牛","丑牛"],["丑生","醜生"],["丑男","醜男"],["丑相","醜相"],["丑类","醜類"],["丑类恶物","醜類惡物"],["丑脸","醜臉"],["丑虏","醜虜"],["丑行","醜行"],["丑角","丑角"],["丑言","醜言"],["丑诋","醜詆"],["丑话","醜話"],["丑语","醜語"],["丑贼生","醜賊生"],["丑辞","醜辭"],["丑辱","醜辱"],["丑逆","醜逆"],["丑闻","醜聞"],["丑闻案","醜聞案"],["丑陋","醜陋"],["专业人才","專業人才"],["专修","專修"],["专修班","專修班"],["专修科","專修科"],["专修科目","專修科目"],["专利药","專利藥"],["专利药品","專利藥品"],["专制","專制"],["专制主义","專制主義"],["专制制度","專制制度"],["专制君主制","專制君主制"],["专制政体","專制政體"],["专制政府","專制政府"],["专制政治","專制政治"],["专制权","專制權"],["专制起来","專制起來"],["专勤制度","專勤制度"],["专向","專向"],["专家系统","專家系統"],["专家评价","專家評價"],["专干","專幹"],["专征","專征"],["专心一志","專心一志"],["专心致志","專心致志"],["专才","專才"],["专摆","專擺"],["专柜","專櫃"],["专柜小姐","專櫃小姐"],["专欲难成","專欲難成"],["专注","專注"],["专注力","專注力"],["专精于","專精於"],["专美于前","專美於前"],["专辑里","專輯裏"],["专鉴","專鑒"],["专门人才","專門人才"],["专门术语","專門術語"],["且于","且於"],["且听下回分解","且聽下回分解"],["世上无难事只怕有心人","世上無難事只怕有心人"],["世仇","世仇"],["世出世","世出世"],["世台","世臺"],["世台会","世臺會"],["世彩堂","世綵堂"],["世彩堂帖","世綵堂帖"],["世恩录","世恩錄"],["世情看冷暖人面逐高低","世情看冷暖人面逐高低"],["世所周知","世所周知"],["世田谷","世田谷"],["世界大同","世界大同"],["世界旅游组织","世界旅遊組織"],["世界杯","世界盃"],["世界杯室","世界盃室"],["世界杯赛","世界盃賽"],["世界纪录","世界紀錄"],["世界范围","世界範圍"],["世界里","世界裏"],["世系","世系"],["世纪钟","世紀鐘"],["世纪钟表","世紀鐘錶"],["世胄","世胄"],["世表","世表"],["世阿弥","世阿彌"],["世面","世面"],["丘克","丘克"],["丙种","丙種"],["丙种射线","丙種射線"],["丙舍","丙舍"],["业余","業餘"],["业余大学","業餘大學"],["业余教育","業餘教育"],["业余爱好","業餘愛好"],["业余者","業餘者"],["业务范围","業務範圍"],["业界标准","業界標準"],["业种","業種"],["业精于勤","業精於勤"],["业荒于嬉","業荒於嬉"],["业馀电台","業餘電臺"],["丛台区","叢臺區"],["丛生叶","叢生葉"],["东丰","東豐"],["东丰县","東豐縣"],["东丰阁","東豐閣"],["东京柜","東京櫃"],["东仓里","東倉里"],["东伙","東夥"],["东冲西突","東衝西突"],["东加里曼丹","東加里曼丹"],["东北向","東北向"],["东北面","東北面"],["东升","東昇"],["东南向","東南向"],["东南面","東南面"],["东厂","東廠"],["东台","東臺"],["东台市","東臺市"],["东台湾","東臺灣"],["东向","東向"],["东周","東周"],["东周时","東周時"],["东周时代","東周時代"],["东周时期","東周時期"],["东周钟","東周鐘"],["东奔西向","東奔西向"],["东学党","東學黨"],["东山之志","東山之志"],["东山里","東山里"],["东山里站","東山里站"],["东岳","東嶽"],["东干","東干"],["东征","東征"],["东征西怨","東征西怨"],["东征西讨","東征西討"],["东扬西荡","東揚西蕩"],["东折西绕","東折西繞"],["东挨西撞","東挨西撞"],["东挪西借","東挪西借"],["东摇西摆","東搖西擺"],["东方发白","東方發白"],["东方汇理","東方匯理"],["东林党","東林黨"],["东欧集团","東歐集團"],["东海捞针","東海撈針"],["东涂西抹","東塗西抹"],["东淨里的砖儿","東淨裏的磚兒"],["东游","東遊"],["东窗事发","東窗事發"],["东胜区","東勝區"],["东胡","東胡"],["东芝医疗系","東芝醫療繫"],["东荡西除","東蕩西除"],["东蒙","東蒙"],["东西向","東西向"],["东西周","東西周"],["东讨西征","東討西征"],["东谷拉瓦","東谷拉瓦"],["东邻西舍","東鄰西舍"],["东里","東里"],["东量西折","東量西折"],["东面","東面"],["东飘西荡","東飄西蕩"],["丝发","絲髮"],["丝发之功","絲髮之功"],["丝布","絲布"],["丝弦","絲絃"],["丝恩发怨","絲恩髮怨"],["丝托索","絲托索"],["丝挂子","絲掛子"],["丝杆","絲桿"],["丝杠","絲槓"],["丝来线去","絲來線去"],["丝板","絲板"],["丝瓜布","絲瓜布"],["丝盘虫","絲盤蟲"],["丝线","絲線"],["丝织厂","絲織廠"],["丝绒布","絲絨布"],["丝虫","絲蟲"],["丝虫病","絲蟲病"],["丢丑","丟醜"],["丢了","丟了"],["丢体面","丟體面"],["丢入爪哇国里","丟入爪哇國裏"],["丢出","丟出"],["丢出去","丟出去"],["丢包术","丟包術"],["丢在脑后","丟在腦後"],["丢巧针","丟巧針"],["丢面子","丟面子"],["两万","兩萬"],["两个","兩個"],["两个中国","兩個中國"],["两个或两个以上","兩個或兩個以上"],["两个或更多","兩個或更多"],["两个肩膀扛张嘴","兩個肩膀扛張嘴"],["两人同心","兩人同心"],["两余","兩餘"],["两克","兩克"],["两党","兩黨"],["两千","兩千"],["两厢情愿","兩廂情願"],["两只","兩隻"],["两只手","兩隻手"],["两只脚赶不上一张嘴","兩隻腳趕不上一張嘴"],["两台","兩臺"],["两叶","兩葉"],["两叶掩目","兩葉掩目"],["两合公司","兩合公司"],["两周","兩週"],["两周年","兩週年"],["两回","兩回"],["两回事","兩回事"],["两国关系","兩國關係"],["两天后","兩天後"],["两天晒网","兩天曬網"],["两头三面","兩頭三面"],["两头白面","兩頭白面"],["两娘女","兩娘女"],["两岸关系","兩岸關係"],["两当","兩當"],["两当一","兩當一"],["两当县","兩當縣"],["两性关系","兩性關係"],["两情两愿","兩情兩願"],["两扎","兩紮"],["两撇胡","兩撇鬍"],["两方面","兩方面"],["两杆","兩杆"],["两杠","兩槓"],["两杯","兩杯"],["两板","兩板"],["两极","兩極"],["两极分化","兩極分化"],["两极化","兩極化"],["两极管","兩極管"],["两极观点","兩極觀點"],["两段制","兩段制"],["两点钟","兩點鐘"],["两班制","兩班制"],["两百万","兩百萬"],["两百个","兩百個"],["两百多万","兩百多萬"],["两相情愿","兩相情願"],["两眼发直","兩眼發直"],["两种","兩種"],["两种人","兩種人"],["两秒钟","兩秒鐘"],["两腿发软","兩腿發軟"],["两虎共斗","兩虎共鬥"],["两虎相斗","兩虎相鬥"],["两西西里王国","兩西西里王國"],["两院制","兩院制"],["两面","兩面"],["两面三刀","兩面三刀"],["两面不是人","兩面不是人"],["两面不讨好","兩面不討好"],["两面二舌","兩面二舌"],["两面作战","兩面作戰"],["两面倒","兩面倒"],["两面光","兩面光"],["两面刀","兩面刀"],["两面夹攻","兩面夾攻"],["两面性","兩面性"],["两面手法","兩面手法"],["两面派","兩面派"],["两面讨好","兩面討好"],["两面转圜","兩面轉圜"],["两面锯","兩面鋸"],["两面顾全","兩面顧全"],["两鼠斗穴","兩鼠鬥穴"],["严丝合缝","嚴絲合縫"],["严了眼儿","嚴了眼兒"],["严于","嚴於"],["严于律己","嚴於律己"],["严云农","嚴云農"],["严冬","嚴冬"],["严制","嚴制"],["严加防范","嚴加防範"],["严复","嚴復"],["严恶","嚴惡"],["严禁吸烟","嚴禁吸菸"],["严禁烟火","嚴禁煙火"],["严重后果","嚴重後果"],["丧失殆尽","喪失殆盡"],["丧尸","喪屍"],["丧尽","喪盡"],["丧尽天良","喪盡天良"],["丧志","喪志"],["丧荡游魂","喪蕩游魂"],["丧钟","喪鐘"],["个个","個個"],["个个称羡","個個稱羨"],["个中","箇中"],["个中三昧","箇中三昧"],["个中人","箇中人"],["个中原因","箇中原因"],["个中奥妙","箇中奧妙"],["个中奥秘","箇中奧祕"],["个中好手","箇中好手"],["个中强手","箇中強手"],["个中消息","箇中消息"],["个中滋味","箇中滋味"],["个中玄机","箇中玄機"],["个中理由","箇中理由"],["个中讯息","箇中訊息"],["个中资讯","箇中資訊"],["个中道理","箇中道理"],["个中高手","箇中高手"],["个事","個事"],["个人","個人"],["个人主义","個人主義"],["个人伤害","個人傷害"],["个人储蓄","個人儲蓄"],["个人利益","個人利益"],["个人化","個人化"],["个人单季","個人單季"],["个人卫生","個人衛生"],["个人外交","個人外交"],["个人奖","個人獎"],["个人崇拜","個人崇拜"],["个人工作室","個人工作室"],["个人得失","個人得失"],["个人性","個人性"],["个人所得","個人所得"],["个人所得税","個人所得稅"],["个人护理","個人護理"],["个人拨接","個人撥接"],["个人本位","個人本位"],["个人消费","個人消費"],["个人用","個人用"],["个人用户","個人用戶"],["个人电脑","個人電腦"],["个人组","個人組"],["个人网站","個人網站"],["个人资料","個人資料"],["个人赛","個人賽"],["个人隐私","個人隱私"],["个人风","個人風"],["个人首页","個人首頁"],["个位","個位"],["个位数","個位數"],["个体","個體"],["个体发育","個體發育"],["个体户","個體戶"],["个体所有","個體所有"],["个体经济","個體經濟"],["个例","個例"],["个儿","個兒"],["个别","個別"],["个别差异","個別差異"],["个别性","個別性"],["个别情况","個別情況"],["个别指导","個別指導"],["个别教学","個別教學"],["个别测验","個別測驗"],["个别现象","個別現象"],["个别生产","個別生產"],["个别谈话","個別談話"],["个别辅导","個別輔導"],["个头","個頭"],["个头儿","個頭兒"],["个子","個子"],["个屁阿","個屁阿"],["个展","個展"],["个性","個性"],["个性化","個性化"],["个性难改","個性難改"],["个把","個把"],["个把月","個把月"],["个数","個數"],["个旧","箇舊"],["个旧县","箇舊縣"],["个旧市","箇舊市"],["个样","個樣"],["个核","個核"],["个案","個案"],["个案分析","個案分析"],["个案研究","個案研究"],["个案纪录","個案紀錄"],["个股为","個股爲"],["个过客","個過客"],["个钟","個鐘"],["个钟表","個鐘錶"],["中上游","中上游"],["中下游","中下游"],["中书舍人","中書舍人"],["中了暑","中了暑"],["中了标","中了標"],["中了毒","中了毒"],["中于","中於"],["中云","中雲"],["中介社团","中介社團"],["中仑","中崙"],["中仑站","中崙站"],["中价位","中價位"],["中低价位","中低價位"],["中俄关系","中俄關系"],["中千世界","中千世界"],["中华台北","中華臺北"],["中华电视台","中華電視臺"],["中华肝吸虫病","中華肝吸蟲病"],["中华苏维埃共和国","中華蘇維埃共和國"],["中华革命党","中華革命黨"],["中原板荡","中原板蕩"],["中原标准时间","中原標準時間"],["中台","中臺","中颱"],["中台医专","中臺醫專"],["中台湾","中臺灣"],["中台禅寺","中臺禪寺"],["中台科技大学","中臺科技大學"],["中叶","中葉"],["中国共产党","中國共產黨"],["中国制","中國製"],["中国制造","中國製造"],["中国剩余定理","中國剩餘定理"],["中国医药","中國醫藥"],["中国历史","中國歷史"],["中国同盟会","中國同盟會"],["中国国民党","中國國民黨"],["中型钟","中型鐘"],["中型钟表","中型鐘錶"],["中型钟表面","中型鐘表面"],["中型钟面","中型鐘面"],["中央专制集权","中央專制集權"],["中央党","中央黨"],["中央党部","中央黨部"],["中央台","中央臺"],["中央广播电台","中央廣播電臺"],["中央标准局","中央標準局"],["中央汇金","中央匯金"],["中央电视台","中央電視臺"],["中央监控系统","中央監控系統"],["中央空调系统","中央空調系統"],["中央面","中央面"],["中子俘获","中子俘獲"],["中岳","中嶽"],["中度台风","中度颱風"],["中彩","中彩"],["中心汇率","中心匯率"],["中恶","中惡"],["中懑之症","中懣之症"],["中才","中才"],["中控台","中控臺"],["中控面板","中控面板"],["中搜","中搜"],["中文台","中文臺"],["中文系","中文系"],["中文里","中文裏"],["中日关系","中日關係"],["中暗箭","中暗箭"],["中板","中板"],["中极","中極"],["中枢系统","中樞系統"],["中核","中核"],["中止症","中止症"],["中比关系","中比關係"],["中注模样","中注模樣"],["中涂","中塗"],["中港台","中港臺"],["中游","中游"],["中环杯","中環盃"],["中盘胜","中盤勝"],["中秋","中秋"],["中秋佳节","中秋佳節"],["中秋帖","中秋帖"],["中秋月饼","中秋月餅"],["中秋节","中秋節"],["中程计划","中程計劃"],["中筋面粉","中筋麪粉"],["中签","中籤"],["中美发表","中美發表"],["中胡","中胡"],["中草药","中草藥"],["中药","中藥"],["中药偏方","中藥偏方"],["中药学","中藥學"],["中药店","中藥店"],["中药房","中藥房"],["中药材","中藥材"],["中药铺","中藥鋪"],["中表","中表"],["中西合并","中西合併"],["中西合璧","中西合璧"],["中谷","中谷"],["中谷有蓷","中谷有蓷"],["中转柜台","中轉櫃檯"],["中远集团","中遠集團"],["中远香港集团","中遠香港集團"],["中间纤维","中間纖維"],["中风后","中風後"],["丰上锐下","豐上銳下"],["丰下","豐下"],["丰丘明","豐丘明"],["丰业","豐業"],["丰乐","豐樂"],["丰乐亭","豐樂亭"],["丰产","豐產"],["丰产田","豐產田"],["丰亨豫大","豐亨豫大"],["丰仪","丰儀"],["丰伟","豐偉"],["丰俭由人","豐儉由人"],["丰儀","丰儀"],["丰功","豐功"],["丰功伟业","豐功偉業"],["丰功伟绩","豐功偉績"],["丰功厚利","豐功厚利"],["丰功大业","豐功大業"],["丰功懋烈","豐功懋烈"],["丰功盛烈","豐功盛烈"],["丰华","豐華"],["丰南","豐南"],["丰南区","豐南區"],["丰厚","豐厚"],["丰原","豐原"],["丰原市","豐原市"],["丰县","豐縣"],["丰取刻与","豐取刻與"],["丰台","豐臺"],["丰台区","豐臺區"],["丰城","豐城"],["丰城剑气","豐城劍氣"],["丰城市","豐城市"],["丰城贯斗","豐城貫斗"],["丰壤","豐壤"],["丰奢","豐奢"],["丰妍","豐妍"],["丰姿","丰姿"],["丰姿冶丽","丰姿冶麗"],["丰姿绰约","丰姿綽約"],["丰宁","豐寧"],["丰宁县","豐寧縣"],["丰实","豐實"],["丰容","丰容"],["丰容靓饰","豐容靚飾"],["丰富","豐富"],["丰富多彩","豐富多彩"],["丰富性","豐富性"],["丰川悦司","豐川悅司"],["丰年","豐年"],["丰年玉","豐年玉"],["丰年祭","豐年祭"],["丰年稔岁","豐年稔歲"],["丰年节","豐年節"],["丰年虾","豐年蝦"],["丰度","丰度","豐度"],["丰悴","豐悴"],["丰情","丰情"],["丰收","豐收"],["丰收年","豐收年"],["丰本","豐本"],["丰杀","豐殺"],["丰标","丰標"],["丰标不凡","丰標不凡"],["丰歉","豐歉"],["丰殖","豐殖"],["丰水","豐水"],["丰水期","豐水期"],["丰沛","豐沛"],["丰注","豐注"],["丰泽","豐澤"],["丰泽区","豐澤區"],["丰润","豐潤"],["丰润区","豐潤區"],["丰渔桥","豐漁橋"],["丰溪里","豐溪里"],["丰满","豐滿"],["丰满区","豐滿區"],["丰滨","豐濱"],["丰滨乡","豐濱鄉"],["丰炽","豐熾"],["丰熟","豐熟"],["丰田","豐田"],["丰登","豐登"],["丰盈","豐盈"],["丰盛","豐盛"],["丰硕","豐碩"],["丰碑","豐碑"],["丰神","丰神"],["丰神俊美","丰神俊美"],["丰神异彩","豐神異彩"],["丰神绰约","丰神綽約"],["丰神飘洒","丰神飄灑"],["丰稔","豐稔"],["丰穰","豐穰"],["丰美","豐美"],["丰耗","豐耗"],["丰肌","豐肌"],["丰胸","豐胸"],["丰腆","豐腆"],["丰腴","豐腴"],["丰臣秀吉","豐臣秀吉"],["丰若晖","豐若暉"],["丰若有肌柔若无骨","丰若有肌柔若無骨"],["丰茂","豐茂"],["丰茸","丰茸"],["丰草","豐草"],["丰蔚","豐蔚"],["丰衍","豐衍"],["丰衣足食","豐衣足食"],["丰裕","豐裕"],["丰赡","豐贍"],["丰足","豐足"],["丰都","豐都"],["丰都县","豐都縣"],["丰采","丰采"],["丰镇","豐鎮"],["丰镇市","豐鎮市"],["丰镐","豐鎬"],["丰隆","豐隆"],["丰韵","丰韻"],["丰韻","丰韻"],["丰顺","豐順"],["丰顺县","豐順縣"],["丰颊","豐頰"],["丰饶","豐饒"],["丰饶丰足","豐饒豐足"],["串亲戚","串親戚"],["串出来","串出來"],["串同","串同"],["串哄","串哄"],["串游","串游"],["临别","臨別"],["临别依依","臨別依依"],["临别时","臨別時"],["临别赠言","臨別贈言"],["临制","臨制"],["临危致命","臨危致命"],["临去秋波","臨去秋波"],["临夏回族自治州","臨夏回族自治州"],["临幸","臨幸"],["临床特征","臨牀特徵"],["临机制变","臨機制變"],["临机制胜","臨機制勝"],["临江折轴","臨江折軸"],["临海水土志","臨海水土誌"],["临潼斗宝","臨潼鬥寶"],["丸药","丸藥"],["丸药盒","丸藥盒"],["丹参","丹蔘"],["丹台","丹臺"],["丹布朗","丹布朗"],["丹干","丹干"],["丹徒布衣","丹徒布衣"],["丹朱","丹朱"],["丹药","丹藥"],["为中台","爲中颱"],["为了","爲了"],["为人师表","爲人師表"],["为准","爲準"],["为念","爲念"],["为恶不悛","爲惡不悛"],["为所欲为","爲所欲爲"],["为模范","爲模範"],["为着","爲着"],["为规范","爲規範"],["为鉴","爲鑑"],["主仆","主僕"],["主修","主修"],["主修科目","主修科目"],["主席台","主席臺"],["主席团","主席團"],["主干","主幹"],["主干家庭","主幹家庭"],["主干线","主幹線"],["主干网络","主幹網絡"],["主干网路","主幹網路"],["主控台","主控臺"],["主播台","主播臺"],["主教团","主教團"],["主普坛","主普壇"],["主机板","主機板"],["主板","主板"],["主梁","主樑"],["主法向量","主法向量"],["主画面","主畫面"],["主要树种","主要樹種"],["主钟差","主鐘差"],["主钟曲线","主鐘曲線"],["主题曲","主題曲"],["主题论坛区","主題論壇區"],["丽于","麗於"],["丽舍","麗舍"],["举不胜举","舉不勝舉"],["举了","舉了"],["举例发凡","舉例發凡"],["举出","舉出"],["举出来","舉出來"],["举发","舉發"],["举尾虫","舉尾蟲"],["举手可采","舉手可采"],["举手表","舉手表"],["举手表决","舉手表決"],["举措失当","舉措失當"],["举杯","舉杯","舉盃"],["举杯畅饮","舉杯暢飲"],["举止闲冶","舉止閒冶"],["举目千里","舉目千里"],["举荐征辟","舉薦征辟"],["乃至于","乃至於"],["乃里","乃里"],["久仰山斗","久仰山斗"],["久别","久別"],["久别相逢","久別相逢"],["久别重逢","久別重逢"],["久违颜范","久違顏範"],["么娘","麼娘"],["义义合合","義義合合"],["义仆","義僕"],["义占","義佔"],["义同生死","義同生死"],["义和团","義和團"],["义大利杯","義大利杯"],["义大利面","義大利麪"],["义庄","義莊"],["义形于色","義形於色"],["义气干霄","義氣干霄"],["义薄云天","義薄雲天"],["之于","之於"],["之余","之餘"],["之八九只","之八九只"],["之叹","之嘆"],["之后","之後"],["之征","之徵"],["之念","之念"],["之托","之託"],["之杯","之杯"],["之核","之核"],["之欲","之慾"],["之游","之遊"],["之秋","之秋"],["之鉴","之鑑"],["之钟","之鐘"],["乌东察克","烏東察克"],["乌东査克","烏東查克"],["乌云","烏雲"],["乌云密布","烏雲密佈"],["乌云蔽日","烏雲蔽日"],["乌什塔拉回族乡","烏什塔拉回族鄉"],["乌克丽丽","烏克麗麗"],["乌克兰","烏克蘭"],["乌克兰人","烏克蘭人"],["乌克兰籍","烏克蘭籍"],["乌克兰队","烏克蘭隊"],["乌兰察布","烏蘭察布"],["乌兰察布市","烏蘭察布市"],["乌兰巴托","烏蘭巴托"],["乌兹冲锋枪","烏茲衝鋒槍"],["乌兹别克","烏茲別克"],["乌兹别克人","烏茲別克人"],["乌兹别克共和国","烏茲別克共和國"],["乌兹别克斯坦","烏茲別克斯坦"],["乌兹别克族","烏茲別克族"],["乌冬面","烏冬面"],["乌发","烏髮"],["乌合","烏合"],["乌合之众","烏合之衆"],["乌合之卒","烏合之卒"],["乌孜别克","烏孜別克"],["乌孜别克族","烏孜別克族"],["乌孜别克语","烏孜別克語"],["乌干达","烏干達"],["乌干达共和国","烏干達共和國"],["乌当","烏當"],["乌当区","烏當區"],["乌托邦","烏托邦"],["乌拉特后旗","烏拉特後旗"],["乌松","烏松"],["乌梁海","烏梁海"],["乌梁海盆地","烏梁海盆地"],["乌沈沈","烏沈沈"],["乌洛托品","烏洛托品"],["乌涂","烏塗"],["乌涂水","烏塗水"],["乌滋别克","烏滋別克"],["乌滋别克斯坦","烏滋別克斯坦"],["乌烟瘴气","烏煙瘴氣"],["乌狗吃食白狗当灾","烏狗吃食白狗當災"],["乌苏","烏蘇"],["乌苏市","烏蘇市"],["乌苏拉","烏蘇拉"],["乌苏里斯克","烏蘇里斯克"],["乌苏里江","烏蘇里江"],["乌药","烏藥"],["乌获","烏獲"],["乌菲兹美术馆","烏菲茲美術館"],["乌里","烏里"],["乌里雅苏台","烏里雅蘇臺"],["乌鲁克恰提","烏魯克恰提"],["乌鲁克恰提县","烏魯克恰提縣"],["乌鲁克穆河","烏魯克穆河"],["乌龙面","烏龍麪"],["乏困","乏困"],["乐不可极","樂不可極"],["乐于","樂於"],["乐于助人","樂於助人"],["乐合彩","樂合彩"],["乐器钟","樂器鐘"],["乐团","樂團"],["乐坏了","樂壞了"],["乐坛","樂壇"],["乐府杂录","樂府雜錄"],["乐意于","樂意於"],["乐曲","樂曲"],["乐极则悲","樂極則悲"],["乐极忘形","樂極忘形"],["乐极悲来","樂極悲來"],["乐极悲生","樂極悲生"],["乐极生悲","樂極生悲"],["乐游原","樂遊原"],["乐祸幸灾","樂禍幸災"],["乐透彩","樂透彩"],["乐颠了馅","樂顛了餡"],["乒乓球台","乒乓球檯"],["乔修亚","喬修亞"],["乔修亚．吉尔菲艾斯","喬修亞．吉爾菲艾斯"],["乔做胡为","喬做胡爲"],["乔岳","喬嶽"],["乔布斯","喬布斯"],["乔德里","喬德里"],["乔志","喬志"],["乔才","喬才"],["乔杰立","喬傑立"],["乔松","喬松"],["乔松之寿","喬松之壽"],["乔治克隆尼","喬治克隆尼"],["乔治克鲁尼","喬治克魯尼"],["乔治．布希","喬治．布希"],["乖别","乖別"],["乘了","乘了"],["乘云","乘雲"],["乘凶完配","乘凶完配"],["乘奔御风","乘奔御風"],["乘法表","乘法表"],["乘胜","乘勝"],["乘胜追击","乘勝追擊"],["乘胜逐北","乘勝逐北"],["乘鹤驾云","乘鶴駕雲"],["乙丑","乙丑"],["乙种","乙種"],["乙种射线","乙種射線"],["乙种粒子","乙種粒子"],["乙种维生素","乙種維生素"],["九世之仇","九世之仇"],["九个","九個"],["九个人","九個人"],["九个月","九個月"],["九九乘法表","九九乘法表"],["九九表","九九表"],["九亿五千万","九億五千萬"],["九余","九餘"],["九冬","九冬"],["九出祁山","九出祁山"],["九分钟","九分鐘"],["九划","九劃"],["九千点","九千點"],["九只","九隻"],["九台","九臺"],["九台市","九臺市"],["九合","九合"],["九合一匡","九合一匡"],["九吊六的","九吊六的"],["九回肠","九迴腸"],["九天后","九天後"],["九宵云","九宵雲"],["九宵云外","九宵雲外"],["九扎","九紮"],["九折","九折"],["九折优待","九折優待"],["九折臂","九折臂"],["九曲","九曲"],["九曲桥","九曲橋"],["九曲洞","九曲洞"],["九杯","九杯"],["九点钟","九點鐘"],["九炼成钢","九鍊成鋼"],["九百万","九百萬"],["九百个","九百個"],["九秋","九秋"],["九秒钟","九秒鐘"],["九章算术","九章算術"],["九谷","九穀"],["九里","九里"],["九里余","九里餘"],["九里区","九里區"],["九针","九針"],["九零后","九零後"],["九霄云外","九霄雲外"],["九面体","九面體"],["九香虫","九香蟲"],["九龙杯","九龍杯"],["九龙表行","九龍表行"],["乞力马扎罗山","乞力馬扎羅山"],["乞留恶滥","乞留惡濫"],["乞留曲律","乞留曲律"],["也不尽然","也不盡然"],["也克制","也剋制"],["也向","也向"],["也对于","也對於"],["也念","也念"],["也斗了胆","也斗了膽"],["也舍下","也舍下"],["也须","也須"],["习于","習於"],["习惯于","習慣於"],["习非胜是","習非勝是"],["乡党","鄉黨"],["乡党尚齿","鄉黨尚齒"],["乡团","鄉團"],["乡土艺术","鄉土藝術"],["乡愿","鄉愿"],["乡曲","鄉曲"],["乡曲之誉","鄉曲之譽"],["乡民代表","鄉民代表"],["乡民代表会","鄉民代表會"],["乡里","鄉里"],["乡里小人","鄉里小人"],["乡镇代表","鄉鎮代表"],["乡镇民代表","鄉鎮民代表"],["乡间别墅","鄉間別墅"],["乡面","鄉面"],["书不尽","書不盡"],["书不尽言","書不盡言"],["书中自有千钟粟","書中自有千鍾粟"],["书写不能症","書寫不能症"],["书刊杂志","書刊雜誌"],["书卷","書卷"],["书卷奖","書卷獎"],["书卷气","書卷氣"],["书台","書檯"],["书后","書後"],["书呆子","書呆子"],["书坛","書壇"],["书录","書錄"],["书报杂志","書報雜誌"],["书柜","書櫃"],["书种","書種"],["书签","書籤"],["书系","書系"],["书虫","書蟲"],["书虫子","書蟲子"],["书面","書面"],["书面上","書面上"],["书面报告","書面報告"],["书面纸","書面紙"],["书面许可","書面許可"],["书面语","書面語"],["书面资料","書面資料"],["乩坛","乩壇"],["买一个饶一个","買一個饒一個"],["买了","買了"],["买价","買價"],["买凶","買兇"],["买咸鱼放生","買鹹魚放生"],["买回","買回"],["买回去","買回去"],["买回家","買回家"],["买回来","買回來"],["买大彩","買大彩"],["买汇","買匯"],["买烟","買菸"],["买物历","買物歷"],["买臣复水","買臣覆水"],["买进对冲","買進對沖"],["买闲钱","買閒錢"],["买面子","買面子"],["买风云雷雨","買風雲雷雨"],["乱世凶年","亂世凶年"],["乱了","亂了"],["乱了手脚","亂了手腳"],["乱作一团","亂作一團"],["乱党","亂黨"],["乱冲","亂衝"],["乱发","亂髮"],["乱哄","亂鬨"],["乱哄不过来","亂鬨不過來"],["乱哄哄","亂哄哄"],["乱成一团","亂成一團"],["乱扣","亂扣"],["乱搞男女关系","亂搞男女關係"],["乱松松","亂鬆鬆"],["乱极则平","亂極則平"],["乱棒胡敲","亂棒胡敲"],["乱涂","亂塗"],["乱针绣","亂針繡"],["乱集团","亂集團"],["乱首垢面","亂首垢面"],["乳制品","乳製品"],["乳娘","乳孃"],["乳液聚合","乳液聚合"],["乳糖不耐症","乳糖不耐症"],["乳臭未干","乳臭未乾"],["乳药求死","乳藥求死"],["乾元","乾元"],["乾兌","乾兌"],["乾卦","乾卦"],["乾坤一掷","乾坤一擲"],["乾坤再造","乾坤再造"],["乾坤大挪移","乾坤大挪移"],["乾尽午中","乾盡午中"],["乾象历","乾象曆"],["乾隆","乾隆"],["乾隆年间","乾隆年間"],["乾隆皇帝","乾隆皇帝"],["了不得","了不得"],["了不成","了不成"],["了不起","了不起"],["了了","了了"],["了事","了事"],["了事环","了事環"],["了债","了債"],["了儿","了兒"],["了决","了決"],["了劣","了劣"],["了却","了卻"],["了却此生","了卻此生"],["了去","了去"],["了如","瞭如"],["了如指掌","瞭如指掌"],["了局","了局"],["了帐","了帳"],["了当","了當"],["了当不得","了當不得"],["了得","了得"],["了得了","了得了"],["了悟","了悟"],["了愿","了願"],["了手","了手"],["了收","了收"],["了断","了斷"],["了无","了無"],["了无挂碍","了無掛礙"],["了无新意","了無新意"],["了无牵挂","了無牽掛"],["了无生机","了無生機"],["了无生趣","了無生趣"],["了无痕迹","了無痕跡"],["了无罣碍","了無罣礙"],["了无长进","了無長進"],["了望","瞭望"],["了望台","瞭望臺"],["了望塔","瞭望塔"],["了望山","瞭望山"],["了望所","瞭望所"],["了案","了案"],["了此残生","了此殘生"],["了毕","了畢"],["了清","了清"],["了然","瞭然"],["了然不惑","瞭然不惑"],["了然于心","瞭然於心"],["了纳","了納"],["了结","了結"],["了若指掌","瞭若指掌"],["了落","了落"],["了解","瞭解"],["了解到","瞭解到"],["了讫","了訖"],["了话","了話"],["了语","了語"],["了账","了賬"],["了身达命","了身達命"],["了鸟","了鳥"],["争了","爭了"],["争先发言","爭先發言"],["争先后","爭先後"],["争先恐后","爭先恐後"],["争出","爭出"],["争奇斗妍","爭奇鬥妍"],["争奇斗异","爭奇鬥異"],["争奇斗艳","爭奇鬥豔"],["争妍斗奇","爭妍鬥奇"],["争妍斗胜","爭妍鬥勝"],["争妍斗艳","爭妍鬥豔"],["争强好胜","爭強好勝"],["争强斗胜","爭強鬥勝"],["争强显胜","爭強顯勝"],["争强赌胜","爭強賭勝"],["争斗","爭鬥"],["争斗不休","爭鬥不休"],["争相罗致","爭相羅致"],["争红斗紫","爭紅鬥紫"],["争胜","爭勝"],["争胜要强","爭勝要強"],["争闲气","爭閒氣"],["争面子","爭面子"],["事与愿违","事與願違"],["事也干","事也幹"],["事出","事出"],["事出不意","事出不意"],["事出不测","事出不測"],["事出有因","事出有因"],["事前事后","事前事後"],["事发","事發"],["事发地点","事發地點"],["事发时","事發時"],["事可干","事可幹"],["事后","事後"],["事后聪明","事後聰明"],["事后诸葛亮","事後諸葛亮"],["事好干","事好幹"],["事实胜于雄辩","事實勝於雄辯"],["事干","事幹"],["事态发展","事態發展"],["事情可干","事情可幹"],["事情好干","事情好幹"],["事情干脆","事情干脆"],["事成之后","事成之後"],["事有斗巧","事有鬥巧"],["事迹","事蹟"],["二丁挂","二丁掛"],["二仑","二崙"],["二仑乡","二崙鄉"],["二价","二價"],["二余","二餘"],["二党制","二黨制"],["二六板","二六板"],["二冲程引擎","二衝程引擎"],["二出祁山","二出祁山"],["二分钟","二分鐘"],["二划","二劃"],["二叠系","二疊系"],["二口虫","二口蟲"],["二只","二隻"],["二台","二臺"],["二叶松","二葉松"],["二合一","二合一"],["二吊六","二吊六"],["二周","二週"],["二和药","二和藥"],["二回","二回"],["二回熟","二回熟"],["二堂舍子","二堂舍子"],["二天后","二天後"],["二姑娘顽老雕","二姑娘頑老雕"],["二娘","二孃","二娘"],["二娘子","二娘子"],["二屋里","二屋裏"],["二年制","二年制"],["二弦","二絃"],["二志","二志"],["二恶英","二噁英"],["二手烟","二手菸"],["二拉八当","二拉八當"],["二撇胡","二撇鬍"],["二斗","二斗"],["二杆子","二桿子"],["二杯","二杯"],["二板","二板"],["二极","二極"],["二极体","二極體"],["二极管","二極管"],["二柜","二櫃"],["二次曲","二次曲"],["二次曲线","二次曲線"],["二次曲面","二次曲面"],["二段制","二段制"],["二流人才","二流人才"],["二点钟","二點鐘"],["二班制","二班制"],["二田制","二田制"],["二百万","二百萬"],["二百个","二百個"],["二百多万","二百多萬"],["二种","二種"],["二秒钟","二秒鐘"],["二缶钟惑","二缶鐘惑"],["二老板","二老闆"],["二胡","二胡"],["二致","二致"],["二苏","二蘇"],["二虎相斗","二虎相鬥"],["二表哥","二表哥"],["二表妹","二表妹"],["二表姊","二表姊"],["二表姊夫","二表姊夫"],["二表姐","二表姐"],["二表嫂","二表嫂"],["二表弟","二表弟"],["二进位制","二進位制"],["二进制","二進制"],["二部制","二部制"],["二部合唱","二部合唱"],["二部曲","二部曲"],["二里","二里"],["二里头","二里頭"],["二里头文化","二里頭文化"],["二重分类表","二重分類表"],["二门不出","二門不出"],["二面角","二面角"],["二项式系数","二項式係數"],["于一","於一"],["于一役","於一役"],["于七","於七"],["于三","於三"],["于丑","於醜"],["于世","於世"],["于丹","于丹"],["于之","於之"],["于乎","於乎"],["于乐","於樂"],["于九","於九"],["于事","於事"],["于事无济","於事無濟"],["于事无补","於事無補"],["于二","於二"],["于于","于于"],["于五","於五"],["于人","於人"],["于仁泰","于仁泰"],["于今","於今"],["于今犹烈","於今猶烈"],["于从濂","于從濂"],["于他","於他"],["于伏","於伏"],["于会泳","于會泳"],["于伟国","于偉國"],["于何","於何"],["于余曲折","于餘曲折"],["于你","於你"],["于佳卉","于佳卉"],["于光远","于光遠"],["于克勒","于克勒"],["于八","於八"],["于六","於六"],["于冕","于冕"],["于军","于軍"],["于农","於農"],["于凌奎","于凌奎"],["于凤桐","于鳳桐"],["于凤至","于鳳至"],["于前","於前"],["于劣","於劣"],["于勒","于勒"],["于勤","於勤"],["于化虎","于化虎"],["于十","於十"],["于半","於半"],["于占元","于占元"],["于双戈","于雙戈"],["于台烟","于臺煙"],["于右任","于右任"],["于吉","于吉"],["于后","於後"],["于呼哀哉","於呼哀哉"],["于品海","于品海"],["于嗟","于嗟"],["于四","於四"],["于国","於國"],["于国桢","于國楨"],["于坚","于堅"],["于垂","於垂"],["于堅","于堅"],["于墙","於牆"],["于大宝","于大寶"],["于天仁","于天仁"],["于夫罗","於夫羅"],["于奇库杜克","于奇庫杜克"],["于她","於她"],["于好","於好"],["于始","於始"],["于姓","于姓"],["于娜","于娜"],["于娟","于娟"],["于子千","于子千"],["于孔兼","于孔兼"],["于学忠","于學忠"],["于它","於它"],["于家","於家"],["于家为国","於家爲國"],["于家堡","于家堡"],["于密","於密"],["于寘","于寘"],["于小伟","于小偉"],["于小彤","于小彤"],["于尔岑","于爾岑"],["于尔根","于爾根"],["于尔里克","于爾里克"],["于尽","於盡"],["于山","于山"],["于山国","于山國"],["于左","於左"],["于差","於差"],["于己","於己"],["于市","於市"],["于帅","于帥"],["于帥","于帥"],["于幕","於幕"],["于幼军","于幼軍"],["于幼华","於幼華"],["于广洲","于廣洲"],["于康震","于康震"],["于式枚","于式枚"],["于弱","於弱"],["于强","於強"],["于归","于歸"],["于征","於徵"],["于徐","于徐"],["于從濂","于從濂"],["于德海","于德海"],["于心","於心"],["于心不安","於心不安"],["于心不忍","於心不忍"],["于心何忍","於心何忍"],["于心无愧","於心無愧"],["于志宁","于志寧"],["于怀","於懷"],["于思","于思"],["于慎行","于慎行"],["于慧","于慧"],["于戏","於戲"],["于成龍","于成龍"],["于成龙","于成龍"],["于我","於我"],["于振","于振"],["于振武","于振武"],["于敏","于敏"],["于敏中","于敏中"],["于敝","於敝"],["于斌","于斌"],["于斯","於斯"],["于斯塔德","于斯塔德"],["于斯納爾斯貝里","于斯納爾斯貝里"],["于斯纳尔斯贝里","于斯納爾斯貝里"],["于斯达尔","于斯達爾"],["于斯達爾","于斯達爾"],["于时","於時"],["于明涛","于明濤"],["于是","於是"],["于是之","於是之"],["于是乎","於是乎"],["于是就","於是就"],["于晨楠","于晨楠"],["于晴","于晴"],["于杰","于傑"],["于树洁","于樹潔"],["于根伟","于根偉"],["于格","于格"],["于梨华","於梨華"],["于樂","于樂"],["于欣源","于欣源"],["于正升","于正昇"],["于正昌","于正昌"],["于此","於此"],["于毕","於畢"],["于民","於民"],["于民润国","於民潤國"],["于水","於水"],["于永波","于永波"],["于汉超","于漢超"],["于江震","于江震"],["于法","於法"],["于法无据","於法無據"],["于波","于波"],["于泽尔","于澤爾"],["于洪区","于洪區"],["于浩威","于浩威"],["于海洋","于海洋"],["于涛","于濤"],["于湘兰","于湘蘭"],["于潜县","於潛縣"],["于濤","于濤"],["于火","於火"],["于焉","於焉"],["于爾里克","于爾里克"],["于物","於物"],["于特森","于特森"],["于玉立","于玉立"],["于田","于田"],["于田县","于田縣"],["于盲","於盲"],["于祂","於祂"],["于禁","于禁"],["于秀敏","于秀敏"],["于穆","於穆"],["于素秋","于素秋"],["于终","於終"],["于美","於美"],["于美人","於美人"],["于色","於色"],["于若木","于若木"],["于荫霖","于蔭霖"],["于菟","於菟"],["于蓝","於藍"],["于行","於行"],["于衡","于衡"],["于衷","於衷"],["于西翰","于西翰"],["于謙","于謙"],["于该","於該"],["于谦","于謙"],["于贈","于贈"],["于贝尔","于貝爾"],["于赠","于贈"],["于越","于越"],["于軍","于軍"],["于过","於過"],["于远伟","于遠偉"],["于途","於途"],["于道泉","于道泉"],["于邑","於邑"],["于都县","於都縣"],["于里察","于里察"],["于野","於野"],["于阗","于闐"],["于陆","於陸"],["于雾霭之中","於霧靄之中"],["于震寰","于震寰"],["于震环","于震環"],["于靖","于靖"],["于韋斯屈萊","于韋斯屈萊"],["于韦斯屈莱","于韋斯屈萊"],["于风政","于風政"],["于飞","于飛"],["于飞之乐","于飛之樂"],["于馀曲折","于餘曲折"],["于默奥","于默奧"],["亏不尽","虧不盡"],["亏了","虧了"],["亏折","虧折"],["亏本出售","虧本出售"],["云中","雲中"],["云中君","雲中君"],["云中白鹤","雲中白鶴"],["云为","云爲"],["云乎","云乎"],["云云","云云"],["云从龙风从虎","雲從龍風從虎"],["云仙杂记","雲仙雜記"],["云何","云何"],["云儿","雲兒"],["云兴霞蔚","雲興霞蔚"],["云冈","雲岡"],["云冈石佛","雲岡石佛"],["云冈石窟","雲岡石窟"],["云出无心","雲出無心"],["云华","雲華"],["云南","雲南"],["云南回变","雲南回變"],["云南白药","雲南白藥"],["云南省","雲南省"],["云南起义","雲南起義"],["云南黄馨","雲南黃馨"],["云县","雲縣"],["云台","雲臺"],["云台山","雲臺山"],["云合雾集","雲合霧集"],["云吞","雲吞"],["云吞面","雲吞麪"],["云和","雲和"],["云和县","雲和縣"],["云嘉南","雲嘉南"],["云团","雲團"],["云图","雲圖"],["云城区","云城區"],["云天","雲天"],["云天昊","雲天昊"],["云天高谊","雲天高誼"],["云头","雲頭"],["云头儿","雲頭兒"],["云子","雲子"],["云孙","雲孫"],["云安","雲安"],["云安县","雲安縣"],["云实","雲實"],["云室","雲室"],["云小啾","雲小啾"],["云尔","云爾"],["云层","雲層"],["云屏","雲屏"],["云屯雨集","雲屯雨集"],["云山","雲山"],["云山雾罩","雲山霧罩"],["云岩区","雲巖區"],["云岭","雲嶺"],["云帆","雲帆"],["云师","雲師"],["云帚","雲帚"],["云开见日","雲開見日"],["云形定规","雲形定規"],["云彩","雲彩"],["云影","雲影"],["云情雨意","雲情雨意"],["云房","雲房"],["云手","雲手"],["云扰","雲擾"],["云收雨散","雲收雨散"],["云收雾散","雲收霧散"],["云散","雲散"],["云散风流","雲散風流"],["云景","雲景"],["云朵","雲朵"],["云杉","雲杉"],["云板","雲板"],["云林","雲林"],["云林人","雲林人"],["云林县","雲林縣"],["云林寺","雲林寺"],["云林工专","雲林工專"],["云林科技大学","雲林科技大學"],["云林讯","雲林訊"],["云栈","雲棧"],["云根","雲根"],["云梢","雲梢"],["云梦","雲夢"],["云梦县","雲夢縣"],["云梦大泽","雲夢大澤"],["云梯","雲梯"],["云梯车","雲梯車"],["云步","雲步"],["云母","雲母"],["云母片","雲母片"],["云母石","雲母石"],["云气","雲氣"],["云水","雲水"],["云水僧","雲水僧"],["云水道人","雲水道人"],["云汉","雲漢"],["云河","雲河"],["云泥","雲泥"],["云泥之别","雲泥之別"],["云泥异路","雲泥異路"],["云浮","雲浮"],["云浮市","雲浮市"],["云海","雲海"],["云消雨散","雲消雨散"],["云消雾散","雲消霧散"],["云涌","雲涌"],["云涛","雲濤"],["云液","雲液"],["云淡风轻","雲淡風輕"],["云游","雲遊"],["云游四方","雲遊四方"],["云溪","云溪"],["云溪区","云溪區"],["云烟","雲煙"],["云烟过眼","雲煙過眼"],["云烟过眼录","雲煙過眼錄"],["云然","云然"],["云爲","云爲"],["云片糕","雲片糕"],["云版","雲版"],["云物","雲物"],["云石","雲石"],["云科大","雲科大"],["云程发轫","雲程發軔"],["云窗雾槛","雲窗霧檻"],["云章","雲章"],["云端","雲端"],["云端里看厮杀","雲端裏看廝殺"],["云端里老鼠","雲端裏老鼠"],["云笈七签","雲笈七籤"],["云笈七籤","雲笈七籤"],["云篦","雲篦"],["云精","雲精"],["云系","雲系"],["云网","雲網"],["云翳","雲翳"],["云翻雨复","雲翻雨覆"],["云肩","雲肩"],["云腿","雲腿"],["云芝","雲芝"],["云英","雲英"],["云英未嫁","雲英未嫁"],["云莽莽","雲莽莽"],["云蒸霞蔚","雲蒸霞蔚"],["云行雨施","雲行雨施"],["云表","雲表"],["云西市","雲西市"],["云谲波诡","雲譎波詭"],["云谷","雲谷"],["云豆","雲豆"],["云豹","雲豹"],["云贵","雲貴"],["云贵川","雲貴川"],["云贵高原","雲貴高原"],["云起龙骧","雲起龍驤"],["云路","雲路"],["云车","雲車"],["云车风马","雲車風馬"],["云遮月","雲遮月"],["云量","雲量"],["云锣","雲鑼"],["云锦","雲錦"],["云门","雲門"],["云门舞集","雲門舞集"],["云阳","雲陽"],["云阳县","雲陽縣"],["云阳市","雲陽市"],["云阶月地","雲階月地"],["云际","雲際"],["云雀","雲雀"],["云集","雲集"],["云雨","雲雨"],["云雨之欢","雲雨之歡"],["云雨巫山","雲雨巫山"],["云雨高唐","雲雨高唐"],["云雾","雲霧"],["云雾径迹","雲霧徑跡"],["云霄","雲霄"],["云霄县","雲霄縣"],["云霄飞车","雲霄飛車"],["云霓","雲霓"],["云霓之望","雲霓之望"],["云霞","雲霞"],["云霭","雲靄"],["云顶","雲頂"],["云须","雲鬚"],["云髻","雲髻"],["云鬓","雲鬢"],["云鬟","雲鬟"],["云麾勋章","雲麾勳章"],["云麾将军碑","雲麾將軍碑"],["云龙","雲龍"],["云龙区","雲龍區"],["云龙县","雲龍縣"],["云龙风虎","雲龍風虎"],["互不干涉","互不干涉"],["互不干涉內政","互不干涉內政"],["互于","互於"],["互别苗头","互別苗頭"],["互制","互制"],["互动关系","互動關係"],["互动台","互動臺"],["互助合作","互助合作"],["互发","互發"],["互向","互向"],["互有胜负","互有勝負"],["互生叶","互生葉"],["互相联系","互相聯繫"],["互致问候","互致問候"],["互蒙其利","互蒙其利"],["互鉴","互鑑"],["五七干校","五七幹校"],["五七干部学校","五七幹部學校"],["五万","五萬"],["五万三千","五萬三千"],["五万两千","五萬兩千"],["五万五千","五萬五千"],["五万八千","五萬八千"],["五世同堂","五世同堂"],["五个","五個"],["五代同堂","五代同堂"],["五余","五餘"],["五倍子虫","五倍子蟲"],["五克","五克"],["五党","五黨"],["五公里","五公里"],["五出戏","五齣戲"],["五出祁山","五出祁山"],["五分钟","五分鐘"],["五划","五劃"],["五十五万","五十五萬"],["五十六万","五十六萬"],["五十多万","五十多萬"],["五千","五千"],["五千多万","五千多萬"],["五发","五發"],["五只","五隻"],["五台","五臺"],["五台县","五臺縣"],["五台山","五臺山"],["五台市","五臺市"],["五叶","五葉"],["五周","五週"],["五周年","五週年"],["五天后","五天後"],["五岳","五嶽"],["五年计划","五年計劃"],["五度制调值标记法","五度制調值標記法"],["五弦","五絃"],["五彩","五彩"],["五彩夺目","五彩奪目"],["五彩宾纷","五彩賓紛"],["五彩缤纷","五彩繽紛"],["五扎","五紮"],["五折","五折"],["五斗","五斗"],["五斗折腰","五斗折腰"],["五斗柜","五斗櫃"],["五斗橱","五斗櫥"],["五斗米","五斗米"],["五斗米道","五斗米道"],["五斗解酲","五斗解酲"],["五杯","五杯"],["五板","五板"],["五棵松","五棵松"],["五浊恶世","五濁惡世"],["五点钟","五點鐘"],["五百万","五百萬"],["五百个","五百個"],["五百多万","五百多萬"],["五百姻缘天注定","五百姻緣天註定"],["五种","五種"],["五种性","五種性"],["五秒钟","五秒鐘"],["五笔划","五筆劃"],["五育并重","五育並重"],["五胡","五胡"],["五胡之乱","五胡之亂"],["五胡乱华","五胡亂華"],["五胡十六国","五胡十六國"],["五脏","五臟"],["五脏俱全","五臟俱全"],["五脏六腑","五臟六腑"],["五脏庙","五臟廟"],["五脏神","五臟神"],["五色祥云","五色祥雲"],["五花腌猪肉","五花醃豬肉"],["五虫","五蟲"],["五行并下","五行並下"],["五行生克","五行生剋"],["五谷","五穀"],["五谷不分","五穀不分"],["五谷不升","五穀不升"],["五谷丰收","五穀豐收"],["五谷丰登","五穀豐登"],["五谷丰稔","五穀豐稔"],["五谷杂粮","五穀雜糧"],["五谷王北街","五谷王北街"],["五谷王南街","五谷王南街"],["五辟","五辟"],["五采","五采"],["五里","五里"],["五里雾","五里霧"],["五里雾中","五里霧中"],["五面","五面"],["五面体","五面體"],["五马分尸","五馬分屍"],["井台","井臺"],["井干","井榦"],["井干摧败","井榦摧敗"],["井田制","井田制"],["井田制度","井田制度"],["井里","井裏"],["亘古","亙古"],["亚东关系","亞東關係"],["亚于","亞於"],["亚克力","亞克力"],["亚克朗","亞克朗"],["亚利叶","亞利葉"],["亚力克","亞力克"],["亚历","亞歷"],["亚历山大","亞歷山大"],["亚历桑","亞歷桑"],["亚当","亞當"],["亚当山德勒","亞當山德勒"],["亚当斯","亞當斯"],["亚当斯密","亞當斯密"],["亚得里亚海","亞得里亞海"],["亚德安布洛迪","亞德安布洛迪"],["亚松森","亞松森"],["亚核","亞核"],["亚洲周刊","亞洲週刊"],["亚洲杯","亞洲盃"],["亚穆苏克罗","亞穆蘇克羅"],["亚美利加人种","亞美利加人種"],["亚美尼亚历","亞美尼亞曆"],["亚词汇单元","亞詞彙單元"],["亚里","亞里"],["亚里士多德","亞里士多德"],["亚里斯多德","亞里斯多德"],["亚里斯提","亞里斯提"],["亚雷克斯","亞雷克斯"],["亚青杯","亞青盃"],["亚麻布","亞麻布"],["亟欲","亟欲"],["亟须","亟須"],["亡了","亡了"],["亡国灭种","亡國滅種"],["交个","交個"],["交了","交了"],["交于","交於"],["交出","交出"],["交出去","交出去"],["交出来","交出來"],["交割价","交割價"],["交卷","交卷"],["交叉耐药性","交叉耐藥性"],["交发","交發"],["交口称赞","交口稱讚"],["交合","交合"],["交哄","交鬨"],["交响乐团","交響樂團"],["交响曲","交響曲"],["交回","交回"],["交回去","交回去"],["交回来","交回來"],["交困","交困"],["交差了事","交差了事"],["交并","交併"],["交恶","交惡"],["交战团体","交戰團體"],["交托","交託"],["交换价值","交換價值"],["交换技术","交換技術"],["交易价","交易價"],["交易台","交易臺"],["交杯","交杯"],["交杯盏","交杯盞"],["交杯酒","交杯酒"],["交汇","交匯"],["交汇处","交匯處"],["交流团","交流團"],["交游","交遊"],["交游广阔","交遊廣闊"],["交白卷","交白卷"],["交货价","交貨價"],["交通号志","交通號誌"],["交通标志","交通標誌"],["交通管制","交通管制"],["交面","交面"],["亦云","亦云"],["亦同","亦同"],["亦对于","亦對於"],["亦庄亦谐","亦莊亦諧"],["亦当","亦當"],["亦舍下","亦捨下"],["亦须","亦須"],["产业别","產業別"],["产业后备","產業後備"],["产业链","產業鏈"],["产出","產出"],["产制","產製"],["产卵洄游","產卵洄游"],["产后","產後"],["产后检査","產後檢查"],["产品组合","產品組合"],["产地价格","產地價格"],["产婆术","產婆術"],["产学合作","產學合作"],["产生出","產生出"],["产销合一","產銷合一"],["产销合同","產銷合同"],["亨利克森","亨利克森"],["亨塞克","亨塞克"],["享尽","享盡"],["享御","享御"],["京二胡","京二胡"],["京胡","京胡"],["亭台","亭臺"],["亭台楼榭","亭臺樓榭"],["亭台楼阁","亭臺樓閣"],["亭彩","亭彩"],["亭彩店","亭彩店"],["亮丑","亮醜"],["亮光蜡","亮光蠟"],["亮彩","亮彩"],["亮钟","亮鐘"],["亲历","親歷"],["亲历其境","親歷其境"],["亲友团","親友團"],["亲台","親臺"],["亲娘","親孃"],["亲子关系","親子關係"],["亲子台","親子臺"],["亲子鉴定","親子鑑定"],["亲密关系","親密關係"],["亲属关系","親屬關係"],["亲幸","親倖"],["亲征","親征"],["亲戚","親戚"],["亲戚关系","親戚關係"],["亲极反疏","親極反疏"],["亲民党","親民黨"],["亲痛仇快","親痛仇快"],["亲笔签名","親筆簽名"],["亲系","親系"],["亲缘关系","親緣關係"],["亲自出马","親自出馬"],["亲自干","親自幹"],["亲自挂帅","親自掛帥"],["亲身经历","親身經歷"],["亹亹不卷","亹亹不卷"],["人中豪杰","人中豪傑"],["人为万物之灵","人爲萬物之靈"],["人云","人云"],["人云亦云","人云亦云"],["人众胜天","人衆勝天"],["人体彩绘","人體彩繪"],["人克莱门斯","人克萊門斯"],["人出现","人出現"],["人别哭","人別哭"],["人到中年万事休","人到中年萬事休"],["人制","人制"],["人前人后","人前人後"],["人力回天","人力回天"],["人千人万","人千人萬"],["人参","人蔘"],["人参果","人蔘果"],["人参精","人蔘精"],["人口分布","人口分佈"],["人各有志","人各有志"],["人同此心","人同此心"],["人同此心心同此理","人同此心心同此理"],["人后","人後"],["人团法","人團法"],["人困马乏","人困馬乏"],["人如其面","人如其面"],["人如风后入江云","人如風後入江雲"],["人定胜天","人定勝天"],["人寿年丰","人壽年豐"],["人尽其才","人盡其才"],["人尽可夫","人盡可夫"],["人尽皆知","人盡皆知"],["人工冬眠","人工冬眠"],["人工心脏","人工心臟"],["人工阅卷","人工閱卷"],["人心不同","人心不同"],["人心向背","人心向背"],["人心如面","人心如面"],["人心所向","人心所向"],["人心涣漓","人心渙漓"],["人性本恶","人性本惡"],["人才","人才"],["人才出众","人才出衆"],["人才外流","人才外流"],["人才库","人才庫"],["人才流失","人才流失"],["人才济济","人才濟濟"],["人才辈出","人才輩出"],["人才难得","人才難得"],["人无千日","人無千日"],["人机介面","人機介面"],["人机界面","人機界面"],["人权斗士","人權鬥士"],["人杰","人傑"],["人杰地灵","人傑地靈"],["人极","人極"],["人欲","人慾"],["人欲横流","人慾橫流"],["人民代表","人民代表"],["人民党","人民黨"],["人民团体","人民團體"],["人民意志","人民意志"],["人流手术","人流手術"],["人浮于事","人浮於事"],["人浮于食","人浮於食"],["人海战术","人海戰術"],["人烟","人煙"],["人烟凑集","人煙湊集"],["人烟浩穰","人煙浩穰"],["人烟稀少","人煙稀少"],["人烟稠密","人煙稠密"],["人烟辐辏","人煙輻輳"],["人物志","人物誌"],["人生价值","人生價值"],["人生舞台","人生舞臺"],["人神同愤","人神同憤"],["人种","人種"],["人种学","人種學"],["人种差别","人種差別"],["人穷志不穷","人窮志不窮"],["人穷志短","人窮志短"],["人老精姜老辣","人老精薑老辣"],["人胜节","人勝節"],["人赃俱获","人贓俱獲"],["人造板","人造板"],["人造纤维","人造纖維"],["人链","人鏈"],["人间烟火","人間煙火"],["人际关系","人際關係"],["人面","人面"],["人面上","人面上"],["人面兽心","人面獸心"],["人面桃花","人面桃花"],["人面狮身","人面獅身"],["人面逐高低","人面逐高低"],["人饥己饥","人飢己飢"],["亿万","億萬"],["亿万富翁","億萬富翁"],["亿万富豪","億萬富豪"],["亿万斯年","億萬斯年"],["亿个","億個"],["亿余","億餘"],["亿只","億隻"],["亿多只","億多隻"],["亿天后","億天後"],["什不闲","什不閒"],["什么","什麼"],["什叶派","什葉派"],["什锦炒面","什錦炒麪"],["什锦面","什錦麪"],["什面","什面"],["仁人志士","仁人志士"],["仁布","仁布"],["仁布县","仁布縣"],["仁心仁术","仁心仁術"],["仁术","仁術"],["仁杰","仁杰"],["仁武厂","仁武廠"],["仁至义尽","仁至義盡"],["仅余","僅餘"],["仅作参考","僅作參考"],["仅供参考","僅供參考"],["仅占","僅佔"],["仅只","僅只"],["仅次于","僅次於"],["仆人","僕人"],["仆仆","僕僕"],["仆仆风尘","僕僕風塵"],["仆从","僕從"],["仆使","僕使"],["仆倒","仆倒"],["仆僮","僕僮"],["仆僮成群","僕僮成羣"],["仆吏","僕吏"],["仆固怀恩","僕固懷恩"],["仆地","仆地"],["仆夫","僕伕"],["仆妇","僕婦"],["仆姑","僕姑"],["仆婢","僕婢"],["仆射","僕射"],["仆射姑","僕射姑"],["仆少","僕少"],["仆役","僕役"],["仆憎","僕憎"],["仆欧","僕歐"],["仆然","仆然"],["仆程","僕程"],["仆虽罢驽","僕雖罷駑"],["仆街","仆街"],["仇人","仇人"],["仇仇","仇讎"],["仇偶","仇偶"],["仇口儿","仇口兒"],["仇国论","仇國論"],["仇外心理","仇外心理"],["仇家","仇家"],["仇怨","仇怨"],["仇恨","仇恨"],["仇恨罪","仇恨罪"],["仇恨罪行","仇恨罪行"],["仇敌","仇敵"],["仇杀","仇殺"],["仇梓鸣","仇梓鳴"],["仇疙瘩","仇疙瘩"],["仇英","仇英"],["仇视","仇視"],["仇隙","仇隙"],["仇香","仇香"],["今儿个","今兒個"],["今冬","今冬"],["今后","今後"],["今秋","今秋"],["介于","介於"],["介于两难","介於兩難"],["介壳虫","介殼蟲"],["介系词","介係詞"],["介绍出来","介紹出來"],["介胄","介冑"],["介虫","介蟲"],["介面","介面"],["介面卡","介面卡"],["介面板","介面板"],["仍复","仍復"],["从上向下","從上向下"],["从下向上","從下向上"],["从事于","從事於"],["从于","從於"],["从今以后","從今以後"],["从价税","從價稅"],["从外向內","從外向內"],["从宽发落","從寬發落"],["从属于","從屬於"],["从属关系","從屬關係"],["从心所欲","從心所欲"],["从此以后","從此以後"],["从此往后","從此往後"],["从轻发落","從輕發落"],["从里到外","從裏到外"],["从里向外","從裏向外"],["仑丰村","崙豐村"],["仑背","崙背"],["仑背乡","崙背鄉"],["仓皇出逃","倉皇出逃"],["他了","他了"],["他克制","他剋制"],["他出","他出"],["他出去","他出去"],["他出来","他出來"],["他志","他志"],["他念","他念"],["他种","他種"],["他钟","他鐘"],["仗托","仗托"],["付了","付了"],["付出","付出"],["付出去","付出去"],["付出型","付出型"],["付合","付合"],["付托","付託"],["仙台","仙台"],["仙后","仙后"],["仙后座","仙后座"],["仙坛","仙壇"],["仙岩","仙岩"],["仙才","仙才"],["仙术","仙術"],["仙游","仙遊"],["仙游县","仙遊縣"],["仙药","仙藥"],["仙迹","仙蹟"],["仟克","仟克"],["仡栗","仡栗"],["代价","代價"],["代出","代出"],["代工厂","代工廠"],["代录","代錄"],["代扣","代扣"],["代数几何","代數幾何"],["代数曲线","代數曲線"],["代数曲面","代數曲面"],["代码表","代碼表"],["代签","代簽"],["代签人","代簽人"],["代表","代表"],["代表人","代表人"],["代表人物","代表人物"],["代表会","代表會"],["代表作","代表作"],["代表团","代表團"],["代表处","代表處"],["代表大会","代表大會"],["代表性","代表性"],["代表权","代表權"],["代表署","代表署"],["代表色","代表色"],["代表金","代表金"],["代表队","代表隊"],["代议制","代議制"],["令人发指","令人髮指"],["令人注目","令人注目"],["令出如山","令出如山"],["令出必行","令出必行"],["令出惟行","令出惟行"],["令岳","令岳"],["令狐冲","令狐沖"],["以一当十","以一當十"],["以一持万","以一持萬"],["以一知万","以一知萬"],["以一驭万","以一馭萬"],["以人为鉴","以人爲鑑"],["以价制量","以價制量"],["以众克寡","以衆克寡"],["以免借口","以免藉口"],["以冰致蝇","以冰致蠅"],["以利于","以利於"],["以功复过","以功覆過"],["以升量石","以升量石"],["以华制华","以華制華"],["以古为鉴","以古爲鑑"],["以后","以後"],["以售其奸","以售其奸"],["以多胜少","以多勝少"],["以夷制夷","以夷制夷"],["以少克众","以少克衆"],["以少胜多","以少勝多"],["以弱制强","以弱制強"],["以弱胜强","以弱勝強"],["以往鉴来","以往鑑來"],["以意逆志","以意逆志"],["以智取胜","以智取勝"],["以暴制暴","以暴制暴"],["以柔克刚","以柔克剛"],["以柔制刚","以柔制剛"],["以泪洗面","以淚洗面"],["以点带面","以點帶面"],["以自制","以自制"],["以至于","以至於"],["以致","以致"],["以致于","以致於"],["以药养医","以藥養醫"],["以莛叩钟","以莛叩鐘"],["以莛撞钟","以莛撞鐘"],["以蜡代薪","以蠟代薪"],["以观后效","以觀後效"],["以貍致鼠","以貍致鼠"],["以防万一","以防萬一"],["以静制动","以靜制動"],["仪制","儀制"],["仪器表","儀器表"],["仪征","儀徵"],["仪征市","儀徵市"],["仪态万千","儀態萬千"],["仪态万方","儀態萬方"],["仪注","儀注"],["仪范","儀範"],["仪表","儀表","儀錶"],["仪表出众","儀表出衆"],["仪表堂堂","儀表堂堂"],["仪表板","儀表板"],["仪表版","儀表版"],["仪表盘","儀表盤"],["仰之弥高","仰之彌高"],["仰叹","仰嘆"],["仰给于人","仰給於人"],["仰药","仰藥"],["仰面","仰面"],["仲冬","仲冬"],["仲秋","仲秋"],["件钟","件鐘"],["价位","價位"],["价值","價值"],["价值冲突","價值衝突"],["价值判断","價值判斷"],["价值增殖","價值增殖"],["价值尺度","價值尺度"],["价值工程","價值工程"],["价值形式","價值形式"],["价值感","價值感"],["价值指标","價值指標"],["价值标准","價值標準"],["价值观","價值觀"],["价值观念","價值觀念"],["价值规律","價值規律"],["价值论","價值論"],["价值连城","價值連城"],["价值逻辑","價值邏輯"],["价值量","價值量"],["价单","價單"],["价差","價差"],["价廉物美","價廉物美"],["价格","價格"],["价格冻结","價格凍結"],["价格战","價格戰"],["价格标","價格標"],["价格标签","價格標籤"],["价格范围","價格範圍"],["价格表","價格表"],["价款","價款"],["价比","價比"],["价电子","價電子"],["价目","價目"],["价目单","價目單"],["价目表","價目表"],["价码","價碼"],["价钱","價錢"],["任一个","任一個"],["任于","任於"],["任人摆布","任人擺佈"],["任务团","任務團"],["任教于","任教於"],["任期制","任期制"],["任由摆布","任由擺佈"],["任笔沈诗","任筆沈詩"],["任重致远","任重致遠"],["仿佛","彷彿"],["仿制","仿製"],["仿制品","仿製品"],["仿制药","仿製藥"],["企业团","企業團"],["企业系","企業系"],["企业集团","企業集團"],["企划","企劃"],["企划书","企劃書"],["企划人","企劃人"],["企划厅","企劃廳"],["企划处","企劃處"],["企划案","企劃案"],["企划组","企劃組"],["企划部","企劃部"],["企管系","企管系"],["伊万诺","伊萬諾"],["伊于湖底","伊于湖底"],["伊于胡底","伊于胡底"],["伊吉克","伊吉克"],["伊周","伊周"],["伊塞克湖","伊塞克湖"],["伊布拉欣","伊布拉欣"],["伊府面","伊府麪"],["伊拉克","伊拉克"],["伊拉克人","伊拉克人"],["伊拉克籍","伊拉克籍"],["伊拉克队","伊拉克隊"],["伊斯兰党","伊斯蘭黨"],["伊斯兰历","伊斯蘭曆"],["伊核","伊核"],["伊犁纵谷","伊犁縱谷"],["伊莱克斯","伊萊克斯"],["伊郁","伊鬱"],["伊里奇","伊里奇"],["伊里布","伊里布"],["伊里格瑞","伊裏格瑞"],["伊面","伊麪"],["伍员鞭尸","伍員鞭屍"],["伍德合金","伍德合金"],["伍瑞克","伍瑞克"],["伍采克","伍采克"],["伏几","伏几"],["伏尸","伏屍"],["伏尸流血","伏屍流血"],["伏尸遍野","伏屍遍野"],["伏愿","伏願"],["伏胜","伏勝"],["伐异党同","伐異黨同"],["伐罪吊民","伐罪弔民"],["休仑湖","休崙湖"],["休克","休克"],["休征","休徵"],["休戚","休慼"],["休戚与共","休慼與共"],["休戚相关","休慼相關"],["休杰克曼","休傑克曼"],["休致","休致"],["休闲区","休閒區"],["休闲服","休閒服"],["休闲活动","休閒活動"],["休闲组","休閒組"],["休闲裤","休閒褲"],["休闲鞋","休閒鞋"],["休闲风","休閒風"],["休闲馆","休閒館"],["众口同声","衆口同聲"],["众口熏天","衆口熏天"],["众志成城","衆志成城"],["众所周知","衆所周知"],["众曲不容直","衆曲不容直"],["优于","優於"],["优先发展","優先發展"],["优势种","優勢種"],["优哉游哉","優哉遊哉"],["优惠价","優惠價"],["优惠价格","優惠價格"],["优游","優遊"],["优游不迫","優遊不迫"],["优游自在","優遊自在"],["优游自得","優遊自得"],["优胜","優勝"],["优胜劣败","優勝劣敗"],["优胜奖","優勝獎"],["优胜者","優勝者"],["优胜队","優勝隊"],["伙人","夥人"],["伙众","夥衆"],["伙伴","夥伴"],["伙伴国","夥伴國"],["伙伴龙","夥伴龍"],["伙办","夥辦"],["伙友","夥友"],["伙同","夥同"],["伙够","夥夠"],["伙夫","伙伕"],["伙头","伙頭"],["伙房","伙房"],["伙穿","夥穿"],["伙计","夥計"],["伙食","伙食"],["伙食团","伙食團"],["伙食费","伙食費"],["会上签署","會上簽署"],["会上签订","會上簽訂"],["会个","會個"],["会了","會了"],["会于","會於"],["会党","會黨"],["会出","會出"],["会出去","會出去"],["会出来","會出來"],["会升","會升"],["会占","會佔"],["会占卜","會占卜"],["会发","會發"],["会合","會合"],["会合周期","會合周期"],["会合处","會合處"],["会合点","會合點"],["会吊","會弔"],["会同","會同"],["会同县","會同縣"],["会后","會後"],["会员价","會員價"],["会员制","會員制"],["会员团","會員團"],["会场价","會場價"],["会尽","會盡"],["会干","會幹"],["会干净","會乾淨"],["会干扰","會干擾"],["会干政","會干政"],["会干杯","會乾杯"],["会干枯","會乾枯"],["会干涉","會干涉"],["会干涸","會乾涸"],["会干脆","會乾脆"],["会干裂","會乾裂"],["会干预","會干預"],["会当","會當"],["会念","會念"],["会扣","會扣"],["会杯","會杯"],["会种","會種"],["会签制度","會簽制度"],["会计分录","會計分錄"],["会计制度","會計制度"],["会计报表","會計報表"],["会计标准","會計標準"],["会计系","會計系"],["会议记录","會議記錄"],["会逢其适","會逢其適"],["会里","會裏"],["会里县","會裏縣"],["会长团","會長團"],["会面","會面"],["会面处","會面處"],["会须","會須"],["伞面","傘面"],["伟克适","偉克適"],["伟晶岩","偉晶岩"],["传习录","傳習錄"],["传于","傳於"],["传位于四太子","傳位于四太子"],["传出","傳出"],["传出去","傳出去"],["传出来","傳出來"],["传出神经","傳出神經"],["传制权","傳制權"],["传动系统","傳動系統"],["传动链","傳動鏈"],["传发","傳發"],["传回","傳回"],["传回来","傳回來"],["传布","傳佈"],["传心术","傳心術"],["传播出去","傳播出去"],["传播学系","傳播學系"],["传教团","傳教團"],["传杯弄盏","傳杯弄盞"],["传杯换盏","傳杯換盞"],["传杯送盏","傳杯送盞"],["传板","傳板"],["传灯录","傳燈錄"],["传热系数","傳熱係數"],["传真发送","傳真發送"],["传种","傳種"],["传统中国医药","傳統中國醫藥"],["传统医药","傳統醫藥"],["传舍","傳舍"],["传译出","傳譯出"],["传赞","傳贊"],["传输技术","傳輸技術"],["传输控制","傳輸控制"],["传输控制协定","傳輸控制協定"],["传达出","傳達出"],["传达出来","傳達出來"],["传递出去","傳遞出去"],["传闻证据","傳聞證據"],["传颂千古","傳頌千古"],["伤了","傷了"],["伤亡枕借","傷亡枕藉"],["伤别","傷別"],["伤口发炎","傷口發炎"],["伤寒杆菌","傷寒桿菌"],["伤寒症","傷寒症"],["伤心欲绝","傷心欲絕"],["伤心致死","傷心致死"],["伤痕累累","傷痕累累"],["伤药","傷藥"],["伤风克","傷風克"],["伦理规范","倫理規範"],["伪托","僞託"],["伪药","僞藥"],["伯余","伯余"],["伯克","伯克"],["伯克利","伯克利"],["伯克制度","伯克制度"],["伯克来","伯克來"],["伯南克","伯南克"],["伯娘","伯孃"],["伯尔发斯特","伯爾發斯特"],["伯杰","伯傑"],["伯纳克","伯納克"],["伯罗奔尼撒同盟","伯羅奔尼撒同盟"],["伯里克利","伯里克利"],["伯雍种玉","伯雍種玉"],["估价","估價"],["估价单","估價單"],["估价行","估價行"],["估算出","估算出"],["伴同","伴同"],["伴娘","伴娘"],["伴游","伴遊"],["伸出","伸出"],["伸出去","伸出去"],["伸出援手","伸出援手"],["伸出来","伸出來"],["伸向","伸向"],["伸回","伸回"],["伸回去","伸回去"],["伸回来","伸回來"],["伸展出","伸展出"],["伸展出去","伸展出去"],["伸志","伸志"],["伸手不打笑面人","伸手不打笑面人"],["似于","似於"],["似松实紧","似鬆實緊"],["佃租制度","佃租制度"],["但云","但云"],["但得一片橘皮吃且莫忘了洞庭湖","但得一片橘皮吃且莫忘了洞庭湖"],["但愿","但願"],["但愿如此","但願如此"],["但曲","但曲"],["但求如愿","但求如願"],["但须","但須"],["位于","位於"],["位准","位準"],["位极人臣","位極人臣"],["低了","低了"],["低于","低於"],["低价","低價"],["低价买进","低價買進"],["低价位","低價位"],["低价卖出","低價賣出"],["低价团","低價團"],["低价格","低價格"],["低价高报","低價高報"],["低卡路里","低卡路里"],["低合金钢","低合金鋼"],["低回","低迴"],["低回不已","低迴不已"],["低度发展国家","低度發展國家"],["低标准","低標準"],["低洼","低窪"],["低筋面粉","低筋麪粉"],["低荡","低盪"],["低谷","低谷"],["住个","住個"],["住宅凶方","住宅兇方"],["住扎","住紮"],["佐饔得尝","佐饔得嘗"],["体会出","體會出"],["体制","體制"],["体坛","體壇"],["体坛人士","體壇人士"],["体察出","體察出"],["体干班","體幹班"],["体彩","體彩"],["体征","體徵"],["体念","體念"],["体温表","體溫表"],["体物写志","體物寫志"],["体现出","體現出"],["体系","體系"],["体系化","體系化"],["体育台","體育臺"],["体育系","體育系"],["体育锻炼","體育鍛煉"],["体胀系数","體脹係數"],["体范","體範"],["体表","體表"],["体重表","體重表"],["体面","體面"],["体面起来","體面起來"],["体验出","體驗出"],["何以克当","何以克當"],["何只","何只"],["何小升","何小昇"],["何尝","何嘗"],["何干","何干"],["何当","何當"],["何必当初","何必當初"],["何志","何志"],["何志钦","何志欽"],["何杰金氏病","何杰金氏病"],["何极","何極"],["何济于事","何濟於事"],["何秋美","何秋美"],["何种","何種"],["何胜雄","何勝雄"],["何至于","何至於"],["何至于此","何至於此"],["何豪杰","何豪傑"],["何足挂齿","何足掛齒"],["何须","何須"],["余〇","餘〇"],["余一","餘一"],["余七","餘七"],["余三","餘三"],["余三勝","余三勝"],["余三胜","余三勝"],["余上沅","余上沅"],["余下","餘下"],["余业","餘業"],["余个","餘個"],["余九","餘九"],["余事","餘事"],["余二","餘二"],["余五","餘五"],["余亩","餘畝"],["余人","餘人"],["余件","餘件"],["余众","餘衆"],["余位","餘位"],["余余","余余"],["余俗","餘俗"],["余倍","餘倍"],["余僇","餘僇"],["余元","餘元"],["余光","餘光"],["余光中","余光中"],["余光生","余光生"],["余党","餘黨"],["余八","餘八"],["余六","餘六"],["余兰香","余蘭香"],["余兴","餘興"],["余刃","餘刃"],["余切","餘切"],["余利","餘利"],["余剩","餘剩"],["余割","餘割"],["余力","餘力"],["余勇","餘勇"],["余勇可贾","餘勇可賈"],["余十","餘十"],["余压","餘壓"],["余发扬","余發揚"],["余只","餘隻"],["余名","餘名"],["余吾镇","余吾鎮"],["余味","餘味"],["余响","餘響"],["余响绕梁","餘響繞梁"],["余喘","餘喘"],["余四","餘四"],["余地","餘地"],["余墨","餘墨"],["余声","餘聲"],["余外","餘外"],["余天","余天"],["余头","餘頭"],["余妙","餘妙"],["余姓","余姓"],["余姚","餘姚"],["余姚市","餘姚市"],["余威","餘威"],["余威德","余威德"],["余子","餘子"],["余子明","余子明"],["余子碌碌","餘子碌碌"],["余字","餘字"],["余存","餘存"],["余孽","餘孽"],["余宪宗","余憲宗"],["余岁","餘歲"],["余干","餘干"],["余干县","餘干縣"],["余年","餘年"],["余庆","餘慶"],["余庆县","餘慶縣"],["余座","餘座"],["余弦","餘弦"],["余思","餘思"],["余思敏","余思敏"],["余悸","餘悸"],["余情","餘情"],["余情未了","餘情未了"],["余户","餘戶"],["余政宪","余政憲"],["余数","餘數"],["余数定理","餘數定理"],["余文","余文"],["余文彬","余文彬"],["余日","餘日"],["余明","餘明"],["余映","餘映"],["余晖","餘暉"],["余暇","餘暇"],["余月","余月"],["余本","餘本"],["余杭","餘杭"],["余杭区","餘杭區"],["余杯","餘杯"],["余枝","餘枝"],["余桃","餘桃"],["余桶","餘桶"],["余次","餘次"],["余款","餘款"],["余歌沧","余歌滄"],["余步","餘步"],["余殃","餘殃"],["余毒","餘毒"],["余气","餘氣"],["余氯","餘氯"],["余江","餘江"],["余江县","餘江縣"],["余沥","餘瀝"],["余波","餘波"],["余波荡漾","餘波盪漾"],["余泽","餘澤"],["余派","餘派"],["余温","餘溫"],["余火","餘火"],["余灿荣","余燦榮"],["余炳贤","余炳賢"],["余点","餘點"],["余烈","餘烈"],["余烬","餘燼"],["余热","餘熱"],["余珍","餘珍"],["余珮琳","余珮琳"],["余生","餘生"],["余男","余男"],["余留","餘留"],["余留事务","餘留事務"],["余留无符号数","餘留無符號數"],["余码","餘碼"],["余碧芬","余碧芬"],["余秀菁","余秀菁"],["余秉谚","余秉諺"],["余种","餘種"],["余窍","餘竅"],["余筱萍","余筱萍"],["余篇","餘篇"],["余粮","餘糧"],["余绪","餘緒"],["余缺","餘缺"],["余罪","餘罪"],["余羡","餘羨"],["余脉","餘脈"],["余膏","餘膏"],["余苑绮","余苑綺"],["余英时","余英時"],["余荫","餘蔭"],["余蓄","餘蓄"],["余裕","餘裕"],["余角","餘角"],["余论","餘論"],["余貾","餘貾"],["余责","餘責"],["余贤明","余賢明"],["余车","余車"],["余载","餘載"],["余辉","餘輝"],["余辜","餘辜"],["余部","餘部"],["余酲","餘酲"],["余里","餘里"],["余量","餘量"],["余钱","餘錢"],["余闰","餘閏"],["余闲","餘閒"],["余集","餘集"],["余雪兰","余雪蘭"],["余雪明","余雪明"],["余零","餘零"],["余震","餘震"],["余霞","餘霞"],["余音","餘音"],["余音绕梁","餘音繞樑"],["余韵","餘韻"],["余项","餘項"],["余额","餘額"],["余风","餘風"],["余食","餘食"],["余香","餘香"],["佚游","佚遊"],["佚荡","佚蕩"],["佛修根","佛修根"],["佛克斯","佛克斯"],["佛克纳","佛克納"],["佛兰克林","佛蘭克林"],["佛前佛后","佛前佛後"],["佛历","佛曆"],["佛尼亚克","佛尼亞克"],["佛布兹","佛布茲"],["佛曲","佛曲"],["佛瑞克","佛瑞克"],["佛瑞斯特怀特克","佛瑞斯特懷特克"],["佛科摆","佛科擺"],["佛罗棱萨","佛羅棱薩"],["佛罗里达","佛羅里達"],["佛罗里达州","佛羅里達州"],["佛舍利","佛舍利"],["佛蒙特","佛蒙特"],["佛蒙特州","佛蒙特州"],["佛里特","佛里特"],["佛里特曼","佛里特曼"],["佛钟","佛鐘"],["佛雷克","佛雷克"],["佛面上刮金","佛面上刮金"],["作业平台","作業平臺"],["作业系统","作業系統"],["作了","作了"],["作价","作價"],["作倒了行市","作倒了行市"],["作准","作準"],["作出","作出"],["作出来","作出來"],["作出让步","作出讓步"],["作别","作別"],["作品里","作品裏"],["作奸犯科","作奸犯科"],["作好准备","作好準備"],["作幸","作倖"],["作庄","作莊"],["作废后","作廢後"],["作息时间表","作息時間表"],["作恶","作惡"],["作恶多端","作惡多端"],["作曲","作曲"],["作曲人","作曲人"],["作曲家","作曲家"],["作曲者","作曲者"],["作育英才","作育英才"],["作舍道旁","作舍道旁"],["作舍道边","作舍道邊"],["佞幸","佞幸"],["你克制","你剋制"],["你夸我逞","你誇我逞"],["你干一杯","你乾一杯"],["你干那杯","你乾那杯"],["你念","你念"],["你才子发昏","你纔子發昏"],["你搜","你搜"],["你斗了胆","你斗了膽"],["你是为了","你是爲了"],["你有千条妙计我有一定之规","你有千條妙計我有一定之規"],["你系","你係"],["佣中佼佼","傭中佼佼"],["佣书","傭書"],["佣人","傭人"],["佣仆","傭僕"],["佣作","傭作"],["佣保","傭保"],["佣兵","傭兵"],["佣工","傭工"],["佣懒","傭懶"],["佣给","傭給"],["佣耕","傭耕"],["佣金","佣金"],["佣金收益","佣金收益"],["佣金费用","佣金費用"],["佣钱","佣錢"],["佣钿","佣鈿"],["佥同","僉同"],["佩挂","佩掛"],["佩斯托瑞斯","佩斯托瑞斯"],["佩脱拉克","佩脫拉克"],["佳人才子","佳人才子"],["佳冬","佳冬"],["佳冬乡","佳冬鄉"],["佳肴","佳餚"],["佳致","佳致"],["佳里","佳里"],["佳里鎮","佳里鎮"],["佳里镇","佳里鎮"],["使其斗","使其鬥"],["使出","使出"],["使出来","使出來"],["使团","使團"],["使困扰","使困擾"],["使困窘","使困窘"],["使尽","使盡"],["使心作幸","使心作倖"],["使用价值","使用價值"],["使用借贷","使用借貸"],["使用者介面","使用者介面"],["使用范围","使用範圍"],["使节团","使節團"],["使转向","使轉向"],["侍仆","侍僕"],["侍御","侍御"],["侏儒症","侏儒症"],["侏罗系","侏羅系"],["侔德复载","侔德覆載"],["供出","供出"],["供制","供製"],["供大于求","供大於求"],["供应链","供應鏈"],["供暖系统","供暖系統"],["供水系统","供水系統"],["供油系统","供油系統"],["供电系统","供電系統"],["供给制","供給制"],["供给面","供給面"],["供过于求","供過於求"],["供销合作","供銷合作"],["供销合作社","供銷合作社"],["依个人","依個人"],["依从关系","依從關係"],["依依不舍","依依不捨"],["依依难舍","依依難捨"],["依头缕当","依頭縷當"],["依存关系","依存關係"],["依托","依託"],["依据","依據"],["依法炮制","依法炮製"],["依然范特西","依然范特西"],["依赞","依贊"],["依附于","依附於"],["侠气干云","俠氣干雲"],["侥天之幸","僥天之倖"],["侥幸","僥倖"],["侥幸取胜","僥倖取勝"],["侥幸获胜","僥倖獲勝"],["侦听台","偵聽臺"],["侦讯笔录","偵訊筆錄"],["侧冲","側衝"],["侧向","側向"],["侧录","側錄"],["侧撞防护系统","側撞防護系統"],["侧链","側鏈"],["侧面","側面"],["侧面图","側面圖"],["侧面性","側面性"],["侨团","僑團"],["侨汇","僑匯"],["侨选代表","僑選代表"],["侮蔑","侮蔑"],["侯万户","侯萬戶"],["侯彩凤","侯彩鳳"],["侯胜茂","侯勝茂"],["侵入岩","侵入岩"],["侵占","侵佔"],["侵占到","侵佔到"],["侵占罪","侵佔罪"],["侵哄","侵哄"],["侵并","侵併"],["侵蚀基准","侵蝕基準"],["便了","便了"],["便于","便於"],["便吃干","便吃乾"],["便宜不过当家","便宜不過當家"],["便当","便當"],["便当店","便當店"],["便当盒","便當盒"],["便益不失当家","便益不失當家"],["便签","便籤"],["便药","便藥"],["便辟","便辟"],["便面","便面"],["便须","便須"],["促发","促發"],["促销价","促銷價"],["俄克拉何马","俄克拉何馬"],["俄克拉何马城","俄克拉何馬城"],["俄克拉何马州","俄克拉何馬州"],["俄克拉荷马州","俄克拉荷馬州"],["俄制","俄製"],["俄占","俄佔"],["俄国共产党","俄國共產黨"],["俄文系","俄文系"],["俄罗斯党","俄羅斯黨"],["俄语系","俄語系"],["俊刮","俊刮"],["俊杰","俊傑"],["俊游","俊遊"],["俊眼修眉","俊眼修眉"],["俏丽短发","俏麗短髮"],["俗念","俗念"],["俘获","俘獲"],["俚曲","俚曲"],["保不准","保不準"],["保丽龙板","保麗龍板"],["保修期","保修期"],["保养厂","保養廠"],["保准","保準"],["保发","保發"],["保守党","保守黨"],["保安团","保安團"],["保安责任制","保安責任制"],["保护状制","保護狀制"],["保护范围","保護範圍"],["保持克制","保持克制"],["保持联系","保持聯繫"],["保暖杯","保暖杯"],["保温杯","保溫杯"],["保甲制度","保甲制度"],["保留价格","保留價格"],["保留征收","保留徵收"],["保留曲线","保留曲線"],["保皇党","保皇黨"],["保税工厂","保稅工廠"],["保结制度","保結制度"],["保证价格","保證價格"],["保险杆","保險桿"],["保险柜","保險櫃"],["保险范围","保險範圍"],["保险解开系统","保險解開系統"],["保障范围","保障範圍"],["信个","信個"],["信丰","信豐"],["信丰县","信豐縣"],["信义计划","信義計劃"],["信人调丢了瓢","信人調丟了瓢"],["信口开合","信口開合"],["信口胡说","信口胡說"],["信号台","信號臺"],["信号系统","信號系統"],["信合社","信合社"],["信嘴胡说","信嘴胡說"],["信噪","信噪"],["信天游","信天游"],["信念","信念"],["信息技术","信息技術"],["信息系统","信息系統"],["信托","信託"],["信托公司","信託公司"],["信托贸易","信托貿易"],["信据","信據"],["信步闲游","信步閒遊"],["信汇","信匯"],["信用合作","信用合作"],["信笔涂鸦","信筆塗鴉"],["信箱里","信箱裏"],["信而有征","信而有徵"],["信马游缰","信馬游繮"],["俪采","儷采"],["俭仆","儉僕"],["俭朴","儉樸"],["俭确之教","儉确之教"],["修业","修業"],["修业年限","修業年限"],["修业期满","修業期滿"],["修习","修習"],["修书","修書"],["修五脏庙","修五臟廟"],["修仙","修仙"],["修伊特","修伊特"],["修修","修修"],["修修补补","修修補補"],["修养","修養"],["修养成","修養成"],["修函","修函"],["修到","修到"],["修剪","修剪"],["修史","修史"],["修名","脩名"],["修和","修和"],["修墓","修墓"],["修士","修士"],["修复","修復"],["修女","修女"],["修好","修好"],["修威特","修威特"],["修学","修學"],["修定","修定"],["修宪","修憲"],["修宪案","修憲案"],["修容","修容"],["修己","修己"],["修建","修建"],["修得","修得"],["修心养性","修心養性"],["修成","修成"],["修护","修護"],["修护站","修護站"],["修护队","修護隊"],["修持","修持"],["修指甲","修指甲"],["修撰","修撰"],["修改","修改"],["修改为","修改爲"],["修改后","修改後"],["修改成","修改成"],["修敬","脩敬"],["修整","修整"],["修文","修文"],["修文偃武","修文偃武"],["修文县","修文縣"],["修斋","修齋"],["修旧利废","修舊利廢"],["修明","修明"],["修曼德","修曼德"],["修杰楷","修杰楷"],["修枝","修枝"],["修桥舖路","修橋舖路"],["修桥补路","修橋補路"],["修樾","脩樾"],["修正","修正"],["修正为","修正爲"],["修正主义","修正主義"],["修正期","修正期"],["修正案","修正案"],["修正档","修正檔"],["修正法","修正法"],["修正液","修正液"],["修武县","修武縣"],["修母画荻","修母畫荻"],["修水","修水"],["修水利","修水利"],["修水县","修水縣"],["修治","修治"],["修润","脩潤"],["修濬","修濬"],["修炼","修煉"],["修炼成仙","修煉成仙"],["修版","修版"],["修理","修理"],["修理匠","修理匠"],["修理厂","修理廠"],["修理好","修理好"],["修理店","修理店"],["修理站","修理站"],["修理费","修理費"],["修理起来","修理起來"],["修理部","修理部"],["修的","修的"],["修盖","修蓋"],["修省","修省"],["修眉","修眉"],["修睦","修睦"],["修短","修短"],["修竹","修竹"],["修筑","修築"],["修筑公路","修築公路"],["修筑工事","修築工事"],["修筑工程","修築工程"],["修筑道路","修築道路"],["修练","修練"],["修缮","修繕"],["修缮费","修繕費"],["修罗","修羅"],["修置产室","修置產室"],["修耕","修耕"],["修胡刀","修鬍刀"],["修脚","修腳"],["修脯","脩脯"],["修葺","修葺"],["修行","修行"],["修行人","修行人"],["修补","修補"],["修补匠","修補匠"],["修褉","修褉"],["修订","修訂"],["修订历史","修訂歷史"],["修订本","修訂本"],["修订案","修訂案"],["修订版","修訂版"],["修词学","修詞學"],["修课","修課"],["修谨以俟","修謹以俟"],["修谱","修譜"],["修起","修起"],["修起来","修起來"],["修路","修路"],["修蹄","修蹄"],["修身","修身"],["修身养性","修身養性"],["修身齐家","修身齊家"],["修车厂","修車廠"],["修辞","修辭"],["修辞学","修辭學"],["修辞格","修辭格"],["修边","修邊"],["修边幅","修邊幅"],["修造","修造"],["修造厂","修造廠"],["修道","修道"],["修道人","修道人"],["修道会","修道會"],["修道士","修道士"],["修道张","修道張"],["修道院","修道院"],["修配","修配"],["修配厂","修配廠"],["修金","脩金"],["修长","修長"],["修阻","修阻"],["修面","修面"],["修鞋匠","修鞋匠"],["修饰","修飾"],["修饰句","修飾句"],["修饰字","修飾字"],["修饰词","修飾詞"],["修饰话","修飾話"],["修饰语","修飾語"],["修饰边幅","修飾邊幅"],["修齐","修齊"],["修龄","修齡"],["俯冲","俯衝"],["俯冲点","俯衝點"],["俯冲角","俯衝角"],["俯曲","俯曲"],["俯首就范","俯首就範"],["俱发","俱發"],["俱收并蓄","俱收並蓄"],["俱杯","俱杯"],["俱舍师","俱舍師"],["俱舍论","俱舍論"],["俾资挹注","俾資挹注"],["倍日并行","倍日並行"],["倒了","倒了"],["倒了八辈子楣","倒了八輩子楣"],["倒了架","倒了架"],["倒了架子","倒了架子"],["倒了柴","倒了柴"],["倒了核桃车子","倒了核桃車子"],["倒价","倒價"],["倒八字须","倒八字鬚"],["倒出","倒出"],["倒出去","倒出去"],["倒出来","倒出來"],["倒前倒后","倒前倒後"],["倒台","倒臺"],["倒吊","倒吊"],["倒吊蜡烛","倒吊蠟燭"],["倒向","倒向"],["倒回","倒回"],["倒回去","倒回去"],["倒回来","倒回來"],["倒屣奔出","倒屣奔出"],["倒彩","倒彩"],["倒念","倒唸"],["倒悬挨命","倒懸捱命"],["倒扣","倒扣"],["倒扣针儿","倒扣針兒"],["倒抽了一口气","倒抽了一口氣"],["倒持干戈","倒持干戈"],["倒挂","倒掛"],["倒挂金钩","倒掛金鉤"],["倒杯","倒杯"],["倒杯水","倒杯水"],["倒杯茶","倒杯茶"],["倒板","倒板"],["倒竖虎须","倒豎虎鬚"],["倒绷孩儿","倒繃孩兒"],["倒置干戈","倒置干戈"],["倒载干戈","倒載干戈"],["倒钟摆效应","倒鐘擺效應"],["候虫","候蟲"],["倚儿不当","倚兒不當"],["倚多为胜","倚多爲勝"],["倚托","倚托"],["倚晴楼七种","倚晴樓七種"],["倚闲","倚閑"],["倚马千言","倚馬千言"],["倛丑","倛醜"],["借一步","借一步"],["借不到","借不到"],["借东风","借東風"],["借个","借個"],["借个火","借個火"],["借主","借主"],["借书","借書"],["借书单","借書單"],["借书证","借書證"],["借了","借了"],["借交报仇","借交報仇"],["借人","借人"],["借代","借代"],["借令","借令"],["借以","藉以"],["借位","借位"],["借住","借住"],["借作","借作"],["借使","借使"],["借借","藉藉"],["借借看","借借看"],["借债","借債"],["借债人","借債人"],["借债度日","借債度日"],["借光","借光"],["借入方","借入方"],["借入款","借入款"],["借典","借典"],["借出","借出"],["借出去","借出去"],["借出来","借出來"],["借刀杀人","借刀殺人"],["借到","借到"],["借券","借券"],["借剑杀人","借劍殺人"],["借力","借力"],["借助","藉助"],["借助于","藉助於"],["借势","借勢"],["借卉","藉卉"],["借单","借單"],["借单儿","借單兒"],["借去","借去"],["借取","借取"],["借口","藉口"],["借古喻今","借古喻今"],["借古讽今","借古諷今"],["借名","借名"],["借听于聋","借聽於聾"],["借唱","借唱"],["借喻","借喻"],["借回","借回"],["借回去","借回去"],["借回来","借回來"],["借地","借地"],["借坐","借坐"],["借契","借契"],["借好","借好"],["借妻","借妻"],["借字","借字"],["借字儿","借字兒"],["借完","借完"],["借客报仇","借客報仇"],["借宿","借宿"],["借宿一夜","借宿一夜"],["借宿一晚","借宿一晚"],["借寇兵","藉寇兵"],["借寇兵赍盗粮","藉寇兵齎盜糧"],["借寇恂","借寇恂"],["借对","借對"],["借寿","借壽"],["借尸还魂","借屍還魂"],["借弹","借彈"],["借得","借得"],["借手","藉手"],["借手除敌","借手除敵"],["借托","借托"],["借抄","借抄"],["借抽","借抽"],["借招","借招"],["借据","借據"],["借提","借提"],["借支","借支"],["借放","借放"],["借故","藉故"],["借故推辞","藉故推辭"],["借方","借方"],["借方差额","借方差額"],["借有","借有"],["借机","藉機"],["借条","借條"],["借来","借來"],["借来借去","借來借去"],["借梯子下楼","借梯子下樓"],["借槁","藉槁"],["借款","借款"],["借款人","借款人"],["借此","藉此"],["借此机会","藉此機會"],["借水推船","借水推船"],["借水行舟","借水行舟"],["借满","借滿"],["借火","借火"],["借点","借點"],["借球","借球"],["借甚","藉甚"],["借用","借用"],["借由","藉由"],["借的","借的"],["借看","借看"],["借看一下","借看一下"],["借着","藉着"],["借穿","借穿"],["借端","藉端"],["借端生事","藉端生事"],["借箸","借箸"],["借箸代筹","藉箸代籌"],["借箸代谋","借箸代謀"],["借米下得锅讨米下不得锅","借米下得鍋討米下不得鍋"],["借约","借約"],["借给","借給"],["借腹生子","借腹生子"],["借花献佛","借花獻佛"],["借茶活捉","借茶活捉"],["借草枕块","藉草枕塊"],["借让","借讓"],["借讬","借託"],["借记卡","借記卡"],["借词","藉詞","借詞"],["借读","借讀"],["借调","借調"],["借贷","借貸"],["借贷无门","借貸無門"],["借贷资本","借貸資本"],["借资","藉資"],["借资挹注","借資挹注"],["借走","借走"],["借过","借過"],["借过一下","借過一下"],["借道","借道"],["借酒三分醉","借酒三分醉"],["借酒浇愁","借酒澆愁"],["借酒装疯","借酒裝瘋"],["借重","借重"],["借鉴","借鑑"],["借鑑","借鑑"],["借钱","借錢"],["借镜","借鏡"],["借问","借問"],["借阅","借閱"],["借阅率","借閱率"],["借韵","借韻"],["借题","借題"],["借题发挥","借題發揮"],["借风使船","借風使船"],["借齿牙","借齒牙"],["倡条冶叶","倡條冶葉"],["倦游","倦遊"],["倦鸟余花","倦鳥餘花"],["倪云林","倪雲林"],["倪嗣冲","倪嗣沖"],["倮虫","倮蟲"],["债台高筑","債臺高築"],["债权团","債權團"],["值回票价","值回票價"],["值得一干","值得一幹"],["值得干","值得幹"],["值得庆幸","值得慶幸"],["值得注意","值得注意"],["值得注意的是","值得注意的是"],["值得称赞","值得稱讚"],["值日表","值日表"],["倾出","傾出"],["倾向","傾向"],["倾向于","傾向於"],["倾向性","傾向性"],["倾复重器","傾覆重器"],["倾家尽产","傾家盡產"],["倾家荡产","傾家蕩產"],["倾尽","傾盡"],["倾巢出动","傾巢出動"],["倾巢而出","傾巢而出"],["倾斜面","傾斜面"],["倾杯","傾杯"],["倾注","傾注"],["倾箱倒柜","傾箱倒櫃"],["倾耳注目","傾耳注目"],["倾诉衷曲","傾訴衷曲"],["偃仆","偃仆"],["偃松","偃松"],["偃武修文","偃武修文"],["偃蹇困穷","偃蹇困窮"],["假借","假借"],["假借义","假借義"],["假借字","假借字"],["假借法","假借法"],["假力于人","假力於人"],["假发","假髮"],["假叶","假葉"],["假意周旋","假意周旋"],["假托","假託"],["假期忧郁症候群","假期憂鬱症候羣"],["假药","假藥"],["假面","假面"],["假面具","假面具"],["假面剧","假面劇"],["偎干","偎乾"],["偎干就湿","偎乾就溼"],["偏了","偏了"],["偏于","偏於"],["偏信则暗","偏信則闇"],["偏出","偏出"],["偏后","偏後"],["偏向","偏向"],["偏回","偏回"],["偏回去","偏回去"],["偏回来","偏回來"],["偏幸","偏倖"],["偏才","偏才"],["偏执症","偏執症"],["偏暗","偏暗"],["偏极光","偏極光"],["偏极光镜","偏極光鏡"],["偏极化","偏極化"],["偏极滤光镜","偏極濾光鏡"],["偏极镜","偏極鏡"],["偏正式合成词","偏正式合成詞"],["偏相关系数","偏相關係數"],["偏重于","偏重於"],["偕同","偕同"],["做一天和尚撞一天钟","做一天和尚撞一天鐘"],["做不了","做不了"],["做了","做了"],["做准备工作","做準備工作"],["做出","做出"],["做出事来","做出事來"],["做出场","做出場"],["做出好戏","做齣好戲"],["做出来","做出來"],["做好做恶","做好做惡"],["做尽","做盡"],["做庄","做莊"],["做张做致","做張做致"],["做得了","做得了"],["做针线","做針線"],["停了","停了"],["停云","停雲"],["停云慢步","停雲慢步"],["停云落月","停雲落月"],["停停当当","停停當當"],["停制","停製"],["停尸","停屍"],["停尸房","停屍房"],["停尸间","停屍間"],["停当","停當"],["停征","停徵"],["停摆","停擺"],["停板","停板"],["停板制度","停板制度"],["停表","停表"],["偢采","偢采"],["健康胜于财富","健康勝於財富"],["健忘症","健忘症"],["偶发","偶發"],["偶发事件","偶發事件"],["偶发性","偶發性"],["偶合","偶合"],["偷了","偷了"],["偷出","偷出"],["偷出去","偷出去"],["偷出来","偷出來"],["偷发","偷發"],["偷合取容","偷合取容"],["偷合苟容","偷合苟容"],["偷回","偷回"],["偷回去","偷回去"],["偷回来","偷回來"],["偷婆娘","偷婆娘"],["偷尝禁果","偷嚐禁果"],["偷得浮生半日闲","偷得浮生半日閒"],["偷期暗会","偷期暗會"],["偷梁换柱","偷樑換柱"],["偷种","偷種"],["偷鸡不着","偷雞不着"],["偷鸡吊狗","偷雞吊狗"],["偿回","償回"],["偿回去","償回去"],["偿回来","償回來"],["偿得夙愿","償得夙願"],["偿愿","償願"],["傅克斯","傅克斯"],["傅利叶","傅利葉"],["傅匀余","傅勻余"],["傅岩","傅巖"],["傅彩","傅彩"],["傅科摆","傅科擺"],["傅立叶","傅立葉"],["傅立叶变换","傅立葉變換"],["傅粉施朱","傅粉施朱"],["傅说版筑","傅說版築"],["傅里叶","傅里葉"],["傍个影儿","傍個影兒"],["傍系","傍系"],["傒幸","傒倖"],["傢伙","傢伙"],["傢伙座儿","傢伙座兒"],["傥荡","儻蕩"],["储备干部","儲備幹部"],["储训人才","儲訓人才"],["储训干部","儲訓幹部"],["催并","催併"],["催眠曲","催眠曲"],["催眠术","催眠術"],["催眠药","催眠藥"],["催谷","催谷"],["傲世轻才","傲世輕才"],["傲睨万物","傲睨萬物"],["傲霜斗雪","傲霜鬥雪"],["傻大个","傻大個"],["傻大个儿","傻大個兒"],["傻里傻气","傻里傻氣"],["像杯","像杯"],["像赞","像贊"],["僦舍","僦舍"],["僮仆","僮僕"],["僮御","僮御"],["僮手指千","僮手指千"],["僵事","僵事"],["僵仆","僵仆"],["僵住","僵住"],["僵冷","僵冷"],["僵化","僵化"],["僵卧","僵臥"],["僵固","僵固"],["僵固性","僵固性"],["僵尸","殭屍"],["僵尸网络","殭屍網絡"],["僵局","僵局"],["僵持","僵持"],["僵持不下","僵持不下"],["僵掉","僵掉"],["僵李代桃","僵李代桃"],["僵死","僵死"],["僵直","僵直"],["僵直性","僵直性"],["僵直性脊椎炎","僵直性脊椎炎"],["僵硬","僵硬"],["僵立","僵立"],["僵臥","僵臥"],["僵蚕","殭蠶"],["儌幸","儌倖"],["儒术","儒術"],["儒略历","儒略曆"],["儒略历史","儒略歷史"],["儒略改革历","儒略改革曆"],["儒略改革历史","儒略改革歷史"],["儿不嫌母丑犬不怨主贫","兒不嫌母醜犬不怨主貧"],["儿童台","兒童臺"],["儿童团","兒童團"],["兀术","兀朮"],["允准","允准"],["允当","允當"],["元凶","元兇"],["元后","元后"],["元培医事技术学校","元培醫事技術學校"],["元恶","元惡"],["元恶大奸","元惡大奸"],["元恶大憝","元惡大憝"],["元曲","元曲"],["元曲四大家","元曲四大家"],["元秋","元秋"],["元素周期表","元素週期表"],["兄台","兄臺"],["兄弟党","兄弟黨"],["充发","充發"],["充场面","充場面"],["充当","充當"],["充斥市面","充斥市面"],["充满了","充滿了"],["充类至尽","充類至盡"],["充能干","充能幹"],["充门面","充門面"],["充饥","充飢"],["充饥止渴","充飢止渴"],["充饥画饼","充飢畫餅"],["兆个","兆個"],["兆丰","兆豐"],["兆丰金","兆豐金"],["兆丰银","兆豐銀"],["兆余","兆餘"],["先义后利","先義後利"],["先了","先了"],["先了一步","先了一步"],["先于","先於"],["先人后己","先人後己"],["先修班","先修班"],["先借","先借"],["先公后私","先公後私"],["先出","先出"],["先出去","先出去"],["先出来","先出來"],["先占","先佔"],["先发","先發"],["先发制人","先發制人"],["先发投手","先發投手"],["先发投手群","先發投手羣"],["先后","先後","先后"],["先后倒置","先後倒置"],["先后顺序","先後順序"],["先向","先向"],["先回","先回"],["先回到","先回到"],["先回去","先回去"],["先回来","先回來"],["先声后实","先聲後實"],["先天下之忧而忧后天下之乐而乐","先天下之憂而憂后天下之樂而樂"],["先天不足后天失调","先天不足後天失調"],["先守后攻","先守後攻"],["先小人后君子","先小人後君子"],["先尝","先嚐"],["先干为敬","先乾爲敬"],["先忧后乐","先憂後樂"],["先念","先念"],["先意承志","先意承志"],["先攻后守","先攻後守"],["先斩后奏","先斬後奏"],["先斩后闻","先斬後聞"],["先期录音","先期錄音"],["先来后上","先來後上"],["先来后下","先來後下"],["先来后到","先來後到"],["先盛后衰","先盛後衰"],["先礼后兵","先禮後兵"],["先签","先簽"],["先缺后空","先缺後空"],["先花后果","先花後果"],["先苦后甘","先苦後甘"],["先行后闻","先行後聞"],["先赢后输","先贏後輸"],["先进先出","先進先出"],["先进后出","先進後出"],["先采","先採"],["先锋模范作用","先鋒模範作用"],["先难后获","先難後獲"],["先驱新党","先驅新黨"],["光了","光了"],["光了了","光了了"],["光二极管","光二極管"],["光价","光價"],["光光荡荡","光光蕩蕩"],["光冲量","光衝量"],["光出律","光出律"],["光出溜","光出溜"],["光前绝后","光前絕後"],["光前耀后","光前耀後"],["光前裕后","光前裕後"],["光卤石","光鹵石"],["光发送器","光發送器"],["光可鉴人","光可鑑人"],["光合","光合"],["光合作用","光合作用"],["光合细菌","光合細菌"],["光向","光向"],["光周期","光周期"],["光圈范围","光圈範圍"],["光复","光復"],["光复乡","光復鄉"],["光复会","光復會"],["光复南路","光復南路"],["光复国土","光復國土"],["光复国小","光復國小"],["光复旧京","光復舊京"],["光复旧物","光復舊物"],["光复节","光復節"],["光复路","光復路"],["光学字符识别","光學字符識別"],["光学录音","光學錄音"],["光学系统","光學系統"],["光导纤维","光導纖維"],["光度表","光度表"],["光彩","光彩"],["光彩夺目","光彩奪目"],["光彩耀眼","光彩耀眼"],["光彩起来","光彩起來"],["光念","光念"],["光效应艺术","光效應藝術"],["光敏症","光敏症"],["光明云","光明雲"],["光明党","光明黨"],["光明面","光明面"],["光杆","光桿"],["光杆儿","光桿兒"],["光杆司令","光桿司令"],["光杠","光槓"],["光板儿","光板兒"],["光烟雾","光煙霧"],["光焰万丈","光焰萬丈"],["光电二极","光電二極"],["光电二极体","光電二極體"],["光电二极管","光電二極管"],["光碟杂志","光碟雜誌"],["光碟柜","光碟櫃"],["光纤","光纖"],["光纤分布式数据介面","光纖分佈式數據介面"],["光纤分布数据接口","光纖分佈數據接口"],["光纤分散式资料介面","光纖分散式資料介面"],["光纤接口","光纖接口"],["光纤电缆","光纖電纜"],["光纤维","光纖維"],["光纤衰减","光纖衰減"],["光纤通信","光纖通信"],["光纤通信系统","光纖通信系統"],["光纤通讯","光纖通訊"],["光纤通讯干道网路系统","光纖通訊幹道網路系統"],["光纤飞弹","光纖飛彈"],["光能合成","光能合成"],["光脊梁","光脊樑"],["光致致","光緻緻"],["光艺术","光藝術"],["光芒万丈","光芒萬丈"],["光范围","光範圍"],["光表","光表"],["光辉典范","光輝典範"],["光采","光采"],["光面","光面"],["光面内质网","光面內質網"],["光面子","光面子"],["克东","克東"],["克东县","克東縣"],["克丝钳子","克絲鉗子"],["克丽丝","克麗絲"],["克亚","克亞"],["克什","克什"],["克什克腾","克什克騰"],["克什克腾旗","克什克騰旗"],["克什米尔","克什米爾"],["克仑特罗","克侖特羅"],["克伦克","克倫克"],["克伦奇","克倫奇"],["克伦威尔","克倫威爾"],["克佩罗","克佩羅"],["克俭","克儉"],["克俭克勤","克儉克勤"],["克克","剋剋"],["克克尔","克克爾"],["克兰诗","克蘭詩"],["克兰达尔","克蘭達爾"],["克分子","克分子"],["克利","克利"],["克利斯","克利斯"],["克利斯提","克利斯提"],["克利福洛","克利福洛"],["克制","剋制"],["克制不了","剋制不了"],["克制不住","剋制不住"],["克剥","剋剝"],["克劳","克勞"],["克劳佛","克勞佛"],["克劳修斯","克勞修斯"],["克劳可","克勞可"],["克劳契","克勞契"],["克劳德","克勞德"],["克劳斯","克勞斯"],["克劳福","克勞福"],["克劳福德","克勞福德"],["克劳芙特","克勞芙特"],["克勒","克勒"],["克勒拉省","克勒拉省"],["克勒特","克勒特"],["克勤","克勤"],["克勤克俭","克勤克儉"],["克卜勒","克卜勒"],["克卜勒定律","克卜勒定律"],["克原子","克原子"],["克啬","剋嗇"],["克基拉岛","克基拉島"],["克复","克復"],["克夫","剋夫"],["克娄巴特拉","克婁巴特拉"],["克孜勒苏","克孜勒蘇"],["克孜勒苏地区","克孜勒蘇地區"],["克孜勒苏柯尔克孜自治州","克孜勒蘇柯爾克孜自治州"],["克孜勒苏河","克孜勒蘇河"],["克孜尔千佛洞","克孜爾千佛洞"],["克孜尔尕哈","克孜爾尕哈"],["克孜尔尕哈烽火台","克孜爾尕哈烽火臺"],["克宁","克寧"],["克定","克定"],["克家","克家"],["克家子","克家子"],["克尔","克爾"],["克尔白","克爾白"],["克尽","克盡"],["克尽厥职","克盡厥職"],["克尽夫道","克盡夫道"],["克尽妇道","克盡婦道"],["克尽己职","克盡己職"],["克山","克山"],["克山县","克山縣"],["克己","克己"],["克己主义","克己主義"],["克己复礼","克己復禮"],["克己奉公","克己奉公"],["克强","克強"],["克当一面","克當一面"],["克当量","克當量"],["克意","剋意"],["克扣","剋扣"],["克拉","克拉"],["克拉克","克拉克"],["克拉兹","克拉茲"],["克拉夫特","克拉夫特"],["克拉姆","克拉姆"],["克拉本","克拉本"],["克拉玛依","克拉瑪依"],["克捷","克捷"],["克敌","克敵"],["克敌制胜","克敵制勝"],["克敦孝行","克敦孝行"],["克文","克文"],["克斯","克斯"],["克日","剋日"],["克明","克明"],["克星","剋星"],["克服","克服"],["克服不了","克服不了"],["克服困难","克服困難"],["克朗","克朗"],["克朗代克","克朗代克"],["克期","剋期"],["克来汀症","克來汀症"],["克林伊斯威特","克林伊斯威特"],["克林德","克林德"],["克林斯曼","克林斯曼"],["克林霉素","克林黴素"],["克林顿","克林頓"],["克柔","克柔"],["克核","剋核"],["克格勃","克格勃"],["克死","剋死"],["克汀病","克汀病"],["克汗","克汗"],["克沙奇病毒","克沙奇病毒"],["克洛","克洛"],["克洛尔","克洛爾"],["克洛斯","克洛斯"],["克洛格","克洛格"],["克流感","克流感"],["克瑞强","克瑞強"],["克瑞斯波","克瑞斯波"],["克瑞格","克瑞格"],["克绍箕裘","克紹箕裘"],["克绳祖武","克繩祖武"],["克罗地亚","克羅地亞"],["克罗地亚共和国","克羅地亞共和國"],["克罗地亚语","克羅地亞語"],["克罗埃","克羅埃"],["克罗埃西亚","克羅埃西亞"],["克罗德","克羅德"],["克罗恩科","克羅恩科"],["克罗诺斯","克羅諾斯"],["克罗齐","克羅齊"],["克耳文","克耳文"],["克耶族","克耶族"],["克耶邦","克耶邦"],["克苦耐劳","克苦耐勞"],["克药","克藥"],["克莉","克莉"],["克莉丝","克莉絲"],["克莉丝汀","克莉絲汀"],["克莉丝汀娜","克莉絲汀娜"],["克莉丝特丝","克莉絲特絲"],["克莉兰柯","克莉蘭柯"],["克莉奥佩特拉","克莉奧佩特拉"],["克莉斯蒂纳","克莉斯蒂納"],["克莉芭丝","克莉芭絲"],["克莱","克萊"],["克莱伦斯宫","克萊倫斯宮"],["克莱儿","克萊兒"],["克莱因","克萊因"],["克莱恩","克萊恩"],["克莱斯勒","克萊斯勒"],["克莱斯勒汽车公司","克萊斯勒汽車公司"],["克莱曼","克萊曼"],["克莱柏","克萊柏"],["克莱査克","克萊查克"],["克莱格","克萊格"],["克莱蒙特","克萊蒙特"],["克莱门斯","克萊門斯"],["克莱顿","克萊頓"],["克萨斯州","克薩斯州"],["克落","剋落"],["克蕾儿","克蕾兒"],["克薄","剋薄"],["克虏伯","克虜伯"],["克西","克西"],["克让","克讓"],["克谐","克諧"],["克赖斯特彻奇","克賴斯特徹奇"],["克郎","克郎"],["克郡","克郡"],["克里","克里"],["克里丝蒂娃","克里絲蒂娃"],["克里契科","克里契科"],["克里奥尔语","克里奧爾語"],["克里姆林","克里姆林"],["克里姆林宫","克里姆林宮"],["克里姆林杯","克里姆林杯"],["克里岛","克里島"],["克里斯","克里斯"],["克里斯伊凡","克里斯伊凡"],["克里斯塔基斯","克里斯塔基斯"],["克里斯托","克里斯托"],["克里斯托弗","克里斯托弗"],["克里斯普","克里斯普"],["克里斯汀","克里斯汀"],["克里斯汀贝尔","克里斯汀貝爾"],["克里斯蒂安","克里斯蒂安"],["克里斯蒂安松","克里斯蒂安松"],["克里普斯","克里普斯"],["克里木","克里木"],["克里木半岛","克里木半島"],["克里木战争","克里木戰爭"],["克里梅","克里梅"],["克里特","克里特"],["克里特克","克里特克"],["克里特克里岛","克里特克里島"],["克里特岛","克里特島"],["克里米亚","克里米亞"],["克里米亚半岛","克里米亞半島"],["克里米亚战争","克里米亞戰爭"],["克里蒙梭","克里蒙梭"],["克里门","克里門"],["克里门特","克里門特"],["克队","克隊"],["克隆","克隆"],["克隆人","克隆人"],["克隆尼","克隆尼"],["克隆技术","克隆技術"],["克隆斯台","克隆斯臺"],["克隆氏病","克隆氏病"],["克难","克難"],["克难街","克難街"],["克难运动","克難運動"],["克雅氏症","克雅氏症"],["克雷伯氏菌属","克雷伯氏菌屬"],["克雷因","克雷因"],["克雷姆凯","克雷姆凱"],["克雷尼尔","克雷尼爾"],["克雷文","克雷文"],["克雷斯","克雷斯"],["克雷斯吉","克雷斯吉"],["克雷格","克雷格"],["克雷门斯","克雷門斯"],["克雷默","克雷默"],["克霉唑","克黴唑"],["克顺克卑","克順克卑"],["克食","克食"],["克鲁","克魯"],["克鲁伦河","克魯倫河"],["克鲁克斯","克魯克斯"],["克鲁兹","克魯茲"],["克鲁利","克魯利"],["克鲁尼","克魯尼"],["克鲁斯","克魯斯"],["克鲁斯州","克魯斯州"],["克鲁格","克魯格"],["克麦洛伏","克麥洛伏"],["免不了","免不了"],["免于","免於"],["免参","免參"],["免征","免徵"],["免疫系统","免疫系統"],["免胄","免冑"],["免试升学","免試升學"],["免试升高中班","免試升高中班"],["兔尽狗烹","兔盡狗烹"],["党三役","黨三役"],["党中央","黨中央"],["党主席","黨主席"],["党义","黨義"],["党争","黨爭"],["党产","黨產"],["党人","黨人"],["党代会","黨代會"],["党代表","黨代表"],["党伍","黨伍"],["党內","黨內"],["党內人士","黨內人士"],["党內初选","黨內初選"],["党內斗争","黨內鬥爭"],["党八股","黨八股"],["党公职","黨公職"],["党军","黨軍"],["党刊","黨刊"],["党务","黨務"],["党参","黨蔘"],["党友","黨友"],["党史","黨史"],["党同伐异","黨同伐異"],["党名","黨名"],["党员","黨員"],["党员大会","黨員大會"],["党员证","黨員證"],["党团","黨團"],["党团员","黨團員"],["党国","黨國"],["党国元老","黨國元老"],["党外","黨外"],["党外人士","黨外人士"],["党太尉","党太尉"],["党太尉吃匾食","党太尉吃匾食"],["党委","黨委"],["党委书记","黨委書記"],["党委会","黨委會"],["党小组","黨小組"],["党工","黨工"],["党徒","黨徒"],["党徽","黨徽"],["党怀英","党懷英"],["党性","黨性"],["党总支","黨總支"],["党报","黨報"],["党支书","党支書"],["党政","黨政"],["党政军","黨政軍"],["党政机关","黨政機關"],["党旗","黨旗"],["党校","黨校"],["党格","黨格"],["党棍","黨棍"],["党歌","黨歌"],["党法","黨法"],["党派","黨派"],["党派集会","黨派集會"],["党的基本","黨的基本"],["党祸","黨禍"],["党禁","黨禁"],["党章","黨章"],["党籍","黨籍"],["党籍碑","黨籍碑"],["党纪","黨紀"],["党纪国法","黨紀國法"],["党纲","黨綱"],["党组","黨組"],["党羽","黨羽"],["党职","黨職"],["党营","黨營"],["党见","黨見"],["党言","黨言"],["党论","黨論"],["党证","黨證"],["党课","黨課"],["党费","黨費"],["党进","党進"],["党部","黨部"],["党锢","黨錮"],["党锢之祸","黨錮之禍"],["党阀","黨閥"],["党鞭","黨鞭"],["党項","党項"],["党项","党項"],["党项族","党項族"],["党风","黨風"],["党魁","黨魁"],["党龄","黨齡"],["兜肚断了带子","兜肚斷了帶子"],["入不支出","入不支出"],["入不敷出","入不敷出"],["入主出奴","入主出奴"],["入伍须知","入伍須知"],["入伙","入夥"],["入党","入黨"],["入冬","入冬"],["入出境","入出境"],["入出境管理局","入出境管理局"],["入口匝道号志管制","入口匝道號誌管制"],["入团","入團"],["入境签证","入境簽證"],["入夜后","入夜後"],["入室升堂","入室升堂"],["入帘","入簾"],["入托","入托"],["入秋","入秋"],["入舍","入舍"],["入药","入藥"],["內出血","內出血"],["內分泌系统","內分泌系統"],["內制作","內製作"],["內务柜","內務櫃"],["內外交困","內外交困"],["內外向包办","內外向包辦"],["內外姻党","內外姻黨"],["內外并重","內外並重"],["內婚制","內婚制"],["內布拉斯","內布拉斯"],["內布拉斯加","內布拉斯加"],["內心里","內心裏"],["內掌柜的","內掌櫃的"],["內服药","內服藥"],["內科手术","內科手術"],["內脏器官移植","內臟器官移植"],["內蒙古","內蒙古"],["內蒙古自治区","內蒙古自治區"],["內部联系","內部聯繫"],["內阁制","內閣制"],["全世界无产者联合起来","全世界無產者聯合起來"],["全体同仁","全體同仁"],["全党","全黨"],["全党全军","全黨全軍"],["全党同志","全黨同志"],["全军复没","全軍覆沒"],["全军复灭","全軍覆滅"],["全出","全出"],["全出去","全出去"],["全出来","全出來"],["全台","全臺"],["全台湾","全臺灣"],["全向","全向"],["全国不分区代表","全國不分區代表"],["全国人民代表大会","全國人民代表大會"],["全国人民代表大会常务委员会","全國人民代表大會常務委員會"],["全国代表大会","全國代表大會"],["全国劳动模范","全國勞動模範"],["全国同胞","全國同胞"],["全国大会党","全國大會黨"],["全国教育资讯服务系统","全國教育資訊服務系統"],["全国纪录","全國紀錄"],["全国范围","全國範圍"],["全场一致","全場一致"],["全尸","全屍"],["全干","全乾"],["全当","全當"],["全录","全錄"],["全彩","全綵"],["全彩干式印表机","全彩乾式印表機"],["全所同仁","全所同仁"],["全才","全才"],["全托","全託"],["全挂子","全掛子"],["全斗焕","全斗煥"],["全无准备","全無準備"],["全日制","全日制"],["全权代表","全權代表"],["全校同学","全校同學"],["全然不同","全然不同"],["全班同学","全班同學"],["全球位置测定系统","全球位置測定系統"],["全球卫星导航系统","全球衛星導航系統"],["全球发展中心","全球發展中心"],["全球定位系统","全球定位系統"],["全球定位系统卫星测量","全球定位系統衛星測量"],["全球气候升温","全球氣候升溫"],["全球环境变迁资讯系统","全球環境變遷資訊系統"],["全球范围","全球範圍"],["全盘托出","全盤托出"],["全神灌注","全神灌注"],["全神贯注","全神貫注"],["全票价","全票價"],["全程参加","全程參加"],["全系列","全系列"],["全系统","全系統"],["全线出击","全線出擊"],["全缘叶","全緣葉"],["全胜","全勝"],["全胜记录","全勝記錄"],["全范围","全範圍"],["全裂叶","全裂葉"],["全谷物","全穀物"],["全面","全面"],["全面包围","全面包圍"],["全面包裹","全面包裹"],["全面发展","全面發展"],["全面实施","全面實施"],["全面性","全面性"],["全面战争","全面戰爭"],["全面禁止","全面禁止"],["全面禁止核试验条约","全面禁止核試驗條約"],["全面规划","全面規劃"],["全面进行","全面進行"],["八万","八萬"],["八万一千","八萬一千"],["八万四千法门","八萬四千法門"],["八万多","八萬多"],["八万大藏经","八萬大藏經"],["八个","八個"],["八仙桌上摆夜壶","八仙桌上擺夜壺"],["八位元个人电脑","八位元個人電腦"],["八余","八餘"],["八克","八克"],["八军团","八軍團"],["八出祁山","八出祁山"],["八十天环游地球","八十天環遊地球"],["八十种好","八十種好"],["八千里","八千里"],["八厂","八廠"],["八只","八隻"],["八台","八臺"],["八周","八週"],["八周年","八週年"],["八大胡同","八大胡同"],["八天后","八天後"],["八字方针","八字方針"],["八字胡","八字鬍"],["八字胡须","八字鬍鬚"],["八小时制","八小時制"],["八小时工作制","八小時工作制"],["八扎","八紮"],["八折","八折"],["八斗","八斗"],["八斗之才","八斗之才"],["八斗子","八斗子"],["八斗才","八斗才"],["八斗陈思","八斗陳思"],["八旗制度","八旗制度"],["八极","八極"],["八极拳","八極拳"],["八步周行","八步周行"],["八点钟","八點鐘"],["八珍咸粥","八珍鹹粥"],["八百万","八百萬"],["八百多万","八百多萬"],["八秒钟","八秒鐘"],["八级工资制","八級工資制"],["八蜡","八蜡"],["八表","八表"],["八辟","八辟"],["八进制","八進制"],["八里","八里"],["八里乡","八里鄉"],["八面","八面"],["八面体","八面體"],["八面光","八面光"],["八面受敌","八面受敵"],["八面圆通","八面圓通"],["八面威风","八面威風"],["八面玲珑","八面玲瓏"],["八面见光","八面見光"],["八面锋","八面鋒"],["公之于众","公之於衆"],["公了","公了"],["公仆","公僕"],["公仔面","公仔麪"],["公价","公價"],["公众参与","公衆參與"],["公余","公餘"],["公使团","公使團"],["公克","公克"],["公公向孙子磕头","公公向孫子磕頭"],["公共休闲环境","公共休閒環境"],["公共关系","公共關係"],["公共团体","公共團體"],["公共支出","公共支出"],["公出","公出"],["公切面","公切面"],["公制","公制"],["公制单位","公制單位"],["公升","公升"],["公历","公曆"],["公厘","公釐"],["公合","公合"],["公同","公同"],["公同共有","公同共有"],["公听并观","公聽並觀"],["公告价格","公告價格"],["公告地价","公告地價"],["公墓里放鞭炮","公墓裏放鞭炮"],["公孙丑","公孫丑"],["公孙大娘","公孫大娘"],["公定价","公定價"],["公定价格","公定價格"],["公布","公佈"],["公布于众","公佈於衆"],["公布出来","公佈出來"],["公布栏","公佈欄"],["公干","公幹"],["公平合理","公平合理"],["公广集团","公廣集團"],["公开出来","公開出來"],["公开场合","公開場合"],["公才公望","公才公望"],["公报私仇","公報私仇"],["公据","公據"],["公斗","公斗"],["公方代表","公方代表"],["公明党","公明黨"],["公有制","公有制"],["公民表决","公民表決"],["公然表示","公然表示"],["公用征收","公用徵收"],["公用限制","公用限制"],["公益彩券","公益彩券"],["公私两尽","公私兩盡"],["公私合营","公私合營"],["公羊春秋","公羊春秋"],["公认会计准","公認會計准"],["公诸于世","公諸於世"],["公诸同好","公諸同好"],["公路个人赛","公路個人賽"],["公里","公里"],["公里数","公里數"],["公里时","公里時"],["公门之中好修行","公門之中好修行"],["公门修行","公門修行"],["公门里好修行","公門裏好修行"],["六万","六萬"],["六个","六個"],["六余","六餘"],["六冲","六沖"],["六出奇计","六出奇計"],["六出祁山","六出祁山"],["六厂","六廠"],["六发","六發"],["六只","六隻"],["六台","六臺"],["六合","六合"],["六合区","六合區"],["六合彩","六合彩"],["六合拳","六合拳"],["六合路","六合路"],["六周","六週"],["六周年","六週年"],["六回","六回"],["六天后","六天後"],["六度万行","六度萬行"],["六弦","六絃"],["六彩","六彩"],["六才子书","六才子書"],["六扎","六紮"],["六折","六折"],["六星彩","六星彩"],["六曲","六曲"],["六极","六極"],["六欲","六慾"],["六点钟","六點鐘"],["六百万","六百萬"],["六百个","六百個"],["六百多万","六百多萬"],["六祖坛经","六祖壇經"],["六种","六種"],["六谷","六穀"],["六通四辟","六通四辟"],["六道轮回","六道輪迴"],["六面","六面"],["六面体","六面體"],["六须鲇","六鬚鮎"],["六须鲶","六鬚鮎"],["兰克","蘭克"],["兰台","蘭臺"],["兰台令史","蘭臺令史"],["兰台公子","蘭臺公子"],["兰台石室","蘭臺石室"],["兰叶描","蘭葉描"],["兰叶撇","蘭葉撇"],["兰摧玉折","蘭摧玉折"],["兰摧蕙折","蘭摧蕙折"],["兰秋","蘭秋"],["兰艾同烬","蘭艾同燼"],["兰艾同焚","蘭艾同焚"],["兰花烟","蘭花煙"],["兰里老太太","蘭里老太太"],["共产主义青年团","共產主義青年團"],["共产党","共產黨"],["共产党人","共產黨人"],["共产党员","共產黨員"],["共产党宣言","共產黨宣言"],["共产党政府","共產黨政府"],["共产党部队","共產黨部隊"],["共产制","共產制"],["共产集团","共產集團"],["共享计划","共享計劃"],["共价","共價"],["共价键","共價鍵"],["共党","共黨"],["共出","共出"],["共发射极","共發射極"],["共同","共同"],["共同交际语","共同交際語"],["共同代理","共同代理"],["共同代表","共同代表"],["共同企业","共同企業"],["共同体","共同體"],["共同保证","共同保證"],["共同决议案","共同決議案"],["共同利益","共同利益"],["共同努力","共同努力"],["共同基金","共同基金"],["共同市场","共同市場"],["共同性","共同性"],["共同感觉","共同感覺"],["共同正犯","共同正犯"],["共同海损","共同海損"],["共同点","共同點"],["共同社","共同社"],["共同科目","共同科目"],["共同筛选","共同篩選"],["共同管道","共同管道"],["共同纲领","共同綱領"],["共同经营","共同經營"],["共同继承","共同繼承"],["共同被告人","共同被告人"],["共同诉讼","共同訴訟"],["共同语","共同語"],["共同财产","共同財產"],["共同财产制","共同財產制"],["共同趋向","共同趨向"],["共同运销","共同運銷"],["共同通讯社","共同通訊社"],["共同闸道介面","共同閘道介面"],["共和党","共和黨"],["共和党人","共和黨人"],["共和党籍","共和黨籍"],["共和制","共和制"],["共和历","共和曆"],["共和历史","共和歷史"],["共基极","共基極"],["共审制度","共審制度"],["共御外侮","共禦外侮"],["共挽鹿车","共挽鹿車"],["共摆","共擺"],["共游","共遊"],["共获","共獲"],["共轭不尽根","共軛不盡根"],["共轭双曲线","共軛雙曲線"],["共轭复数","共軛複數"],["共通意志","共通意志"],["共铲","共剷"],["共青团","共青團"],["共餐青年团","共餐青年團"],["关不了","關不了"],["关个","關個"],["关了","關了"],["关了钉儿","關了釘兒"],["关于","關於"],["关云长","關雲長"],["关出","關出"],["关台","關臺"],["关合","關合"],["关同","關同"],["关回","關回"],["关回去","關回去"],["关山万里","關山萬里"],["关岭布依族苗族自治县","關嶺布依族苗族自治縣"],["关岳","關岳"],["关弓与我确","關弓與我确"],["关征","關征"],["关念","關念"],["关怀面","關懷面"],["关注","關注"],["关注度","關注度"],["关税同盟","關稅同盟"],["关系","關係"],["关系人","關係人"],["关系代名词","關係代名詞"],["关系企业","關係企業"],["关系到","關係到"],["关系命题","關係命題"],["关系奖","關係獎"],["关系密切","關係密切"],["关系式","關係式"],["关系户","關係戶"],["关系法","關係法"],["关系着","關係着"],["关系融洽","關係融洽"],["关系词","關係詞"],["关系调","關係調"],["关系运算","關係運算"],["关系部","關係部"],["关节面","關節面"],["兴云作雨","興雲作雨"],["兴云作雾","興雲作霧"],["兴云吐雾","興雲吐霧"],["兴云布雨","興雲佈雨"],["兴云致雨","興雲致雨"],["兴会淋漓","興會淋漓"],["兴修","興修"],["兴冲冲","興沖沖"],["兴叹","興嘆"],["兴复","興復"],["兴复不浅","興復不淺"],["兴尽","興盡"],["兴尽悲来","興盡悲來"],["兴尽意阑","興盡意闌"],["兴旺发达","興旺發達"],["兴筑","興築"],["兴致","興致"],["兴致勃勃","興致勃勃"],["兴致勃发","興致勃發"],["兴致盎然","興致盎然"],["兴致索然","興致索然"],["兴隆台","興隆臺"],["兴隆台区","興隆臺區"],["兴高彩烈","興高彩烈"],["兴高采烈","興高采烈"],["兵出无名","兵出無名"],["兵制","兵制"],["兵器术","兵器術"],["兵团","兵團"],["兵尽器竭","兵盡器竭"],["兵尽矢穷","兵盡矢窮"],["兵工厂","兵工廠"],["兵工厂队","兵工廠隊"],["兵疲马困","兵疲馬困"],["兵种","兵種"],["兵籍表","兵籍表"],["兵马司倒了墙","兵馬司倒了牆"],["其从如云","其從如雲"],["其他支出","其他支出"],["其余","其餘"],["其八九只","其八九只"],["其势凶凶","其勢兇兇"],["其后","其後"],["其核","其核"],["其次辟地","其次辟地"],["具体计划","具體計劃"],["典借","典借"],["典制","典制"],["典型示范","典型示範"],["典当","典當"],["典据","典據"],["典章制度","典章制度"],["典范","典範"],["典范性","典範性"],["典范长存","典範長存"],["兹核","茲核"],["养了","養了"],["养儿待老积谷防饥","養兒待老積穀防饑"],["养儿防老积谷防饥","養兒防老積穀防飢"],["养兵千日","養兵千日"],["养兵千日用兵一时","養兵千日用兵一時"],["养兵千日用在一时","養兵千日用在一時"],["养兵千日用在一朝","養兵千日用在一朝"],["养军千日","養軍千日"],["养军千日用军一时","養軍千日用軍一時"],["养军千日用在一时","養軍千日用在一時"],["养军千日用在一朝","養軍千日用在一朝"],["养出","養出"],["养发","養髮"],["养娘","養娘"],["养婆娘","養婆娘"],["养子防老积谷防饥","養子防老積穀防飢"],["养家糊口","養家餬口"],["养小防老积谷防饥","養小防老積穀防饑"],["养志","養志"],["养性修真","養性修真"],["养老鼠咬布袋","養老鼠咬布袋"],["养颜有术","養顏有術"],["兼了","兼了"],["兼修","兼修"],["兼听则明偏信则暗","兼聽則明偏信則暗"],["兼容并包","兼容幷包"],["兼容并蓄","兼容幷蓄"],["兼并","兼併"],["兼并与收购","兼併與收購"],["兼收并蓄","兼收幷蓄"],["兼筹并顾","兼籌幷顧"],["兽医系","獸醫系"],["兽奸","獸姦"],["兽心人面","獸心人面"],["兽性大发","獸性大發"],["兽欲","獸慾"],["兽药","獸藥"],["内出血","內出血"],["内制","內製"],["内参","內參"],["内向","內向"],["内哄","內鬨"],["内在几何","內在幾何"],["内在几何学","內在幾何學"],["内塔尼亚胡","內塔尼亞胡"],["内奸","內奸"],["内容管理系统","內容管理系統"],["内布拉斯加","內布拉斯加"],["内布拉斯加州","內布拉斯加州"],["内忧外困","內憂外困"],["内扣","內扣"],["内斗","內鬥"],["内松外紧","內鬆外緊"],["内核","內核"],["内紧外松","內緊外鬆"],["内细胞团","內細胞團"],["内脏","內臟"],["内蒙","內蒙"],["内蒙古","內蒙古"],["内蒙古大学","內蒙古大學"],["内蒙古自治区","內蒙古自治區"],["内部斗争","內部鬥爭"],["内面包的","內面包的"],["冈田准","岡田准"],["冉冉上升","冉冉上升"],["冉有仆","冉有僕"],["冊叶","冊葉"],["再于","再於"],["再借","再借"],["再借不难","再借不難"],["再冲","再衝"],["再出","再出"],["再出去","再出去"],["再出来","再出來"],["再出现","再出現"],["再制","再製"],["再制品","再製品"],["再制盐","再製鹽"],["再制纸","再製紙"],["再发","再發"],["再发生","再發生"],["再发见","再發見"],["再向","再向"],["再回","再回"],["再回到","再回到"],["再回去","再回去"],["再回来","再回來"],["再干","再幹"],["再干一杯","再乾一杯"],["再念","再念"],["再斗一斗","再鬥一鬥"],["再来一个","再來一個"],["再生制动","再生制動"],["再生纤维","再生纖維"],["再种","再種"],["再见面","再見面"],["再转复","再轉復"],["再造手术","再造手術"],["再长爹娘","再長爹孃"],["冒了","冒了"],["冒儿咕冬","冒兒咕冬"],["冒出","冒出"],["冒出来","冒出來"],["冒升","冒升"],["冒烟","冒煙"],["冒烟突火","冒煙突火"],["冒镝当锋","冒鏑當鋒"],["冗余","冗餘"],["写不出","寫不出"],["写个","寫個"],["写了","寫了"],["写出","寫出"],["写出去","寫出去"],["写出来","寫出來"],["写回","寫回"],["写回去","寫回去"],["写回来","寫回來"],["写字台","寫字檯"],["写真合成海报","寫真合成海報"],["军事管制","軍事管制"],["军制","軍制"],["军品出口领导小组","軍品出口領導小組"],["军团","軍團"],["军团杆菌","軍團桿菌"],["军团菌","軍團菌"],["军团菌病","軍團菌病"],["军官团","軍官團"],["军政当局","軍政當局"],["军民合作","軍民合作"],["军种","軍種"],["军舰岩","軍艦岩"],["军阀割据","軍閥割據"],["军队克制","軍隊剋制"],["农业合作","農業合作"],["农业合作化","農業合作化"],["农业技术","農業技術"],["农业生产合作社","農業生產合作社"],["农业生产技术","農業生產技術"],["农产品平准基金","農產品平準基金"],["农作曲","農作曲"],["农作物品种","農作物品種"],["农化系","農化系"],["农历","農曆"],["农历年","農曆年"],["农历新年","農曆新年"],["农地重划","農地重劃"],["农复会","農復會"],["农奴制","農奴制"],["农奴制度","農奴制度"],["农家品种","農家品種"],["农庄","農莊"],["农技团","農技團"],["农机系","農機系"],["农村合作化","農村合作化"],["农村家庭联产承包责任制","農村家庭聯產承包責任制"],["农民党","農民黨"],["农民历","農民曆"],["农民历史","農民歷史"],["农民团体","農民團體"],["农经系","農經系"],["农舍","農舍"],["农艺系","農藝系"],["农药","農藥"],["农药商","農藥商"],["冠世之才","冠世之才"],["冠军杯","冠軍盃"],["冠子虫","冠子蟲"],["冠状动脉旁路移植手术","冠狀動脈旁路移植手術"],["冠状动脉旁通手术","冠狀動脈旁通手術"],["冠状动脉硬化症","冠狀動脈硬化症"],["冠盖云集","冠蓋雲集"],["冠盖如云","冠蓋如雲"],["冠胄","冠冑"],["冤仇","冤仇"],["冥凌","冥淩"],["冥凌浃行","冥淩浹行"],["冥子里","冥子裏"],["冥蒙","冥濛"],["冬不拉","冬不拉"],["冬事","冬事"],["冬令","冬令"],["冬令救济","冬令救濟"],["冬令进补","冬令進補"],["冬储","冬儲"],["冬冬","鼕鼕"],["冬冬鼓","鼕鼕鼓"],["冬凌","冬凌"],["冬初","冬初"],["冬夏","冬夏"],["冬天","冬天"],["冬天里","冬天裏"],["冬奥会","冬奧會"],["冬字头","冬字頭"],["冬季","冬季"],["冬季世界","冬季世界"],["冬季作物","冬季作物"],["冬季档","冬季檔"],["冬季节","冬季節"],["冬季赛","冬季賽"],["冬季运动","冬季運動"],["冬学","冬學"],["冬宫","冬宮"],["冬小麦","冬小麥"],["冬山","冬山"],["冬山乡","冬山鄉"],["冬山河","冬山河"],["冬心","冬心"],["冬扇夏炉","冬扇夏爐"],["冬日","冬日"],["冬日可爱","冬日可愛"],["冬日里","冬日裏"],["冬暖","冬暖"],["冬暖夏凉","冬暖夏涼"],["冬月","冬月"],["冬柴铁","冬柴鐵"],["冬温夏凊","冬溫夏凊"],["冬游","冬遊"],["冬灌","冬灌"],["冬烘","冬烘"],["冬烘先生","冬烘先生"],["冬狩","冬狩"],["冬瓜","冬瓜"],["冬瓜汤","冬瓜湯"],["冬瓜茶","冬瓜茶"],["冬眠","冬眠"],["冬眠期","冬眠期"],["冬笋","冬筍"],["冬粉","冬粉"],["冬耕","冬耕"],["冬至","冬至"],["冬至点","冬至點"],["冬节","冬節"],["冬菇","冬菇"],["冬藏","冬藏"],["冬虫夏草","冬蟲夏草"],["冬衣","冬衣"],["冬装","冬裝"],["冬赈","冬賑"],["冬运","冬運"],["冬运会","冬運會"],["冬闲","冬閒"],["冬防","冬防"],["冬雨","冬雨"],["冬雪","冬雪"],["冬雾","冬霧"],["冬青","冬青"],["冬青树","冬青樹"],["冬风","冬風"],["冬麦","冬麥"],["冯胜贤","馮勝賢"],["冯虚御风","馮虛御風"],["冯骥才","馮驥才"],["冰上曲棍球","冰上曲棍球"],["冰上表演","冰上表演"],["冰了","冰了"],["冰前刮雪","冰前颳雪"],["冰厂","冰廠"],["冰壶秋月","冰壺秋月"],["冰岩","冰岩"],["冰斗","冰斗"],["冰杯","冰杯"],["冰柜","冰櫃"],["冰核","冰核"],["冰火不同炉","冰火不同爐"],["冰炭不同器","冰炭不同器"],["冰炭不同罏","冰炭不同罏"],["冰生于水而寒于水","冰生於水而寒於水"],["冰碛岩","冰磧岩"],["冰雕","冰雕"],["冰雪皇后","冰雪皇后"],["冰面","冰面"],["冲上","衝上"],["冲上前","衝上前"],["冲上去","衝上去"],["冲上来","衝上來"],["冲下","衝下"],["冲下去","衝下去"],["冲下来","衝下來"],["冲不上","衝不上"],["冲不下","衝不下"],["冲不入","衝不入"],["冲不出","衝不出"],["冲不开","衝不開"],["冲不破","衝不破"],["冲不过","衝不過"],["冲不进","衝不進"],["冲了上","衝了上"],["冲了下","衝了下"],["冲了入","衝了入"],["冲了出","衝了出"],["冲了来","衝了來"],["冲了过","衝了過"],["冲了进","衝了進"],["冲人","沖人"],["冲他","衝他"],["冲你","衝你"],["冲倒","衝倒"],["冲克","沖剋"],["冲入","衝入"],["冲冠","衝冠"],["冲冠发怒","衝冠髮怒"],["冲冲","沖沖"],["冲冲水","沖沖水"],["冲决","沖決"],["冲决堤防","沖決堤防"],["冲凉","沖涼"],["冲出","衝出"],["冲出去","衝出去"],["冲出来","衝出來"],["冲出重围","衝出重圍"],["冲击","衝擊"],["冲击力","衝擊力"],["冲击性","衝擊性"],["冲击波","衝擊波"],["冲击韧性","衝擊韌性"],["冲到","衝到"],["冲刷","沖刷"],["冲刺","衝刺"],["冲刺班","衝刺班"],["冲剂","沖劑"],["冲力","衝力"],["冲动","衝動"],["冲动型","衝動型"],["冲劲","衝勁"],["冲劲十足","衝勁十足"],["冲势","衝勢"],["冲印","沖印"],["冲压","衝壓"],["冲压机","衝壓機"],["冲厕所","沖廁所"],["冲去","衝去"],["冲口而出","衝口而出"],["冲口而发","衝口而發"],["冲向","衝向"],["冲向前","衝向前"],["冲和","沖和"],["冲喜","沖喜"],["冲回","衝回"],["冲回去","衝回去"],["冲在下","衝在下"],["冲在前","衝在前"],["冲在最前","衝在最前"],["冲坏","沖壞"],["冲坚陷阵","衝堅陷陣"],["冲垮","沖垮","衝垮"],["冲堂","衝堂"],["冲塌","沖塌"],["冲天","沖天"],["冲天之怒","沖天之怒"],["冲天炉","沖天爐"],["冲天炮","沖天炮"],["冲头阵","衝頭陣"],["冲她","衝她"],["冲子","衝子"],["冲州撞府","衝州撞府"],["冲帐","沖帳"],["冲年","沖年"],["冲床","衝牀"],["冲开","衝開"],["冲弱","沖弱"],["冲得入","衝得入"],["冲得出","衝得出"],["冲得过","衝得過"],["冲得进","衝得進"],["冲心","衝心"],["冲怀","沖懷"],["冲我","衝我"],["冲扩","沖擴"],["冲掉","沖掉"],["冲撞","衝撞"],["冲撞力","衝撞力"],["冲散","衝散"],["冲断","沖斷"],["冲断层","衝斷層"],["冲昏","衝昏"],["冲昏头脑","衝昏頭腦"],["冲昧","沖昧"],["冲服","沖服"],["冲服剂","沖服劑"],["冲末","沖末"],["冲杀","衝殺"],["冲来","衝來"],["冲来冲去","衝來衝去"],["冲模","沖模"],["冲毁","沖毀"],["冲水","沖水"],["冲沟","沖溝"],["冲泡","沖泡"],["冲泡式","沖泡式"],["冲波","衝波"],["冲波激浪","衝波激浪"],["冲波逆折","衝波逆折"],["冲泻","沖瀉"],["冲洗","沖洗"],["冲洗照片","沖洗照片"],["冲流","沖流"],["冲浪","衝浪"],["冲浪客","衝浪客"],["冲浪板","衝浪板"],["冲浪者","衝浪者"],["冲浪赛","衝浪賽"],["冲涤","沖滌"],["冲淋浴","沖淋浴"],["冲淡","沖淡"],["冲澡","沖澡"],["冲然","衝然"],["冲牀工","沖牀工"],["冲犯","衝犯"],["冲田","沖田"],["冲盹","衝盹"],["冲盹儿","衝盹兒"],["冲着","衝着"],["冲破","衝破"],["冲积","沖積"],["冲积土","沖積土"],["冲积堤","沖積堤"],["冲积层","沖積層"],["冲积岛","沖積島"],["冲积平原","沖積平原"],["冲积扇","沖積扇"],["冲积物","沖積物"],["冲程","衝程"],["冲税","沖稅"],["冲穴","衝穴"],["冲空机","沖空機"],["冲突","衝突"],["冲突区","衝突區"],["冲突性","衝突性"],["冲突点","衝突點"],["冲线","衝線"],["冲绳","沖繩"],["冲绳县","沖繩縣"],["冲绳岛","沖繩島"],["冲绳群岛","沖繩羣島"],["冲脉","衝脈"],["冲自己","衝自己"],["冲至","衝至"],["冲茶","沖茶"],["冲虚","沖虛"],["冲虚真人","沖虛真人"],["冲虚真经","沖虛真經"],["冲蚀","沖蝕"],["冲襟","沖襟"],["冲要","衝要"],["冲走","沖走"],["冲起","衝起"],["冲起来","衝起來"],["冲车","衝車"],["冲过","衝過"],["冲过去","衝過去"],["冲过来","衝過來"],["冲进","衝進"],["冲进去","衝進去"],["冲进来","衝進來"],["冲退","衝退"],["冲量","衝量"],["冲销","沖銷"],["冲锋","衝鋒"],["冲锋号","衝鋒號"],["冲锋枪","衝鋒槍"],["冲锋鎗","衝鋒鎗"],["冲锋陷阵","衝鋒陷陣"],["冲门","衝門"],["冲陷","衝陷"],["冲霄","沖霄"],["冲霄汉外","沖霄漢外"],["冲风","衝風"],["冲高","衝高"],["冲默","沖默"],["冲鼻","沖鼻"],["冲龄","沖齡"],["决了","決了"],["决定出","決定出"],["决心干","決心幹"],["决志","決志"],["决斗","決鬥"],["决斗者","決鬥者"],["决策千里","決策千里"],["决策当局","決策當局"],["决胜","決勝"],["决胜千里","決勝千里"],["决胜局","決勝局"],["决胜期","決勝期"],["决胜点","決勝點"],["决胜盘","決勝盤"],["决胜节","決勝節"],["决胜负","決勝負"],["冶叶倡条","冶葉倡條"],["冶游","冶遊"],["冶炼","冶煉"],["冶炼厂","冶煉廠"],["冶炼炉","冶煉爐"],["冶荡","冶蕩"],["冷冻柜","冷凍櫃"],["冷地里","冷地里"],["冷布","冷布"],["冷心冷面","冷心冷面"],["冷感症","冷感症"],["冷战以后","冷戰以後"],["冷板凳","冷板凳"],["冷板曲","冷板曲"],["冷气团","冷氣團"],["冷淡关系","冷淡關係"],["冷灰里爆出火来","冷灰裏爆出火來"],["冷腌法","冷醃法"],["冷藏柜","冷藏櫃"],["冷读术","冷讀術"],["冷轧钢板","冷軋鋼板"],["冷酒儿后犯","冷酒兒後犯"],["冷锅里爆豆","冷鍋裏爆豆"],["冷面","冷麪","冷面"],["冷面冷心","冷面冷心"],["冷面相","冷面相"],["冻僵","凍僵"],["净余","淨餘"],["净发","淨髮"],["净尽","淨盡"],["净心修身","淨心修身"],["凄丽","悽麗"],["凄冷","淒冷"],["凄凄","悽悽"],["凄凉","淒涼"],["凄切","悽切"],["凄历","悽歷"],["凄厉","淒厲"],["凄咽","悽咽"],["凄婉","悽婉"],["凄寒","淒寒"],["凄怆","悽愴"],["凄怨","悽怨"],["凄恻","悽惻"],["凄惨","悽慘"],["凄惶","悽惶"],["凄楚","悽楚"],["凄沧","淒滄"],["凄清","悽清"],["凄然","悽然"],["凄紧","悽緊"],["凄绝","悽絕"],["凄美","悽美"],["凄艳","悽豔"],["凄苦","悽苦"],["凄迷","悽迷"],["凄酸","悽酸"],["凄雨","淒雨"],["凄风","悽風"],["准三后","准三后"],["准不准","準不準"],["准不准他","准不准他"],["准不准你","准不准你"],["准不准备","準不準備"],["准不准她","准不准她"],["准不准它","准不准它"],["准不准我","准不准我"],["准不准确","準不準確"],["准不准许","准不准許"],["准不准谁","准不准誰"],["准予","准予"],["准以","准以"],["准伏","准伏"],["准会","準會"],["准例","準例"],["准保","準保"],["准保护","准保護"],["准保释","准保釋"],["准信","準信"],["准假","准假"],["准儿","準兒"],["准入","准入"],["准决斗","准決鬥"],["准决赛","準決賽"],["准分子","準分子"],["准分子雷射仪","準分子雷射儀"],["准则","準則"],["准噶尔","準噶爾"],["准噶尔盆地","準噶爾盆地"],["准噶尔翼龙","準噶爾翼龍"],["准备","準備"],["准备下","準備下"],["准备充分","準備充分"],["准备准备","準備準備"],["准备好","準備好"],["准备好了","準備好了"],["准备好的","準備好的"],["准备活动","準備活動"],["准备率","準備率"],["准备给","準備給"],["准备金","準備金"],["准备金率","準備金率"],["准头","準頭"],["准奏","准奏"],["准妈妈","準媽媽"],["准定","準定"],["准将","准將"],["准尉","准尉"],["准平原","準平原"],["准度","準度"],["准式","準式"],["准得","準得"],["准折","准折"],["准拟","準擬"],["准拿督","準拿督"],["准据","準據"],["准新娘","準新娘"],["准新郎","準新郎"],["准时","準時"],["准时出席","準時出席"],["准时到","準時到"],["准时到达","準時到達"],["准星","準星"],["准是","準是"],["准普尔","准普爾"],["准格尔","準格爾"],["准格尔盆地","準格爾盆地"],["准此","准此"],["准決賽","準決賽"],["准点","準點"],["准点率","準點率"],["准用","準用"],["准的","準的"],["准确","準確"],["准确度","準確度"],["准确性","準確性"],["准确无误","準確無誤"],["准确率","準確率"],["准稳旋涡结构","準穩旋渦結構"],["准算","准算"],["准线","準線"],["准绳","準繩"],["准考证","准考證"],["准葛尔盆地","準葛爾盆地"],["准许","准許"],["准话","準話"],["准谱","準譜"],["准谱儿","準譜兒"],["准货币","準貨幣"],["准错不了","準錯不了"],["凉了","涼了"],["凉了半截","涼了半截"],["凉台","涼臺"],["凉席","涼蓆"],["凉药","涼藥"],["凉面","涼麪"],["凌云","凌雲"],["凌云健笔","凌雲健筆"],["凌云县","凌雲縣"],["凌云壮志","凌雲壯志"],["凌云翰","淩云翰"],["凌借","凌藉"],["凌十八","淩十八"],["凌如焕","淩如焕"],["凌姓","淩姓"],["凌小姐","淩小姐"],["凌志","凌志"],["凌志美","淩志美"],["凌惠平","淩惠平"],["凌昌焕","淩昌焕"],["凌氏","淩氏"],["凌氏惠平","淩氏惠平"],["凌水","淩水"],["凌河","淩河"],["凌烟阁","凌煙閣"],["凌策","淩策"],["凌统","淩統"],["凌蒙初","淩濛初"],["凌退思","淩退思"],["凌驰","淩馳"],["减个","減個"],["减了","減了"],["减价","減價"],["减价出售","減價出售"],["减价时间","減價時間"],["减压时间表","減壓時間表"],["减压症","減壓症"],["减压表","減壓表"],["减噪","減噪"],["减征","減徵"],["减肥药","減肥藥"],["凑不出来","湊不出來"],["凑出","湊出"],["凑合","湊合"],["凑合着","湊合着"],["凑四合六","湊四合六"],["凛栗","凜慄"],["凝合","凝合"],["凝合力","凝合力"],["凝咽","凝咽"],["凝灰岩","凝灰岩"],["凝炼","凝鍊"],["几丁质","幾丁質"],["几万","幾萬"],["几万个","幾萬個"],["几万人","幾萬人"],["几万元","幾萬元"],["几万块","幾萬塊"],["几上","几上"],["几下","幾下"],["几世","幾世"],["几世纪","幾世紀"],["几丝","幾絲"],["几两","幾兩"],["几个","幾個"],["几个人","幾個人"],["几个月","幾個月"],["几为所害","幾爲所害"],["几乎","幾乎"],["几乎不","幾乎不"],["几乎不可能","幾乎不可能"],["几乎在","幾乎在"],["几乎完全","幾乎完全"],["几乎是","幾乎是"],["几乎没有","幾乎沒有"],["几事","幾事"],["几于","幾於"],["几人","幾人"],["几人份","幾人份"],["几亿","幾億"],["几付","幾付"],["几代","幾代"],["几令","幾令"],["几件","幾件"],["几件事","幾件事"],["几任","幾任"],["几份","幾份"],["几伍","幾伍"],["几众","幾衆"],["几位","幾位"],["几位数","幾位數"],["几何","幾何"],["几何体","幾何體"],["几何光学","幾何光學"],["几何原本","幾何原本"],["几何图形","幾何圖形"],["几何图案","幾何圖案"],["几何学","幾何學"],["几何拓扑","幾何拓撲"],["几何拓扑学","幾何拓撲學"],["几何级数","幾何級數"],["几何线","幾何線"],["几何量","幾何量"],["几倍","幾倍"],["几儿","幾兒"],["几儿个","幾兒個"],["几元","幾元"],["几克","幾克"],["几党","幾黨"],["几內亚","幾內亞"],["几內亚共和国","幾內亞共和國"],["几內亚比索","幾內亞比索"],["几內亚比索共和国","幾內亞比索共和國"],["几內亚比绍","幾內亞比紹"],["几內亚湾","幾內亞灣"],["几关","幾關"],["几具","幾具"],["几内亚","幾內亞"],["几内亚比绍","幾內亞比紹"],["几内亚湾","幾內亞灣"],["几冊","幾冊"],["几净窗明","几淨窗明"],["几几","几几"],["几几乎乎","幾幾乎乎"],["几凳","几凳"],["几出","幾齣"],["几刀","幾刀"],["几分","幾分"],["几分之几","幾分之幾"],["几分收获","幾分收穫"],["几分钟","幾分鐘"],["几划","幾劃"],["几列","幾列"],["几副","幾副"],["几动","幾動"],["几化","幾化"],["几匹","幾匹"],["几匹马","幾匹馬"],["几区","幾區"],["几十","幾十"],["几十万","幾十萬"],["几十个","幾十個"],["几十人","幾十人"],["几十亿","幾十億"],["几十年","幾十年"],["几千","幾千"],["几千万","幾千萬"],["几千个","幾千個"],["几千人","幾千人"],["几千元","幾千元"],["几千块","幾千塊"],["几千年","幾千年"],["几发","幾發"],["几句","幾句"],["几句话","幾句話"],["几只","幾隻"],["几可乱真","幾可亂真"],["几台","幾臺"],["几号","幾號"],["几吋","幾吋"],["几名","幾名"],["几员","幾員"],["几回","幾回"],["几回价","幾回價"],["几因","幾因"],["几团","幾團"],["几国","幾國"],["几圆","幾圓"],["几圈","幾圈"],["几场","幾場"],["几块","幾塊"],["几块钱","幾塊錢"],["几垒","幾壘"],["几声","幾聲"],["几处","幾處"],["几多","幾多"],["几大","幾大"],["几大块","幾大塊"],["几大片","幾大片"],["几大类","幾大類"],["几天","幾天"],["几天后","幾天後"],["几天来","幾天來"],["几头","幾頭"],["几子","几子"],["几孔","幾孔"],["几字","幾字"],["几季","幾季"],["几客","幾客"],["几家","幾家"],["几家欢乐","幾家歡樂"],["几家欢乐几家愁","幾家歡樂幾家愁"],["几寸","幾寸"],["几封","幾封"],["几封信","幾封信"],["几小时","幾小時"],["几尾","幾尾"],["几局","幾局"],["几层","幾層"],["几层楼","幾層樓"],["几届","幾屆"],["几岁","幾歲"],["几巷","幾巷"],["几师","幾師"],["几希","幾希"],["几席","几席"],["几幅","幾幅"],["几年","幾年"],["几年几班","幾年幾班"],["几年来","幾年來"],["几年生","幾年生"],["几年级","幾年級"],["几床","幾牀"],["几度","幾度"],["几度春风","幾度春風"],["几座","幾座"],["几开","幾開"],["几弄","幾弄"],["几张","幾張"],["几弹","幾彈"],["几微","幾微"],["几成","幾成"],["几成新","幾成新"],["几截","幾截"],["几户","幾戶"],["几所","幾所"],["几手","幾手"],["几打","幾打"],["几批","幾批"],["几拳","幾拳"],["几支","幾支"],["几文钱","幾文錢"],["几斤","幾斤"],["几斤几两","幾斤幾兩"],["几旁","几旁"],["几旅","幾旅"],["几日","幾日"],["几日份","幾日份"],["几时","幾時"],["几星","幾星"],["几星期","幾星期"],["几晚","幾晚"],["几曾","幾曾"],["几月","幾月"],["几月份","幾月份"],["几期","幾期"],["几本","幾本"],["几本书","幾本書"],["几杆","幾桿"],["几杖","几杖"],["几杯","幾杯"],["几板","幾板"],["几枚","幾枚"],["几枝","幾枝"],["几枪","幾槍"],["几架","幾架"],["几栋","幾棟"],["几株","幾株"],["几样","幾樣"],["几格","幾格"],["几案","几案"],["几案之才","几案之才"],["几档","幾檔"],["几桶","幾桶"],["几梯次","幾梯次"],["几棵","幾棵"],["几椅","几椅"],["几楼","幾樓"],["几榻","几榻"],["几次","幾次"],["几次三番","幾次三番"],["几欲","幾欲"],["几步","幾步"],["几殆","幾殆"],["几段","幾段"],["几比几","幾比幾"],["几毛","幾毛"],["几毛钱","幾毛錢"],["几洞","幾洞"],["几滴","幾滴"],["几滴水","幾滴水"],["几炷香","幾炷香"],["几点","幾點"],["几点了","幾點了"],["几点几","幾點幾"],["几点钟","幾點鐘"],["几版","幾版"],["几率","機率"],["几环","幾環"],["几班","幾班"],["几番","幾番"],["几番家","幾番家"],["几百","幾百"],["几百万","幾百萬"],["几百个","幾百個"],["几百人","幾百人"],["几百亿","幾百億"],["几百元","幾百元"],["几百块","幾百塊"],["几百年","幾百年"],["几盏","幾盞"],["几盒","幾盒"],["几盒装","幾盒裝"],["几眼","幾眼"],["几碗","幾碗"],["几碗饭","幾碗飯"],["几社","幾社"],["几票","幾票"],["几种","幾種"],["几科","幾科"],["几秒","幾秒"],["几秒钟","幾秒鐘"],["几稀","幾稀"],["几窝","幾窩"],["几站","幾站"],["几章","幾章"],["几竿","幾竿"],["几笔","幾筆"],["几笼","幾籠"],["几筒","幾筒"],["几筵","几筵"],["几箱","幾箱"],["几米","幾米"],["几类","幾類"],["几粒","幾粒"],["几级","幾級"],["几线","幾線"],["几组","幾組"],["几经","幾經"],["几缕","幾縷"],["几罐","幾罐"],["几股","幾股"],["几胎","幾胎"],["几能","幾能"],["几能勾","幾能勾"],["几脚","幾腳"],["几至","幾至"],["几般","幾般"],["几节","幾節"],["几节课","幾節課"],["几街","幾街"],["几袋","幾袋"],["几角","幾角"],["几角形","幾角形"],["几许","幾許"],["几课","幾課"],["几谏","幾諫"],["几起","幾起"],["几趟","幾趟"],["几趟路","幾趟路"],["几路","幾路"],["几车","幾車"],["几转","幾轉"],["几辆","幾輛"],["几辆车","幾輛車"],["几近","幾近"],["几近于","幾近於"],["几通","幾通"],["几道","幾道"],["几道菜","幾道菜"],["几部","幾部"],["几针","幾針"],["几门","幾門"],["几间","幾間"],["几集","幾集"],["几面上","几面上"],["几页","幾頁"],["几顶","幾頂"],["几项","幾項"],["几顿","幾頓"],["几颗","幾顆"],["几题","幾題"],["几首","幾首"],["几首歌","幾首歌"],["凡事总有一个开头","凡事總有一個開頭"],["凡于","凡於"],["凡才","凡才"],["凡此种种","凡此種種"],["凡须","凡須"],["凤凰于蜚","鳳凰于蜚"],["凤凰于飞","鳳凰于飛"],["凤凰台","鳳凰臺"],["凤占","鳳占"],["凤去台空","鳳去臺空"],["凤台","鳳台"],["凤台县","鳳臺縣"],["凤尾松","鳳尾松"],["凤梨干","鳳梨乾"],["凤皇于蜚","鳳皇于蜚"],["凭借","憑藉"],["凭借着","憑藉着"],["凭准","憑準"],["凭几","憑几"],["凭吊","憑弔"],["凭媒说合","憑媒說合"],["凭折","憑摺"],["凭据","憑據"],["凭空出现","憑空出現"],["凭虚御风","憑虛御風"],["凭闲","憑閑"],["凯复","凱復"],["凯特布兰琪","凱特布蘭琪"],["凯迪拉克","凱迪拉克"],["凯里","凱里"],["凯里市","凱裏市"],["凶事","凶事"],["凶人","兇人"],["凶仪","兇儀"],["凶侠","兇俠"],["凶信","凶信"],["凶兆","凶兆"],["凶党","兇黨"],["凶具","兇具"],["凶凶","兇兇"],["凶凶恶恶","兇兇惡惡"],["凶凶狠狠","兇兇狠狠"],["凶刀","兇刀"],["凶器","兇器"],["凶地","凶地"],["凶多吉少","凶多吉少"],["凶嫌","兇嫌"],["凶宅","凶宅"],["凶岁","凶歲"],["凶巴巴","兇巴巴"],["凶年","凶年"],["凶年饥岁","凶年饑歲"],["凶徒","兇徒"],["凶得","兇得"],["凶得狠","兇得狠"],["凶德","凶德"],["凶怪","凶怪"],["凶恶","兇惡"],["凶悍","兇悍"],["凶惧","兇懼"],["凶手","兇手"],["凶日","凶日"],["凶暴","兇暴"],["凶服","凶服"],["凶杀","兇殺"],["凶杀案","兇殺案"],["凶枪","兇槍"],["凶案","兇案"],["凶横","兇橫"],["凶死","凶死"],["凶残","兇殘"],["凶殘","兇殘"],["凶殴","兇毆"],["凶殺","兇殺"],["凶气","凶氣"],["凶焰","兇焰"],["凶煞","凶煞"],["凶燄","凶燄"],["凶犯","兇犯"],["凶狂","兇狂"],["凶狠","兇狠"],["凶猛","兇猛"],["凶疑","兇疑"],["凶相","兇相"],["凶相毕露","兇相畢露"],["凶礼","凶禮"],["凶神","凶神"],["凶神恶煞","凶神惡煞"],["凶神附体","凶神附體"],["凶竖","凶豎"],["凶终隙末","凶終隙末"],["凶耗","凶耗"],["凶肆","凶肆"],["凶荒","凶荒"],["凶虐","兇虐"],["凶讯","凶訊"],["凶起来","兇起來"],["凶身","凶身"],["凶逆","凶逆"],["凶门","凶門"],["凶险","兇險"],["凶顽","兇頑"],["凸出","凸出"],["凸出去","凸出去"],["凸出成","凸出成"],["凸出来","凸出來"],["凸多面体","凸多面體"],["凸折线","凸折線"],["凸显出","凸顯出"],["凸显出来","凸顯出來"],["凸板印刷","凸板印刷"],["凸面","凸面"],["凸面体","凸面體"],["凸面部分","凸面部分"],["凸面镜","凸面鏡"],["凹凸有致","凹凸有致"],["凹板","凹板"],["凹洞里","凹洞裏"],["凹雕","凹雕"],["凹面","凹面"],["凹面镜","凹面鏡"],["出一回神","出一回神"],["出上","出上"],["出下","出下"],["出不起","出不起"],["出丑","出醜"],["出丑扬疾","出醜揚疾"],["出丑狼借","出醜狼藉"],["出世","出世"],["出世作","出世作"],["出世法","出世法"],["出丧","出喪"],["出个","出個"],["出个价","出個價"],["出主意","出主意"],["出乎","出乎"],["出乎寻常","出乎尋常"],["出乎意外","出乎意外"],["出乎意料","出乎意料"],["出乎预料","出乎預料"],["出乖弄丑","出乖弄醜"],["出乖露丑","出乖露醜"],["出乘","出乘"],["出书","出書"],["出乱子","出亂子"],["出了","出了"],["出了事","出了事"],["出了月","出了月"],["出事","出事"],["出事情","出事情"],["出于","出於"],["出云","出雲"],["出亡","出亡"],["出产","出產"],["出产地","出產地"],["出人","出人"],["出人命","出人命"],["出人头地","出人頭地"],["出人意外","出人意外"],["出人意料","出人意料"],["出人意料之外","出人意料之外"],["出人意表","出人意表"],["出仕","出仕"],["出价","出價"],["出任","出任"],["出份子","出份子"],["出伏","出伏"],["出众","出衆"],["出伦之才","出倫之才"],["出使","出使"],["出倒","出倒"],["出借","出借"],["出借书","出借書"],["出儿","齣兒"],["出入","出入"],["出入口","出入口"],["出入境","出入境"],["出入将相","出入將相"],["出入平安","出入平安"],["出入相随","出入相隨"],["出入証","出入証"],["出入证","出入證"],["出入门","出入門"],["出公差","出公差"],["出关","出關"],["出兵","出兵"],["出其不备","出其不備"],["出其不意","出其不意"],["出其不意攻其不备","出其不意攻其不備"],["出其东门","出其東門"],["出其右","出其右"],["出具","出具"],["出典","出典"],["出军","出軍"],["出冷门","出冷門"],["出出","出出"],["出出气","出出氣"],["出出进进","出出進進"],["出击","出擊"],["出分子","出分子"],["出刊","出刊"],["出列","出列"],["出到","出到"],["出力","出力"],["出动","出動"],["出勤","出勤"],["出勤率","出勤率"],["出卖","出賣"],["出卖灵魂","出賣靈魂"],["出厂","出廠"],["出厂价","出廠價"],["出厂价格","出廠價格"],["出去","出去"],["出去会","出去會"],["出去时","出去時"],["出去玩","出去玩"],["出双入对","出雙入對"],["出发","出發"],["出发到","出發到"],["出发地","出發地"],["出发日","出發日"],["出发点","出發點"],["出口","出口"],["出口产品","出口產品"],["出口伤人","出口傷人"],["出口值","出口值"],["出口入耳","出口入耳"],["出口到","出口到"],["出口区","出口區"],["出口商","出口商"],["出口商品","出口商品"],["出口国","出口國"],["出口处","出口處"],["出口导向","出口導向"],["出口成章","出口成章"],["出口税","出口稅"],["出口调查","出口調查"],["出口货","出口貨"],["出口贸易","出口貿易"],["出口量","出口量"],["出口额","出口額"],["出台","出臺"],["出号","出號"],["出名","出名"],["出品","出品"],["出品人","出品人"],["出品国","出品國"],["出售","出售"],["出售一空","出售一空"],["出售给","出售給"],["出唱片","出唱片"],["出喽子","出嘍子"],["出团","出團"],["出国","出國"],["出国前","出國前"],["出国时","出國時"],["出国者","出國者"],["出圈","出圈"],["出圈儿","出圈兒"],["出土","出土"],["出土文物","出土文物"],["出土物","出土物"],["出在","出在"],["出场","出場"],["出场费","出場費"],["出埃及记","出埃及記"],["出城","出城"],["出堂","出堂"],["出塞","出塞"],["出境","出境"],["出境检查","出境檢查"],["出境签证","出境簽證"],["出境証","出境証"],["出境证","出境證"],["出声","出聲"],["出处","出處"],["出处不如聚处","出處不如聚處"],["出外","出外"],["出外人","出外人"],["出外景","出外景"],["出大差","出大差"],["出大恭","出大恭"],["出太阳","出太陽"],["出头","出頭"],["出头之日","出頭之日"],["出头天","出頭天"],["出头日子","出頭日子"],["出头棍","出頭棍"],["出头椽儿先朽烂","出頭椽兒先朽爛"],["出头露角","出頭露角"],["出头露面","出頭露面"],["出头鸟","出頭鳥"],["出奇","出奇"],["出奇不意","出奇不意"],["出奇制胜","出奇制勝"],["出奔","出奔"],["出好","出好"],["出妇","出婦"],["出妻","出妻"],["出姓","出姓"],["出娄子","出婁子"],["出嫁","出嫁"],["出完","出完"],["出官","出官"],["出定","出定"],["出宰","出宰"],["出家","出家"],["出家人","出家人"],["出家人吃八方","出家人吃八方"],["出将入相","出將入相"],["出小恭","出小恭"],["出尔反尔","出爾反爾"],["出尖","出尖"],["出尖儿","出尖兒"],["出尘","出塵"],["出尽","出盡"],["出局","出局"],["出局数","出局數"],["出山","出山"],["出岔","出岔"],["出岔儿","出岔兒"],["出岔子","出岔子"],["出巡","出巡"],["出工","出工"],["出差","出差"],["出差费","出差費"],["出差错","出差錯"],["出师","出師"],["出师不利","出師不利"],["出师表","出師表"],["出席","出席"],["出席率","出席率"],["出席者","出席者"],["出席表决比例","出席表決比例"],["出席费","出席費"],["出幼","出幼"],["出店","出店"],["出庭","出庭"],["出庭作证","出庭作證"],["出庭应讯","出庭應訊"],["出彩","出彩"],["出征","出征"],["出征收","出徵收"],["出得","出得"],["出心","出心"],["出恭","出恭"],["出息","出息"],["出意外","出意外"],["出戏","齣戲"],["出战","出戰"],["出户","出戶"],["出手","出手"],["出手得卢","出手得盧"],["出手见高低","出手見高低"],["出把戏","出把戲"],["出招","出招"],["出拳","出拳"],["出挑","出挑"],["出掌","出掌"],["出操","出操"],["出操课","出操課"],["出故典","出故典"],["出教","出教"],["出数儿","出數兒"],["出文","出文"],["出斩","出斬"],["出新","出新"],["出景","出景"],["出月","出月"],["出月子","出月子"],["出有","出有"],["出有入无","出有入無"],["出材","出材"],["出条子","出條子"],["出来","出來"],["出来时","出來時"],["出校","出校"],["出格","出格"],["出梅","出梅"],["出楼子","出樓子"],["出榜","出榜"],["出橐","出橐"],["出此下策","出此下策"],["出死入生","出死入生"],["出殃","出殃"],["出殡","出殯"],["出殡日","出殯日"],["出毛病","出毛病"],["出气","出氣"],["出气口","出氣口"],["出气多进气少","出氣多進氣少"],["出气筒","出氣筒"],["出水","出水"],["出水伙计","出水夥計"],["出水口","出水口"],["出水管","出水管"],["出水芙蓉","出水芙蓉"],["出汗","出汗"],["出汙泥而不染","出污泥而不染"],["出江","出江"],["出没","出沒"],["出没不定","出沒不定"],["出没无常","出沒無常"],["出油","出油"],["出注","出注"],["出洋","出洋"],["出洋相","出洋相"],["出活","出活"],["出浴","出浴"],["出海","出海"],["出海口","出海口"],["出海打鱼","出海打魚"],["出海捕鱼","出海捕魚"],["出涕","出涕"],["出淤泥而不染","出淤泥而不染"],["出清","出清"],["出港","出港"],["出港大厅","出港大廳"],["出港证","出港證"],["出游","出遊"],["出溜","出溜"],["出溜儿","出溜兒"],["出漏子","出漏子"],["出演","出演"],["出火","出火"],["出火炕","出火炕"],["出炉","出爐"],["出点","出點"],["出点子","出點子"],["出热","出熱"],["出片","出片"],["出版","出版"],["出版业","出版業"],["出版业务","出版業務"],["出版人","出版人"],["出版前编目","出版前編目"],["出版品","出版品"],["出版品奖","出版品獎"],["出版商","出版商"],["出版地缺","出版地缺"],["出版所","出版所"],["出版日","出版日"],["出版日期","出版日期"],["出版期缺","出版期缺"],["出版法","出版法"],["出版物","出版物"],["出版界","出版界"],["出版社","出版社"],["出版社不详","出版社不詳"],["出版社丛集","出版社叢集"],["出版社清样","出版社清樣"],["出版社目录卡","出版社目錄卡"],["出版社装祯","出版社裝禎"],["出版者","出版者"],["出版自由","出版自由"],["出版节","出版節"],["出版项","出版項"],["出牌","出牌"],["出状况","出狀況"],["出狱","出獄"],["出猎","出獵"],["出现","出現"],["出现意外","出現意外"],["出现数","出現數"],["出球","出球"],["出生","出生"],["出生入死","出生入死"],["出生别","出生別"],["出生地","出生地"],["出生地点","出生地點"],["出生年","出生年"],["出生日","出生日"],["出生日期","出生日期"],["出生牙","出生牙"],["出生率","出生率"],["出生纸","出生紙"],["出生缺陷","出生缺陷"],["出生证","出生證"],["出界","出界"],["出疹子","出疹子"],["出的","出的"],["出监","出監"],["出盘","出盤"],["出示","出示"],["出示证件","出示證件"],["出社会","出社會"],["出神","出神"],["出神入化","出神入化"],["出票","出票"],["出科","出科"],["出租","出租"],["出租人","出租人"],["出租店","出租店"],["出租汽车","出租汽車"],["出租率","出租率"],["出租给","出租給"],["出租车","出租車"],["出稿","出稿"],["出窍","出竅"],["出窝老","出窩老"],["出站","出站"],["出笏","出笏"],["出笼","出籠"],["出笼鸟","出籠鳥"],["出籍","出籍"],["出类拔群","出類拔羣"],["出类拔萃","出類拔萃"],["出类超群","出類超羣"],["出粗","出粗"],["出粜","出糶"],["出粮","出糧"],["出糗","出糗"],["出红差","出紅差"],["出纳","出納"],["出纳台","出納臺"],["出纳员","出納員"],["出纳处","出納處"],["出纳科","出納科"],["出纳系统","出納系統"],["出纳组","出納組"],["出线","出線"],["出结","出結"],["出给","出給"],["出继","出繼"],["出缺","出缺"],["出群","出羣"],["出群拔萃","出羣拔萃"],["出老千","出老千"],["出脱","出脫"],["出自","出自"],["出自于","出自於"],["出自娘胎","出自孃胎"],["出自肺腑","出自肺腑"],["出臭子儿","出臭子兒"],["出航","出航"],["出色","出色"],["出花儿","出花兒"],["出花样","出花樣"],["出芽","出芽"],["出芽法","出芽法"],["出芽生殖","出芽生殖"],["出苗","出苗"],["出苗率","出苗率"],["出草","出草"],["出落","出落"],["出虚恭","出虛恭"],["出蛰","出蟄"],["出血","出血"],["出血性","出血性"],["出血性登革热","出血性登革熱"],["出血热","出血熱"],["出血病","出血病"],["出血筒子","出血筒子"],["出血量","出血量"],["出行","出行"],["出言","出言"],["出言不逊","出言不遜"],["出言成章","出言成章"],["出言无状","出言無狀"],["出言有序","出言有序"],["出警入跸","出警入蹕"],["出让","出讓"],["出记","出記"],["出访","出訪"],["出诉","出訴"],["出诊","出診"],["出调","出調"],["出谋划策","出謀劃策"],["出谋献策","出謀獻策"],["出谷迁乔","出谷遷喬"],["出豁","出豁"],["出货","出貨"],["出货单","出貨單"],["出货量","出貨量"],["出费","出費"],["出资","出資"],["出资人","出資人"],["出赘","出贅"],["出赛","出賽"],["出走","出走"],["出起","出起"],["出起来","出起來"],["出超","出超"],["出超国","出超國"],["出超额","出超額"],["出路","出路"],["出跳","出跳"],["出身","出身"],["出车","出車"],["出车祸","出車禍"],["出轨","出軌"],["出轨行为","出軌行爲"],["出过","出過"],["出迎","出迎"],["出进口","出進口"],["出远门","出遠門"],["出逃","出逃"],["出道","出道"],["出道时","出道時"],["出量","出量"],["出金","出金"],["出钱","出錢"],["出钱出力","出錢出力"],["出铁","出鐵"],["出锋头","出鋒頭"],["出错","出錯"],["出错信息","出錯信息"],["出锤","出錘"],["出镜","出鏡"],["出镜头","出鏡頭"],["出门","出門"],["出门在外","出門在外"],["出门子","出門子"],["出门时","出門時"],["出问题","出問題"],["出闸","出閘"],["出阁","出閣"],["出阁之喜","出閣之喜"],["出阵","出陣"],["出陈布新","出陳佈新"],["出院","出院"],["出险","出險"],["出难题","出難題"],["出面","出面"],["出鞘","出鞘"],["出韵","出韻"],["出顶","出頂"],["出项","出項"],["出题","出題"],["出风口","出風口"],["出风头","出風頭"],["出饭","出飯"],["出首","出首"],["出马","出馬"],["出马上场","出馬上場"],["出马上阵","出馬上陣"],["出高价","出高價"],["出鬼入神","出鬼入神"],["出齐","出齊"],["击出","擊出"],["击发","擊發"],["击向","擊向"],["击板","擊板"],["击沈","擊沈"],["击筑","擊築"],["击钟","擊鐘"],["击钟陈鼎","擊鐘陳鼎"],["击钟鼎食","擊鐘鼎食"],["函复","函覆"],["函谷关","函谷關"],["凿出","鑿出"],["凿出去","鑿出去"],["凿出来","鑿出來"],["凿凿有据","鑿鑿有據"],["凿壁悬梁","鑿壁懸梁"],["凿岩","鑿巖"],["凿岩机","鑿岩機"],["凿船虫","鑿船蟲"],["刀创药","刀創藥"],["刀削面","刀削麪"],["刀割针扎","刀割針扎"],["刀布","刀布"],["刀板","刀板"],["刀耕火种","刀耕火種"],["刀面","刀面"],["刁奸","刁姦"],["刁恶","刁惡"],["刁斗","刁斗"],["分一杯羹","分一杯羹"],["分不出","分不出"],["分个","分個"],["分久必合","分久必合"],["分久必合合久必分","分久必合合久必分"],["分了","分了"],["分伙","分夥"],["分克","分克"],["分党","分黨"],["分出","分出"],["分出去","分出去"],["分出来","分出來"],["分分合合","分分合合"],["分别","分別"],["分别出","分別出"],["分别财产制","分別財產制"],["分别部居","分別部居"],["分半钟","分半鐘"],["分占","分佔"],["分厂","分廠"],["分厘卡","分釐卡"],["分厘毫丝","分釐毫絲"],["分发","分發"],["分发到","分發到"],["分发区","分發區"],["分发给","分發給"],["分合","分合"],["分向岛","分向島"],["分多钟","分多鐘"],["分天之仇","分天之仇"],["分子化合物","分子化合物"],["分子钟","分子鐘"],["分封制","分封制"],["分尸","分屍"],["分尸案","分屍案"],["分工合作","分工合作"],["分工整合","分工整合"],["分布","分佈"],["分布于","分佈於"],["分布区","分佈區"],["分布图","分佈圖"],["分布学习","分佈學習"],["分布式","分佈式"],["分布式发展模型","分佈式發展模型"],["分布式拒绝服务","分佈式拒絕服務"],["分布式环境","分佈式環境"],["分布式结构","分佈式結構"],["分布式网络","分佈式網絡"],["分布控制","分佈控制"],["分布范围","分佈範圍"],["分布连结网络","分佈連結網絡"],["分当","分當"],["分录","分錄"],["分形几何","分形幾何"],["分形几何学","分形幾何學"],["分形同气","分形同氣"],["分得出","分得出"],["分我杯羹","分我杯羹"],["分摆","分擺"],["分散于","分散於"],["分散注意","分散注意"],["分数挂帅","分數掛帥"],["分时系统","分時系統"],["分权制衡","分權制衡"],["分杯羹","分杯羹"],["分析出","分析出"],["分析出来","分析出來"],["分泌出","分泌出"],["分泌系统","分泌系統"],["分离出","分離出"],["分离出来","分離出來"],["分离术","分離術"],["分种","分種"],["分筋术","分筋術"],["分类目录","分類目錄"],["分系","分系"],["分系统","分系統"],["分级制","分級制"],["分获","分獲"],["分行布白","分行布白"],["分裂症","分裂症"],["分身乏术","分身乏術"],["分身术","分身術"],["分辨出","分辨出"],["分辨出来","分辨出來"],["分辨善恶","分辨善惡"],["分进合","分進合"],["分进合击","分進合擊"],["分针","分針"],["分钟","分鐘"],["分门别类","分門別類"],["切个","切個"],["切云","切雲"],["切出","切出"],["切出去","切出去"],["切出来","切出來"],["切合","切合"],["切合实际","切合實際"],["切合需要","切合需要"],["切向","切向"],["切向力","切向力"],["切向速度","切向速度"],["切向量","切向量"],["切平面","切平面"],["切开术","切開術"],["切当","切當"],["切菜板","切菜板"],["切除术","切除術"],["切面","切面"],["切骨之仇","切骨之仇"],["刊了","刊了"],["刊出","刊出"],["刊出来","刊出來"],["刊布","刊佈"],["刊板","刊板"],["刊误表","刊誤表"],["刑于","刑于"],["刑余","刑餘"],["刑克","刑剋"],["刑法志","刑法志"],["刑辟","刑辟"],["划一","劃一"],["划一不二","劃一不二"],["划一桨","划一槳"],["划上","劃上"],["划下","劃下"],["划下道来","劃下道來"],["划不来","划不來"],["划为","劃爲"],["划了","劃了"],["划了一会","划了一會"],["划价","劃價"],["划伤","劃傷"],["划位","劃位"],["划入","劃入"],["划具","划具"],["划出","劃出"],["划分","劃分"],["划分为","劃分爲"],["划分成","劃分成"],["划分法","劃分法"],["划划","劃劃"],["划到","劃到"],["划到岸","划到岸"],["划到江心","划到江心"],["划动","划動"],["划单人艇","划單人艇"],["划去","劃去"],["划双人","划雙人"],["划向","划向"],["划圆防守","劃圓防守"],["划在","劃在"],["划地","劃地"],["划地为王","劃地爲王"],["划地自限","劃地自限"],["划子","划子"],["划定","劃定"],["划定为","劃定爲"],["划座位","劃座位"],["划开","劃開"],["划归","劃歸"],["划得","劃得"],["划得来","划得來"],["划成","劃成"],["划拉","劃拉"],["划拨","劃撥"],["划拨帐号","劃撥帳號"],["划拳","划拳"],["划掉","劃掉"],["划时代","劃時代"],["划来","划來"],["划来划去","劃來劃去"],["划桨","划槳"],["划款","劃款"],["划水","划水"],["划法","劃法"],["划清","劃清"],["划清界线","劃清界線"],["划清界限","劃清界限"],["划然","劃然"],["划界","劃界"],["划痕","劃痕"],["划着","划着"],["划着走","划着走"],["划破","劃破"],["划策","劃策"],["划算","划算"],["划纹症","劃紋症"],["划线","劃線"],["划船","划船"],["划艇","划艇"],["划花","劃花"],["划行","划行"],["划设","劃設"],["划走","划走"],["划起","划起"],["划起来","划起來"],["划足","劃足"],["划过","劃過"],["划过去","划過去"],["划过来","划過來"],["划进","划進"],["划进去","划進去"],["划进来","划進來"],["划龙舟","划龍舟"],["刓团","刓團"],["刖足适屦","刖足適屨"],["刖趾适屦","刖趾適屨"],["列举出","列舉出"],["列了","列了"],["列克星顿","列克星頓"],["列出","列出"],["列出来","列出來"],["列别杰夫","列別傑夫"],["列印出来","列印出來"],["列夫托尔斯泰","列夫托爾斯泰"],["列宁威权体系","列寧威權體系"],["列布","列布"],["列席代表","列席代表"],["列当","列當"],["列御寇","列禦寇"],["列氏寒暑表","列氏寒暑表"],["列表","列表"],["列表机","列表機"],["刘云山","劉雲山"],["刘任杰","劉任傑"],["刘伟杰","劉偉杰"],["刘克庄","劉克莊"],["刘克襄","劉克襄"],["刘占吉","劉占吉"],["刘向","劉向"],["刘嘉发","劉嘉發"],["刘复","劉復"],["刘宗周","劉宗周"],["刘峰松","劉峯松"],["刘幸义","劉幸義"],["刘幸如","劉倖如"],["刘志勤","劉志勤"],["刘志升","劉志昇"],["刘志威","劉志威"],["刘念","劉念"],["刘松仁","劉松仁"],["刘松年","劉松年"],["刘松藩","劉松藩"],["刘知几","劉知幾"],["刘秋凤","劉秋鳳"],["刘胡兰","劉胡蘭"],["刘表","劉表"],["刘鉴","劉鑑"],["刘鉴庭","劉鑑庭"],["刘长发","劉長發"],["刘阮上天台","劉阮上天臺"],["刘青云","劉青雲"],["则个","則個"],["刚出","剛出"],["刚出去","剛出去"],["刚出来","剛出來"],["刚出道","剛出道"],["刚回","剛回"],["刚回到","剛回到"],["刚回去","剛回去"],["刚回来","剛回來"],["刚干","剛乾"],["刚才","剛纔"],["刚才一载","剛纔一載"],["刚才在","剛纔在"],["刚才是","剛纔是"],["刚板硬正","剛板硬正"],["刚柔并济","剛柔並濟"],["创业板","創業板"],["创业板上市","創業板上市"],["创价学会","創價學會"],["创伤后","創傷後"],["创伤后压力","創傷後壓力"],["创伤后压力紊乱","創傷後壓力紊亂"],["创作出","創作出"],["创作曲","創作曲"],["创出","創出"],["创制","創制","創製"],["创制权","創制權"],["创历年","創歷年"],["创巨","創鉅"],["创意曲","創意曲"],["创意杯","創意盃"],["创汇","創匯"],["创立出","創立出"],["创纪录","創紀錄"],["创获","創穫"],["创记录","創記錄"],["创造出","創造出"],["创造出来","創造出來"],["创面","創面"],["初冬","初冬"],["初出茅庐","初出茅廬"],["初升","初升"],["初发","初發"],["初发芙蓉","初發芙蓉"],["初唐四杰","初唐四傑"],["初回","初回"],["初征","初征"],["初志","初志"],["初愿","初願"],["初次见面","初次見面"],["初登板","初登板"],["初秋","初秋"],["初秋图","初秋圖"],["初级关系","初級關係"],["初级团体","初級團體"],["初选制","初選制"],["初露才华","初露才華"],["判别","判別"],["判别式","判別式"],["判据","判據"],["判断出","判斷出"],["判然不合","判然不合"],["判若云泥","判若雲泥"],["別干净","別乾淨"],["刨出来","刨出來"],["利于","利於"],["利古里亚","利古里亞"],["利多于弊","利多於弊"],["利多出尽","利多出盡"],["利字当头","利字當頭"],["利害关系","利害關係"],["利害关系人","利害關係人"],["利害关系方","利害關係方"],["利害冲突","利害衝突"],["利弊参半","利弊參半"],["利得汇","利得彙"],["利息支出","利息支出"],["利托","利托"],["利析秋毫","利析秋毫"],["利欲","利慾"],["利欲心","利慾心"],["利欲熏心","利慾薰心"],["利欲薰心","利慾薰心"],["利比里亚","利比里亞"],["利用价值","利用價值"],["利用系数","利用係數"],["利益团体","利益團體"],["利益集团","利益集團"],["利空出尽","利空出盡"],["利纳克斯","利納克斯"],["利默里克","利默里克"],["别上","別上"],["别上去","別上去"],["别上来","別上來"],["别下","別下"],["别下去","別下去"],["别下来","別下來"],["别业","別業"],["别个","別個"],["别义","別義"],["别乡","別鄉"],["别乱","別亂"],["别了","別了"],["别于","別於"],["别人","別人"],["别人的","別人的"],["别人的孩子死不完","別人的孩子死不完"],["别人的肉偎不热","別人的肉偎不熱"],["别人肉帖不在腮颊上","別人肉帖不在腮頰上"],["别从","別從"],["别传","別傳"],["别体","別體"],["别作一眼","別作一眼"],["别使","別使"],["别倒","別倒"],["别傻","別傻"],["别傻了","別傻了"],["别像","別像"],["别克","別克"],["别党","別黨"],["别关","別關"],["别具","別具"],["别具一格","別具一格"],["别具匠心","別具匠心"],["别具只眼","別具隻眼"],["别具慧眼","別具慧眼"],["别具炉锤","別具爐錘"],["别具肺肠","別具肺腸"],["别再","別再"],["别出","別出"],["别出去","別出去"],["别出心裁","別出心裁"],["别出新裁","別出新裁"],["别出机杼","別出機杼"],["别出来","別出來"],["别创新格","別創新格"],["别别扭扭","彆彆扭扭"],["别到","別到"],["别刻","別刻"],["别办","別辦"],["别加","別加"],["别动","別動"],["别动队","別動隊"],["别劲","別勁"],["别区","別區"],["别去","別去"],["别县","別縣"],["别又","別又"],["别受","別受"],["别变","別變"],["别口气","彆口氣"],["别句","別句"],["别只","別隻"],["别叫","別叫"],["别史","別史"],["别号","別號"],["别名","別名"],["别后","別後"],["别后寒温","別後寒溫"],["别向","別向"],["别吓","別嚇"],["别吓人","別嚇人"],["别哭","別哭"],["别嘴","彆嘴"],["别国","別國"],["别在","別在"],["别墅","別墅"],["别墅区","別墅區"],["别墨","別墨"],["别处","別處"],["别太客气","別太客氣"],["别套","別套"],["别子","別子"],["别字","別字"],["别守","別守"],["别客气","別客氣"],["别室","別室"],["别宫祭江","別宮祭江"],["别害羞","別害羞"],["别家","別家"],["别寄","別寄"],["别对","別對"],["别将","別將"],["别局","別局"],["别岁","別歲"],["别巷","別巷"],["别师","別師"],["别庄","別莊"],["别开","別開"],["别开生面","別開生面"],["别开蹊径","別開蹊徑"],["别异","別異"],["别弹","別彈"],["别强","彆強"],["别当","別當"],["别得","別得"],["别忙","別忙"],["别念","別念"],["别急","別急"],["别怪","別怪"],["别情","別情"],["别情依依","別情依依"],["别想","別想"],["别意","別意"],["别成","別成"],["别房","別房"],["别手","別手"],["别扭","彆扭"],["别把","別把"],["别拍","別拍"],["别拔","別拔"],["别拗","彆拗"],["别拿","別拿"],["别挤","別擠"],["别排","別排"],["别描头","別描頭"],["别提","別提"],["别提了","別提了"],["别搬","別搬"],["别支","別支"],["别收","別收"],["别教","別教"],["别数","別數"],["别族","別族"],["别无","別無"],["别无他法","別無他法"],["别无他物","別無他物"],["别无他用","別無他用"],["别无分号","別無分號"],["别无选择","別無選擇"],["别无长物","別無長物"],["别日南鸿才北去","別日南鴻纔北去"],["别是","別是"],["别替","別替"],["别有","別有"],["别有天地","別有天地"],["别有居心","別有居心"],["别有所指","別有所指"],["别有洞天","別有洞天"],["别有用心","別有用心"],["别有用意","別有用意"],["别有肺肠","別有肺腸"],["别有韵味","別有韻味"],["别有风味","別有風味"],["别本","別本"],["别杀","別殺"],["别材","別材"],["别束","別束"],["别来","別來"],["别来无恙","別來無恙"],["别枝","別枝"],["别架","別架"],["别栋","別棟"],["别树一帜","別樹一幟"],["别树一旗","別樹一旗"],["别树一格","別樹一格"],["别校","別校"],["别样","別樣"],["别棵","別棵"],["别殿","別殿"],["别气","彆氣"],["别法","別法"],["别派","別派"],["别爲","別爲"],["别现","別現"],["别班","別班"],["别理","別理"],["别生","別生"],["别生枝节","別生枝節"],["别生气","別生氣"],["别用","別用"],["别由","別由"],["别白","別白"],["别的","別的"],["别的人","別的人"],["别省","別省"],["别看","別看"],["别着","彆着"],["别离","別離"],["别种","別種"],["别种的","別種的"],["别科","別科"],["别称","別稱"],["别笑","別笑"],["别第","別第"],["别答","別答"],["别筵","別筵"],["别管","別管"],["别箱","別箱"],["别线","別線"],["别组","別組"],["别给","別給"],["别绪","別緒"],["别罐","別罐"],["别脚","別腳"],["别致","別緻"],["别致有趣","別致有趣"],["别苗头","別苗頭"],["别被","別被"],["别裁","別裁"],["别裁伪体","別裁僞體"],["别解","別解"],["别讨","別討"],["别让","別讓"],["别记","別記"],["别讲","別講"],["别论","別論"],["别识别见","別識別見"],["别试","別試"],["别话","別話"],["别说","別說"],["别说出","別說出"],["别说到","別說到"],["别说起","別說起"],["别请","別請"],["别课","別課"],["别调","別調"],["别谈","別談"],["别赋","別賦"],["别赏","別賞"],["别走","別走"],["别起","別起"],["别起来","別起來"],["别趣","別趣"],["别跑","別跑"],["别踢","別踢"],["别转","別轉"],["别输","別輸"],["别辟","別闢"],["别辟蹊径","別闢蹊徑"],["别辟门户","別闢門戶"],["别过","別過"],["别过去","別過去"],["别过头","別過頭"],["别过来","別過來"],["别逃","別逃"],["别针","別針"],["别队","別隊"],["别院","別院"],["别除权","別除權"],["别集","別集"],["别项","別項"],["别颏腮","別頦腮"],["别颗","別顆"],["别题","別題"],["别风淮雨","別風淮雨"],["别馆","別館"],["别首","別首"],["别驾","別駕"],["别骑","別騎"],["别鹤","別鶴"],["别鹤孤鸾","別鶴孤鸞"],["别鹤操","別鶴操"],["别鹤离鸾","別鶴離鸞"],["刬恶除奸","剗惡除奸"],["刮上","刮上"],["刮下","刮下"],["刮下去","刮下去"],["刮下来","刮下來"],["刮书背","刮書背"],["刮了","颳了"],["刮伤","刮傷"],["刮倒","颳倒"],["刮冷风","刮冷風"],["刮出","刮出"],["刮刀","刮刀"],["刮刮","刮刮"],["刮刮乐","刮刮樂"],["刮刮匝匝","刮刮匝匝"],["刮刮卡","刮刮卡"],["刮刮叫","刮刮叫"],["刮刮杂杂","刮刮雜雜"],["刮刮而谈","刮刮而談"],["刮到","刮到"],["刮削","刮削"],["刮剌","刮剌"],["刮剌剌","刮剌剌"],["刮去","颳去"],["刮取","刮取"],["刮喇","刮喇"],["刮在","刮在"],["刮地器","刮地器"],["刮地皮","刮地皮"],["刮垢","刮垢"],["刮垢磨光","刮垢磨光"],["刮大风","颳大風"],["刮头","刮頭"],["刮好","刮好"],["刮子","刮子"],["刮宫术","刮宮術"],["刮得","颳得"],["刮打","刮打"],["刮拉","刮拉"],["刮掉","刮掉"],["刮搭板儿","刮搭板兒"],["刮摩","刮摩"],["刮来刮去","刮來刮去"],["刮毒","刮毒"],["刮涎","刮涎"],["刮痕","刮痕"],["刮痧","刮痧"],["刮的","刮的"],["刮皮刀","刮皮刀"],["刮目相待","刮目相待"],["刮目相看","刮目相看"],["刮着","颳着"],["刮研","刮研"],["刮破","刮破"],["刮肠洗胃","刮腸洗胃"],["刮胡","刮鬍"],["刮胡刀","刮鬍刀"],["刮胡子","刮鬍子"],["刮脸","刮臉"],["刮脸刀","刮臉刀"],["刮脸皮","刮臉皮"],["刮舌","刮舌"],["刮舌子","刮舌子"],["刮补","刮補"],["刮言","刮言"],["刮走","颳走"],["刮起","颳起"],["刮起来","刮起來"],["刮躁","刮躁"],["刮过","刮過"],["刮过去","刮過去"],["刮过来","刮過來"],["刮铲","刮鏟"],["刮除","刮除"],["刮雪","颳雪"],["刮须","刮鬚"],["刮风","颳風"],["刮风下雪倒便宜","刮風下雪倒便宜"],["刮风后","颳風後"],["刮骨","刮骨"],["刮骨去毒","刮骨去毒"],["刮骨疗毒","刮骨療毒"],["到不了","到不了"],["到了","到了"],["到岸价","到岸價"],["到岸价格","到岸價格"],["到此一游","到此一遊"],["到达签证","到達簽證"],["到那个时候","到那個時候"],["到那里","到那裏"],["制中","制中"],["制为","製爲"],["制举","制舉"],["制义","制義"],["制书","制書"],["制于","制於"],["制件","製件"],["制伏","制伏"],["制住","制住"],["制作","製作"],["制作业","製作業"],["制作人","製作人"],["制作出","製作出"],["制作出来","製作出來"],["制作商","製作商"],["制作好","製作好"],["制作成","製作成"],["制作群","製作羣"],["制作者","製作者"],["制作费","製作費"],["制假","製假"],["制做","製做"],["制军","制軍"],["制冰","製冰"],["制冰机","製冰機"],["制冷","製冷"],["制冷剂","製冷劑"],["制冷机","製冷機"],["制出","製出"],["制剂","製劑"],["制动","制動"],["制动器","制動器"],["制动因子","制動因子"],["制动火箭","制動火箭"],["制动缸","制動缸"],["制动踏板","制動踏板"],["制勘","制勘"],["制压射击","制壓射擊"],["制取","製取"],["制变","制變"],["制台","制臺"],["制命","制命"],["制品","製品"],["制售","製售"],["制图","製圖"],["制图员","製圖員"],["制图学","製圖學"],["制图室","製圖室"],["制图尺","製圖尺"],["制图师","製圖師"],["制图板","製圖板"],["制图样","製圖樣"],["制图桌","製圖桌"],["制图者","製圖者"],["制图车","製圖車"],["制坯","製坯"],["制备","製備"],["制定","制定"],["制定出","制定出"],["制定出来","制定出來"],["制宪","制憲"],["制宪会议","制憲會議"],["制宪权","制憲權"],["制导","制導"],["制币","制幣"],["制度","制度"],["制度化","制度化"],["制度性","制度性"],["制度法","制度法"],["制度面","制度面"],["制式","制式"],["制式化","制式化"],["制得","製得"],["制成","製成"],["制成品","製成品"],["制播","製播"],["制敌机先","制敵機先"],["制新宪","制新憲"],["制服","制服"],["制服呢","制服呢"],["制服警察","制服警察"],["制材","製材"],["制梃","制梃"],["制止","制止"],["制毒","製毒"],["制氧","製氧"],["制水阀","制水閥"],["制法","製法"],["制浆","製漿"],["制海","制海"],["制海权","制海權"],["制爲","製爲"],["制片","製片"],["制片人","製片人"],["制片厂","製片廠"],["制片商","製片商"],["制片家","製片家"],["制版","製版"],["制版术","製版術"],["制盐","製鹽"],["制礼","制禮"],["制礼作乐","制禮作樂"],["制科","制科"],["制程","製程"],["制空","制空"],["制空权","制空權"],["制策","制策"],["制签","制籤"],["制糖","製糖"],["制糖厂","製糖廠"],["制约","制約"],["制约刺激","制約刺激"],["制约反应","制約反應"],["制纸","製紙"],["制胜","制勝"],["制胜之道","制勝之道"],["制艺","制藝"],["制茶","製茶"],["制药","製藥"],["制药业","製藥業"],["制药企业","製藥企業"],["制药厂","製藥廠"],["制衡","制衡"],["制衡作用","制衡作用"],["制衣","製衣"],["制衣厂","製衣廠"],["制表","製表"],["制裁","制裁"],["制裁案","制裁案"],["制订","制訂"],["制诰","制誥"],["制造","製造"],["制造业","製造業"],["制造业者","製造業者"],["制造出","製造出"],["制造出来","製造出來"],["制造厂","製造廠"],["制造厂商","製造廠商"],["制造品","製造品"],["制造商","製造商"],["制造器","製造器"],["制造场","製造場"],["制造成","製造成"],["制造术","製造術"],["制造者","製造者"],["制造费用","製造費用"],["制酸剂","制酸劑"],["制酸性","製酸性"],["制醣","制醣"],["制钟","制鐘"],["制钱","制錢"],["制限","制限"],["制限选举","制限選舉"],["制陶","製陶"],["制陶工人","製陶工人"],["制面","制面"],["制面具","製面具"],["制革","製革"],["制革厂","製革廠"],["制革工厂","製革工廠"],["制鞋","製鞋"],["制鞋业","製鞋業"],["制鞋匠","製鞋匠"],["制鞋工人","製鞋工人"],["制音器","制音器"],["制高点","制高點"],["刷卷","刷卷"],["刷新纪录","刷新紀錄"],["刺不准","刺不準"],["刺出","刺出"],["刺出去","刺出去"],["刺出来","刺出來"],["刺参","刺蔘"],["刺头泥里陷","刺頭泥裏陷"],["刺干","刺干"],["刺探出","刺探出"],["刺杀出局","刺殺出局"],["刺枪术","刺槍術"],["刺激启动不同步","刺激啓動不同步"],["刺绣","刺繡"],["刺股悬梁","刺股懸梁"],["刺胳针","刺胳針"],["刺针","刺針"],["刺骨悬梁","刺骨懸梁"],["刻个","刻個"],["刻了","刻了"],["刻于","刻於"],["刻出","刻出"],["刻划","刻劃"],["刻划入微","刻劃入微"],["刻划出","刻劃出"],["刻半钟","刻半鐘"],["刻多钟","刻多鐘"],["刻录机","刻錄機"],["刻板","刻板"],["刻板印象","刻板印象"],["刻蜡纸","刻蠟紙"],["刻足适屦","刻足適屨"],["刻钟","刻鐘"],["剂量当量","劑量當量"],["剃了","剃了"],["剃发","剃髮"],["剃发为尼","剃髮爲尼"],["剃发令","剃髮令"],["剃发留辫","剃髮留辮"],["剃发铺","剃髮鋪"],["剃头发","剃頭髮"],["剃胡","剃鬍"],["剃须","剃鬚"],["剃须刀","剃鬚刀"],["剉折","剉折"],["削了","削了"],["削价","削價"],["削发","削髮"],["削发为僧","削髮爲僧"],["削发为尼","削髮爲尼"],["削发披缁","削髮披緇"],["削苹果","削蘋果"],["削足适履","削足適履"],["削趾适屦","削趾適屨"],["削面","削麪"],["前不巴村后不巴店","前不巴村後不巴店"],["前事不忘后事之师","前事不忘後事之師"],["前亲晚后","前親晚後"],["前人失脚后人把滑","前人失腳後人把滑"],["前人撒土迷了后人的眼","前人撒土迷了後人的眼"],["前人栽树后人乘凉","前人栽樹後人乘涼"],["前人种树","前人種樹"],["前仆后继","前仆後繼"],["前仆后起","前仆後起"],["前仇","前仇"],["前仰后合","前仰後合"],["前修","前修"],["前俯后仰","前俯後仰"],["前倨后卑","前倨後卑"],["前倨后恭","前倨後恭"],["前儿个","前兒個"],["前几天","前幾天"],["前出后空","前出後空"],["前前后后","前前後後"],["前功尽废","前功盡廢"],["前功尽弃","前功盡棄"],["前功尽灭","前功盡滅"],["前厂","前廠"],["前台","前臺"],["前叶","前葉"],["前合后仰","前合後仰"],["前合后偃","前合後偃"],["前后","前後"],["前后任","前後任"],["前后夹攻","前後夾攻"],["前后左右","前後左右"],["前后文","前後文"],["前后相悖","前後相悖"],["前后相随","前後相隨"],["前后矛盾","前後矛盾"],["前后脚儿","前後腳兒"],["前向拥塞通知","前向擁塞通知"],["前呼后应","前呼後應"],["前呼后拥","前呼後擁"],["前回","前回"],["前因后果","前因後果"],["前奏曲","前奏曲"],["前婚后嫁","前婚後嫁"],["前家后继","前家後繼"],["前志","前志"],["前怕狼后怕虎","前怕狼後怕虎"],["前思后想","前思後想"],["前扑后继","前撲後繼"],["前挽后推","前挽後推"],["前推后拥","前推後擁"],["前新系","前新系"],["前无古人后无来者","前無古人後無來者"],["前核","前核"],["前歌后舞","前歌後舞"],["前甲板","前甲板"],["前短后长","前短後長"],["前程万里","前程萬里"],["前缘未了","前緣未了"],["前苏联","前蘇聯"],["前街后巷","前街後巷"],["前言不对后语","前言不對後語"],["前言不答后语","前言不答後語"],["前词汇加工","前詞彙加工"],["前词汇语音加工","前詞彙語音加工"],["前词汇阶段","前詞彙階段"],["前赴后继","前赴後繼"],["前车之复","前車之覆"],["前车之覆后车之鉴","前車之覆後車之鑑"],["前车之鉴","前車之鑑"],["前车可鉴","前車可鑑"],["前车复后车戒","前車覆後車戒"],["前进党","前進黨"],["前途未卜","前途未卜"],["前遮后拥","前遮後擁"],["前郭尔罗斯蒙古族自治县","前郭爾羅斯蒙古族自治縣"],["前长后短","前長後短"],["前门不进师姑后门不进和尚","前門不進師姑後門不進和尚"],["前门打虎后门打狼","前門打虎後門打狼"],["前门拒虎后门进狼","前門拒虎後門進狼"],["前面","前面"],["剑叶","劍葉"],["剑合珠还","劍合珠還"],["剑术","劍術"],["剑杆","劍桿"],["剔了","剔了"],["剔出","剔出"],["剔团圆","剔團圓"],["剔团𪢮","剔團圞"],["剔庄货","剔莊貨"],["剔齿纤","剔齒纖"],["剖别","剖別"],["剖宫产手术","剖宮產手術"],["剖腹产手术","剖腹產手術"],["剖腹手术","剖腹手術"],["剖面","剖面"],["剖面图","剖面圖"],["剥制","剝製"],["剥尽","剝盡"],["剥挽","剝挽"],["剥极必复","剝極必復"],["剥离症","剝離症"],["剥采比","剝採比"],["剥面皮","剝面皮"],["剧力万钧","劇力萬鈞"],["剧团","劇團"],["剧坛","劇壇"],["剧曲","劇曲"],["剧种","劇種"],["剧药","劇藥"],["剩个","剩個"],["剩了","剩了"],["剩余","剩餘"],["剩余价值","剩餘價值"],["剩余定理","剩餘定理"],["剩余放射性","剩餘放射性"],["剩余辐射","剩餘輻射"],["剩馀价值","剩餘價值"],["剩馀价值率","剩餘價值率"],["剪个","剪個"],["剪了","剪了"],["剪其发","剪其髮"],["剪出","剪出"],["剪发","剪髮"],["剪发披缁","剪髮披緇"],["剪头发","剪頭髮"],["剪彩","剪綵"],["剪彩仪式","剪彩儀式"],["剪恶除奸","剪惡除奸"],["剪牡丹喂牛","剪牡丹喂牛"],["剪秋罗","剪秋羅"],["剪贴出","剪貼出"],["副厂长","副廠長"],["副团长","副團長"],["副性征","副性徵"],["副总干事","副總幹事"],["副曲","副曲"],["副法向量","副法向量"],["割了","割了"],["割出","割出"],["割回","割回"],["割回去","割回去"],["割回来","割回來"],["割圆术","割圓術"],["割据","割據"],["割舍","割捨"],["割舍不下","割捨不下"],["剺面","剺面"],["剿获","剿獲"],["劈划","劈劃"],["劈地价来","劈地價來"],["劈尸万段","劈屍萬段"],["劈心里","劈心裏"],["劈挂拳","劈掛拳"],["劈脑后","劈腦後"],["劈里","劈里"],["劈里啪啦","劈里啪啦"],["劈面","劈面"],["力不从愿","力不從願"],["力不同科","力不同科"],["力不胜任","力不勝任"],["力不自胜","力不自勝"],["力争上游","力爭上游"],["力克","力克"],["力克制","力剋制"],["力回馈","力回饋"],["力困筋乏","力困筋乏"],["力尽","力盡"],["力尽神危","力盡神危"],["力尽筋疲","力盡筋疲"],["力尽筋舒","力盡筋舒"],["力征","力征"],["力拼众敌","力拼衆敵"],["力挽","力挽"],["力挽狂澜","力挽狂瀾"],["力敌万人","力敵萬人"],["力敌万夫","力敵萬夫"],["力系","力系"],["力胜","力勝"],["力薄才疏","力薄才疏"],["力量党","力量黨"],["劝出","勸出"],["劝出去","勸出去"],["劝出来","勸出來"],["劝善惩恶","勸善懲惡"],["劝善戒恶","勸善戒惡"],["劝善黜恶","勸善黜惡"],["劝回","勸回"],["劝回去","勸回去"],["劝回来","勸回來"],["办伙","辦伙"],["办公台","辦公檯"],["办公室里","辦公室裏"],["办后事","辦後事"],["功同良相","功同良相"],["功同赏异","功同賞異"],["功大于过","功大於過"],["功布","功布"],["功流万世","功流萬世"],["功率恶化","功率惡化"],["功率表","功率表"],["功率输出","功率輸出"],["功绩制","功績制"],["功能团","功能團"],["功能团体","功能團體"],["功能磁共振成像术","功能磁共振成像術"],["功能表","功能表"],["功致","功緻"],["功课表","功課表"],["功过参半","功過參半"],["加个","加個"],["加了","加了"],["加于","加於"],["加仑","加侖"],["加价","加價"],["加出","加出"],["加利波里","加利波里"],["加勒比海共同体","加勒比海共同體"],["加勒比海共同市场","加勒比海共同市場"],["加升","加升"],["加卷","加捲"],["加发","加發"],["加回","加回"],["加回去","加回去"],["加回来","加回來"],["加害于","加害於"],["加密后的","加密後的"],["加尔克汉德省","加爾克漢德省"],["加州技术学院","加州技術學院"],["加工出口","加工出口"],["加工出口区","加工出口區"],["加工厂","加工廠"],["加巴里雅","加巴里雅"],["加布","加布"],["加强控制","加強控制"],["加强管制","加強管制"],["加当","加當"],["加拉干达","加拉干達"],["加拿大铝业集团","加拿大鋁業集團"],["加挂","加掛"],["加挂车厢","加掛車廂"],["加杯","加杯"],["加杯水","加杯水"],["加氢精制","加氫精制"],["加油团","加油團"],["加注","加註","加注"],["加涂","加塗"],["加签","加簽"],["加签证","加簽證"],["加荣耀于","加榮耀於"],["加药","加藥"],["加解密系统","加解密系統"],["加达里","加達裏"],["加速踏板","加速踏板"],["加里","加里"],["加里宁","加裏寧"],["加里宁格勒","加里寧格勒"],["加里宁格勒州","加裏寧格勒州"],["加里曼丹","加裏曼丹"],["加里曼丹岛","加裏曼丹島"],["加里波的","加里波的"],["加里波第","加里波第"],["加里肋亚","加里肋亞"],["加里肋亚海","加里肋亞海"],["务须","務須"],["劣于","劣於"],["劣种","劣種"],["劣缺搊搜","劣缺搊搜"],["劣药","劣藥"],["动不了","動不了"],["动了","動了"],["动力系统","動力系統"],["动向","動向"],["动向不明","動向不明"],["动如参商","動如參商"],["动干戈","動干戈"],["动念","動念"],["动态范围","動態範圍"],["动手术","動手術"],["动物系","動物系"],["动物纤维","動物纖維"],["动物育种","動物育種"],["动画艺术","動畫藝術"],["动荡","動盪"],["动荡不安","動盪不安"],["动荡不定","動盪不定"],["动配合","動配合"],["助于","助於"],["助恶","助惡"],["助选团","助選團"],["努瓦克肖特","努瓦克肖特"],["劫余","劫餘"],["劫制","劫制"],["劫后余生","劫後餘生"],["劫后英雄传","劫後英雄傳"],["劫后馀烬","劫後餘燼"],["劫后馀生","劫後餘生"],["劬劳顾复","劬勞顧復"],["励志","勵志"],["励志书","勵志書"],["劲度系数","勁度係數"],["劲秋","勁秋"],["劲舞团","勁舞團"],["劲骨丰肌","勁骨豐肌"],["劳军团","勞軍團"],["劳力士表","勞力士錶"],["劳务出口","勞務出口"],["劳动党","勞動黨"],["劳动合同","勞動合同"],["劳动基准法","勞動基準法"],["劳动模范","勞動模範"],["劳发","勞發"],["劳台重","勞臺重"],["劳困","勞困"],["劳工党","勞工黨"],["劳工团体","勞工團體"],["劳工退休准备金","勞工退休準備金"],["劳资关系","勞資關係"],["劳资合作","勞資合作"],["劳逸结合","勞逸結合"],["劳里斯","勞里斯"],["劳雇关系","勞僱關係"],["劾系","劾繫"],["势不可当","勢不可當"],["势不并立","勢不並立"],["势力并行","勢力並行"],["势力范围","勢力範圍"],["势合形离","勢合形離"],["势同水火","勢同水火"],["势穷力极","勢窮力極"],["勃发","勃發"],["勃德修正案","勃德修正案"],["勃极烈","勃極烈"],["勃郁","勃鬱"],["勇于","勇於"],["勇于认错","勇於認錯"],["勋章","勳章"],["勒借","勒借"],["勒克","勒克"],["勒克司","勒克司"],["勒克莱尔","勒克萊爾"],["勒里勒得","勒里勒得"],["勘合","勘合"],["勘误表","勘誤表"],["募兵制","募兵制"],["勤仆","勤僕"],["勤俭朴实","勤儉樸實"],["勤俭朴素","勤儉樸素"],["勤劳致富","勤勞致富"],["勤朴","勤樸"],["勺药","勺藥"],["勾了","勾了"],["勾出","勾出"],["勾划","勾劃"],["勾勒出","勾勒出"],["勾干","勾幹"],["勾当","勾當"],["勾心斗角","勾心鬥角"],["勾画出","勾畫出"],["勾魂荡魄","勾魂蕩魄"],["勿念","勿念"],["勿施于人","勿施於人"],["勿药","勿藥"],["勿药有喜","勿藥有喜"],["勿药而愈","勿藥而愈"],["勿里洞岛","勿里洞島"],["匀出","勻出"],["匀出来","勻出來"],["匀面","勻面"],["包乘制","包乘制"],["包产到户制","包產到戶制"],["包价旅游","包價旅遊"],["包伙","包伙"],["包准","包準"],["包利克莱荳斯","包利克萊荳斯"],["包占","包占"],["包干","包乾"],["包干儿","包乾兒"],["包干制","包乾制"],["包庄","包莊"],["包待制","包待制"],["包扎","包紮"],["包扎法","包紮法"],["包承制","包承制"],["包揽闲事","包攬閒事"],["包班制","包班制"],["包皮环切术","包皮環切術"],["包种茶","包種茶"],["包罗万象","包羅萬象"],["包衣种子","包衣種子"],["包裹表决","包裹表決"],["包谷","包穀"],["包谷花","包谷花"],["包里斯","包里斯"],["包髻团衫","包髻團衫"],["匋斋吉金录","匋齋吉金錄"],["匏有苦叶","匏有苦葉"],["匏系","匏繫"],["化了","化了"],["化出","化出"],["化出化入","化出化入"],["化合","化合"],["化合价","化合價"],["化合反应","化合反應"],["化合态","化合態"],["化合性","化合性"],["化合物","化合物"],["化合量","化合量"],["化妆台","化妝臺"],["化学合成","化學合成"],["化学工厂","化學工廠"],["化学弹药","化學彈藥"],["化学当量","化學當量"],["化学战斗部","化學戰斗部"],["化学系","化學系"],["化学纤维","化學纖維"],["化工厂","化工廠"],["化工系","化工系"],["化干戈为玉帛","化干戈爲玉帛"],["化暗为明","化暗爲明"],["化纤","化纖"],["化纤厂","化纖廠"],["化肥厂","化肥廠"],["化隆回族自治县","化隆回族自治縣"],["化验台","化驗臺"],["北京中医药大学","北京中醫藥大學"],["北京周报","北京週報"],["北京国家游泳中心","北京國家游泳中心"],["北京师范大学","北京師範大學"],["北京汽车制造厂有限公司","北京汽車製造廠有限公司"],["北京艺术学院","北京藝術學院"],["北仑","北侖"],["北仑区","北侖區"],["北叶门","北葉門"],["北向","北向"],["北周","北周"],["北回","北迴"],["北回归线","北迴歸線"],["北回线","北迴線"],["北回铁路","北迴鐵路"],["北岳","北嶽"],["北征","北征"],["北斗","北斗"],["北斗七星","北斗七星"],["北斗星","北斗星"],["北斗镇","北斗鎮"],["北曲","北曲"],["北极","北極"],["北极光","北極光"],["北极冻原","北極凍原"],["北极区","北極區"],["北极圈","北極圈"],["北极地区","北極地區"],["北极星","北極星"],["北极星飞弹","北極星飛彈"],["北极海","北極海"],["北极熊","北極熊"],["北极犬","北極犬"],["北极狐","北極狐"],["北极锋","北極鋒"],["北极鲸","北極鯨"],["北柴胡","北柴胡"],["北洋系","北洋系"],["北瓦兹里斯坦","北瓦茲里斯坦"],["北辕适楚","北轅適楚"],["北里","北里"],["北面","北面"],["北面称臣","北面稱臣"],["北马里亚纳","北馬裏亞納"],["北马里亚纳群岛","北馬裏亞納羣島"],["匙扣","匙扣"],["匡合","匡合"],["匡复","匡復"],["匡当","匡當"],["匡济之才","匡濟之才"],["匣里龙吟","匣裏龍吟"],["匪党","匪黨"],["匪干","匪幹"],["匪徒集团","匪徒集團"],["匹似闲","匹似閒"],["匹头里","匹頭裏"],["匹面","匹面"],["匹马只轮","匹馬隻輪"],["区分出","區分出"],["区划","區劃"],["区别","區別"],["区别性","區別性"],["区别词","區別詞"],["区域网路技术","區域網路技術"],["区域范围","區域範圍"],["区段征收","區段徵收"],["医卜星相","醫卜星相"],["医学系","醫學系"],["医宗金鉴","醫宗金鑑"],["医托","醫托"],["医术","醫術"],["医疗团","醫療團"],["医药","醫藥"],["医药业","醫藥業"],["医药分业","醫藥分業"],["医药分离","醫藥分離"],["医药品","醫藥品"],["医药商店","醫藥商店"],["医药学","醫藥學"],["医药气候学","醫藥氣候學"],["医药界","醫藥界"],["医药罔效","醫藥罔效"],["医药费","醫藥費"],["医院里","醫院裏"],["匾扎","匾扎"],["匿于","匿於"],["十万","十萬"],["十三经注疏","十三經注疏"],["十个","十個"],["十个月","十個月"],["十九万","十九萬"],["十九个","十九個"],["十二万","十二萬"],["十二万分","十二萬分"],["十二个","十二個"],["十二指肠虫","十二指腸蟲"],["十二木表法","十二木表法"],["十二面体","十二面體"],["十五万","十五萬"],["十五个","十五個"],["十五个吊桶打水","十五個吊桶打水"],["十余","十餘"],["十余只","十餘隻"],["十余里","十餘里"],["十克","十克"],["十克拉","十克拉"],["十八万","十八萬"],["十八个","十八個"],["十八姑娘","十八姑娘"],["十公克","十公克"],["十公升","十公升"],["十公里","十公里"],["十六万","十六萬"],["十六个","十六個"],["十六国春秋","十六國春秋"],["十六进制","十六進制"],["十冬腊月","十冬臘月"],["十几","十幾"],["十几万","十幾萬"],["十几个","十幾個"],["十几个月","十幾個月"],["十几二十","十幾二十"],["十几人","十幾人"],["十几元","十幾元"],["十几分","十幾分"],["十几号","十幾號"],["十几块","十幾塊"],["十几天","十幾天"],["十几岁","十幾歲"],["十几年","十幾年"],["十几次","十幾次"],["十出戏","十齣戲"],["十出祁山","十出祁山"],["十分干","十分乾"],["十分钟","十分鐘"],["十划","十劃"],["十加仑","十加侖"],["十卷","十卷"],["十发","十發"],["十只","十隻"],["十台","十臺"],["十叶","十葉"],["十周","十週"],["十周年","十週年"],["十四万","十四萬"],["十四个","十四個"],["十回","十回"],["十团","十團"],["十国春秋","十國春秋"],["十多万","十多萬"],["十多个","十多個"],["十多只","十多隻"],["十天半个月","十天半個月"],["十天后","十天後"],["十天干","十天干"],["十字军东征","十字軍東征"],["十字军远征","十字軍遠征"],["十干","十干"],["十年后","十年後"],["十恶","十惡"],["十恶不赦","十惡不赦"],["十扎","十紮"],["十方地面","十方地面"],["十曲","十曲"],["十来个","十來個"],["十杯","十杯"],["十杯水","十杯水"],["十杯酒","十杯酒"],["十点钟","十點鐘"],["十种","十種"],["十秒钟","十秒鐘"],["十荡十决","十蕩十決"],["十谒朱门九不开","十謁朱門九不開"],["十足虫","十足蟲"],["十进位制","十進位制"],["十进制","十進制"],["十进算术","十進算術"],["十郎八当","十郎八當"],["十里","十里"],["十里余","十里餘"],["十里洋场","十里洋場"],["十里长亭","十里長亭"],["十里长亭无客走","十里長亭無客走"],["十针","十針"],["十面","十面"],["十面体","十面體"],["十面埋伏","十面埋伏"],["十鼠同穴","十鼠同穴"],["千万","千萬"],["千万买邻","千萬買鄰"],["千万分之一","千萬分之一"],["千万千万","千萬千萬"],["千万富翁","千萬富翁"],["千万年","千萬年"],["千不幸万不幸","千不幸萬不幸"],["千不是万不是","千不是萬不是"],["千丝万缕","千絲萬縷"],["千个","千個"],["千乘","千乘"],["千乘万骑","千乘萬騎"],["千乞","千乞"],["千了百当","千了百當"],["千亩","千畝"],["千人所指","千人所指"],["千亿","千億"],["千仇万恨","千仇萬恨"],["千仓万箱","千倉萬箱"],["千仞","千仞"],["千伏","千伏"],["千位","千位"],["千位元","千位元"],["千余","千餘"],["千余只","千餘隻"],["千余里","千餘里"],["千佛塔","千佛塔"],["千佛山","千佛山"],["千佛洞","千佛洞"],["千依万顺","千依萬順"],["千依百顺","千依百順"],["千兆","千兆"],["千克","千克"],["千兵万马","千兵萬馬"],["千军万马","千軍萬馬"],["千军易得一将难求","千軍易得一將難求"],["千刀万剁","千刀萬剁"],["千刀万剐","千刀萬剮"],["千刁万恶","千刁萬惡"],["千分","千分"],["千分之","千分之"],["千分之一","千分之一"],["千分之三","千分之三"],["千分之二","千分之二"],["千分表","千分表"],["千千","千千"],["千千万万","千千萬萬"],["千卡","千卡"],["千变万化","千變萬化"],["千变万状","千變萬狀"],["千变万轸","千變萬軫"],["千古","千古"],["千古事","千古事"],["千古传诵","千古傳誦"],["千古恨","千古恨"],["千古未闻","千古未聞"],["千古流传","千古流傳"],["千古独步","千古獨步"],["千古绝唱","千古絕唱"],["千古罪人","千古罪人"],["千古遗恨","千古遺恨"],["千只","千隻"],["千只足够","千只足夠"],["千叮万嘱","千叮萬囑"],["千叶","千葉"],["千叶县","千葉縣"],["千吨","千噸"],["千吨级核武器","千噸級核武器"],["千周","千周"],["千呼万唤","千呼萬喚"],["千咒万骂","千咒萬罵"],["千唤万唤","千喚萬喚"],["千回百折","千迴百折"],["千回百转","千迴百轉"],["千多只","千多隻"],["千天后","千天後"],["千夫","千夫"],["千夫所指","千夫所指"],["千夫长","千夫長"],["千头万绪","千頭萬緒"],["千头橘奴","千頭橘奴"],["千头百绪","千頭百緒"],["千奇百怪","千奇百怪"],["千妥万妥","千妥萬妥"],["千妥万当","千妥萬當"],["千姿百态","千姿百態"],["千娇百媚","千嬌百媚"],["千娇百态","千嬌百態"],["千孔百疮","千孔百瘡"],["千字文","千字文"],["千字节","千字節"],["千家","千家"],["千家万户","千家萬戶"],["千家姓","千家姓"],["千家诗","千家詩"],["千寻","千尋"],["千层糕","千層糕"],["千层面","千層麪"],["千山万壑","千山萬壑"],["千山万水","千山萬水"],["千山区","千山區"],["千山山脉","千山山脈"],["千岁","千歲"],["千岁一时","千歲一時"],["千岐万辙","千岐萬轍"],["千岛列岛","千島列島"],["千岛湖","千島湖"],["千岛湖事件","千島湖事件"],["千岛群岛","千島羣島"],["千岛酱","千島醬"],["千岩万壑","千巖萬壑"],["千岩万谷","千巖萬谷"],["千岩竞秀","千巖競秀"],["千嶂","千嶂"],["千差万别","千差萬別"],["千差万差来人不差","千差萬差來人不差"],["千帆","千帆"],["千年","千年"],["千年万载","千年萬載"],["千年前","千年前"],["千年怪兽","千年怪獸"],["千年田地八百主","千年田地八百主"],["千年艾","千年艾"],["千态万状","千態萬狀"],["千思万想","千思萬想"],["千总","千總"],["千恩万谢","千恩萬謝"],["千愁万恨","千愁萬恨"],["千愁万绪","千愁萬緒"],["千愁万虑","千愁萬慮"],["千户","千戶"],["千手千眼观音","千手千眼觀音"],["千扎","千紮"],["千挑万选","千挑萬選"],["千挑百选","千挑百選"],["千推万阻","千推萬阻"],["千支万派","千支萬派"],["千斤","千斤"],["千斤重担","千斤重擔"],["千斤顶","千斤頂"],["千方万计","千方萬計"],["千方百计","千方百計"],["千日","千日"],["千日红","千日紅"],["千日菊","千日菊"],["千日酒","千日酒"],["千村万落","千村萬落"],["千条万端","千條萬端"],["千条万绪","千條萬緒"],["千杯","千杯"],["千欢万喜","千歡萬喜"],["千步","千步"],["千湖国","千湖國"],["千点","千點"],["千牛","千牛"],["千牛刀","千牛刀"],["千状万态","千狀萬態"],["千状万端","千狀萬端"],["千瓦","千瓦"],["千瓦小时","千瓦小時"],["千瓦时","千瓦時"],["千生万死","千生萬死"],["千疮百孔","千瘡百孔"],["千百万","千百萬"],["千百年","千百年"],["千百成群","千百成羣"],["千皓宣","千皓宣"],["千真万真","千真萬真"],["千真万确","千真萬確"],["千石","千石"],["千碱基对","千鹼基對"],["千禧","千禧"],["千禧年","千禧年"],["千秋","千秋"],["千秋万世","千秋萬世"],["千秋万代","千秋萬代"],["千秋万古","千秋萬古"],["千秋万岁","千秋萬歲"],["千秋佳城","千秋佳城"],["千秋大业","千秋大業"],["千秋庙","千秋廟"],["千秋节","千秋節"],["千章","千章"],["千端万绪","千端萬緒"],["千算万算不值天一划","千算萬算不值天一劃"],["千篇一律","千篇一律"],["千米","千米"],["千粒重","千粒重"],["千红万紫","千紅萬紫"],["千经万卷","千經萬卷"],["千绪万端","千緒萬端"],["千羊之皮不如一狐之腋","千羊之皮不如一狐之腋"],["千般","千般"],["千般万样","千般萬樣"],["千英宇","千英宇"],["千虑一失","千慮一失"],["千虑一得","千慮一得"],["千言","千言"],["千言万语","千言萬語"],["千赫","千赫"],["千赫兹","千赫茲"],["千足港条","千足港條"],["千足虫","千足蟲"],["千载","千載"],["千载一会","千載一會"],["千载一合","千載一合"],["千载一时","千載一時"],["千载一逢","千載一逢"],["千载一遇","千載一遇"],["千载扬名","千載揚名"],["千载独步","千載獨步"],["千载难逢","千載難逢"],["千辛万苦","千辛萬苦"],["千辛百苦","千辛百苦"],["千里","千里"],["千里一曲","千里一曲"],["千里之堤","千里之堤"],["千里之外","千里之外"],["千里之行","千里之行"],["千里命驾","千里命駕"],["千里始足下","千里始足下"],["千里姻缘一线牵","千里姻緣一線牽"],["千里寄鹅毛","千里寄鵝毛"],["千里搭长棚","千里搭長棚"],["千里犹面","千里猶面"],["千里目","千里目"],["千里眼","千里眼"],["千里移檄","千里移檄"],["千里足","千里足"],["千里达","千里達"],["千里迢迢","千里迢迢"],["千里迢遥","千里迢遙"],["千里送鹅毛","千里送鵝毛"],["千里镜","千里鏡"],["千里馈粮","千里饋糧"],["千里马","千里馬"],["千里驹","千里駒"],["千里鹅毛","千里鵝毛"],["千金","千金"],["千金一刻","千金一刻"],["千金一掷","千金一擲"],["千金一笑","千金一笑"],["千金一诺","千金一諾"],["千金之子","千金之子"],["千金之家","千金之家"],["千金买笑","千金買笑"],["千金买骨","千金買骨"],["千金小姐","千金小姐"],["千金市骨","千金市骨"],["千金敝帚","千金敝帚"],["千金方","千金方"],["千金裘","千金裘"],["千金要方","千金要方"],["千金记","千金記"],["千金躯","千金軀"],["千金难买","千金難買"],["千钧","千鈞"],["千钧一发","千鈞一髮"],["千钧重负","千鈞重負"],["千锤百炼","千錘百煉"],["千锺粟","千鍾粟"],["千镒之裘非一狐之白","千鎰之裘非一狐之白"],["千门","千門"],["千门万户","千門萬戶"],["千闻不如一见","千聞不如一見"],["千阳","千陽"],["千阳县","千陽縣"],["千难万险","千難萬險"],["千难万难","千難萬難"],["千面人","千面人"],["千页群岛","千頁羣島"],["千顷陂","千頃陂"],["千鬼百怪","千鬼百怪"],["千鸟","千鳥"],["千鸟渊国家公墓","千鳥淵國家公墓"],["升上","升上"],["升上去","升上去"],["升上来","升上來"],["升为","升爲"],["升了","升了"],["升仙","昇仙"],["升任","升任"],["升任为","升任爲"],["升值","升值"],["升入","升入"],["升出","升出"],["升出来","升出來"],["升到","升到"],["升力","升力"],["升势","升勢"],["升势受阻","升勢受阻"],["升升","升升"],["升华","昇華"],["升华作用","昇華作用"],["升压","升壓"],["升号","升號"],["升回","升回"],["升回去","升回去"],["升回来","升回來"],["升在","升在"],["升坐","升坐"],["升堂","升堂"],["升堂入室","升堂入室"],["升堂拜母","升堂拜母"],["升天","昇天"],["升好","升好"],["升学","升學"],["升学主义","升學主義"],["升学压力","升學壓力"],["升学率","升學率"],["升学班","升學班"],["升学考试","升學考試"],["升官","升官"],["升官发财","升官發財"],["升官图","升官圖"],["升帐","升帳"],["升幂","升冪"],["升幂级数","升冪級數"],["升幅","升幅"],["升平","昇平"],["升引","升引"],["升得","升得"],["升息","升息"],["升成","升成"],["升斗","升斗"],["升斗之禄","升斗之祿"],["升斗小民","升斗小民"],["升旗","升旗"],["升旗仪式","升旗儀式"],["升旗典礼","升旗典禮"],["升来","升來"],["升来升去","升來升去"],["升格","升格"],["升格为","升格爲"],["升格成","升格成"],["升水","升水"],["升汞","昇汞"],["升沉","升沉"],["升温","升溫"],["升火","升火"],["升点","升點"],["升爲","升爲"],["升班","升班"],["升班考试","升班考試"],["升的","升的"],["升破","升破"],["升科","升科"],["升空","升空"],["升等","升等"],["升等考试","升等考試"],["升级","升級"],["升级性","升級性"],["升级成","升級成"],["升级换代","升級換代"],["升级版","升級版"],["升结肠","升結腸"],["升职","升職"],["升腾","升騰"],["升至","升至"],["升记号","升記號"],["升调","升調"],["升起","升起"],["升起来","升起來"],["升迁","升遷"],["升迁制度","升遷制度"],["升迁管道","升遷管道"],["升过","升過"],["升速","升速"],["升遐","升遐"],["升阳","昇陽"],["升阶","升階"],["升降","升降"],["升降机","升降機"],["升降梯","升降梯"],["升降舵","升降舵"],["升降记号","升降記號"],["升限","升限"],["升高","升高"],["升高为","升高爲"],["升高自下","升高自下"],["午后","午後"],["半个","半個"],["半个世纪","半個世紀"],["半乳糖血症","半乳糖血症"],["半于","半於"],["半价","半價"],["半价优待","半價優待"],["半价倍息","半價倍息"],["半保留复制","半保留複製"],["半分钟","半分鐘"],["半制品","半製品"],["半只","半隻"],["半吊子","半吊子"],["半夜里","半夜裏"],["半导体厂","半導體廠"],["半岛电视台","半島電視臺"],["半干","半乾"],["半径范围","半徑範圍"],["半托","半托"],["半排出期","半排出期"],["半日制","半日制"],["半日制学校","半日制學校"],["半杯","半杯"],["半板","半板"],["半涂而罢","半塗而罷"],["半点钟","半點鐘"],["半票价","半票價"],["半秒钟","半秒鐘"],["半老徐娘","半老徐娘"],["半路出家","半路出家"],["半里","半里"],["半面","半面"],["半面之交","半面之交"],["半面之旧","半面之舊"],["华东师范","華東師範"],["华东师范大学","華東師範大學"],["华严钟","華嚴鐘"],["华中师范大学","華中師範大學"],["华冈艺术学校","華岡藝術學校"],["华南师范大学","華南師範大學"],["华发","華髮"],["华尔滋舞曲","華爾滋舞曲"],["华彩","華彩"],["华志","華志"],["华星秋月之章","華星秋月之章"],["华核","華覈"],["华氏寒暑表","華氏寒暑表"],["华润万家","華潤萬家"],["华特里德","華特里德"],["华纳音乐集团","華納音樂集團"],["华胄","華胄"],["华表","華表"],["华表鹤归","華表鶴歸"],["华里","華里"],["华阳国志","華陽國志"],["协力同心","協力同心"],["协合","協合"],["协同","協同"],["协同作战","協同作戰"],["协同作用","協同作用"],["协同动作","協同動作"],["协奏曲","協奏曲"],["协议范本","協議範本"],["协议规范","協議規範"],["协调出","協調出"],["卑梁之衅","卑梁之釁"],["卓别林","卓別林"],["卓尔出群","卓爾出羣"],["卓柏卡布拉","卓柏卡布拉"],["单一价","單一價"],["单一合体字","單一合體字"],["单个儿","單個兒"],["单于","單于"],["单交种","單交種"],["单价","單價"],["单位价格","單位價格"],["单位信托","單位信托"],["单位切向量","單位切向量"],["单位制","單位制"],["单位向量","單位向量"],["单位面积","單位面積"],["单克隆","單克隆"],["单克隆抗体","單克隆抗體"],["单单于","單單於"],["单只","單隻"],["单只是","單只是"],["单叶双曲面","單葉雙曲面"],["单向","單向"],["单向天线","單向天線"],["单向电流","單向電流"],["单向行驶","單向行駛"],["单向通车","單向通車"],["单向道","單向道"],["单向阀","單向閥"],["单周","單週"],["单味药","單味藥"],["单夫只妇","單夫隻婦"],["单婚制","單婚制"],["单子叶","單子葉"],["单子叶植物","單子葉植物"],["单字表","單字表"],["单干","單幹"],["单干户","單幹戶"],["单张汇票","單張匯票"],["单弦","單絃"],["单循环赛制","單循環賽制"],["单打独斗","單打獨鬥"],["单挂号","單掛號"],["单据","單據"],["单摆","單擺"],["单方制剂","單方製劑"],["单方向","單方向"],["单方面","單方面"],["单曲","單曲"],["单曲榜","單曲榜"],["单杠","單槓"],["单杯","單杯"],["单板","單板"],["单板心合板","單板心合板"],["单板机","單板機"],["单核","單核"],["单核细胞增多症","單核細胞增多症"],["单模光纤","單模光纖"],["单法货制","單法貨制"],["单端孢霉烯类毒素中毒症","單端孢黴烯類毒素中毒症"],["单系","單系"],["单链","單鏈"],["单面","單面"],["单面山","單面山"],["卖不出去","賣不出去"],["卖个破绽","賣個破綻"],["卖了","賣了"],["卖了儿子招女婿","賣了兒子招女婿"],["卖价","賣價"],["卖俏营奸","賣俏營奸"],["卖俏行奸","賣俏行奸"],["卖俏迎奸","賣俏迎奸"],["卖光了","賣光了"],["卖出","賣出"],["卖出去","賣出去"],["卖卜","賣卜"],["卖卜测字","賣卜測字"],["卖卦口没量斗","賣卦口沒量斗"],["卖呆","賣呆"],["卖奸","賣姦"],["卖恶","賣惡"],["卖拐","賣柺"],["卖油娘子水梳头","賣油娘子水梳頭"],["卖炭的掉在面缸里","賣炭的掉在麪缸裏"],["卖盐的做雕銮匠","賣鹽的做雕鑾匠"],["卖红萝卜","賣紅蘿蔔"],["卖膏药的","賣膏藥的"],["卖良姜","賣良姜"],["卖药","賣藥"],["卖药人","賣藥人"],["卖荳腐点了河滩地","賣荳腐點了河灘地"],["卖金须向识金家","賣金須向識金家"],["卖面子","賣面子"],["南丰","南豐"],["南丰县","南豐縣"],["南京钟","南京鐘"],["南京钟表","南京鐘錶"],["南出","南出"],["南北向","南北向"],["南北极","南北極"],["南台","南臺"],["南台工专","南臺工專"],["南台湾","南臺灣"],["南叶门","南葉門"],["南向","南向"],["南回","南迴"],["南回公路","南迴公路"],["南回归线","南迴歸線"],["南回线","南迴線"],["南回铁路","南迴鐵路"],["南宫适","南宮适"],["南屏晚钟","南屏晚鐘"],["南山并寿","南山並壽"],["南山有台","南山有臺"],["南山杯","南山盃"],["南岳","南嶽"],["南征","南征"],["南征北伐","南征北伐"],["南征北战","南征北戰"],["南征北讨","南征北討"],["南方周末","南方週末"],["南无阿弥陀佛","南無阿彌陀佛"],["南曲","南曲"],["南朝梁","南朝梁"],["南极","南極"],["南极仙翁","南極仙翁"],["南极光","南極光"],["南极呈祥","南極呈祥"],["南极圈","南極圈"],["南极地区","南極地區"],["南极大陆","南極大陸"],["南极座","南極座"],["南极星沉","南極星沉"],["南极星辉","南極星輝"],["南极洲","南極洲"],["南极洲半岛","南極洲半島"],["南极老人星","南極老人星"],["南极腾辉","南極騰輝"],["南枝向火北枝寒","南枝向火北枝寒"],["南汇","南匯"],["南汇区","南匯區"],["南洋模范","南洋模範"],["南游","南遊"],["南特杰克","南特傑克"],["南筑","南筑"],["南箕北斗","南箕北斗"],["南胡","南胡"],["南里","南里"],["南针","南針"],["南面","南面"],["南面为王","南面爲王"],["南面百城","南面百城"],["南面称伯","南面稱伯"],["南面称孤","南面稱孤"],["南面称王","南面稱王"],["博克达山","博克達山"],["博古图录","博古圖錄"],["博士后","博士後"],["博学多才","博學多才"],["博客里","博客裏"],["博尔塔拉蒙古自治州","博爾塔拉蒙古自治州"],["博彩","博彩"],["博彩业","博彩業"],["博文反应系列","博文反應系列"],["博斗","博鬥"],["博汇","博彙"],["博物志","博物志"],["博莱克","博萊克"],["博蒙特","博蒙特"],["博采","博採"],["博采众长","博採衆長"],["博闻彊志","博聞彊志"],["博鳌亚洲论坛","博鰲亞洲論壇"],["卜人","卜人"],["卜儿","卜兒"],["卜冠文","卜冠文"],["卜卜","卜卜"],["卜卜米","卜卜米"],["卜卦","卜卦"],["卜卦家","卜卦家"],["卜吉","卜吉"],["卜商","卜商"],["卜夜卜昼","卜夜卜晝"],["卜威廉","卜威廉"],["卜婿","卜婿"],["卜学亮","卜學亮"],["卜宅","卜宅"],["卜居","卜居"],["卜年","卜年"],["卜度","卜度"],["卜式","卜式"],["卜征","卜征"],["卜日","卜日"],["卜易","卜易"],["卜昼卜夜","卜晝卜夜"],["卜珓","卜珓"],["卜睿哲","卜睿哲"],["卜祝","卜祝"],["卜窀穸","卜窀穸"],["卜筑","卜築"],["卜筮","卜筮"],["卜筮官","卜筮官"],["卜算","卜算"],["卜老","卜老"],["卜者","卜者"],["卜舫济","卜舫濟"],["卜蜂","卜蜂"],["卜课","卜課"],["卜辞","卜辭"],["卜邻","卜鄰"],["卜骨","卜骨"],["卞庄","卞莊"],["卞庄子","卞莊子"],["卞梁","卞梁"],["占〇","佔〇"],["占一","佔一"],["占七","佔七"],["占万","佔万"],["占三","佔三"],["占上","占上"],["占上游","佔上游"],["占上风","佔上風"],["占下","佔下"],["占下风","佔下風"],["占不占","佔不佔"],["占不足","佔不足"],["占世界","佔世界"],["占东","佔東"],["占两","佔兩"],["占个","佔個"],["占个位","佔個位"],["占中","佔中"],["占为","佔爲"],["占为己有","佔爲己有"],["占主","佔主"],["占主导地位","占主導地位"],["占九","佔九"],["占了","佔了"],["占了卜","占了卜"],["占二","佔二"],["占五","佔五"],["占亲","占親"],["占人","占人"],["占人便宜","佔人便宜"],["占亿","佔億"],["占优","佔優"],["占优势","佔優勢"],["占位","佔位"],["占住","佔住"],["占便宜","佔便宜"],["占便宜的是呆","佔便宜的是呆"],["占俄","佔俄"],["占候","占候"],["占停车","佔停車"],["占先","佔先"],["占光","佔光"],["占全","佔全"],["占八","佔八"],["占六","佔六"],["占凤","占鳳"],["占分","佔分"],["占到","佔到"],["占加","佔加"],["占劣","佔劣"],["占北","佔北"],["占十","佔十"],["占千","佔千"],["占半","佔半"],["占南","佔南"],["占卜","占卜"],["占卜师","占卜師"],["占卜术","占卜術"],["占占","佔佔"],["占卦","占卦"],["占印","佔印"],["占压","佔壓"],["占去","佔去"],["占取","佔取"],["占台","佔臺"],["占后","佔後"],["占哺乳","佔哺乳"],["占嗫","佔囁"],["占四","佔四"],["占国内","佔國內"],["占在","佔在"],["占地","佔地"],["占地盘","佔地盤"],["占场","佔場"],["占场儿","佔場兒"],["占城","占城","佔城"],["占多","佔多"],["占多数","佔多數"],["占大","佔大"],["占头","佔頭"],["占头筹","佔頭籌"],["占好","佔好"],["占射","占射"],["占小","佔小"],["占少","佔少"],["占尽","佔盡"],["占尽便宜","佔盡便宜"],["占局部","佔局部"],["占居","佔居"],["占屋","佔屋"],["占山","佔山"],["占市场","佔市場"],["占平均","佔平均"],["占床","佔牀"],["占座","佔座"],["占强","占強"],["占得","佔得"],["占德","佔德"],["占总","佔總"],["占房","占房"],["占拜","占拜"],["占据","佔據"],["占掉","佔掉"],["占整体","佔整體"],["占断","占斷"],["占新","佔新"],["占星","占星"],["占星学","占星學"],["占星家","占星家"],["占星师","占星師"],["占星术","占星術"],["占有","佔有"],["占有五不验","占有五不驗"],["占有权","佔有權"],["占有欲","佔有慾"],["占有率","佔有率"],["占查","佔查"],["占梦","占夢"],["占次","佔次"],["占比","佔比"],["占毕","佔畢"],["占法","佔法"],["占满","佔滿"],["占澳","佔澳"],["占爲","佔爲"],["占率","佔率"],["占用","佔用"],["占百","佔百"],["占着","佔着"],["占稳","佔穩"],["占筮","占筮"],["占线","佔線"],["占缺","佔缺"],["占网","佔網"],["占美","佔美"],["占耕","佔耕"],["占至多","佔至多"],["占至少","佔至少"],["占花魁","佔花魁"],["占苏","佔蘇"],["占英","佔英"],["占葡","佔葡"],["占西","佔西"],["占课","占課","佔課"],["占资源","佔資源"],["占起","佔起"],["占起来","佔起來"],["占超过","佔超過"],["占身","占身"],["占过","佔過"],["占过去","佔過去"],["占过来","佔過來"],["占道","佔道"],["占零","佔零"],["占領","佔領"],["占领","佔領"],["占领军","佔領軍"],["占领区","佔領區"],["占领地","佔領地"],["占领者","佔領者"],["占风使帆","占風使帆"],["占饭","佔飯"],["占香","佔香"],["占马","佔馬"],["占验","占驗"],["占高枝儿","佔高枝兒"],["占鳌头","佔鰲頭"],["卡其布","卡其布"],["卡卡布","卡卡布"],["卡尔加里","卡爾加里"],["卡尔扎伊","卡爾扎伊"],["卡尔文克莱因","卡爾文克萊因"],["卡布","卡布"],["卡布其诺","卡布其諾"],["卡布其诺咖啡","卡布其諾咖啡"],["卡布列拉","卡布列拉"],["卡布奇诺","卡布奇諾"],["卡布瑞","卡布瑞"],["卡布瑞拉","卡布瑞拉"],["卡布雷拉","卡布雷拉"],["卡带柜","卡帶櫃"],["卡式录音带","卡式錄音帶"],["卡式录音机","卡式錄音機"],["卡扎菲","卡扎菲"],["卡扣","卡扣"],["卡拉布里亚","卡拉布里亞"],["卡拉曼里斯","卡拉曼里斯"],["卡洛里","卡洛里"],["卡片柜","卡片櫃"],["卡片目录","卡片目錄"],["卡特里娜","卡特里娜"],["卡纳塔克邦","卡納塔克邦"],["卡耶里","卡耶里"],["卡芬雅克","卡芬雅克"],["卡苏里","卡蘇里"],["卡萨布兰加","卡薩布蘭加"],["卡萨布兰卡","卡薩布蘭卡"],["卡路里","卡路里"],["卡迪拉克","卡迪拉克"],["卡里","卡里"],["卡里扎德","卡里紮德"],["卡面","卡面"],["卢仁杰","盧仁傑"],["卢克索","盧克索"],["卢千惠","盧千惠"],["卢同","盧同"],["卢布","盧布"],["卢布尔雅那","盧布爾雅那"],["卢布里雅纳","盧布里雅納"],["卢棱伽","盧棱伽"],["卢比西克","盧比西克"],["卢胡","盧胡"],["卢贝松","盧貝松"],["卢郁佳","盧郁佳"],["卤人","鹵人"],["卤代烃","鹵代烴"],["卤制","滷製"],["卤化","鹵化"],["卤化物","鹵化物"],["卤化银","鹵化銀"],["卤味","滷味"],["卤地","鹵地"],["卤族","鹵族"],["卤梅水","滷梅水"],["卤水","滷水"],["卤汁","滷汁"],["卤湖","滷湖"],["卤煮","滷煮"],["卤牛肉","滷牛肉"],["卤簿","鹵簿"],["卤素","鹵素"],["卤素灯","鹵素燈"],["卤肉","滷肉"],["卤肉饭","滷肉飯"],["卤莽","鹵莽"],["卤莽灭裂","鹵莽滅裂"],["卤菜","滷菜"],["卤虾","滷蝦"],["卤虾油","滷蝦油"],["卤蛋","滷蛋"],["卤钝","鹵鈍"],["卤面","滷麪"],["卤鸡","滷雞"],["卤鸡肉","滷雞肉"],["卦千纸","卦千紙"],["卧室里","臥室裏"],["卧游","臥遊"],["卧薪尝胆","臥薪嚐膽"],["卫教系","衛教系"],["卫星云图","衛星雲圖"],["卫星定位系统","衛星定位系統"],["卫星导航系统","衛星導航系統"],["卫星钟","衛星鐘"],["卫生标准","衛生標準"],["卫生系","衛生系"],["卯上干","卯上幹"],["卯后酒","卯後酒"],["卯尽全力","卯盡全力"],["卯足了劲","卯足了勁"],["卯酉参辰","卯酉參辰"],["印不出","印不出"],["印佣","印傭"],["印出","印出"],["印出去","印出去"],["印出来","印出來"],["印制","印製"],["印制厂","印製廠"],["印制电路","印製電路"],["印制电路板","印製電路板"],["印刷厂","印刷廠"],["印刷术","印刷術"],["印刷电路板","印刷電路板"],["印发","印發"],["印台","印臺"],["印台区","印臺區"],["印合","印合"],["印堂发黑","印堂發黑"],["印度人民党","印度人民黨"],["印度国大党","印度國大黨"],["印度法系","印度法系"],["印板儿","印板兒"],["印染厂","印染廠"],["印核","印核"],["印欧语系","印歐語系"],["印累绶若","印累綬若"],["印花布","印花布"],["印表","印表"],["印表机","印表機"],["印鉴","印鑑"],["印鉴鉴定","印鑑鑑定"],["危于","危於"],["危于累卵","危於累卵"],["危亡之秋","危亡之秋"],["危害评价","危害評價"],["即兴发挥","即興發揮"],["即兴曲","即興曲"],["即兴表演","即興表演"],["即期外汇交易","即期外匯交易"],["即期汇票","即期匯票"],["即食面","即食麪"],["却后","卻後"],["却回去","卻回去"],["却回来","卻回來"],["却才","卻纔"],["卵与石斗","卵與石鬥"],["卵核","卵核"],["卷一卷","捲一捲"],["卷上","捲上"],["卷不起","捲不起"],["卷了","捲了"],["卷云","捲雲"],["卷住","捲住"],["卷儿","卷兒"],["卷入","捲入"],["卷入漩涡","捲入漩渦"],["卷刃","捲刃"],["卷到","捲到"],["卷动","捲動"],["卷动门","捲動門"],["卷包","捲包"],["卷卷","卷卷"],["卷去","捲去"],["卷发","捲髮"],["卷发器","捲髮器"],["卷取","卷取"],["卷叶蛾","卷葉蛾"],["卷吸作用","捲吸作用"],["卷回","捲回"],["卷图","捲圖"],["卷土","捲土"],["卷土重来","捲土重來"],["卷地皮","卷地皮"],["卷娄","卷婁"],["卷子","卷子"],["卷子本","卷子本"],["卷宗","卷宗"],["卷尺","捲尺"],["卷尾猴","捲尾猴"],["卷层云","卷層雲"],["卷層云","捲層雲"],["卷帘","捲簾"],["卷帘格","捲簾格"],["卷帘门","捲簾門"],["卷帙","卷帙"],["卷帙浩繁","卷帙浩繁"],["卷帻","卷幘"],["卷开","捲開"],["卷心","捲心"],["卷心菜","捲心菜"],["卷怀","卷懷"],["卷成","捲成"],["卷扬","捲揚"],["卷扬机","捲揚機"],["卷拢","捲攏"],["卷旋","捲旋"],["卷旗息鼓","卷旗息鼓"],["卷曲","捲曲"],["卷来","捲來"],["卷来卷去","捲來捲去"],["卷柏","卷柏"],["卷染","卷染"],["卷棚","捲棚"],["卷款","捲款"],["卷款潜逃","捲款潛逃"],["卷款逃走","捲款逃走"],["卷毛","捲毛"],["卷浪","捲浪"],["卷浪翻波","捲浪翻波"],["卷烟","捲菸"],["卷烟画片","捲煙畫片"],["卷烟盒","捲菸盒"],["卷甲","卷甲"],["卷甲重来","捲甲重來"],["卷积云","卷積雲"],["卷笔刀","卷筆刀"],["卷筒","捲筒"],["卷筒纸","捲筒紙"],["卷繖花序","卷繖花序"],["卷纬","卷緯"],["卷纸","捲紙"],["卷线器","捲線器"],["卷绕","卷繞"],["卷缠","捲纏"],["卷缩","捲縮"],["卷翘","捲翹"],["卷耳","卷耳"],["卷腿裤","捲腿褲"],["卷舌","捲舌"],["卷舌元音","捲舌元音"],["卷舌音","捲舌音"],["卷舒","卷舒"],["卷舖盖","捲舖蓋"],["卷菸","捲菸"],["卷落叶","捲落葉"],["卷衣袖","捲衣袖"],["卷袖","捲袖"],["卷装","卷裝"],["卷走","捲走"],["卷起","捲起"],["卷起來","捲起來"],["卷起来","捲起來"],["卷轴","卷軸"],["卷轴式","卷軸式"],["卷轴装","卷軸裝"],["卷过","捲過"],["卷进","捲進"],["卷逃","捲逃"],["卷钢","捲鋼"],["卷铺盖","捲鋪蓋"],["卷阿","卷阿"],["卷须","卷鬚"],["卷领","卷領"],["卷风","捲風"],["卷饼","捲餅"],["卸了","卸了"],["卸尸宴","卸屍宴"],["卸扣","卸扣"],["卿云","卿雲"],["厂主","廠主"],["厂卫","廠衛"],["厂名","廠名"],["厂商","廠商"],["厂地","廠地"],["厂址","廠址"],["厂外","廠外"],["厂子","廠子"],["厂字旁","廠字旁"],["厂家","廠家"],["厂容","廠容"],["厂房","廠房"],["厂方","廠方"],["厂棚","廠棚"],["厂牌","廠牌"],["厂用电","廠用電"],["厂矿","廠礦"],["厂礼拜","廠禮拜"],["厂税","廠稅"],["厂衣","廠衣"],["厂规","廠規"],["厂部","厂部"],["厂长","廠長"],["厄台","厄臺"],["厄尔布鲁士","厄爾布魯士"],["厄立特里亚","厄立特里亞"],["厅舍","廳舍"],["历下","歷下"],["历下区","歷下區"],["历久","歷久"],["历久不衰","歷久不衰"],["历久常新","歷久常新"],["历久弥坚","歷久彌堅"],["历久弥新","歷久彌新"],["历书","曆書"],["历乱","歷亂"],["历代","歷代"],["历代先皇","歷代先皇"],["历代名画记","歷代名畫記"],["历代志上","歷代志上"],["历代志下","歷代志下"],["历代祖先","歷代祖先"],["历任","歷任"],["历元","曆元"],["历劫","歷劫"],["历劫归来","歷劫歸來"],["历历","歷歷"],["历历可数","歷歷可數"],["历历可纪","歷歷可紀"],["历历可考","歷歷可考"],["历历可见","歷歷可見"],["历历可辨","歷歷可辨"],["历历在目","歷歷在目"],["历历如绘","歷歷如繪"],["历历落落","歷歷落落"],["历史","歷史"],["历史上","歷史上"],["历史久远","歷史久遠"],["历史事件","歷史事件"],["历史人物","歷史人物"],["历史剧","歷史劇"],["历史博物馆","歷史博物館"],["历史名词","歷史名詞"],["历史学","歷史學"],["历史学家","歷史學家"],["历史学者","歷史學者"],["历史家","歷史家"],["历史小说","歷史小說"],["历史年表","歷史年表"],["历史性","歷史性"],["历史总在重演","歷史總在重演"],["历史悠久","歷史悠久"],["历史意义","歷史意義"],["历史文学","歷史文學"],["历史新高","歷史新高"],["历史时代","歷史時代"],["历史时期","歷史時期"],["历史比较语言学","歷史比較語言學"],["历史沿革","歷史沿革"],["历史潮流","歷史潮流"],["历史版本","歷史版本"],["历史社会学","歷史社會學"],["历史系","歷史系"],["历史线图","歷史線圖"],["历史背景","歷史背景"],["历史观","歷史觀"],["历史观点","歷史觀點"],["历史语言学","歷史語言學"],["历史语词","歷史語詞"],["历史课","歷史課"],["历史遗产","歷史遺產"],["历史遗迹","歷史遺蹟"],["历史里","歷史裏"],["历史重演","歷史重演"],["历命","曆命"],["历城","歷城"],["历城区","歷城區"],["历城县","歷城縣"],["历夏经秋","歷夏經秋"],["历头","曆頭"],["历始","曆始"],["历审","歷審"],["历室","曆室"],["历尽","歷盡"],["历尽沧桑","歷盡滄桑"],["历尽艰辛","歷盡艱辛"],["历尽艰险","歷盡艱險"],["历尽艰难","歷盡艱難"],["历尾","曆尾"],["历届","歷屆"],["历山","歷山"],["历年","歷年"],["历年来","歷年來"],["历数","歷數"],["历日","歷日"],["历日旷久","歷日曠久"],["历时","歷時"],["历月","歷月"],["历有年所","歷有年所"],["历朝","歷朝"],["历朝历代","歷朝歷代"],["历朝通俗演义","歷朝通俗演義"],["历本","曆本"],["历来","歷來"],["历来如此","歷來如此"],["历来最低点","歷來最低點"],["历次","歷次"],["历正","歷正"],["历沴","歷沴"],["历法","曆法"],["历澜","歷瀾"],["历物之意","歷物之意"],["历狱","曆獄"],["历碌","歷碌"],["历程","歷程"],["历纪","曆紀"],["历线","歷線"],["历练","歷練"],["历练之才","歷練之才"],["历练老成","歷練老成"],["历经","歷經"],["历经沧桑","歷經滄桑"],["历经波折","歷經波折"],["历落","歷落"],["历象","曆象"],["历象表","曆象表"],["历遍","歷遍"],["历险","歷險"],["历险归来","歷險歸來"],["历险记","歷險記"],["历齿","歷齒"],["压价","壓價"],["压克力","壓克力"],["压克力板","壓克力板"],["压出","壓出"],["压出去","壓出去"],["压出来","壓出來"],["压制","壓制","壓製"],["压制住","壓制住"],["压制性","壓制性"],["压力团体","壓力團體"],["压力症","壓力症"],["压力表","壓力錶"],["压卷","壓卷"],["压回","壓回"],["压回去","壓回去"],["压回来","壓回來"],["压杆","壓桿"],["压板","壓板"],["压缩饼干","壓縮餅乾"],["压胄子","壓冑子"],["压舌板","壓舌板"],["压面棍","壓麪棍"],["厌恶","厭惡"],["厌恶感","厭惡感"],["厌食症","厭食症"],["厓谷","厓谷"],["厘出","釐出"],["厘升","釐升"],["厘定","釐定"],["厘改","釐改"],["厘整","釐整"],["厘正","釐正"],["厘清","釐清"],["厘米","釐米"],["厘订","釐訂"],["厘金","厘金"],["厘革","釐革"],["厚朴","厚朴"],["厚板","厚板"],["厚纸板","厚紙板"],["厝薪于火","厝薪於火"],["原于","原於"],["原价","原價"],["原厂","原廠"],["原厂药","原廠藥"],["原发","原發"],["原发性","原發性"],["原发性进行性失语","原發性進行性失語"],["原叶体","原葉體"],["原始公社制度","原始公社制度"],["原始艺术","原始藝術"],["原始记录","原始記錄"],["原子云","原子雲"],["原子价","原子價"],["原子发电厂","原子發電廠"],["原子团","原子團"],["原子爆破弹药","原子爆破彈藥"],["原子能发电","原子能發電"],["原子能发电站","原子能發電站"],["原子钟","原子鐘"],["原定价","原定價"],["原料价格","原料價格"],["原料药","原料藥"],["原曲","原曲"],["原板","原板"],["原核","原核"],["原种","原種"],["原纤维","原纖維"],["原苏联","原蘇聯"],["原虫","原蟲"],["原野游侠","原野遊俠"],["原钟","原鐘"],["原须","原須"],["厥后","厥後"],["厨余","廚餘"],["厨娘","廚娘"],["厨柜","廚櫃"],["厮斗","廝鬥"],["厮舍","廝舍"],["去不了","去不了"],["去了","去了"],["去借","去借"],["去台人员","去臺人員"],["去后","去後"],["去向","去向"],["去向不明","去向不明"],["去干","去幹"],["去念","去念"],["去恶从善","去惡從善"],["去搜","去搜"],["去暗投明","去暗投明"],["去杀胜残","去殺勝殘"],["去核","去核"],["县党部","縣黨部"],["县志","縣誌"],["县里","縣裏"],["参与","參與"],["参与人员","參與人員"],["参与制","參與制"],["参与度","參與度"],["参与感","參與感"],["参与权","參與權"],["参与率","參與率"],["参与者","參與者"],["参两院","參兩院"],["参予","參予"],["参事","參事"],["参伍","參伍"],["参众两院","參衆兩院"],["参会","參會"],["参佐","參佐"],["参假","參假"],["参军","參軍"],["参前落后","參前落後"],["参加","參加"],["参加为","參加爲"],["参加人","參加人"],["参加国","參加國"],["参加奖","參加獎"],["参加完","參加完"],["参加者","參加者"],["参劾","參劾"],["参半","參半"],["参合","參合"],["参同契","參同契"],["参商","參商"],["参团","參團"],["参场","參場"],["参堂","參堂"],["参天","參天"],["参头","參頭"],["参奏","參奏"],["参孙","參孫"],["参宿","參宿"],["参宿七","參宿七"],["参将","參將"],["参展","參展"],["参展商","參展商"],["参展团","參展團"],["参差","參差"],["参差不齐","參差不齊"],["参差错落","參差錯落"],["参度","參度"],["参悟","參悟"],["参战","參戰"],["参战国","參戰國"],["参拜","參拜"],["参拾壹","參拾壹"],["参拾陆","參拾陸"],["参政","參政"],["参政权","參政權"],["参数","參數"],["参朝","參朝"],["参本","參本"],["参杂","參雜"],["参校","參校"],["参汤","蔘湯"],["参演","參演"],["参灵","參靈"],["参照","參照"],["参照卡","參照卡"],["参照物","參照物"],["参照系","參照系"],["参看","參看"],["参知政事","參知政事"],["参破","參破"],["参禅","參禪"],["参绥","蔘綏"],["参综","參綜"],["参考","參考"],["参考书","參考書"],["参考书目","參考書目"],["参考价","參考價"],["参考价值","參考價值"],["参考值","參考值"],["参考参考","參考參考"],["参考座标","參考座標"],["参考性","參考性"],["参考手冊","參考手冊"],["参考文献","參考文獻"],["参考材料","參考材料"],["参考法","參考法"],["参考消息","參考消息"],["参考特藏","參考特藏"],["参考系","參考系"],["参考资料","參考資料"],["参股","參股"],["参茸","蔘茸"],["参见","參見"],["参见互照","參見互照"],["参见注","參見注"],["参观","參觀"],["参观券","參觀券"],["参观参观","參觀參觀"],["参观团","參觀團"],["参观团体","參觀團體"],["参观完","參觀完"],["参观者","參觀者"],["参订","參訂"],["参训","參訓"],["参议","參議"],["参议会","參議會"],["参议员","參議員"],["参议院","參議院"],["参访","參訪"],["参访团","參訪團"],["参评","參評"],["参话头","參話頭"],["参请","參請"],["参谋","參謀"],["参谋总部","參謀總部"],["参谋总长","參謀總長"],["参谋长","參謀長"],["参谒","參謁"],["参谭","參譚"],["参赛","參賽"],["参赛国","參賽國"],["参赛权","參賽權"],["参赛片","參賽片"],["参赛者","參賽者"],["参赞","參贊"],["参辰","參辰"],["参辰卯酉","參辰卯酉"],["参辰日月","參辰日月"],["参选","參選"],["参选人","參選人"],["参透","參透"],["参道","參道"],["参酌","參酌"],["参量","參量"],["参量空间","參量空間"],["参错","參錯"],["参阅","參閱"],["参院","參院"],["参革","參革"],["参预","參預"],["参验","參驗"],["又云","又云"],["又咸","又鹹"],["又咽","又咽"],["又干","又幹"],["又干又硬","又乾又硬"],["又弱一个","又弱一個"],["又当别论","又當別論"],["又摇又摆","又搖又擺"],["又来了","又來了"],["又饥又渴","又飢又渴"],["及于","及於"],["及早准备","及早準備"],["友于","友于"],["友党","友黨"],["友台","友臺"],["友好代表","友好代表"],["友好关系","友好關係"],["友情价","友情價"],["友民党","友民黨"],["友谊万岁","友誼萬歲"],["双丰","雙豐"],["双主修","雙主修"],["双凸面","雙凸面"],["双台子","雙臺子"],["双台子区","雙臺子區"],["双叶","雙葉"],["双后前兵开局","雙后前兵開局"],["双向","雙向"],["双向交通","雙向交通"],["双向沟通","雙向溝通"],["双向讨论区","雙向討論區"],["双周","雙週"],["双周刊","雙週刊"],["双周期性","雙週期性"],["双回门","雙回門"],["双复磷","雙復磷"],["双子叶","雙子葉"],["双子叶植物","雙子葉植物"],["双手万能","雙手萬能"],["双手赞成","雙手贊成"],["双扣","雙扣"],["双折","雙摺"],["双折射","雙折射"],["双拐","雙柺"],["双挂号","雙掛號"],["双捻布","雙捻布"],["双方同意","雙方同意"],["双方面","雙方面"],["双曲","雙曲"],["双曲余割","雙曲餘割"],["双曲余弦","雙曲餘弦"],["双曲抛物面","雙曲拋物面"],["双曲拱桥","雙曲拱橋"],["双曲正弦","雙曲正弦"],["双曲线","雙曲線"],["双曲线正弦","雙曲線正弦"],["双杠","雙槓"],["双杯","雙杯"],["双柑斗酒","雙柑斗酒"],["双核","雙核"],["双江拉祜族佤族布朗族傣族自治县","雙江拉祜族佤族布朗族傣族自治縣"],["双湖特别区","雙湖特別區"],["双画面电视","雙畫面電視"],["双胜类","雙胜類"],["双语立体声系统","雙語立體聲系統"],["双轨制","雙軌制"],["双进双出","雙進雙出"],["双重标准","雙重標準"],["双链","雙鏈"],["双链核酸","雙鏈核酸"],["双雕","雙鵰"],["双面","雙面"],["双面人","雙面人"],["双面娇娃","雙面嬌娃"],["双面谍","雙面諜"],["双龙大裂谷","雙龍大裂谷"],["反个","反個"],["反乱并","反亂併"],["反了","反了"],["反于","反於"],["反修","反修"],["反光板","反光板"],["反光面","反光面"],["反冲","反衝"],["反冲力","反衝力"],["反制","反制"],["反升","反升"],["反卷","反捲"],["反反复复","反反覆覆"],["反叛党","反叛黨"],["反右派斗争","反右派鬥爭"],["反向","反向"],["反向而行","反向而行"],["反回头","反回頭"],["反坦克","反坦克"],["反坦克炮","反坦克炮"],["反复","反覆","反復"],["反复不一","反覆不一"],["反复不定","反覆不定"],["反复不常","反覆不常"],["反复制","反複製"],["反复思维","反覆思維"],["反复思量","反覆思量"],["反复性","反覆性"],["反复无常","反覆無常"],["反对党","反對黨"],["反导向","反導向"],["反导向飞弹","反導向飛彈"],["反导系统","反導系統"],["反射面","反射面"],["反录病毒","反錄病毒"],["反托拉斯","反托拉斯"],["反托拉斯法案","反托拉斯法案"],["反扣","反扣","反釦"],["反掌折枝","反掌折枝"],["反攻复国","反攻復國"],["反攻复国大业","反攻復國大業"],["反攻复国战争","反攻復國戰爭"],["反斗","反斗"],["反斗城","反斗城"],["反方向","反方向"],["反时针","反時針"],["反时钟","反時鐘"],["反时钟方向","反時鐘方向"],["反映出","反映出"],["反映出来","反映出來"],["反曲弓","反曲弓"],["反朴","反樸"],["反核","反核"],["反清复明","反清復明"],["反烟","反煙"],["反烟运动","反煙運動"],["反目成仇","反目成仇"],["反经合义","反經合義"],["反袁斗争","反袁鬥爭"],["反败为胜","反敗爲勝"],["反转录","反轉錄"],["反转录病毒","反轉錄病毒"],["反酷刑折磨公约","反酷刑折磨公約"],["反铲","反剷"],["反阴复阴","反陰復陰"],["反面","反面"],["反面人物","反面人物"],["反面儿","反面兒"],["反面教员","反面教員"],["反面教材","反面教材"],["反面无情","反面無情"],["反面角色","反面角色"],["反颜相向","反顏相向"],["反馈表","反饋表"],["发上","發上"],["发上冲冠","髮上衝冠"],["发上去","發上去"],["发上指冠","髮上指冠"],["发上来","發上來"],["发下","發下"],["发下去","發下去"],["发下来","發下來"],["发不出","發不出"],["发不到","發不到"],["发不起","發不起"],["发业","發業"],["发丝","髮絲"],["发丧","發喪"],["发个","發個"],["发个儿","發個兒"],["发为血之本","髮爲血之本"],["发乎情","發乎情"],["发乎情止乎礼义","發乎情止乎禮義"],["发乔","發喬"],["发书","發書"],["发乱钗横","髮亂釵橫"],["发乳","髮乳"],["发了","發了"],["发予","發予"],["发于","發於"],["发些","發些"],["发交","發交"],["发亮","發亮"],["发人","發人"],["发人深省","發人深省"],["发人省思","發人省思"],["发付","發付"],["发令","發令"],["发令枪","發令槍"],["发件人","發件人"],["发作","發作"],["发俊科","發俊科"],["发信","發信"],["发信号","發信號"],["发像管","發像管"],["发僵","發僵"],["发兆","發兆"],["发光","發光"],["发光二极体","發光二極體"],["发光二极管","發光二極管"],["发光体","發光體"],["发光可鉴","髮光可鑑"],["发光器","發光器"],["发光屏","發光屏"],["发光度","發光度"],["发光强度","發光強度"],["发光颜料","發光顏料"],["发兵","發兵"],["发冢","發冢"],["发冷","發冷"],["发凡","發凡"],["发凡举例","發凡舉例"],["发出","發出"],["发出去","發出去"],["发出指示","發出指示"],["发出来","發出來"],["发函","發函"],["发刊","發刊"],["发刊词","發刊詞"],["发利市","發利市"],["发到","發到"],["发功","發功"],["发动","發動"],["发动力","發動力"],["发动期","發動期"],["发动机","發動機"],["发包","發包"],["发包给","發包給"],["发匪","髮匪"],["发匮","發匱"],["发单","發單"],["发卖","發賣"],["发卡","髮卡","發卡"],["发卷","髮捲"],["发去","發去"],["发发","發發"],["发叶","發葉"],["发号","發號"],["发号令","發號令"],["发号出令","發號出令"],["发号布令","發號佈令"],["发号施令","發號施令"],["发向","發向"],["发呆","發呆"],["发呕","發嘔"],["发咒","發咒"],["发响","發響"],["发哑","發啞"],["发哥","發哥"],["发售","發售"],["发售量","發售量"],["发喉急","發喉急"],["发喊连天","發喊連天"],["发喘","發喘"],["发嘎嘎声","發嘎嘎聲"],["发嘘声","發噓聲"],["发噱","發噱"],["发回","發回"],["发回去","發回去"],["发回来","發回來"],["发困","發睏"],["发圈","髮圈"],["发型","髮型"],["发型师","髮型師"],["发墨","發墨"],["发声","發聲"],["发声器","發聲器"],["发声器官","發聲器官"],["发声法","發聲法"],["发复","發覆"],["发天阴","發天陰"],["发头","發頭"],["发头风","發頭風"],["发夹","髮夾"],["发奉","發奉"],["发奋","發奮"],["发奋图强","發奮圖強"],["发奋有为","發奮有爲"],["发奖","發獎"],["发套","髮套"],["发奸摘隐","發奸摘隱"],["发奸擿伏","發奸擿伏"],["发好","發好"],["发如飞蓬","髮如飛蓬"],["发妻","髮妻"],["发姐","髮姐"],["发威","發威"],["发威动怒","發威動怒"],["发嫁","發嫁"],["发完","發完"],["发家","發家"],["发富发贵","發富發貴"],["发封","發封"],["发射","發射"],["发射井","發射井"],["发射台","發射臺"],["发射器","發射器"],["发射场","發射場"],["发射控制","發射控制"],["发射机","發射機"],["发射机应答器","發射機應答器"],["发射极","發射極"],["发射点","發射點"],["发射站","發射站"],["发尾","髮尾"],["发屋","髮屋"],["发屋求狸","發屋求狸"],["发展","發展"],["发展下去","發展下去"],["发展不平均","發展不平均"],["发展中","發展中"],["发展中国","發展中國"],["发展中国家","發展中國家"],["发展为","發展爲"],["发展出","發展出"],["发展出来","發展出來"],["发展到","發展到"],["发展区","發展區"],["发展史","發展史"],["发展局","發展局"],["发展心理","發展心理"],["发展性","發展性"],["发展成","發展成"],["发展核武器","發展核武器"],["发展潜力","發展潛力"],["发展生产","發展生產"],["发展的国家","發展的國家"],["发展研究中心","發展研究中心"],["发展观","發展觀"],["发展起来","發展起來"],["发展趋势","發展趨勢"],["发展速度","發展速度"],["发展部","發展部"],["发岁","發歲"],["发已霜白","髮已霜白"],["发市","發市"],["发布","發佈"],["发布会","發佈會"],["发带","髮帶"],["发干","發乾"],["发庄","發莊"],["发廊","髮廊"],["发廪","發廩"],["发开","發開"],["发式","髮式"],["发引","發引"],["发引千钧","髮引千鈞"],["发往","發往"],["发得","發得"],["发心","發心"],["发忿","發忿"],["发怒","發怒"],["发怔","發怔"],["发急","發急"],["发性","發性"],["发怨言","發怨言"],["发怵","發怵"],["发恨","發恨"],["发息","發息"],["发恼","發惱"],["发悲","發悲"],["发悸","發悸"],["发情","發情"],["发情周期","發情周期"],["发情期","發情期"],["发想","發想"],["发愁","發愁"],["发意","發意"],["发愣","發愣"],["发愤","發憤"],["发愤努力","發憤努力"],["发愤向上","發憤向上"],["发愤图强","發憤圖強"],["发愤忘食","發憤忘食"],["发愿","發願"],["发慌","發慌"],["发憷","發憷"],["发懒","發懶"],["发成","發成"],["发扬","發揚"],["发扬光大","發揚光大"],["发扬踔厉","發揚踔厲"],["发扬蹈厉","發揚蹈厲"],["发抒","發抒"],["发抖","發抖"],["发报","發報"],["发报人","發報人"],["发报员","發報員"],["发报器","發報器"],["发报机","發報機"],["发指","髮指"],["发指令","發指令"],["发指眦裂","髮指眥裂"],["发挥","發揮"],["发挥不了","發揮不了"],["发挥作用","發揮作用"],["发挥出","發揮出"],["发挥出来","發揮出來"],["发挥到","發揮到"],["发挥性","發揮性"],["发挥所长","發揮所長"],["发挽双髻","髮挽雙髻"],["发掉","發掉"],["发排","發排"],["发掘","發掘"],["发掘出","發掘出"],["发掘出来","發掘出來"],["发掘到","發掘到"],["发摃","發摃"],["发摆子","發擺子"],["发擂","發擂"],["发擿","發擿"],["发擿奸伏","發擿奸伏"],["发收","發收"],["发改委","發改委"],["发放","發放"],["发政施仁","發政施仁"],["发散","發散"],["发文","發文"],["发文者","發文者"],["发明","發明"],["发明人","發明人"],["发明创造","發明創造"],["发明到","發明到"],["发明奖","發明獎"],["发明家","發明家"],["发明展","發明展"],["发明者","發明者"],["发昏","發昏"],["发昏章第十一","發昏章第十一"],["发春","發春"],["发晕","發暈"],["发暗","發暗"],["发有","發有"],["发木","發木"],["发村","發村"],["发束","髮束"],["发条","發條"],["发来","發來"],["发来发去","發來發去"],["发松","發鬆"],["发极","發極"],["发标","發標"],["发样","發樣"],["发根","髮根"],["发案","發案"],["发梢","髮梢"],["发梳","髮梳"],["发棠","發棠"],["发棵","發棵"],["发楞","發楞"],["发榜","發榜"],["发横","發橫"],["发横财","發橫財"],["发款","發款"],["发毛","發毛"],["发气","發氣"],["发水","發水"],["发汗","發汗"],["发汗剂","發汗劑"],["发汗药","發汗藥"],["发油","髮油"],["发泄","發泄"],["发泄出来","發泄出來"],["发泡","發泡"],["发泡体","發泡體"],["发泡剂","發泡劑"],["发泡成形","發泡成形"],["发泡胶","發泡膠"],["发洋财","發洋財"],["发洪","發洪"],["发派","發派"],["发淡科","發淡科"],["发源","發源"],["发源地","發源地"],["发漂","髮漂"],["发潮","發潮"],["发火","發火"],["发火器","發火器"],["发火点","發火點"],["发炎","發炎"],["发炎性","發炎性"],["发炮","發炮"],["发点","發點"],["发烛","發燭"],["发烟","發煙"],["发烟剂","發煙劑"],["发烦","發煩"],["发烧","發燒"],["发烧友","發燒友"],["发烧客","發燒客"],["发烧度","發燒度"],["发烧时","發燒時"],["发烧片","發燒片"],["发烫","發燙"],["发热","發熱"],["发热时","發熱時"],["发热量","發熱量"],["发爲","發爲"],["发片","發片"],["发片日","發片日"],["发牌","發牌"],["发牒","發牒"],["发牙豆","發牙豆"],["发牢骚","發牢騷"],["发物","發物"],["发状","髮狀"],["发狂","發狂"],["发狠","發狠"],["发现","發現"],["发现体","發現體"],["发现出","發現出"],["发现到","發現到"],["发现号","發現號"],["发现学习","發現學習"],["发现数","發現數"],["发现物","發現物"],["发球","發球"],["发球区","發球區"],["发球员","發球員"],["发球局","發球局"],["发球权","發球權"],["发球点","發球點"],["发生","發生"],["发生关系","發生關係"],["发生器","發生器"],["发生地","發生地"],["发生学","發生學"],["发生学分类法","發生學分類法"],["发生率","發生率"],["发甲","發甲"],["发电","發電"],["发电厂","發電廠"],["发电场","發電場"],["发电所","發電所"],["发电机","發電機"],["发电机组","發電機組"],["发电板","發電板"],["发电站","發電站"],["发电量","發電量"],["发疯","發瘋"],["发疹","發疹"],["发疹子","發疹子"],["发病","發病"],["发病率","發病率"],["发痒","發癢"],["发痛","發痛"],["发痧","發痧"],["发痴","發癡"],["发癡","發癡"],["发癣","髮癬"],["发癫","發癲"],["发白","發白"],["发白时","發白時"],["发的","發的"],["发皇","發皇"],["发皓齿","發皓齒"],["发监","發監"],["发直","發直"],["发眩","發眩"],["发矢","發矢"],["发短信","發短信"],["发短心长","髮短心長"],["发石车","發石車"],["发砲","發砲"],["发硎","發硎"],["发硎新试","發硎新試"],["发硬","發硬"],["发硬时","發硬時"],["发神经","發神經"],["发神经病","發神經病"],["发祥","發祥"],["发祥地","發祥地"],["发票","發票"],["发禁","髮禁"],["发福","發福"],["发科","發科"],["发科打诨","發科打諢"],["发积","發積"],["发稿","發稿"],["发稿时","發稿時"],["发窘","發窘"],["发端","發端"],["发端词","發端詞"],["发笑","發笑"],["发笔","發筆"],["发笺","髮箋"],["发策","發策"],["发策决科","發策決科"],["发签","發籤"],["发箍","髮箍"],["发箧","發篋"],["发箭","發箭"],["发簪","髮簪"],["发籤","發籤"],["发粉","發粉"],["发糕","發糕"],["发紫","發紫"],["发红","發紅"],["发纱","髮紗"],["发绀","發紺"],["发结","髮結"],["发给","發給"],["发绿","發綠"],["发缨","髮纓"],["发网","髮網"],["发老狠","發老狠"],["发聋振聩","發聾振聵"],["发肤","髮膚"],["发育","發育"],["发育不良","發育不良"],["发育成","發育成"],["发育期","發育期"],["发育条件","發育條件"],["发育生物学","發育生物學"],["发肿","發腫"],["发胀","發脹"],["发胀感","發脹感"],["发胖","發胖"],["发胡","發胡"],["发胶","髮膠"],["发脚","髮腳"],["发脱","發脫"],["发脱口齿","發脫口齒"],["发脾寒","發脾寒"],["发脾气","發脾氣"],["发腊","髮臘"],["发自","發自"],["发自內心","發自內心"],["发自肺腑","發自肺腑"],["发臭","發臭"],["发船","發船"],["发色","髮色"],["发色勒","髮色勒"],["发花","發花"],["发芽","發芽"],["发芽势","發芽勢"],["发芽率","發芽率"],["发草","發草"],["发草帖","發草帖"],["发菜","髮菜"],["发落","發落"],["发蒙","發矇"],["发蒙振落","發蒙振落"],["发蓝","發藍"],["发蔫","發蔫"],["发薪","發薪"],["发薪水","發薪水"],["发虚","發虛"],["发蜡","髮蠟"],["发蜡条","髮蠟條"],["发行","發行"],["发行人","發行人"],["发行商","發行商"],["发行备忘录","發行備忘錄"],["发行日","發行日"],["发行权","發行權"],["发行红利股","發行紅利股"],["发行者","發行者"],["发行量","發行量"],["发行量加权股价指数","發行量加權股價指數"],["发行额","發行額"],["发行首日","發行首日"],["发表","發表"],["发表会","發表會"],["发表出来","發表出來"],["发表声明","發表聲明"],["发表意见","發表意見"],["发表欲","發表慾"],["发表演讲","發表演講"],["发见","發見"],["发觉","發覺"],["发觉出","發覺出"],["发觉到","發覺到"],["发解","發解"],["发言","發言"],["发言中肯","發言中肯"],["发言人","發言人"],["发言人卡","發言人卡"],["发言人室","發言人室"],["发言发语","發言發語"],["发言台","發言臺"],["发言权","發言權"],["发言条","發言條"],["发言者","發言者"],["发言遣辞","發言遣辭"],["发誓","發誓"],["发讪","發訕"],["发议论","發議論"],["发话","發話"],["发话器","發話器"],["发诨子","發諢子"],["发语词","發語詞"],["发语辞","發語辭"],["发课","發課"],["发财","發財"],["发财票","發財票"],["发财致富","發財致富"],["发财金","發財金"],["发货","發貨"],["发货单","發貨單"],["发质","髮質"],["发贴","發貼"],["发起","發起"],["发起人","發起人"],["发起来","發起來"],["发起烧来","發起燒來"],["发越","發越"],["发足","發足"],["发跡","發跡"],["发踊冲冠","髮踊沖冠"],["发踪指示","發蹤指示"],["发蹙","發蹙"],["发躁","發躁"],["发身","發身"],["发车","發車"],["发轫","發軔"],["发软","發軟"],["发轿","發轎"],["发辫","髮辮"],["发达","發達"],["发达为","發達爲"],["发达到","發達到"],["发达国","發達國"],["发达国家","發達國家"],["发达地区","發達地區"],["发达起来","發達起來"],["发过","發過"],["发过去","發過去"],["发过来","發過來"],["发运","發運"],["发还","發還"],["发进","發進"],["发进去","發進去"],["发进来","發進來"],["发迹","發跡"],["发迹变泰","發跡變泰"],["发送","發送"],["发送功率","發送功率"],["发送器","發送器"],["发送机","發送機"],["发遣","發遣"],["发配","發配"],["发酒疯","發酒瘋"],["发酒风","發酒風"],["发酵","發酵"],["发酵乳","發酵乳"],["发酵乳酸","發酵乳酸"],["发酵出来","發酵出來"],["发酵粉","發酵粉"],["发酵饲料","發酵飼料"],["发酸","發酸"],["发采扬明","發采揚明"],["发野","發野"],["发量","髮量"],["发针","髮針"],["发钗","髮釵"],["发长","髮長"],["发问","發問"],["发问者","發問者"],["发闷","發悶"],["发闹","發鬧"],["发阴天","發陰天"],["发际","髮際"],["发隐擿伏","發隱擿伏"],["发难","發難"],["发雕","髮雕"],["发霉","發黴"],["发霜","髮霜"],["发露","發露"],["发青","發青"],["发面","發麪"],["发鞍","發鞍"],["发音","發音"],["发音体","發音體"],["发音合作人","發音合作人"],["发音器","發音器"],["发音器官","發音器官"],["发音学","發音學"],["发音方法","發音方法"],["发音部位","發音部位"],["发音障碍","發音障礙"],["发须俱","髮鬚俱"],["发须已","髮鬚已"],["发须斑","髮鬚斑"],["发须皆","髮鬚皆"],["发须都","髮鬚都"],["发颤","發顫"],["发风","發風"],["发风骂坐","發風罵坐"],["发飘","發飄"],["发飙","發飆"],["发飚","發飈"],["发饰","髮飾"],["发饷","發餉"],["发香","髮香"],["发马","發馬"],["发骚","發騷"],["发高烧","發高燒"],["发高热","發高熱"],["发髻","髮髻"],["发鬓","髮鬢"],["发麻","發麻"],["发黄","發黃"],["发黏","發黏"],["发黑","發黑"],["叔于田","叔于田"],["叔梁纥","叔梁紇"],["取之不尽","取之不盡"],["取之不尽用之不竭","取之不盡用之不竭"],["取了","取了"],["取信于","取信於"],["取信于人","取信於人"],["取值范围","取值範圍"],["取决于","取決於"],["取出","取出"],["取出来","取出來"],["取向","取向"],["取回","取回"],["取回去","取回去"],["取回来","取回來"],["取得一致","取得一致"],["取得胜利","取得勝利"],["取才","取才"],["取材于","取材於"],["取法于","取法於"],["取胜","取勝"],["取舍","取捨"],["取舍不定","取捨不定"],["取舍之间","取捨之間"],["取舍难定","取捨難定"],["取药","取藥"],["受不了","受不了"],["受了","受了"],["受人之托","受人之託"],["受制","受制"],["受制于","受制於"],["受制于人","受制於人"],["受命于天","受命於天"],["受困","受困"],["受夠了","受夠了"],["受尽","受盡"],["受尽压迫","受盡壓迫"],["受尽折磨","受盡折磨"],["受得了","受得了"],["受托","受託"],["受托人","受託人"],["受托者","受託者"],["受折磨","受折磨"],["受用不尽","受用不盡"],["受聘于","受聘於"],["受阻于","受阻於"],["受限于","受限於"],["受难曲","受難曲"],["受骗上当","受騙上當"],["变不了","變不了"],["变不出花样","變不出花樣"],["变丑","變醜"],["变个","變個"],["变了","變了"],["变了又变","變了又變"],["变价","變價"],["变修","變修"],["变出","變出"],["变出来","變出來"],["变动汇率","變動匯率"],["变化万端","變化萬端"],["变化范围","變化範圍"],["变回","變回"],["变回去","變回去"],["变回来","變回來"],["变奏曲","變奏曲"],["变尽方法","變盡方法"],["变异型克雅氏症","變異型克雅氏症"],["变异系数","變異係數"],["变形虫","變形蟲"],["变征","變徵"],["变征之声","變徵之聲"],["变征之音","變徵之音"],["变性手术","變性手術"],["变性气团","變性氣團"],["变暗","變暗"],["变松","變鬆"],["变相加价","變相加價"],["变种","變種"],["变种人","變種人"],["变脏","變髒"],["变质岩","變質岩"],["变速杆","變速桿"],["变造出","變造出"],["变髒","變髒"],["变魔术","變魔術"],["叙事曲","敘事曲"],["叙别","敘別"],["叙录","敘錄"],["叙述出来","敘述出來"],["叛党","叛黨"],["叠了","疊了"],["叠出","疊出"],["叠出去","疊出去"],["叠出来","疊出來"],["叠合","疊合"],["叠层岩","疊層岩"],["叠彩区","疊彩區"],["口仇","口仇"],["口出","口出"],["口出不逊","口出不遜"],["口出恶言","口出惡言"],["口出秽言","口出穢言"],["口占","口占"],["口布","口布"],["口干","口乾"],["口干舌燥","口乾舌燥"],["口彩","口彩"],["口念","口唸"],["口愿","口願"],["口才","口才"],["口才好","口才好"],["口才辨给","口才辨給"],["口技表演者","口技表演者"],["口服药","口服藥"],["口杯","口杯"],["口燥唇干","口燥脣乾"],["口燥脣干","口燥脣乾"],["口腹之欲","口腹之慾"],["口血未干","口血未乾"],["口语字词识别","口語字詞識別"],["口述出来","口述出來"],["口述历史","口述歷史"],["口里","口裏"],["口钟","口鐘"],["古书云","古書云"],["古云","古云"],["古今注","古今注"],["古典艺术","古典藝術"],["古切里","古切里"],["古制","古制"],["古巴共产党","古巴共產黨"],["古弦","古絃"],["古書云","古書云"],["古朴","古樸"],["古杰拉尔","古傑拉爾"],["古杰拉特邦","古傑拉特邦"],["古板","古板"],["古柯叶","古柯葉"],["古柯咸","古柯鹹"],["古游","古遊"],["古腾堡计划","古騰堡計劃"],["古語云","古語云"],["古语云","古語云"],["古迹","古蹟"],["古里古怪","古里古怪"],["古钟","古鐘"],["古钟表","古鐘錶"],["句践复国","句踐復國"],["另一回","另一回"],["另一回事","另一回事"],["另一方面","另一方面"],["另一种","另一種"],["另一面","另一面"],["另于","另於"],["另借","另借"],["另开生面","另開生面"],["另当别论","另當別論"],["另方面","另方面"],["另谋出路","另謀出路"],["另谋发展","另謀發展"],["另起烟爨","另起煙爨"],["另辟","另闢"],["另辟新径","另闢新徑"],["另辟蹊径","另闢蹊徑"],["叨念","叨唸"],["叩出","叩出"],["叩头虫","叩頭蟲"],["叩钟","叩鐘"],["只不过","只不過"],["只不过几年前","只不過幾年前"],["只不过是","只不過是"],["只为了","只爲了"],["只买","只買"],["只买到","只買到"],["只争旦夕","只爭旦夕"],["只于","只於"],["只产","只產"],["只亮","只亮"],["只亮出","只亮出"],["只亮到","只亮到"],["只今","只今"],["只从","只從"],["只会","只會"],["只会到","只會到"],["只会在","只會在"],["只传","只傳"],["只传出","只傳出"],["只住","只住"],["只余","只餘"],["只作","只作"],["只借","只借"],["只借不还","只借不還"],["只借到","只借到"],["只做","只做"],["只停","只停"],["只养","只養"],["只再","只再"],["只写","只寫"],["只写出","只寫出"],["只写到","只寫到"],["只写在","只寫在"],["只冲","只衝"],["只准","只准"],["只凭","只憑"],["只分","只分"],["只刊","只刊"],["只判","只判"],["只剩","只剩"],["只剩下","只剩下"],["只办","只辦"],["只加","只加"],["只加到","只加到"],["只动","只動"],["只包","只包"],["只卖","只賣"],["只占","只佔"],["只占到","只佔到"],["只占卜","只占卜"],["只占吉","只占吉"],["只占神问卜","只占神問卜"],["只占算","只占算"],["只印","只印"],["只去","只去"],["只发","只發"],["只受","只受"],["只受到","只受到"],["只变","只變"],["只可","只可"],["只可以","只可以"],["只可在","只可在"],["只可意会不可言传","只可意會不可言傳"],["只叹","只嘆"],["只吃","只吃"],["只合","只合"],["只含","只含"],["只听","只聽"],["只听到","只聽到"],["只和","只和"],["只唱","只唱"],["只唱出","只唱出"],["只唱到","只唱到"],["只喊","只喊"],["只喝","只喝"],["只喝到","只喝到"],["只回","只回"],["只回到","只回到"],["只回去","只回去"],["只回来","只回來"],["只因","只因"],["只因为","只因爲"],["只图","只圖"],["只在","只在"],["只坐","只坐"],["只声不出","隻聲不出"],["只多","只多"],["只多不少","只多不少"],["只够","只夠"],["只夠到","只夠到"],["只夠在","只夠在"],["只套","只套"],["只好","只好"],["只好去","只好去"],["只好在","只好在"],["只好来","只好來"],["只字","隻字"],["只字不提","隻字不提"],["只字片纸","隻字片紙"],["只字片言","隻字片言"],["只字片语","隻字片語"],["只学","只學"],["只学会","只學會"],["只学到","只學到"],["只守","只守"],["只守不攻","只守不攻"],["只守到","只守到"],["只定","只定"],["只害","只害"],["只对","只對"],["只封","只封"],["只射","只射"],["只射到","只射到"],["只将","只將"],["只尽","只盡"],["只尽到","只盡到"],["只差","只差"],["只带","只帶"],["只帮","只幫"],["只帮忙","只幫忙"],["只应","只應"],["只延","只延"],["只开","只開"],["只开出","只開出"],["只开到","只開到"],["只开去","只開去"],["只开回","只開回"],["只开来","只開來"],["只当","只當"],["只录","只錄"],["只录到","只錄到"],["只影","隻影"],["只影全无","隻影全無"],["只待","只待"],["只得","只得"],["只得到","只得到"],["只念","只念"],["只怕","只怕"],["只怕会","只怕會"],["只怕是","只怕是"],["只怪","只怪"],["只想","只想"],["只想出","只想出"],["只想到","只想到"],["只想去","只想去"],["只想来","只想來"],["只愿","只願"],["只愿意","只願意"],["只懂","只懂"],["只懂得","只懂得"],["只成","只成"],["只戴","只戴"],["只手","隻手"],["只手单拳","隻手單拳"],["只手擎天","隻手擎天"],["只手空拳","隻手空拳"],["只手遮天","隻手遮天"],["只打","只打"],["只找","只找"],["只找出","只找出"],["只找到","只找到"],["只把","只把"],["只报","只報"],["只抱","只抱"],["只拜","只拜"],["只拼","只拼"],["只挑","只挑"],["只挡","只擋"],["只捉","只捉"],["只捉到","只捉到"],["只排","只排"],["只接","只接"],["只接到","只接到"],["只提","只提"],["只插","只插"],["只插到","只插到"],["只搬","只搬"],["只摆","只擺"],["只撞","只撞"],["只收","只收"],["只收到","只收到"],["只放","只放"],["只教","只教"],["只敢","只敢"],["只数","只數"],["只数到","只數到"],["只日","隻日"],["只是","只是"],["只是为了","只是爲了"],["只是会","只是會"],["只是在","只是在"],["只是有","只是有"],["只替","只替"],["只有","只有"],["只有出的气没有进的气","只有出的氣沒有進的氣"],["只有在","只有在"],["只来","只來"],["只来到","只來到"],["只査","只查"],["只査出","只查出"],["只査到","只查到"],["只欠东风","只欠東風"],["只此一家别无分店","只此一家別無分店"],["只比","只比"],["只求","只求"],["只求无过","只求無過"],["只求自保","只求自保"],["只派","只派"],["只流","只流"],["只流出","只流出"],["只流到","只流到"],["只涂","只塗"],["只消","只消"],["只漏","只漏"],["只漏出","只漏出"],["只漏到","只漏到"],["只演","只演"],["只点","只點"],["只照","只照"],["只照到","只照到"],["只煮","只煮"],["只爲","只爲"],["只猜","只猜"],["只猜出","只猜出"],["只猜到","只猜到"],["只玩","只玩"],["只甚","只甚"],["只用","只用"],["只用到","只用到"],["只画","只畫"],["只留","只留"],["只留下","只留下"],["只留到","只留到"],["只看","只看"],["只看出","只看出"],["只看到","只看到"],["只眼","隻眼"],["只眼独具","隻眼獨具"],["只睡","只睡"],["只睡到","只睡到"],["只知其一不知其二","只知其一不知其二"],["只知有己不知有人","只知有己不知有人"],["只砍","只砍"],["只种","只種"],["只租","只租"],["只租不买","只租不買"],["只租不卖","只租不賣"],["只称","只稱"],["只穿","只穿"],["只立","隻立"],["只站","只站"],["只站到","只站到"],["只等","只等"],["只答","只答"],["只管","只管"],["只管出","只管出"],["只管到","只管到"],["只管去","只管去"],["只管在","只管在"],["只管来","只管來"],["只索","只索"],["只红","只紅"],["只红到","只紅到"],["只约","只約"],["只经","只經"],["只经过","只經過"],["只编","只編"],["只缝","只縫"],["只罚","只罰"],["只考","只考"],["只考出","只考出"],["只考到","只考到"],["只聘","只聘"],["只肯","只肯"],["只能","只能"],["只能在","只能在"],["只能有","只能有"],["只花","只花"],["只补","只補"],["只被","只被"],["只装","只裝"],["只要","只要"],["只要会","只要會"],["只要在","只要在"],["只要是","只要是"],["只要有","只要有"],["只要能","只要能"],["只见","只見"],["只见树木","只見樹木"],["只言片字","隻言片字"],["只言片语","隻言片語"],["只订","只訂"],["只认钱不认人","只認錢不認人"],["只让","只讓"],["只让出","只讓出"],["只让到","只讓到"],["只记","只記"],["只记到","只記到"],["只记在","只記在"],["只记得","只記得"],["只讲","只講"],["只讲出","只講出"],["只讲到","只講到"],["只许","只許"],["只许州官放火不许百姓点灯","只許州官放火不許百姓點燈"],["只许成功","只許成功"],["只设","只設"],["只设到","只設到"],["只设在","只設在"],["只说","只說"],["只说不做","只說不做"],["只说出","只說出"],["只说到","只說到"],["只说是","只說是"],["只读","只讀"],["只调","只調"],["只费","只費"],["只赌","只賭"],["只赔","只賠"],["只赚","只賺"],["只赚到","只賺到"],["只赢","只贏"],["只赢不输","只贏不輸"],["只走","只走"],["只走到","只走到"],["只赶","只趕"],["只赶出","只趕出"],["只赶到","只趕到"],["只赶去","只趕去"],["只赶回","只趕回"],["只赶来","只趕來"],["只跌","只跌"],["只跟","只跟"],["只跟到","只跟到"],["只跟去","只跟去"],["只跟在","只跟在"],["只跟来","只跟來"],["只跳","只跳"],["只踢","只踢"],["只踩","只踩"],["只踩到","只踩到"],["只身","隻身"],["只身一人","隻身一人"],["只身上已","只身上已"],["只身上无","只身上無"],["只身上有","只身上有"],["只身上没","只身上沒"],["只身上的","只身上的"],["只身孤影","隻身孤影"],["只转","只轉"],["只转到","只轉到"],["只轮不反","隻輪不反"],["只轮不返","隻輪不返"],["只轰","只轟"],["只载","只載"],["只输","只輸"],["只输到","只輸到"],["只达","只達"],["只过","只過"],["只过去","只過去"],["只过来","只過來"],["只进","只進"],["只进到","只進到"],["只追","只追"],["只追到","只追到"],["只追回","只追回"],["只送","只送"],["只送不卖","只送不賣"],["只通","只通"],["只通到","只通到"],["只道","只道"],["只配","只配"],["只采","只採"],["只采到","只採到"],["只采声","只採聲"],["只重衣衫不重人","只重衣衫不重人"],["只量","只量"],["只量出","只量出"],["只量到","只量到"],["只铺","只鋪"],["只销","只銷"],["只镀","只鍍"],["只问","只問"],["只闯","只闖"],["只闯出","只闖出"],["只闯到","只闖到"],["只闻","只聞"],["只防","只防"],["只降","只降"],["只降到","只降到"],["只限","只限"],["只限于","只限於"],["只限到","只限到"],["只限在","只限在"],["只陪","只陪"],["只需","只需"],["只需要","只需要"],["只露","只露"],["只露出","只露出"],["只露到","只露到"],["只靠","只靠"],["只须","只須"],["只顾","只顧"],["只顾到","只顧到"],["只顾在","只顧在"],["只领","只領"],["只领到","只領到"],["只飞","只飛"],["只鸡斗酒","只雞斗酒"],["只鸡絮酒","隻雞絮酒"],["叫个","叫個"],["叫了","叫了"],["叫价","叫價"],["叫出","叫出"],["叫出去","叫出去"],["叫出声","叫出聲"],["叫出来","叫出來"],["叫回","叫回"],["叫回去","叫回去"],["叫回来","叫回來"],["叫板","叫板"],["召回","召回"],["召幸","召幸"],["叮人战术","叮人戰術"],["叮叮当当","叮叮噹噹"],["叮叮当当的婆娘","叮叮噹噹的婆娘"],["叮当","叮噹"],["叮当作响","叮噹作響"],["叮当响","叮噹響"],["叮当声","叮噹聲"],["可了不得","可了不得"],["可于","可於"],["可仑坡","可侖坡"],["可以克制","可以剋制"],["可供参考","可供參考"],["可免于","可免於"],["可别","可別"],["可变化合价","可變化合價"],["可可托海","可可托海"],["可可托海镇","可可托海鎮"],["可叹","可嘆"],["可向","可向"],["可周","可週"],["可喜娘","可喜娘"],["可回收","可回收"],["可好了","可好了"],["可少不了","可少不了"],["可展曲面","可展曲面"],["可干制","可乾製"],["可干拭","可乾拭"],["可干饮","可乾飲"],["可当","可當"],["可怜虫","可憐蟲"],["可恶","可惡"],["可愿","可願"],["可愿意","可願意"],["可憎娘","可憎娘"],["可憎才","可憎才"],["可持续发展","可持續發展"],["可操作的艺术","可操作的藝術"],["可擦写可编程只读存储器","可擦寫可編程只讀存儲器"],["可望取胜者","可望取勝者"],["可欲","可欲"],["可紧可松","可緊可鬆"],["可结合性","可結合性"],["可转换同位素","可轉換同位素"],["可采","可採"],["可鉴","可鑑"],["台上","臺上"],["台下","臺下"],["台东","臺東"],["台东人","臺東人"],["台东区","臺東區"],["台东县","臺東縣"],["台东县长","臺東縣長"],["台东大学","臺東大學"],["台东市","臺東市"],["台东线","臺東線"],["台两","臺兩"],["台中","臺中"],["台中人","臺中人"],["台中区","臺中區"],["台中县","臺中縣"],["台中县市","臺中縣市"],["台中商专","臺中商專"],["台中场","臺中場"],["台中市","臺中市"],["台中市人","臺中市人"],["台中市文","臺中市文"],["台中师范","臺中師範"],["台中师范学院","臺中師範學院"],["台中店","臺中店"],["台中敎育大学","臺中教育大學"],["台中港","臺中港"],["台中港路","臺中港路"],["台中盆地","臺中盆地"],["台中站","臺中站"],["台中讯","臺中訊"],["台企联","臺企聯"],["台企银","臺企銀"],["台佟","臺佟"],["台候","臺候"],["台儿庄","臺兒莊"],["台光","臺光"],["台军","臺軍"],["台凤","臺鳳"],["台凳","檯凳"],["台函","臺函"],["台制","臺製"],["台制品","臺製品"],["台前","臺前"],["台前县","臺前縣"],["台前台后","臺前臺後"],["台办","臺辦"],["台北","臺北"],["台北人","臺北人"],["台北区","臺北區"],["台北县","臺北縣"],["台北地院","臺北地院"],["台北场","臺北場"],["台北城","臺北城"],["台北大学","臺北大學"],["台北客","臺北客"],["台北市","臺北市"],["台北市市","臺北市市"],["台北市立","臺北市立"],["台北市长","臺北市長"],["台北市队","臺北市隊"],["台北师院","臺北師院"],["台北护专","臺北護專"],["台北捷运","臺北捷運"],["台北桥","臺北橋"],["台北港","臺北港"],["台北盆地","臺北盆地"],["台北站","臺北站"],["台北讯","臺北訊"],["台北队","臺北隊"],["台华轮","臺華輪"],["台南","臺南"],["台南人","臺南人"],["台南区","臺南區"],["台南县","臺南縣"],["台南县市","臺南縣市"],["台南大学","臺南大學"],["台南孔庙","臺南孔廟"],["台南市","臺南市"],["台南府","臺南府"],["台南站","臺南站"],["台历","檯曆"],["台压版","臺壓版"],["台台","臺臺"],["台号","臺號"],["台司","臺司"],["台后","臺後"],["台启","臺啓"],["台命","臺命"],["台和","臺和"],["台商","臺商"],["台商圈","臺商圈"],["台啤队","臺啤隊"],["台地","臺地"],["台场","臺場"],["台型","臺型"],["台城","臺城"],["台基","臺基"],["台塑","臺塑"],["台墩","臺墩"],["台大","臺大"],["台大医院","臺大醫院"],["台大学生","臺大學生"],["台女","臺女"],["台妹","臺妹"],["台委","臺委"],["台媒","臺媒"],["台子","臺子","檯子"],["台子女","臺子女"],["台子孙","臺子孫"],["台孙","臺孫"],["台孩","臺孩"],["台安","檯安"],["台安县","檯安縣"],["台客","臺客"],["台客呛辣","臺客嗆辣"],["台客舞","臺客舞"],["台尺","臺尺"],["台山","台山"],["台山市","臺山市"],["台峪","臺峪"],["台州","台州"],["台州地区","台州地區"],["台州市","台州市"],["台币","臺幣"],["台布","檯布"],["台布下","檯布下"],["台师大","臺師大"],["台帘","臺簾"],["台席","臺席"],["台庆","臺慶"],["台座","臺座"],["台开","臺開"],["台式","臺式"],["台式机","臺式機"],["台意","臺意"],["台意怒","臺意怒"],["台成","臺成"],["台扇","檯扇"],["台拉维夫","臺拉維夫"],["台指期","臺指期"],["台收","臺收"],["台数","臺數"],["台文","臺文"],["台斤","臺斤"],["台新","臺新"],["台新金","臺新金"],["台新银","臺新銀"],["台日","臺日"],["台旨","臺旨"],["台期指","臺期指"],["台本","臺本"],["台机","臺機"],["台柱","臺柱"],["台榭","臺榭"],["台槐","臺槐"],["台步","臺步"],["台水澎运","臺水澎運"],["台江","臺江"],["台江区","臺江區"],["台江县","臺江縣"],["台汽","臺汽"],["台汽客运","臺汽客運"],["台海","臺海"],["台海两岸","臺海兩岸"],["台港","臺港"],["台港澳侨","臺港澳僑"],["台湾","臺灣"],["台湾世界展望会","臺灣世界展望會"],["台湾人","臺灣人"],["台湾光复","臺灣光復"],["台湾光复节","臺灣光復節"],["台湾共和国","臺灣共和國"],["台湾关系法","臺灣關係法"],["台湾凤蝶","臺灣鳳蝶"],["台湾化","臺灣化"],["台湾区","臺灣區"],["台湾台","臺灣台"],["台湾史","臺灣史"],["台湾叶鼻蝠","臺灣葉鼻蝠"],["台湾味","臺灣味"],["台湾团","臺灣團"],["台湾国","臺灣國"],["台湾国语","臺灣國語"],["台湾土狗","臺灣土狗"],["台湾地区","臺灣地區"],["台湾大学","臺灣大學"],["台湾大学附属医学院","臺灣大學附屬醫學院"],["台湾女","臺灣女"],["台湾学术网路","臺灣學術網路"],["台湾岛","臺灣島"],["台湾工业技术学院","臺灣工業技術學院"],["台湾师范大学","臺灣師範大學"],["台湾心","臺灣心"],["台湾敎育学院","臺灣教育學院"],["台湾散打王","臺灣散打王"],["台湾新美术运动","臺灣新美術運動"],["台湾日","臺灣日"],["台湾日日新报","臺灣日日新報"],["台湾杜鹃","臺灣杜鵑"],["台湾歌","臺灣歌"],["台湾民主自治同盟","臺灣民主自治同盟"],["台湾汽车客运公司","臺灣汽車客運公司"],["台湾海峡","臺灣海峽"],["台湾海洋大学","臺灣海洋大學"],["台湾海洋学院","臺灣海洋學院"],["台湾版","臺灣版"],["台湾犬","臺灣犬"],["台湾猕猴桃","臺灣獼猴桃"],["台湾玉","臺灣玉"],["台湾环颈雉","臺灣環頸雉"],["台湾电力","臺灣電力"],["台湾电力公司","臺灣電力公司"],["台湾电视公司","臺灣電視公司"],["台湾疗养院","臺灣療養院"],["台湾省","臺灣省"],["台湾省政府教育厅","臺灣省政府教育廳"],["台湾省政府林业试验所","臺灣省政府林業試驗所"],["台湾省政府消防处","臺灣省政府消防處"],["台湾省政府警政厅","臺灣省政府警政廳"],["台湾省政府财政厅","臺灣省政府財政廳"],["台湾省立","臺灣省立"],["台湾省议会","臺灣省議會"],["台湾社","臺灣社"],["台湾神学院","臺灣神學院"],["台湾科技大学","臺灣科技大學"],["台湾籍","臺灣籍"],["台湾米","臺灣米"],["台湾粉蝶","臺灣粉蝶"],["台湾精品","臺灣精品"],["台湾糖业公司","臺灣糖業公司"],["台湾红","臺灣紅"],["台湾经验","臺灣經驗"],["台湾肥料公司","臺灣肥料公司"],["台湾航业公司","臺灣航業公司"],["台湾艺术专科学校","臺灣藝術專科學校"],["台湾茶","臺灣茶"],["台湾菜","臺灣菜"],["台湾蓝鹊","臺灣藍鵲"],["台湾行","臺灣行"],["台湾警察专科学校","臺灣警察專科學校"],["台湾证券集中保管公司","臺灣證券集中保管公司"],["台湾话","臺灣話"],["台湾铝业","臺灣鋁業"],["台湾铝业公司","臺灣鋁業公司"],["台湾银行","臺灣銀行"],["台湾队","臺灣隊"],["台湾青年","臺灣青年"],["台湾馆","臺灣館"],["台湾高山族","臺灣高山族"],["台澎","臺澎"],["台澎金马","臺澎金馬"],["台灯","檯燈"],["台照","臺照"],["台版","臺版"],["台独","臺獨"],["台独运动","臺獨運動"],["台玻","臺玻"],["台球","檯球"],["台球桌","檯球桌"],["台甫","臺甫"],["台电","臺電"],["台电公司","臺電公司"],["台盆","臺盆"],["台盏","臺盞"],["台盘","檯盤"],["台省","臺省"],["台矶","臺磯"],["台科大","臺科大"],["台秤","檯秤"],["台积电","臺積電"],["台站","臺站"],["台端","臺端"],["台笔","檯筆"],["台籍","臺籍"],["台糖","臺糖"],["台糖公司","臺糖公司"],["台经院","臺經院"],["台维斯杯","臺維斯杯"],["台网","臺網"],["台美","臺美"],["台联","臺聯"],["台联会","臺聯會"],["台联党","臺聯黨"],["台股","臺股"],["台肥","臺肥"],["台胜科","臺勝科"],["台胞","臺胞"],["台胞证","臺胞證"],["台航","臺航"],["台艺","臺藝"],["台艺大","臺藝大"],["台菜","臺菜"],["台菜餐厅","臺菜餐廳"],["台衔","臺銜"],["台装","臺裝"],["台装货","臺裝貨"],["台西","臺西"],["台西乡","臺西鄉"],["台视","臺視"],["台视公司","臺視公司"],["台讳","臺諱"],["台词","臺詞"],["台语","臺語"],["台语歌","臺語歌"],["台账","臺賬"],["台资","臺資"],["台车","臺車"],["台车道","臺車道"],["台辅","臺輔"],["台达","臺達"],["台达电","臺達電"],["台金","臺金"],["台鉴","臺鑒"],["台钟","檯鐘"],["台钱","臺錢"],["台钻","臺鑽"],["台铁","臺鐵"],["台铁局","臺鐵局"],["台铝","臺鋁"],["台银","臺銀"],["台长","臺長"],["台阁","臺閣"],["台阁生风","臺閣生風"],["台阶","臺階"],["台面","檯面"],["台面上","檯面上"],["台面前","檯面前"],["台音","臺音"],["台风","颱風"],["台风后","颱風後"],["台风夜","颱風夜"],["台风天","颱風天"],["台风季","颱風季"],["台风尾","颱風尾"],["台风眼","颱風眼"],["台风稳健","臺風穩健"],["台风草","颱風草"],["台风警报","颱風警報"],["台风险","颱風險"],["台风雨","颱風雨"],["台马轮","臺馬輪"],["台驾","臺駕"],["叱吒风云","叱吒風雲"],["叱咤乐坛","叱吒樂壇"],["叱咤叱叱咤","叱吒叱叱吒"],["叱咤叱咤叱咤咤","叱吒叱吒叱吒吒"],["叱咤风云","叱吒風雲"],["叱嗟风云","叱嗟風雲"],["史克里亚宾","史克里亞賓"],["史冬鹏","史冬鵬"],["史勒德克","史勒德克"],["史坦尼克","史坦尼克"],["史坦布律克","史坦布律克"],["史坦布瑞纳","史坦布瑞納"],["史坦布莱纳","史坦布萊納"],["史垂克","史垂克"],["史塔克","史塔克"],["史塔克豪斯","史塔克豪斯"],["史崔克","史崔克"],["史托克","史托克"],["史托姆","史托姆"],["史托威","史托威"],["史托瑟","史托瑟"],["史托腾柏格","史托騰柏格"],["史托苏儿","史托蘇兒"],["史査克","史查克"],["史査克队","史查克隊"],["史派克李","史派克李"],["史派克特","史派克特"],["史游","史游"],["史瑞克","史瑞克"],["史瑞波妮克","史瑞波妮克"],["史瓦布","史瓦布"],["史翠克","史翠克"],["史莱克","史萊克"],["史达克","史達克"],["史迹","史蹟"],["右分枝关系从句","右分枝關係從句"],["右后","右後"],["右后卫","右後衛"],["右后方","右後方"],["右戚","右戚"],["右拐","右拐"],["右面","右面"],["叶一茜","葉一茜"],["叶丁仁","葉丁仁"],["叶下珠","葉下珠"],["叶丛","葉叢"],["叶两传","葉兩傳"],["叶亮清","葉亮清"],["叶代芝","葉代芝"],["叶伟志","葉偉志"],["叶佐禹","葉佐禹"],["叶俊凯","葉俊凱"],["叶俊荣","葉俊榮"],["叶儿","葉兒"],["叶全真","葉全真"],["叶公好龙","葉公好龍"],["叶公超","葉公超"],["叶兰","葉蘭"],["叶利钦","葉利欽"],["叶南铭","葉南銘"],["叶卡捷琳堡","葉卡捷琳堡"],["叶卡捷琳娜","葉卡捷琳娜"],["叶卡特琳娜堡","葉卡特琳娜堡"],["叶原","葉原"],["叶县","葉縣"],["叶口蝠科","葉口蝠科"],["叶可欣","葉可欣"],["叶可蓁","葉可蓁"],["叶叶","葉葉"],["叶叶琹","葉叶琹"],["叶名琛","葉名琛"],["叶君璋","葉君璋"],["叶咏捷","葉詠捷"],["叶国兴","葉國興"],["叶圣陶","葉聖陶"],["叶块繁殖","葉塊繁殖"],["叶城县","葉城縣"],["叶堂","葉堂"],["叶天士","葉天士"],["叶子","葉子"],["叶子列","葉子列"],["叶子戏","葉子戲"],["叶子杰","葉子杰"],["叶子格","葉子格"],["叶子烟","葉子菸"],["叶子纲","葉子綱"],["叶宗留","葉宗留"],["叶宗贤","葉宗賢"],["叶宜津","葉宜津"],["叶宪祖","葉憲祖"],["叶尔勤","葉爾勤"],["叶尔羌","葉爾羌"],["叶尔羌河","葉爾羌河"],["叶尔辛","葉爾辛"],["叶尖","葉尖"],["叶尼基河","葉尼基河"],["叶尼塞河","葉尼塞河"],["叶庆元","葉慶元"],["叶序","葉序"],["叶形","葉形"],["叶彦伯","葉彥伯"],["叶彰廷","葉彰廷"],["叶德辉","葉德輝"],["叶志仙","葉志仙"],["叶志远","葉志遠"],["叶恭弘","叶恭弘"],["叶惠青","葉惠青"],["叶慈","葉慈"],["叶成忠","葉成忠"],["叶拱","葉拱"],["叶挺","葉挺"],["叶政彦","葉政彥"],["叶文贵","葉文貴"],["叶斑","葉斑"],["叶斑病","葉斑病"],["叶斯沛森","葉斯沛森"],["叶昌桐","葉昌桐"],["叶明顺","葉明順"],["叶景栋","葉景棟"],["叶杰生","葉傑生"],["叶枝","葉枝"],["叶柄","葉柄"],["叶树","葉樹"],["叶树姗","葉樹姍"],["叶根吉","葉根吉"],["叶正玲","葉正玲"],["叶步梁","葉步樑"],["叶永烈","葉永烈"],["叶永骞","葉永騫"],["叶江川","葉江川"],["叶泰兴","葉泰興"],["叶泽山","葉澤山"],["叶清照","葉清照"],["叶湘伦","葉湘倫"],["叶炳强","葉炳強"],["叶片","葉片"],["叶片状","葉片狀"],["叶状","葉狀"],["叶状体","葉狀體"],["叶状植物","葉狀植物"],["叶王","葉王"],["叶甜菜","葉甜菜"],["叶盛兰","葉盛蘭"],["叶硕堂","葉碩堂"],["叶礼庭","葉禮庭"],["叶紫华","葉紫華"],["叶红素","葉紅素"],["叶绍锜","葉紹錡"],["叶绿体","葉綠體"],["叶绿体基质","葉綠體基質"],["叶绿素","葉綠素"],["叶缘","葉緣"],["叶美君","葉美君"],["叶羿君","葉羿君"],["叶耳","葉耳"],["叶肉","葉肉"],["叶肥","葉肥"],["叶脉","葉脈"],["叶脉序","葉脈序"],["叶脤","葉脤"],["叶腋","葉腋"],["叶舌","葉舌"],["叶芽","葉芽"],["叶茎","葉莖"],["叶菊兰","葉菊蘭"],["叶菜类","葉菜類"],["叶落归根","葉落歸根"],["叶落归秋","葉落歸秋"],["叶落知秋","葉落知秋"],["叶落粪本","葉落糞本"],["叶蕴仪","葉蘊儀"],["叶蜂","葉蜂"],["叶蜡石","葉蠟石"],["叶蝉","葉蟬"],["叶语","葉語"],["叶赛莺","葉賽鶯"],["叶赤铁路","葉赤鐵路"],["叶跡","葉跡"],["叶轮","葉輪"],["叶轮机械","葉輪機械"],["叶轴","葉軸"],["叶适","葉適"],["叶选平","葉選平"],["叶酸","葉酸"],["叶金川","葉金川"],["叶针","葉針"],["叶锈病","葉鏽病"],["叶长龙","葉長龍"],["叶门","葉門"],["叶门共和国","葉門共和國"],["叶闲花","葉閒花"],["叶面","葉面"],["叶面对称","葉面對稱"],["叶面施肥","葉面施肥"],["叶鞘","葉鞘"],["叶音","叶音"],["叶韵","叶韻"],["叶黄素","葉黃素"],["叶鼻蝠","葉鼻蝠"],["号寒啼饥","號寒啼飢"],["号志","號誌"],["号志机","號誌機"],["号志灯","號誌燈"],["号挂子","號掛子"],["号板","號板"],["号码布","號碼布"],["号舍","號舍"],["司令台","司令臺"],["司天台","司天臺"],["司法制度","司法制度"],["叹为","嘆爲"],["叹为观止","歎爲觀止"],["叹之","嘆之"],["叹了","嘆了"],["叹号","歎號"],["叹喟","嘆喟"],["叹声","嘆聲"],["叹息","嘆息"],["叹惋","嘆惋"],["叹惜","嘆惜"],["叹曰","嘆曰"],["叹服","歎服"],["叹气","嘆氣"],["叹绝","歎絕"],["叹羡","歎羨"],["叹老","嘆老"],["叹词","嘆詞"],["叹赏","歎賞"],["叹道","嘆道"],["吁了","吁了"],["吁俞","吁俞"],["吁叹","吁嘆"],["吁吁","吁吁"],["吁咈","吁咈"],["吁咈都俞","吁咈都俞"],["吁嗟","吁嗟"],["吁嘘","吁噓"],["吁天","籲天"],["吁气","吁氣"],["吁求","籲求"],["吁请","籲請"],["吃一顿挨一顿","吃一頓挨一頓"],["吃不了","吃不了"],["吃不出","吃不出"],["吃不出来","吃不出來"],["吃了","吃了"],["吃了定心丸","吃了定心丸"],["吃了秤砣","吃了秤砣"],["吃了蜜蜂儿屎似的","吃了蜜蜂兒屎似的"],["吃了饭","吃了飯"],["吃亏上当","吃虧上當"],["吃亏就是占便宜","吃虧就是佔便宜"],["吃人一个蛋恩情无法断","吃人一個蛋恩情無法斷"],["吃人虫","吃人蟲"],["吃伤了","吃傷了"],["吃几碗干饭","吃幾碗乾飯"],["吃出","吃出"],["吃合家欢","吃合家歡"],["吃后悔药","吃後悔藥"],["吃回头草","吃回頭草"],["吃地面","吃地面"],["吃姜","吃薑"],["吃完面","吃完麪"],["吃尽","吃盡"],["吃尽当光","吃盡當光"],["吃干了","吃乾了"],["吃干醋","吃乾醋"],["吃得了","吃得了"],["吃得出","吃得出"],["吃得出来","吃得出來"],["吃挂络儿","吃掛絡兒"],["吃敲才","吃敲才"],["吃板刀面","吃板刀麪"],["吃枪药","吃槍藥"],["吃烟","吃煙"],["吃药","吃藥"],["吃药前","吃藥前"],["吃药后","吃藥後"],["吃药时","吃藥時"],["吃豆干","吃豆乾"],["吃辣面","吃辣麪"],["吃过面","吃過麪"],["吃里扒外","吃裏扒外"],["吃里爬外","吃裏爬外"],["吃钉板","吃釘板"],["吃错药","吃錯藥"],["吃闲话","吃閒話"],["吃闲饭","吃閒飯"],["吃面","吃麪"],["吃饭傢伙","吃飯傢伙"],["吃饭别忘了种谷人","吃飯別忘了種穀人"],["吃饭家伙","吃飯家伙"],["吃饱了饭撑的","吃飽了飯撐的"],["吃饱没事干","吃飽沒事幹"],["各不相同","各不相同"],["各个","各個"],["各个击破","各個擊破"],["各人儿洗面儿各人儿光","各人兒洗面兒各人兒光"],["各从其志","各從其志"],["各借","各借"],["各党","各黨"],["各党派","各黨派"],["各出","各出"],["各别","各別"],["各升","各升"],["各厂","各廠"],["各发","各發"],["各吊","各吊"],["各向","各向"],["各向异性","各向異性"],["各回","各回"],["各回合","各回合"],["各团","各團"],["各团体","各團體"],["各如其面","各如其面"],["各尽","各盡"],["各尽其用","各盡其用"],["各尽所能","各盡所能"],["各干各","各幹各"],["各当","各當"],["各念","各念"],["各打五十板","各打五十板"],["各方面","各方面"],["各有千秋","各有千秋"],["各有胜负","各有勝負"],["各版面","各版面"],["各种","各種"],["各种事","各種事"],["各种人","各種人"],["各种各样","各種各樣"],["各种颜色","各種顏色"],["各签","各簽"],["各类钟","各類鐘"],["各系","各系"],["各系所","各系所"],["各级党委","各級黨委"],["各胜","各勝"],["各行其志","各行其志"],["各谋出路","各謀出路"],["各辟","各闢"],["各辟蹊径","各闢蹊徑"],["各里","各里"],["各院系","各院系"],["各须","各須"],["合上","合上"],["合下","合下"],["合不合","合不合"],["合不拢嘴","合不攏嘴"],["合不来","合不來"],["合中","閤中"],["合久必分","合久必分"],["合义复词","合義複詞"],["合乎","合乎"],["合乎逻辑","合乎邏輯"],["合于","合於"],["合于时宜","合于時宜"],["合从","合從"],["合付","合付"],["合众","合衆"],["合众为一","合衆爲一"],["合众国","合衆國"],["合众国际社","合衆國際社"],["合众社","合衆社"],["合众银行","合衆銀行"],["合伙","合夥"],["合伙人","合夥人"],["合会","合會"],["合传","合傳"],["合住","合住"],["合体","合體"],["合体字","合體字"],["合作","合作"],["合作主义","合作主義"],["合作伙伴","合作伙伴"],["合作农场","合作農場"],["合作化","合作化"],["合作协议","合作協議"],["合作商店","合作商店"],["合作学","合作學"],["合作市","合作市"],["合作所","合作所"],["合作无懈","合作無懈"],["合作无间","合作無間"],["合作案","合作案"],["合作社","合作社"],["合作署","合作署"],["合作者","合作者"],["合作节","合作節"],["合作金库","合作金庫"],["合借","合借"],["合做","合做"],["合儿","閤兒"],["合八字","合八字"],["合养","合養"],["合准","合準"],["合出","合出"],["合击","合擊"],["合刃","合刃"],["合则两利","合則兩利"],["合到","合到"],["合券","合券"],["合刻","合刻"],["合剂","合劑"],["合力","合力"],["合办","合辦"],["合十","合十"],["合卺","合巹"],["合历","合曆"],["合发","合發"],["合变","合變"],["合口","合口"],["合口元音","合口元音"],["合口味","合口味"],["合口呼","合口呼"],["合叶","合葉"],["合吃","合吃"],["合吃族","合吃族"],["合合","合合"],["合同","合同"],["合同各方","合同各方"],["合同文字","合同文字"],["合同法","合同法"],["合后","合後"],["合唱","合唱"],["合唱团","合唱團"],["合唱曲","合唱曲"],["合唱队","合唱隊"],["合嘴合舌","合嘴合舌"],["合四乙尺工","合四乙尺工"],["合围","合圍"],["合在","合在"],["合在一起","合在一起"],["合声","合聲"],["合夥人","合夥人"],["合头","合頭"],["合奏","合奏"],["合奏团","合奏團"],["合奏曲","合奏曲"],["合契若神","合契若神"],["合好","合好"],["合婚","合婚"],["合子","合子"],["合子钱","合子錢"],["合子饼","合子餅"],["合宅","合宅"],["合定","合定"],["合宜","合宜"],["合家","閤家"],["合家大小","合家大小"],["合家子","閤家子"],["合家欢","閤家歡"],["合局","合局"],["合山市","合山市"],["合川区","合川區"],["合并","合併"],["合并为","合併爲"],["合并在","合併在"],["合并成","合併成"],["合并有","合併有"],["合并案","合併案"],["合并症","合併症"],["合府","閤府"],["合府上","閤府上"],["合度","合度"],["合式","合式"],["合弦","合弦"],["合弹","合彈"],["合当","合當"],["合当有事","合當有事"],["合彩","合彩"],["合影","合影"],["合影留念","合影留念"],["合得","合得"],["合得来","合得來"],["合心","合心"],["合心合意","合心合意"],["合恩角","合恩角"],["合情","合情"],["合情合理","合情合理"],["合情理","合情理"],["合意","合意"],["合意儿","合意兒"],["合成","合成"],["合成乐器","合成樂器"],["合成乳","合成乳"],["合成代谢","合成代謝"],["合成体","合成體"],["合成作用","合成作用"],["合成器","合成器"],["合成数","合成數"],["合成染料","合成染料"],["合成树脂","合成樹脂"],["合成橡胶","合成橡膠"],["合成氨","合成氨"],["合成法","合成法"],["合成洗涤","合成洗滌"],["合成洗涤剂","合成洗滌劑"],["合成清洁剂","合成清潔劑"],["合成物","合成物"],["合成皮","合成皮"],["合成石油","合成石油"],["合成类固醇","合成類固醇"],["合成纤维","合成纖維"],["合成色素","合成色素"],["合成词","合成詞"],["合成语境","合成語境"],["合成语音","合成語音"],["合战","合戰"],["合手","合手"],["合扑","合撲"],["合折","合折"],["合报","合報"],["合抱","合抱"],["合拍","合拍"],["合拢","合攏"],["合指症","合指症"],["合掌","合掌"],["合掌瓜","合掌瓜"],["合数","合數"],["合族","合族"],["合时","合時"],["合时宜","合時宜"],["合昏","合昏"],["合是","合是"],["合朔","合朔"],["合本","合本"],["合机","合機"],["合杀","合殺"],["合板","合板"],["合板眼","合板眼"],["合校","合校"],["合格","合格"],["合格率","合格率"],["合格者","合格者"],["合格证","合格證"],["合格赛","合格賽"],["合欢","合歡"],["合欢山","合歡山"],["合欢扇","合歡扇"],["合欢结","合歡結"],["合款","合款"],["合气","合氣"],["合气道","合氣道"],["合水县","合水縣"],["合江县","合江縣"],["合江省","合江省"],["合沓","合沓"],["合法","合法"],["合法化","合法化"],["合法性","合法性"],["合法斗争","合法鬥爭"],["合注","合注"],["合洗","合洗"],["合派","合派"],["合流","合流"],["合流处","合流處"],["合浦县","合浦縣"],["合浦珠还","合浦珠還"],["合浦还珠","合浦還珠"],["合溜","合溜"],["合演","合演"],["合火","合火"],["合照","合照"],["合照留念","合照留念"],["合爲","合爲"],["合牵","合牽"],["合独","合獨"],["合班","合班"],["合球","合球"],["合理","合理"],["合理化","合理化"],["合理化作用","合理化作用"],["合理合情","合理合情"],["合理密植","合理密植"],["合理布局","合理佈局"],["合理性","合理性"],["合理标","合理標"],["合理错误","合理錯誤"],["合璧","合璧"],["合璧连珠","合璧連珠"],["合瓣","合瓣"],["合瓣花冠","合瓣花冠"],["合生","合生"],["合用","合用"],["合盖","合蓋"],["合眼","閤眼"],["合眼摸象","合眼摸象"],["合着","合着"],["合租","合租"],["合稀释","合稀釋"],["合窆","合窆"],["合站","合站"],["合符","合符"],["合签","合簽"],["合算","合算"],["合纤","合纖"],["合约","合約"],["合约书","合約書"],["合约人","合約人"],["合约价","合約價"],["合约法","合約法"],["合纵","合縱"],["合纵连横","合縱連橫"],["合组","合組"],["合编","合編"],["合缝","合縫"],["合群","合羣"],["合群性","合羣性"],["合而为一","合而爲一"],["合股","合股"],["合肥","合肥"],["合肥人","合肥人"],["合肥县","合肥縣"],["合肥工业大学","合肥工業大學"],["合肥市","合肥市"],["合胃口","合胃口"],["合色鞋","合色鞋"],["合苦","合苦"],["合菜戴帽","合菜戴帽"],["合营","合營"],["合著","合著"],["合著者","合著者"],["合葬","合葬"],["合补","合補"],["合计","合計"],["合计为","合計爲"],["合订本","合訂本"],["合议制","合議制"],["合议庭","合議庭"],["合该","合該"],["合该有事","合該有事"],["合请","合請"],["合读","合讀"],["合调","合調"],["合谋","合謀"],["合谐","合諧"],["合谷","合谷"],["合谷穴","合谷穴"],["合购","合購"],["合资","合資"],["合资案","合資案"],["合起","合起"],["合起来","合起來"],["合踢","合踢"],["合踩","合踩"],["合身","合身"],["合辙","合轍"],["合辙儿","合轍兒"],["合辙押韵","合轍押韻"],["合适","合適"],["合通","合通"],["合造","合造"],["合逻辑","合邏輯"],["合遝","合遝"],["合醵","合醵"],["合采","合採"],["合金","合金"],["合金元素","合金元素"],["合金钢","合金鋼"],["合钓","合釣"],["合锯","合鋸"],["合镜","合鏡"],["合闸","合閘"],["合阳县","合陽縣"],["合零为整","合零爲整"],["合面","合面"],["合音","合音"],["合领","合領"],["合骑","合騎"],["合髻","合髻"],["合龙","合龍"],["合龙门","合龍門"],["吉丁当","吉丁當"],["吉伯特氏症候群","吉伯特氏症候羣"],["吉凶","吉凶"],["吉凶庆吊","吉凶慶弔"],["吉凶悔吝","吉凶悔吝"],["吉凶未卜","吉凶未卜"],["吉卜力工作室","吉卜力工作室"],["吉卜赛","吉卜賽"],["吉卜赛人","吉卜賽人"],["吉卜龄","吉卜齡"],["吉占","吉占"],["吉尔库克","吉爾庫克"],["吉尼普里","吉尼普里"],["吉布兹","吉布茲"],["吉布地","吉布地"],["吉布地共和国","吉布地共和國"],["吉布提","吉布提"],["吉布森","吉布森"],["吉普斯夸","吉普斯夸"],["吉林师范大学","吉林師範大學"],["吉田松阴","吉田松陰"],["吉蔑","吉蔑"],["吉蔑族","吉蔑族"],["吉诺布里","吉諾布里"],["吉里","吉里"],["吉里巴斯","吉里巴斯"],["吉里巴斯共和国","吉里巴斯共和國"],["吊上","吊上"],["吊上去","吊上去"],["吊上来","吊上來"],["吊下","吊下"],["吊下去","吊下去"],["吊下来","吊下來"],["吊丧","弔喪"],["吊丧问疾","弔喪問疾"],["吊个","吊個"],["吊书","弔書"],["吊了","吊了"],["吊伐","吊伐"],["吊儿郎当","吊兒郎當"],["吊兰","吊蘭"],["吊具","吊具"],["吊刑","吊刑"],["吊到","吊到"],["吊卷","吊卷"],["吊去","吊去"],["吊取","吊取"],["吊古","弔古"],["吊古寻幽","弔古尋幽"],["吊吊","吊吊"],["吊名","吊名"],["吊唁","弔唁"],["吊喉","弔喉"],["吊喭","弔喭"],["吊嗓","吊嗓"],["吊嗓子","吊嗓子"],["吊嘴","吊嘴"],["吊场","吊場"],["吊坠","吊墜"],["吊塔","吊塔"],["吊头","弔頭"],["吊奠","弔奠"],["吊好","吊好"],["吊子","吊子"],["吊子曰儿","吊子曰兒"],["吊孝","弔孝"],["吊客","弔客"],["吊客眉","弔客眉"],["吊宴","弔宴"],["吊带","吊帶"],["吊带衫","吊帶衫"],["吊带裤","吊帶褲"],["吊床","吊牀"],["吊影","弔影"],["吊得","吊得"],["吊慰","弔慰"],["吊扇","吊扇"],["吊打","吊打"],["吊扣","吊扣","吊釦"],["吊拷","弔拷"],["吊拷絣把","吊拷絣把"],["吊拷绷扒","吊拷繃扒"],["吊挂","吊掛"],["吊挂在","吊掛在"],["吊挂着","吊掛着"],["吊撒","弔撒"],["吊放声纳","吊放聲納"],["吊文","弔文"],["吊斗","吊斗"],["吊旗","弔旗"],["吊杆","吊杆"],["吊杠","吊槓"],["吊来吊去","吊來吊去"],["吊架","吊架"],["吊档裤","吊檔褲"],["吊桥","吊橋"],["吊桶","吊桶"],["吊桶落在井里","吊桶落在井裏"],["吊楼","吊樓"],["吊死","吊死"],["吊死问孤","弔死問孤"],["吊死问疾","弔死問疾"],["吊死鬼","吊死鬼"],["吊死鬼搽粉","吊死鬼搽粉"],["吊死鬼的裹脚布","吊死鬼的裹腳布"],["吊毛","吊毛"],["吊民","弔民"],["吊民伐罪","弔民伐罪"],["吊水","吊水"],["吊灯","吊燈"],["吊环","吊環"],["吊球","吊球"],["吊瓶族","吊瓶族"],["吊盘","吊盤"],["吊着","吊着"],["吊祭","弔祭"],["吊稍","吊稍"],["吊窗","吊窗"],["吊篮","吊籃"],["吊索","吊索"],["吊纸","弔紙"],["吊线","吊線"],["吊绳","吊繩"],["吊者大悦","弔者大悅"],["吊胃口","吊胃口"],["吊脚","吊腳"],["吊脚儿","吊腳兒"],["吊脚儿事","弔腳兒事"],["吊腰撒跨","弔腰撒跨"],["吊膀子","吊膀子"],["吊臂","吊臂"],["吊衣架","吊衣架"],["吊袜","吊襪"],["吊袜带","吊襪帶"],["吊装","吊裝"],["吊裤","吊褲"],["吊裤带","吊褲帶"],["吊誉沽名","吊譽沽名"],["吊词","弔詞"],["吊诡","弔詭"],["吊诡矜奇","弔詭矜奇"],["吊谎","弔謊"],["吊贺迎送","弔賀迎送"],["吊走","吊走"],["吊起","吊起"],["吊起来","吊起來"],["吊车","吊車"],["吊车尾","吊車尾"],["吊运","吊運"],["吊钟","吊鐘"],["吊钢丝","吊鋼絲"],["吊钩","吊鉤"],["吊铺","吊鋪"],["吊销","吊銷"],["吊销执照","吊銷執照"],["吊门","吊門"],["吊问","弔問"],["吊颈","吊頸"],["吊饰","吊飾"],["吊鹤","弔鶴"],["同一","同一"],["同一个","同一個"],["同一个世界同一个梦想","同一個世界同一個夢想"],["同一人","同一人"],["同一场","同一場"],["同一型","同一型"],["同一处","同一處"],["同一家","同一家"],["同一年","同一年"],["同一座","同一座"],["同一性","同一性"],["同一所","同一所"],["同一片","同一片"],["同一班","同一班"],["同一组","同一組"],["同上","同上"],["同下","同下"],["同不同意","同不同意"],["同业","同業"],["同业公会","同業公會"],["同业拆借","同業拆借"],["同个","同個"],["同中有异","同中有異"],["同为","同爲"],["同义","同義"],["同义反复","同義反復"],["同义字","同義字"],["同义词","同義詞"],["同义语","同義語"],["同乐","同樂"],["同乐会","同樂會"],["同乡","同鄉"],["同乡亲故","同鄉親故"],["同乡会","同鄉會"],["同事","同事"],["同事家","同事家"],["同于","同於"],["同产","同產"],["同享","同享"],["同人","同人"],["同人女","同人女"],["同人志","同人誌"],["同仁","同仁"],["同仁县","同仁縣"],["同仁堂","同仁堂"],["同仇","同仇"],["同仇敌忾","同仇敵愾"],["同休共戚","同休共慼"],["同伙","同夥"],["同传耳麦","同傳耳麥"],["同伴","同伴"],["同位","同位"],["同位素","同位素"],["同位素分离","同位素分離"],["同位素扫描","同位素掃描"],["同位角","同位角"],["同位语","同位語"],["同住","同住"],["同体","同體"],["同余","同餘"],["同余式","同餘式"],["同余类","同餘類"],["同侪","同儕"],["同侪压力","同儕壓力"],["同侪团体","同儕團體"],["同侪审查","同儕審查"],["同侪扶持","同儕扶持"],["同侪检视","同儕檢視"],["同侪谘商","同儕諮商"],["同修","同修"],["同做","同做"],["同僚","同僚"],["同光","同光"],["同党","同黨"],["同出","同出"],["同出一源","同出一源"],["同出一脉","同出一脈"],["同出同进","同出同進"],["同分","同分"],["同分异构体","同分異構體"],["同分异构物","同分異構物"],["同分数","同分數"],["同列","同列"],["同到","同到"],["同功一体","同功一體"],["同动词","同動詞"],["同化","同化"],["同化作用","同化作用"],["同区","同區"],["同升","同升"],["同卵","同卵"],["同卵双生","同卵雙生"],["同卵双胞胎","同卵雙胞胎"],["同去","同去"],["同县","同縣"],["同参","同參"],["同右","同右"],["同号","同號"],["同吃","同吃"],["同吃同住","同吃同住"],["同名","同名"],["同名之累","同名之累"],["同名同姓","同名同姓"],["同名数","同名數"],["同向","同向"],["同命","同命"],["同命鸟","同命鳥"],["同命鸳鸯","同命鴛鴦"],["同唱","同唱"],["同喜","同喜"],["同团","同團"],["同国","同國"],["同在","同在"],["同地","同地"],["同坐","同坐"],["同型","同型"],["同型性","同型性"],["同型机","同型機"],["同型配子","同型配子"],["同堂","同堂"],["同声","同聲"],["同声一哭","同聲一哭"],["同声之谊","同聲之誼"],["同声传译","同聲傳譯"],["同声异俗","同聲異俗"],["同声相应","同聲相應"],["同声翻译","同聲翻譯"],["同天","同天"],["同好","同好"],["同姓","同姓"],["同姓同名","同姓同名"],["同字框","同字框"],["同学","同學"],["同学们","同學們"],["同学会","同學會"],["同学家","同學家"],["同学录","同學錄"],["同学路","同學路"],["同安","同安"],["同安区","同安區"],["同安县","同安縣"],["同安街","同安街"],["同宗","同宗"],["同宗同气","同宗同氣"],["同定","同定"],["同室","同室"],["同室操戈","同室操戈"],["同宿","同宿"],["同寅","同寅"],["同对","同對"],["同尘","同塵"],["同居","同居"],["同居人","同居人"],["同居各爨","同居各爨"],["同屋","同屋"],["同属","同屬"],["同岁","同歲"],["同州梆子","同州梆子"],["同工","同工"],["同工同酬","同工同酬"],["同工异曲","同工異曲"],["同工异调","同工異調"],["同左","同左"],["同席","同席"],["同年","同年"],["同年代","同年代"],["同年同月","同年同月"],["同年级","同年級"],["同年而语","同年而語"],["同庆","同慶"],["同床","同牀"],["同床异梦","同牀異夢"],["同庚","同庚"],["同度","同度"],["同座","同座"],["同异","同異"],["同张","同張"],["同归","同歸"],["同归于尽","同歸於盡"],["同归殊途","同歸殊途"],["同当","同當"],["同形词","同形詞"],["同往","同往"],["同德","同德"],["同德县","同德縣"],["同德同心","同德同心"],["同心","同心"],["同心僇力","同心僇力"],["同心协力","同心協力"],["同心县","同心縣"],["同心合力","同心合力"],["同心合意","同心合意"],["同心同德","同心同德"],["同心圆","同心圓"],["同心圆理论","同心圓理論"],["同心并力","同心並力"],["同心戮力","同心戮力"],["同心断金","同心斷金"],["同心方胜儿","同心方勝兒"],["同心结","同心結"],["同心髻","同心髻"],["同志","同志"],["同志合道","同志合道"],["同志天地","同志天地"],["同志酒吧","同志酒吧"],["同忧相救","同憂相救"],["同态","同態"],["同性","同性"],["同性恋","同性戀"],["同性恋恐惧症","同性戀恐懼症"],["同性恋者","同性戀者"],["同性恋酒吧","同性戀酒吧"],["同性爱","同性愛"],["同性相斥","同性相斥"],["同恩","同恩"],["同恶相助","同惡相助"],["同恶相救","同惡相救"],["同恶相求","同惡相求"],["同恶相济","同惡相濟"],["同情","同情"],["同情心","同情心"],["同情者","同情者"],["同意","同意"],["同意书","同意書"],["同意权","同意權"],["同意案","同意案"],["同意票","同意票"],["同感","同感"],["同愿","同願"],["同房","同房"],["同房兄弟","同房兄弟"],["同手同脚","同手同腳"],["同打","同打"],["同指","同指"],["同排","同排"],["同支","同支"],["同改","同改"],["同文","同文"],["同文同种","同文同種"],["同文算指","同文算指"],["同文韵统","同文韻統"],["同文馆","同文館"],["同斜层","同斜層"],["同方","同方"],["同旁內角","同旁內角"],["同族","同族"],["同日","同日"],["同日生","同日生"],["同日而言","同日而言"],["同日而语","同日而語"],["同时","同時"],["同时代","同時代"],["同时候","同時候"],["同时期","同時期"],["同时语言学","同時語言學"],["同是","同是"],["同是天涯沦落人","同是天涯淪落人"],["同月","同月"],["同月同日","同月同日"],["同有","同有"],["同期","同期"],["同期录音","同期錄音"],["同机","同機"],["同村","同村"],["同条共贯","同條共貫"],["同来","同來"],["同来同往","同來同往"],["同构","同構"],["同枕共眠","同枕共眠"],["同林鸟","同林鳥"],["同校","同校"],["同样","同樣"],["同样会","同樣會"],["同样在","同樣在"],["同样地","同樣地"],["同样是","同樣是"],["同根","同根"],["同案","同案"],["同案犯","同案犯"],["同桌","同桌"],["同梦","同夢"],["同梯","同梯"],["同榜","同榜"],["同榻","同榻"],["同欢","同歡"],["同欢同赏","同歡同賞"],["同款","同款"],["同正","同正"],["同步","同步"],["同步传输","同步傳輸"],["同步加速器","同步加速器"],["同步卫星","同步衛星"],["同步录音","同步錄音"],["同步数位阶层","同步數位階層"],["同步电动","同步電動"],["同步辐射仪","同步輻射儀"],["同步辐射加速器","同步輻射加速器"],["同步辐射研究中心","同步輻射研究中心"],["同步进行","同步進行"],["同母","同母"],["同母异父","同母異父"],["同气","同氣"],["同气之光","同氣之光"],["同气之情","同氣之情"],["同气相求","同氣相求"],["同气连枝","同氣連枝"],["同江","同江"],["同江市","同江市"],["同治","同治"],["同派","同派"],["同流合污","同流合污"],["同济","同濟"],["同济会","同濟會"],["同济医科大学","同濟醫科大學"],["同济大学","同濟大學"],["同渡","同渡"],["同温","同溫"],["同温同压","同溫同壓"],["同温层","同溫層"],["同游","同遊"],["同源","同源"],["同源词","同源詞"],["同点","同點"],["同爨","同爨"],["同爲","同爲"],["同父","同父"],["同父异母","同父異母"],["同牀各梦","同牀各夢"],["同牀异梦","同牀異夢"],["同班","同班"],["同班同学","同班同學"],["同理","同理"],["同理可证","同理可證"],["同理心","同理心"],["同甘共苦","同甘共苦"],["同甘同苦","同甘同苦"],["同甘苦","同甘苦"],["同生","同生"],["同生共死","同生共死"],["同生死","同生死"],["同用","同用"],["同甲","同甲"],["同病相怜","同病相憐"],["同盖","同蓋"],["同盟","同盟"],["同盟会","同盟會"],["同盟会宣言","同盟會宣言"],["同盟党","同盟黨"],["同盟军","同盟軍"],["同盟国","同盟國"],["同盟条约","同盟條約"],["同盟罢工","同盟罷工"],["同盟者","同盟者"],["同省","同省"],["同知","同知"],["同砚","同硯"],["同种","同種"],["同科","同科"],["同穴","同穴"],["同窗","同窗"],["同窗夜语","同窗夜語"],["同窗契友","同窗契友"],["同站","同站"],["同章","同章"],["同符合契","同符合契"],["同等","同等"],["同等学力","同等學力"],["同等学历","同等學歷"],["同篇","同篇"],["同类","同類"],["同类产品","同類產品"],["同类意识","同類意識"],["同类相吸","同類相吸"],["同类相呼","同類相呼"],["同类相残","同類相殘"],["同类相求","同類相求"],["同类相聚","同類相聚"],["同类相食","同類相食"],["同类色","同類色"],["同类项","同類項"],["同系","同系"],["同素异形","同素異形"],["同素异形体","同素異形體"],["同素异性","同素異性"],["同素异性体","同素異性體"],["同约","同約"],["同级","同級"],["同级评审","同級評審"],["同级车","同級車"],["同线","同線"],["同组","同組"],["同缘同相","同緣同相"],["同罗杯","同羅杯"],["同罪","同罪"],["同翅目","同翅目"],["同考官","同考官"],["同职","同職"],["同胞","同胞"],["同胞兄妹","同胞兄妹"],["同胞兄弟","同胞兄弟"],["同胞共乳","同胞共乳"],["同胞双生","同胞雙生"],["同胞爱","同胞愛"],["同致","同致"],["同舍生","同舍生"],["同舟之谊","同舟之誼"],["同舟共济","同舟共濟"],["同舟而济","同舟而濟"],["同船济水","同船濟水"],["同色","同色"],["同行","同行"],["同行同业","同行同業"],["同行相忌","同行相忌"],["同行语","同行語"],["同衾共枕","同衾共枕"],["同衾帱","同衾幬"],["同袍","同袍"],["同袍同泽","同袍同澤"],["同被","同被"],["同襟","同襟"],["同见同知","同見同知"],["同言线","同言線"],["同订","同訂"],["同论","同論"],["同语线","同語線"],["同调","同調"],["同谋","同謀"],["同谋者","同謀者"],["同谱","同譜"],["同质","同質"],["同质性","同質性"],["同走","同走"],["同起同坐","同起同坐"],["同跑","同跑"],["同路","同路"],["同路人","同路人"],["同车","同車"],["同轨","同軌"],["同轨同文","同軌同文"],["同轴","同軸"],["同轴圆","同軸圓"],["同轴圆弧","同軸圓弧"],["同轴电缆","同軸電纜"],["同辈","同輩"],["同边","同邊"],["同达","同達"],["同过","同過"],["同进","同進"],["同进同出","同進同出"],["同进士出身","同進士出身"],["同道","同道"],["同道者","同道者"],["同配生殖","同配生殖"],["同酬","同酬"],["同重","同重"],["同量","同量"],["同量异位素","同量異位素"],["同长","同長"],["同门","同門"],["同门友","同門友"],["同门异户","同門異戶"],["同队","同隊"],["同音","同音"],["同音字","同音字"],["同音词","同音詞"],["同韵词","同韻詞"],["同项","同項"],["同题","同題"],["同高","同高"],["同龄","同齡"],["同龄人","同齡人"],["同龄林","同齡林"],["名不当实","名不當實"],["名义价值","名義價值"],["名人录","名人錄"],["名噪","名噪"],["名坛","名壇"],["名垂后世","名垂後世"],["名垂罔极","名垂罔極"],["名复金瓯","名覆金甌"],["名山胜境","名山勝境"],["名师出高徒","名師出高徒"],["名录","名錄"],["名录服务","名錄服務"],["名曲","名曲"],["名望体面","名望體面"],["名次表","名次表"],["名种","名種"],["名称标签","名稱標籤"],["名系","名系"],["名胄","名胄"],["名胜","名勝"],["名胜古迹","名勝古蹟"],["名臣言行录","名臣言行錄"],["名表","名錶"],["名言录","名言錄"],["名重识暗","名重識暗"],["名鉴","名鑑"],["名门之后","名門之後"],["名闻于世","名聞於世"],["后七子","後七子"],["后上","後上"],["后上去","後上去"],["后上来","後上來"],["后下","後下"],["后下去","後下去"],["后下来","後下來"],["后不为例","後不爲例"],["后世","後世"],["后两者","後兩者"],["后丰","后豐"],["后主","後主"],["后事","後事"],["后事之师","後事之師"],["后于","後於"],["后人","後人"],["后人乘凉","後人乘涼"],["后代","後代"],["后代子孙","後代子孫"],["后仰","後仰"],["后仰前合","後仰前合"],["后件","後件"],["后任","後任"],["后会","後會"],["后会可期","後會可期"],["后会无期","後會無期"],["后会有期","後會有期"],["后会难期","後會難期"],["后传","後傳"],["后作","後作"],["后侧","後側"],["后信号灯","後信號燈"],["后偏","後偏"],["后像","後像"],["后儿","後兒"],["后元音","後元音"],["后先辉映","後先輝映"],["后冠","后冠"],["后冷战","後冷戰"],["后冷战时代","後冷戰時代"],["后凉","後涼"],["后凋","後凋"],["后分","後分"],["后到","後到"],["后制","後製"],["后力不继","後力不繼"],["后加","後加"],["后加成分","後加成分"],["后劲","後勁"],["后劲溪","後勁溪"],["后势","後勢"],["后勤","後勤"],["后勤人员","後勤人員"],["后勤区","後勤區"],["后勤学","後勤學"],["后勤部","後勤部"],["后北街","后北街"],["后区","後區"],["后医系","後醫系"],["后半","後半"],["后半世","後半世"],["后半叶","後半葉"],["后半场","後半場"],["后半夜","後半夜"],["后半天","後半天"],["后半季","後半季"],["后半晌","後半晌"],["后半期","後半期"],["后半段","後半段"],["后半部","後半部"],["后卫","後衛"],["后印","後印"],["后印象主义","後印象主義"],["后去","後去"],["后发先至","後發先至"],["后发制人","後發制人"],["后发座","后髮座"],["后台","後臺"],["后台老板","後臺老闆"],["后叶","後葉"],["后合前仰","後合前仰"],["后后","後後"],["后向","後向"],["后周","後周"],["后味","後味"],["后命","後命"],["后哨","後哨"],["后唐","後唐"],["后嗣","後嗣"],["后园","後園"],["后图","後圖"],["后土","后土"],["后场","後場"],["后坐","後坐"],["后坐力","後坐力"],["后埔","後埔"],["后堂","後堂"],["后壁","後壁"],["后壁乡","後壁鄉"],["后壁湖","後壁湖"],["后备","後備"],["后备军","後備軍"],["后备军人","後備軍人"],["后备部","後備部"],["后天","後天"],["后天免疫","後天免疫"],["后天免疫缺乏症候群","後天免疫缺乏症候羣"],["后天性","後天性"],["后夫","後夫"],["后头","後頭"],["后奏","後奏"],["后奏曲","後奏曲"],["后妃","后妃"],["后妈","後媽"],["后妻","後妻"],["后娘","後孃"],["后婚","後婚"],["后婚儿","後婚兒"],["后嫁","後嫁"],["后学","後學"],["后学儿","後學兒"],["后安路","后安路"],["后实先声","後實先聲"],["后宫","後宮"],["后尘","後塵"],["后尧婆","後堯婆"],["后尾","後尾"],["后尾儿","後尾兒"],["后山","後山"],["后巷","後巷"],["后巷前街","後巷前街"],["后市","後市"],["后帝","后帝"],["后平路","后平路"],["后年","後年"],["后广告纪元","後廣告紀元"],["后庄","後莊"],["后序","後序"],["后座","後座"],["后座力","後座力"],["后座系","後座繫"],["后庭","後庭"],["后庭花","後庭花"],["后弦","後弦"],["后影","後影"],["后心","後心"],["后怕","後怕"],["后恭前倨","後恭前倨"],["后悔","後悔"],["后悔不及","後悔不及"],["后悔不来","後悔不來"],["后悔不迭","後悔不迭"],["后悔何及","後悔何及"],["后悔无及","後悔無及"],["后悔药儿","後悔藥兒"],["后悔莫及","後悔莫及"],["后患","後患"],["后患无穷","後患無窮"],["后感","後感"],["后感觉","後感覺"],["后房","後房"],["后手","後手"],["后手不上","後手不上"],["后手不接","後手不接"],["后手儿","後手兒"],["后手钱","後手錢"],["后拥前呼","後擁前呼"],["后拥前推","後擁前推"],["后拥前遮","後擁前遮"],["后拥前驱","後擁前驅"],["后挡板","後擋板"],["后排","後排"],["后掠翼","後掠翼"],["后掠角","後掠角"],["后接","後接"],["后掩蔽","後掩蔽"],["后援","後援"],["后援会","後援會"],["后援军","後援軍"],["后摆","後襬"],["后撤","後撤"],["后攻","後攻"],["后放","後放"],["后效","後效"],["后文","後文"],["后方","後方"],["后方区","後方區"],["后无来者","後無來者"],["后日","後日"],["后昆","後昆"],["后晋","後晉"],["后晌","後晌"],["后晚","後晚"],["后景","後景"],["后有","後有"],["后望镜","後望鏡"],["后期","後期"],["后期印象派","後期印象派"],["后来","後來"],["后来之秀","後來之秀"],["后来人","後來人"],["后来居上","後來居上"],["后果","後果"],["后果前因","後果前因"],["后果堪忧","後果堪憂"],["后果堪虞","後果堪虞"],["后桅","後桅"],["后桥","後橋"],["后梁","後梁"],["后梁太祖","後梁太祖"],["后槽","後槽"],["后步","後步"],["后段","後段"],["后段班","後段班"],["后殿","後殿"],["后母","後母"],["后汉","後漢"],["后汉书","後漢書"],["后汉纪","後漢紀"],["后派","後派"],["后浪","後浪"],["后浪推前浪","後浪推前浪"],["后海湾","后海灣"],["后海灣","后海灣"],["后港","後港"],["后滚翻","後滾翻"],["后灯","後燈"],["后点","後點"],["后照镜","後照鏡"],["后燕","後燕"],["后爲","後爲"],["后父","後父"],["后爹","後爹"],["后王","后王"],["后现代","後現代"],["后现代主义","後現代主義"],["后现代剧场","後現代劇場"],["后生","後生"],["后生动物","後生動物"],["后生可畏","後生可畏"],["后生小子","後生小子"],["后生小辈","後生小輩"],["后生晚学","後生晚學"],["后用","後用"],["后由","後由"],["后甲板","後甲板"],["后皇","后皇"],["后盖","後蓋"],["后盾","後盾"],["后知","後知"],["后知后觉","後知後覺"],["后福","後福"],["后秃","後禿"],["后秦","後秦"],["后程","後程"],["后稷","后稷"],["后空翻","後空翻"],["后窗","後窗"],["后站","後站"],["后端","後端"],["后竹围","後竹圍"],["后篇","後篇"],["后级扩大机","後級擴大機"],["后继","後繼"],["后继乏人","後繼乏人"],["后继乏力","後繼乏力"],["后继无人","後繼無人"],["后继无力","後繼無力"],["后继有人","後繼有人"],["后续","後續"],["后续力","後續力"],["后续的解释过程","後續的解釋過程"],["后缀","後綴"],["后缘","後緣"],["后罩房","後罩房"],["后置","後置"],["后置词","後置詞"],["后羿","后羿"],["后羿射日","后羿射日"],["后翅","後翅"],["后翻筋斗","後翻筋斗"],["后者","後者"],["后肢","後肢"],["后背","後背"],["后脑","後腦"],["后脑勺","後腦勺"],["后脑杓","後腦杓"],["后脚","後腳"],["后脸儿","後臉兒"],["后腰","後腰"],["后腿","後腿"],["后腿肉","後腿肉"],["后膛","後膛"],["后舱","後艙"],["后舱门","後艙門"],["后节","後節"],["后花园","後花園"],["后菜园","後菜園"],["后藏","後藏"],["后藤","後藤"],["后虑","後慮"],["后蜀","後蜀"],["后行","後行"],["后街","后街"],["后裔","後裔"],["后襟","後襟"],["后西游记","後西遊記"],["后视镜","後視鏡"],["后觉","後覺"],["后角","后角"],["后言","後言"],["后计","後計"],["后记","後記"],["后设","後設"],["后词汇加工","後詞彙加工"],["后话","後話"],["后读","後讀"],["后豐","后豐"],["后账","後賬"],["后赤壁赋","後赤壁賦"],["后走","後走"],["后赵","後趙"],["后起","後起"],["后起之秀","後起之秀"],["后起字","後起字"],["后足","後足"],["后跟","後跟"],["后路","後路"],["后身","後身"],["后车","後車"],["后车之戒","後車之戒"],["后车之鉴","後車之鑑"],["后车站","後車站"],["后车轴","後車軸"],["后转","後轉"],["后轮","後輪"],["后辈","後輩"],["后辈小子","後輩小子"],["后辍","後輟"],["后辛","后辛"],["后辟","后辟"],["后边","後邊"],["后边儿","後邊兒"],["后过","後過"],["后进","後進"],["后进先出","後進先出"],["后述","後述"],["后退","後退"],["后退色","後退色"],["后送","後送"],["后送医院","後送醫院"],["后遗","後遺"],["后遗症","後遺症"],["后部","後部"],["后里","后里"],["后里乡","后里鄉"],["后重","後重"],["后金","後金"],["后钩儿","後鉤兒"],["后镜","後鏡"],["后门","後門"],["后防","後防"],["后院","後院"],["后院子","後院子"],["后院起火","後院起火"],["后集","後集"],["后面","後面"],["后项","後項"],["后顾","後顧"],["后顾之忧","後顧之憂"],["后顾之患","後顧之患"],["后顾之虑","後顧之慮"],["后顾之虞","後顧之虞"],["后颈","後頸"],["后首","後首"],["后魏","後魏"],["后鼻音","後鼻音"],["后龙","後龍"],["后龙溪","後龍溪"],["后龙镇","後龍鎮"],["吐出","吐出"],["吐出来","吐出來"],["吐司面包","吐司麪包"],["吐哺捉发","吐哺捉髮"],["吐哺握发","吐哺握髮"],["吐穗","吐穗"],["吐谷浑","吐谷渾"],["吐露出","吐露出"],["向上","向上"],["向上地","向上地"],["向下","向下"],["向东","向東"],["向东看","向東看"],["向东走","向東走"],["向人","向人"],["向何处","向何處"],["向使","向使"],["向例","向例"],["向光","向光"],["向光性","向光性"],["向內","向內"],["向內走","向內走"],["向前","向前"],["向前看","向前看"],["向前看齐","向前看齊"],["向前翻腾","向前翻騰"],["向前走","向前走"],["向前进","向前進"],["向化","向化"],["向北","向北"],["向北地","向北地"],["向北看","向北看"],["向北走","向北走"],["向午","向午"],["向南","向南"],["向南看","向南看"],["向南走","向南走"],["向右","向右"],["向右拐","向右拐"],["向右看","向右看"],["向右看齐","向右看齊"],["向右转","向右轉"],["向右转走","向右轉走"],["向后","向後"],["向后冲","向後衝"],["向后看","向後看"],["向后翻腾","向後翻騰"],["向后走","向後走"],["向后转","向後轉"],["向后转走","向後轉走"],["向善","向善"],["向地","向地"],["向地性","向地性"],["向培良","向培良"],["向壁虚构","向壁虛構"],["向壁虚造","向壁虛造"],["向声背实","向聲背實"],["向外","向外"],["向外冲","向外衝"],["向外看","向外看"],["向外走","向外走"],["向天","向天"],["向学","向學"],["向宠","向寵"],["向导","嚮導"],["向导公司","嚮導公司"],["向导员","嚮導員"],["向导犬","嚮導犬"],["向左","向左"],["向左拐","向左拐"],["向左看","向左看"],["向左看齐","向左看齊"],["向左转","向左轉"],["向左转走","向左轉走"],["向巴平措","向巴平措"],["向平之愿","向平之願"],["向年","向年"],["向应","嚮應"],["向度","向度"],["向当","向當"],["向往","嚮往"],["向心","向心"],["向心力","向心力"],["向心店","向心店"],["向心花序","向心花序"],["向性","向性"],["向慕","嚮慕"],["向戌","向戌"],["向斜","向斜"],["向斜层","向斜層"],["向日","向日"],["向日性","向日性"],["向日葵","向日葵"],["向时","向時"],["向明","嚮明"],["向晓","向曉"],["向晚","向晚"],["向晦","嚮晦"],["向暮","向暮"],["向来","向來"],["向来是","向來是"],["向来都是","向來都是"],["向流星雨","向流星雨"],["向海","向海"],["向溼性","向溼性"],["向火","向火"],["向火乞儿","向火乞兒"],["向用","向用"],["向电性","向電性"],["向盘","向盤"],["向着","向着"],["向秀","向秀"],["向秀丽","向秀麗"],["向者","曏者"],["向背","向背"],["向荣","向榮"],["向西","向西"],["向西南","向西南"],["向触","向觸"],["向迩","嚮邇"],["向里面冲","向裏面衝"],["向量","向量"],["向量代数","向量代數"],["向量分析","向量分析"],["向量图形","向量圖形"],["向钱看","向錢看"],["向阳","向陽"],["向阳信","向陽信"],["向阳区","向陽區"],["向阳大道","向陽大道"],["向隅","向隅"],["向隅独泣","向隅獨泣"],["向隅而泣","向隅而泣"],["向非","向非"],["向顺","向順"],["向风","向風"],["向风针","向風針"],["吓不了","嚇不了"],["吓了","嚇了"],["吓了一跳","嚇了一跳"],["吓出","嚇出"],["吓出病来","嚇出病來"],["吓得发抖","嚇得發抖"],["吕后","呂后"],["吕太后的筵席","呂太后的筵席"],["吕宋烟","呂宋菸"],["吕岩","呂岩"],["吕布","呂布"],["吕布戟","呂布戟"],["吕梁","呂梁"],["吕梁山","呂梁山"],["吕梁市","呂梁市"],["吕氏春秋","呂氏春秋"],["吕芳烟","呂芳煙"],["吕蒙","呂蒙"],["吕蒙正","呂蒙正"],["吕贝克","呂貝克"],["吗啡针","嗎啡針"],["君主专制","君主專制"],["君主专制制","君主專制制"],["君主制","君主制"],["君主立宪制","君主立憲制"],["君合国","君合國"],["君子不念旧恶","君子不念舊惡"],["君子于役","君子于役"],["君子交绝不出恶声","君子交絕不出惡聲"],["君子坦荡荡小人长戚戚","君子坦蕩蕩小人長慼慼"],["君子报仇十年不晚","君子報仇十年不晚"],["君子言先不言后","君子言先不言後"],["吞了","吞了"],["吞了下去","吞了下去"],["吞云吐雾","吞雲吐霧"],["吞刀刮肠","吞刀刮腸"],["吞咽","吞嚥"],["吞并","吞併"],["吞烟","吞煙"],["吞米桑布札","吞米桑布札"],["吟叹","吟歎"],["吟坛","吟壇"],["吟游","吟遊"],["吟游诗人","吟遊詩人"],["吠舍","吠舍"],["否极必泰","否極必泰"],["否极泰来","否極泰來"],["否极生泰","否極生泰"],["吧台","吧檯"],["吧托女","吧托女"],["吨公里","噸公里"],["含了","含了"],["含商咀征","含商咀徵"],["含宫咀征","含宮咀徵"],["含油岩","含油岩"],["含烟笼雾","含煙籠霧"],["含苞欲放","含苞欲放"],["含蜡","含蠟"],["含齿戴发","含齒戴髮"],["听不出","聽不出"],["听不出来","聽不出來"],["听不得一面之词","聽不得一面之詞"],["听了","聽了"],["听了风就是雨","聽了風就是雨"],["听于","聽於"],["听候发落","聽候發落"],["听出","聽出"],["听出来","聽出來"],["听墙面","聽牆面"],["听弦","聽絃"],["听得出","聽得出"],["听得出来","聽得出來"],["听腻了","聽膩了"],["听见了","聽見了"],["听觉范围","聽覺範圍"],["听证制度","聽證制度"],["听骨链","聽骨鏈"],["启动技术","啓動技術"],["启发","啓發"],["启发式","啓發式"],["启发式敎学法","啓發式教學法"],["启发性","啓發性"],["启发性程式","啓發性程式"],["启发法","啓發法"],["启示录","啓示錄"],["启蒙","啓蒙"],["启蒙专制君主","啓蒙專制君主"],["启蒙哲学","啓蒙哲學"],["启蒙时代","啓蒙時代"],["启蒙运动","啓蒙運動"],["吴下阿蒙","吳下阿蒙"],["吴俊杰","吳俊傑"],["吴克群","吳克羣"],["吴嘉种","吳嘉種"],["吴复连","吳復連"],["吴嶽修","吳嶽修"],["吴幸桦","吳幸樺"],["吴志","吳志"],["吴志伟","吳志偉"],["吴志扬","吳志揚"],["吴志祺","吳志祺"],["吴志远","吳志遠"],["吴皓升","吳皓昇"],["吴育升","吳育昇"],["吴荣杰","吳榮杰"],["吴蒙惠","吳蒙惠"],["吴越同舟","吳越同舟"],["吴越春秋","吳越春秋"],["吴越曲","吳越曲"],["吴采璋","吳采璋"],["吴里克","吳里克"],["吴隆杰","吳隆傑"],["吸了","吸了"],["吸出","吸出"],["吸出去","吸出去"],["吸出来","吸出來"],["吸回","吸回"],["吸回去","吸回去"],["吸回来","吸回來"],["吸地板","吸地板"],["吸尽","吸盡"],["吸干","吸乾"],["吸引不了","吸引不了"],["吸得干干","吸得乾乾"],["吸杯","吸杯"],["吸油烟机","吸油煙機"],["吸烟","吸菸"],["吸烟区","吸菸區"],["吸烟客","吸菸客"],["吸烟室","吸菸室"],["吸烟族","吸菸族"],["吸烟率","吸菸率"],["吸烟者","吸菸者"],["吸管虫","吸管蟲"],["吸虫","吸蟲"],["吸虫纲","吸蟲綱"],["吸血虫","吸血蟲"],["吹了","吹了"],["吹云","吹雲"],["吹出","吹出"],["吹出去","吹出去"],["吹出来","吹出來"],["吹发","吹髮"],["吹台","吹臺"],["吹叶机","吹葉機"],["吹向","吹向"],["吹头发","吹頭髮"],["吹干","吹乾"],["吹气胜兰","吹氣勝蘭"],["吹炼","吹煉"],["吹绵介壳虫","吹綿介殼蟲"],["吹胡","吹鬍"],["吹胡子","吹鬍子"],["吹胡子瞪眼睛","吹鬍子瞪眼睛"],["吹风胡哨","吹風胡哨"],["吻别","吻別"],["吻别时","吻別時"],["吻合","吻合"],["吼出","吼出"],["吾为之范我驰驱","吾爲之範我馳驅"],["吾党","吾黨"],["吾当","吾當"],["呂后","呂后"],["呆串了皮","呆串了皮"],["呆了","呆了"],["呆了一呆","呆了一呆"],["呆呆兽","呆呆獸"],["呆呆挣挣","呆呆掙掙"],["呆头","呆頭"],["呆小症","呆小症"],["呆板","呆板"],["呆气","呆氣"],["呆滞","呆滯"],["呆痴","呆癡"],["呆脑","呆腦"],["呆致致","呆緻緻"],["呆话","呆話"],["呆里呆气","呆裏呆氣"],["呆里撒奸","呆裏撒奸"],["呈准","呈准"],["呈现出","呈現出"],["呈现出来","呈現出來"],["呈逆价差","呈逆價差"],["告别","告別"],["告别式","告別式"],["告发","告發"],["告示板","告示板"],["呕出物","嘔出物"],["呗赞","唄讚"],["员山庄","員山莊"],["呛了","嗆了"],["呜咽","嗚咽"],["周一","週一"],["周一岳","周一嶽"],["周三","週三"],["周三径一","周三徑一"],["周上","週上"],["周世惠","周世惠"],["周东昱","周東昱"],["周中","週中"],["周丽淇","周麗淇"],["周书","周書"],["周事","周事"],["周二","週二"],["周五","週五"],["周亚夫","周亞夫"],["周人","周人"],["周人之急","賙人之急"],["周仓","周倉"],["周代","周代"],["周休","週休"],["周休二日","週休二日"],["周会","週會"],["周伟","周偉"],["周传瑛","周傳瑛"],["周传英","周傳英"],["周传雄","周傳雄"],["周作人","周作人"],["周佳佑","周佳佑"],["周佳琦","周佳琦"],["周俊三","周俊三"],["周俊勳","周俊勳"],["周內","周內"],["周全","周全"],["周全方便","周全方便"],["周公","周公"],["周公吐哺","周公吐哺"],["周公瑾","周公瑾"],["周六","週六"],["周六日","週六日"],["周典论","周典論"],["周刊","週刊"],["周到","周到"],["周助","周助"],["周勃","周勃"],["周匝","周匝"],["周华健","周華健"],["周南","周南"],["周卫","周衛"],["周历","周曆"],["周厉王","周厲王"],["周原","周原"],["周口","周口"],["周口地区","周口地區"],["周口市","周口市"],["周口店","周口店"],["周口店文化","周口店文化"],["周召","周召"],["周召共和","周召共和"],["周台竹","周臺竹"],["周告","周告"],["周周","週週"],["周四","週四"],["周回","週迴"],["周围","周圍"],["周围人","周圍人"],["周围性眩晕","周圍性眩暈"],["周围环境","周圍環境"],["周培蕾","周培蕾"],["周堂","周堂"],["周士榆","周士榆"],["周士渊","周士淵"],["周处","周處"],["周备","周備"],["周大福","周大福"],["周天","周天"],["周奕成","周奕成"],["周妙音","周妙音"],["周姓","周姓"],["周孟晔","周孟曄"],["周宁","周寧"],["周宁县","周寧縣"],["周守训","周守訓"],["周宏哲","周宏哲"],["周宏室","周宏室"],["周官","周官"],["周定纬","周定緯"],["周宣王","周宣王"],["周室","周室"],["周家","周家"],["周密","周密"],["周小","周小"],["周小川","周小川"],["周岁","週歲"],["周平王","周平王"],["周年","週年"],["周年庆","週年慶"],["周年纪念","週年紀念"],["周年视差","周年視差"],["周幼婷","周幼婷"],["周幽王","周幽王"],["周庄","周莊"],["周庄王","周莊王"],["周庄镇","周莊鎮"],["周康王","周康王"],["周延","周延"],["周弘宪","周弘憲"],["周忌","周忌"],["周志全","周志全"],["周志浩","周志浩"],["周志诚","周志誠"],["周思源","周思源"],["周思齐","周思齊"],["周急","周急"],["周急继乏","周急繼乏"],["周总理","周總理"],["周恒毅","周恆毅"],["周恤","周恤"],["周恩来","周恩來"],["周情孔思","周情孔思"],["周慧敏","周慧敏"],["周成王","周成王"],["周承玮","周承瑋"],["周折","周折"],["周报","週報"],["周敏鸿","周敏鴻"],["周敦颐","周敦頤"],["周数","週數"],["周文","周文"],["周文王","周文王"],["周方","周方"],["周旋","周旋"],["周旋到底","周旋到底"],["周日","週日"],["周日版","週日版"],["周昉","周昉"],["周易","周易"],["周星驰","周星馳"],["周春秀","周春秀"],["周晓涵","周曉涵"],["周晬","周晬"],["周朝","周朝"],["周期","週期"],["周期函数","周期函數"],["周期彗星","周期彗星"],["周期律","週期律"],["周期性","週期性"],["周期数","週期數"],["周期系","週期系"],["周期表","週期表"],["周期解","週期解"],["周末","週末"],["周末愉快","週末愉快"],["周末效应","週末效應"],["周村","周村"],["周村区","周村區"],["周杰","周杰"],["周杰伦","周杰倫"],["周柏臣","周柏臣"],["周某","周某"],["周树人","周樹人"],["周梁淑怡","周梁淑怡"],["周梦瑶","周夢瑤"],["周正","周正"],["周武王","周武王"],["周武王姬发","周武王姬發"],["周武雄","周武雄"],["周氏","周氏"],["周永康","周永康"],["周永明","周永明"],["周治平","周治平"],["周泓谕","周泓諭"],["周波","周波"],["周流","周流"],["周浃","周浹"],["周济","賙濟"],["周海媚","周海媚"],["周润发","周潤發"],["周渝民","周渝民"],["周游","周遊"],["周游世界","周遊世界"],["周游列国","周遊列國"],["周游券","周遊券"],["周灿德","周燦德"],["周率","周率"],["周王朝","周王朝"],["周瑜","周瑜"],["周瑜打黄盖","周瑜打黃蓋"],["周璇","周璇"],["周盈成","周盈成"],["周盈文","周盈文"],["周盛渊","周盛淵"],["周相","周相"],["周知","周知"],["周礼","周禮"],["周礼良","周禮良"],["周秀霞","周秀霞"],["周程张朱","周程張朱"],["周穆王","周穆王"],["周立昌","周立昌"],["周立波","周立波"],["周章","周章"],["周章狼狈","周章狼狽"],["周筱涵","周筱涵"],["周经凯","周經凱"],["周给","周給"],["周缘","周緣"],["周置","周置"],["周美里","周美里"],["周美青","周美青"],["周考","週考"],["周而不比","周而不比"],["周而复始","周而復始"],["周至","周至"],["周至县","周至縣"],["周董","周董"],["周蓓姬","周蓓姬"],["周蕙","周蕙"],["周薪","週薪"],["周行","周行"],["周览","周覽"],["周角","周角"],["周记","週記"],["周详","周詳"],["周诰","周誥"],["周赐海","周賜海"],["周赧王","周赧王"],["周走秀","週走秀"],["周身","周身"],["周转","週轉"],["周边","周邊"],["周边设备","周邊設備"],["周迅","周迅"],["周近","週近"],["周遍","周遍"],["周道","周道"],["周遭","周遭"],["周遭事物","週遭事物"],["周遮","周遮"],["周邦彦","周邦彥"],["周郎","周郎"],["周郎癖","周郎癖"],["周郎顾曲","周郎顧曲"],["周采诗","周采詩"],["周锡玮","周錫瑋"],["周锦贵","周錦貴"],["周长","周長"],["周雅淑","周雅淑"],["周韫维","周韞維"],["周顗","周顗"],["周颂","周頌"],["周颙","周顒"],["周髀","周髀"],["周髀算经","周髀算經"],["周龙","周龍"],["呱嗒板儿","呱嗒板兒"],["味同嚼蜡","味同嚼蠟"],["味胜易牙","味勝易牙"],["呼之欲出","呼之欲出"],["呼出","呼出"],["呼出来","呼出來"],["呼吁","呼籲"],["呼吸困难","呼吸困難"],["呼吸系统","呼吸系統"],["呼图克图","呼圖克圖"],["命世之才","命世之才"],["命世才","命世才"],["命中注定","命中註定"],["命名系统","命名系統"],["命运注定","命運註定"],["命题范围","命題範圍"],["咀咽","咀嚥"],["咀嚼出","咀嚼出"],["和丰","和豐"],["和了","和了"],["和光同尘","和光同塵"],["和克制","和剋制"],["和合","和合"],["和合二仙","和合二仙"],["和合僧","和合僧"],["和合日","和合日"],["和合汤","和合湯"],["和同","和同"],["和哄","和哄"],["和奸","和姦"],["和布克赛尔县","和布克賽爾縣"],["和布克赛尔蒙古自治县","和布克賽爾蒙古自治縣"],["和平工作团","和平工作團"],["和平里","和平里"],["和弦","和絃"],["和杯","和杯"],["和核","和核"],["和气致祥","和氣致祥"],["和盘托出","和盤托出"],["和而不同","和而不同"],["和胜","和勝"],["和谐一致","和諧一致"],["和面","和麪"],["和风拂面","和風拂面"],["咍台","咍臺"],["咎征","咎徵"],["咏叹","詠歎"],["咏赞","詠贊"],["咏雪之才","詠雪之才"],["咒印术","咒印術"],["咒愿","咒愿"],["咒术","咒術"],["咕咕钟","咕咕鐘"],["咖啡杯","咖啡杯"],["咖啡色系","咖啡色系"],["咙胡","嚨胡"],["咣当","咣噹"],["咨询","諮詢"],["咫尺万里","咫尺萬里"],["咫尺千里","咫尺千里"],["咬了","咬了"],["咬了一口","咬了一口"],["咬出","咬出"],["咬合","咬合"],["咬合不正","咬合不正"],["咬合调整","咬合調整"],["咬姜呷醋","咬薑呷醋"],["咬字不准","咬字不準"],["咬屁虫","咬屁蟲"],["咬弦","咬弦"],["咬折丁子的老婆","咬折丁子的老婆"],["咬秋","咬秋"],["咬舌自尽","咬舌自盡"],["咭叮当","咭叮噹"],["咭当当","咭噹噹"],["咯当","咯噹"],["咳嗽药","咳嗽藥"],["咸丝丝","鹹絲絲"],["咸丰","咸豐"],["咸丰县","咸豐縣"],["咸丰草","咸豐草"],["咸五登三","咸五登三"],["咸亨","咸亨"],["咸亨酒店","咸亨酒店"],["咸信","咸信"],["咸兴","咸興"],["咸兴市","咸興市"],["咸卤","鹹鹵"],["咸味","鹹味"],["咸和","咸和"],["咸咸","鹹鹹"],["咸嘴淡舌","鹹嘴淡舌"],["咸土","鹹土"],["咸宁","咸寧"],["咸宁地区","咸寧地區"],["咸宁市","咸寧市"],["咸安区","咸安區"],["咸宜","咸宜"],["咸度","鹹度"],["咸得","鹹得"],["咸批","鹹批"],["咸水","鹹水"],["咸水妹","鹹水妹"],["咸水湖","鹹水湖"],["咸水鱼","鹹水魚"],["咸池","咸池"],["咸汤","鹹湯"],["咸津津","鹹津津"],["咸津津儿","鹹津津兒"],["咸派","鹹派"],["咸海","鹹海"],["咸淡","鹹淡"],["咸淡适中","鹹淡適中"],["咸湖","鹹湖"],["咸湿","鹹溼"],["咸潟","鹹潟"],["咸猪手","鹹豬手"],["咸猪肉","鹹豬肉"],["咸的","鹹的"],["咸盐","鹹鹽"],["咸类","鹹類"],["咸粥","鹹粥"],["咸肉","鹹肉"],["咸菜","鹹菜"],["咸菜干","鹹菜乾"],["咸蛋","鹹蛋"],["咸认为","咸認爲"],["咸酥鸡","鹹酥雞"],["咸镜","咸鏡"],["咸镜北道","咸鏡北道"],["咸镜南道","咸鏡南道"],["咸镜道","咸鏡道"],["咸阳","咸陽"],["咸阳地区","咸陽地區"],["咸阳宫","咸陽宮"],["咸阳市","咸陽市"],["咸阳桥","咸陽橋"],["咸阳火","咸陽火"],["咸食","鹹食"],["咸鱼","鹹魚"],["咸鱼翻身","鹹魚翻身"],["咸鸭蛋","鹹鴨蛋"],["咽下","嚥下"],["咽不了","嚥不了"],["咽了","嚥了"],["咽住","嚥住"],["咽到","嚥到"],["咽哽","咽哽"],["咽唾","嚥唾"],["咽喉","咽喉"],["咽峡","咽峽"],["咽干","咽乾"],["咽气","嚥氣"],["咽炎","咽炎"],["咽病","咽病"],["咽痛","咽痛"],["咽着","嚥着"],["咽肌","嚥肌"],["咽苦吞甘","嚥苦吞甘"],["咽进","嚥進"],["咽部","咽部"],["咽镜","咽鏡"],["哀兵必胜","哀兵必勝"],["哀凄","哀悽"],["哀叹","哀嘆"],["哀吊","哀弔"],["哀哀欲绝","哀哀欲絕"],["哀戚","哀慼"],["哀挽","哀輓"],["哀莫大于心死","哀莫大於心死"],["品尝","品嚐"],["品尝会","品嚐會"],["品尝到","品嚐到"],["品汇","品彙"],["品种","品種"],["品种改良","品種改良"],["品系","品系"],["品花宝鉴","品花寶鑑"],["品莲台","品蓮臺"],["品貌出众","品貌出衆"],["品质管制","品質管制"],["品鉴","品鑑"],["哄乱","哄亂"],["哄了","哄了"],["哄人","哄人"],["哄伙","鬨夥"],["哄传","哄傳"],["哄传一时","哄傳一時"],["哄劝","哄勸"],["哄动","鬨動"],["哄动一时","哄動一時"],["哄吓骗诈","哄嚇騙詐"],["哄哄","哄哄"],["哄哄翕翕","哄哄翕翕"],["哄堂","鬨堂"],["哄堂大笑","鬨堂大笑"],["哄弄","哄弄"],["哄得","哄得"],["哄抢","哄搶"],["哄抬","哄擡"],["哄抬物价","哄擡物價"],["哄来哄去","哄來哄去"],["哄然","鬨然"],["哄然大笑","鬨然大笑"],["哄笑","鬨笑"],["哄诱","哄誘"],["哄赚","哄賺"],["哄走","哄走"],["哄闹","鬨鬧"],["哄骗","哄騙"],["哈丰角","哈豐角"],["哈克","哈克"],["哈克莉洛","哈克莉洛"],["哈克贝利芬历险记","哈克貝利芬歷險記"],["哈利发","哈利發"],["哈利法克斯","哈利法克斯"],["哈卡里","哈卡里"],["哈发林","哈發林"],["哈塞布苏","哈塞布蘇"],["哈巴罗夫斯克","哈巴羅夫斯克"],["哈巴谷书","哈巴谷書"],["哈布斯堡","哈布斯堡"],["哈比亚里马纳","哈比亞里馬納"],["哈特谢普苏","哈特謝普蘇"],["哈玛斯派系","哈瑪斯派系"],["哈玛斯集团","哈瑪斯集團"],["哈萨克","哈薩克"],["哈萨克人","哈薩克人"],["哈萨克共和国","哈薩克共和國"],["哈萨克文","哈薩克文"],["哈萨克斯坦","哈薩克斯坦"],["哈萨克族","哈薩克族"],["哈萨克语","哈薩克語"],["哈里","哈里"],["哈里伯顿","哈里伯頓"],["哈里发","哈里發"],["哈里发塔","哈里發塔"],["哈里发帝国","哈里發帝國"],["哈里尔","哈里爾"],["哈里斯","哈里斯"],["哈里斯堡","哈里斯堡"],["哈里札德","哈里札德"],["哈里森史密特","哈裏森史密特"],["哈里路亚","哈里路亞"],["哈里逊","哈里遜"],["哈里逊福特","哈里遜福特"],["哈里里","哈里里"],["响了","響了"],["响卜","響卜"],["响叮当","響叮噹"],["响弦","響絃"],["响当当","響噹噹"],["响彻云汉","響徹雲漢"],["响彻云际","響徹雲際"],["响彻云霄","響徹雲霄"],["响板","響板"],["响遏行云","響遏行雲"],["响钟","響鐘"],["响马党羽","響馬黨羽"],["哑子托梦","啞子托夢"],["哑板","啞板"],["哗众","譁衆"],["哗变","譁變"],["哗哗","嘩嘩"],["哗啦","嘩啦"],["哗地","嘩地"],["哗然","譁然"],["哗的","嘩的"],["哗笑","譁笑"],["哥伦布","哥倫布"],["哥伦布市","哥倫布市"],["哥伦布纪","哥倫布紀"],["哥林多后书","哥林多後書"],["哥萨克","哥薩克"],["哥里","哥里"],["哪一个","哪一個"],["哪一出","哪一齣"],["哪个","哪個"],["哪个人","哪個人"],["哪个月","哪個月"],["哪几","哪幾"],["哪几个","哪幾個"],["哪几天","哪幾天"],["哪几次","哪幾次"],["哪只","哪隻"],["哪台","哪臺"],["哪回","哪回"],["哪方面","哪方面"],["哪种","哪種"],["哪种人","哪種人"],["哪里","哪裏"],["哪里买","哪裏買"],["哪里人","哪裏人"],["哪里哪里","哪裏哪裏"],["哪里摔倒哪里爬","哪裏摔倒哪裏爬"],["哭个","哭個"],["哭个夠","哭個夠"],["哭个痛快","哭個痛快"],["哭了","哭了"],["哭出","哭出"],["哭出来","哭出來"],["哭尽","哭盡"],["哭成一团","哭成一團"],["哭秋风","哭秋風"],["哭脏","哭髒"],["哲学系","哲學系"],["哲学范畴","哲學範疇"],["哲布尊丹巴","哲布尊丹巴"],["哺喂","哺餵"],["哼个","哼個"],["哼出","哼出"],["哽咽","哽咽"],["唁吊","唁弔"],["唇干","脣乾"],["唇彩","脣彩"],["唇燥舌干","脣燥舌乾"],["唉叹","唉嘆"],["唐三彩","唐三彩"],["唐志中","唐志中"],["唐才常","唐才常"],["唐氏症","唐氏症"],["唐氏综合症","唐氏綜合症"],["唐王游地府","唐王遊地府"],["唐美云","唐美雲"],["唐胖子吊在醋缸里","唐胖子吊在醋缸裏"],["唤出","喚出"],["唤回","喚回"],["售价","售價"],["售价为","售價爲"],["售出","售出"],["售台","售臺"],["售后","售後"],["售后服务","售後服務"],["售后部","售後部"],["售货台","售貨臺"],["售货合约","售貨合約"],["唯意志论","唯意志論"],["唱个","唱個"],["唱了","唱了"],["唱出","唱出"],["唱出来","唱出來"],["唱叹","唱嘆"],["唱回","唱回"],["唱回去","唱回去"],["唱回来","唱回來"],["唱对台戏","唱對臺戲"],["唱念","唱唸"],["唱曲","唱曲"],["唱游","唱遊"],["唱片目录","唱片目錄"],["唱针","唱針"],["唸了","唸了"],["唾余","唾餘"],["唾沫直咽","唾沫直嚥"],["唾面","唾面"],["唾面自干","唾面自乾"],["啃书虫","啃書蟲"],["啃出","啃出"],["啄针儿","啄針兒"],["商业发票","商業發票"],["商业计划","商業計劃"],["商借","商借"],["商务代表","商務代表"],["商历","商曆"],["商周","商周"],["商品价值","商品價值"],["商品价格","商品價格"],["商品目录","商品目錄"],["商品输出","商品輸出"],["商团","商團"],["商学系","商學系"],["商秋","商秋"],["商科集团","商科集團"],["啜哄","啜哄"],["啤酒厂","啤酒廠"],["啧啧称赞","嘖嘖稱讚"],["啧啧赞叹","嘖嘖讚歎"],["啮合","齧合"],["啷当","啷噹"],["啼饥号寒","啼飢號寒"],["喀喇崑仑山","喀喇崑崙山"],["喀喇昆仑公路","喀喇崑崙公路"],["喀喇昆仑山","喀喇崑崙山"],["喀喇昆仑山脉","喀喇崑崙山脈"],["喀喇沁左翼蒙古族自治县","喀喇沁左翼蒙古族自治縣"],["喀布尔","喀布爾"],["喀布尔河","喀布爾河"],["喀拉喀托火山","喀拉喀托火山"],["喀拉昆仑山","喀拉崑崙山"],["喂乳","餵乳"],["喂了","餵了"],["喂了一声","喂了一聲"],["喂你","餵你"],["喂偏食","喂偏食"],["喂养","餵養"],["喂动物","餵動物"],["喂哺","餵哺"],["喂喂","喂喂"],["喂奶","餵奶"],["喂奶时","餵奶時"],["喂它","餵它"],["喂我","餵我"],["喂母乳","餵母乳"],["喂猪","餵豬"],["喂眼","喂眼"],["喂给","餵給"],["喂羊","餵羊"],["喂过","餵過"],["喂食","餵食"],["喂饭","餵飯"],["喂饱","餵飽"],["喂马","餵馬"],["喂驴","餵驢"],["喂鱼","餵魚"],["喂鸡","餵雞"],["喂鸭","餵鴨"],["喂鹅","餵鵝"],["善了","善了"],["善于","善於"],["善于词令","善於詞令"],["善于辞令","善於辭令"],["善价","善價"],["善后","善後"],["善后事宜","善後事宜"],["善后借款","善後借款"],["善善恶恶","善善惡惡"],["善尽","善盡"],["善念","善念"],["善恶","善惡"],["善恶不分","善惡不分"],["善意回应","善意回應"],["善才","善才"],["善才童子","善才童子"],["善有善报恶有恶报","善有善報惡有惡報"],["善有善报恶有恶报若然不报时晨未到","善有善報惡有惡報若然不報時晨未到"],["善罢干休","善罷干休"],["善财难舍","善財難捨"],["喇叭虫","喇叭蟲"],["喉咽","喉咽"],["喉头发干","喉頭發乾"],["喉干舌燥","喉乾舌燥"],["喊了","喊了"],["喊价","喊價"],["喊出","喊出"],["喊出去","喊出去"],["喊出来","喊出來"],["喊回","喊回"],["喊回去","喊回去"],["喊回来","喊回來"],["喑恶叱咤","喑惡叱吒"],["喘出","喘出"],["喘吁吁","喘吁吁"],["喜不自胜","喜不自勝"],["喜冲冲","喜衝衝"],["喜出望外","喜出望外"],["喜娘","喜娘"],["喜形于色","喜形於色"],["喜忧参半","喜憂參半"],["喜怒不形于色","喜怒不形於色"],["喜恶","喜惡"],["喜极而泣","喜極而泣"],["喜欢表","喜歡錶"],["喜欢钟","喜歡鐘"],["喜欢钟表","喜歡鐘錶"],["喜获","喜獲"],["喜虫儿","喜蟲兒"],["喝个","喝個"],["喝了","喝了"],["喝交杯","喝交杯"],["喝倒彩","喝倒彩"],["喝倒采","喝倒采"],["喝出","喝出"],["喝参","喝參"],["喝尽","喝盡"],["喝干","喝乾"],["喝彩","喝彩"],["喝彩声","喝彩聲"],["喝杯","喝杯"],["喝采","喝采"],["喝风呵烟","喝風呵煙"],["喝风疴烟","喝風痾煙"],["喟叹","喟嘆"],["喧哄","喧鬨"],["喧哗","喧譁"],["喧噪","喧噪"],["喫亏的是乖占便宜的是呆","喫虧的是乖占便宜的是呆"],["喷云吐雾","噴雲吐霧"],["喷云嗳雾","噴雲噯霧"],["喷出","噴出"],["喷出去","噴出去"],["喷出口","噴出口"],["喷出来","噴出來"],["喷发","噴發"],["喷墨印表机","噴墨印表機"],["喷射发动机","噴射發動機"],["喷射战斗机","噴射戰鬥機"],["喷气发动","噴氣發動"],["喷气发动机","噴氣發動機"],["喷洒","噴灑"],["喷薄欲出","噴薄欲出"],["嗅出","嗅出"],["嗑药","嗑藥"],["嗔拳不打笑面","嗔拳不打笑面"],["嗛志","嗛志"],["嗜欲","嗜慾"],["嗜眠症","嗜眠症"],["嗜睡症","嗜睡症"],["嗜血杆菌","嗜血桿菌"],["嗜酸乳干菌","嗜酸乳干菌"],["嗝症","嗝症"],["嗟叹","嗟嘆"],["嗟吁","嗟吁"],["嗣后","嗣後"],["嗣适","嗣適"],["嘀嗒的表","嘀嗒的錶"],["嘀里嘟噜","嘀裏嘟嚕"],["嘉义师范","嘉義師範"],["嘉义师范学院","嘉義師範學院"],["嘉南药专","嘉南藥專"],["嘉南药理科技大学","嘉南藥理科技大學"],["嘉布瑞尔","嘉布瑞爾"],["嘉柏隆里","嘉柏隆里"],["嘉肴","嘉餚"],["嘉言录","嘉言錄"],["嘉谷","嘉穀"],["嘉里","嘉裏"],["嘘下台","噓下臺"],["嘘下台去","噓下臺去"],["嘘下台来","噓下臺來"],["嘱托","囑託"],["嘴松","嘴鬆"],["嘴答谷","嘴答谷"],["嘴里","嘴裏"],["噎饥","噎饑"],["噙齿戴发","噙齒戴髮"],["噜噜苏苏","嚕嚕囌囌"],["噜苏","嚕囌"],["器物录","器物錄"],["噪动","譟動"],["噪声","噪聲"],["噪杂","噪雜"],["噪点","噪點"],["噪诈","譟詐"],["噪音","噪音"],["噪音控制","噪音控制"],["噪音管制","噪音管制"],["噪音管制法","噪音管制法"],["噪鹛","噪鶥"],["噫吁戏","噫吁戲"],["噶大克","噶大克"],["噶布伦","噶布倫"],["噶当派","噶當派"],["噶拉多杰仁波切","噶拉多傑仁波切"],["嚚暗","嚚闇"],["嚷出","嚷出"],["嚷出去","嚷出去"],["嚷出来","嚷出來"],["嚷刮","嚷刮"],["嚼不了","嚼不了"],["嚼舌自尽","嚼舌自盡"],["嚼蜡","嚼蠟"],["嚼谷","嚼穀"],["囉囉苏苏","囉囉囌囌"],["囉苏","囉囌"],["囊橐丰盈","囊橐豐盈"],["囊温郎当","囊溫郎當"],["囓合","囓合"],["囚系","囚繫"],["囚首丧面","囚首喪面"],["囚首垢面","囚首垢面"],["四万","四萬"],["四万一千","四萬一千"],["四万七千","四萬七千"],["四万三千","四萬三千"],["四万两千","四萬兩千"],["四万五千","四萬五千"],["四万八千","四萬八千"],["四万六千","四萬六千"],["四万四千","四萬四千"],["四下里","四下裏"],["四世同堂","四世同堂"],["四两拨千斤","四兩撥千斤"],["四个","四個"],["四个坚持","四個堅持"],["四个现代化","四個現代化"],["四代同堂","四代同堂"],["四体不勤五谷不分","四體不勤五穀不分"],["四余","四餘"],["四停八当","四停八當"],["四克","四克"],["四党","四黨"],["四六面体","四六面體"],["四凶","四凶"],["四出征收","四出徵收"],["四出戏","四齣戲"],["四出祁山","四出祁山"],["四分历","四分曆"],["四分历史","四分歷史"],["四分钟","四分鐘"],["四十一万","四十一萬"],["四十五万","四十五萬"],["四十四万","四十四萬"],["四十多万","四十多萬"],["四千","四千"],["四千两百","四千兩百"],["四千多万","四千多萬"],["四只","四隻"],["四台","四臺"],["四号台","四號臺"],["四合","四合"],["四合一","四合一"],["四合房","四合房"],["四合院","四合院"],["四向","四向"],["四周","四周","四週"],["四周围","四周圍"],["四周年","四週年"],["四大发明","四大發明"],["四大须生","四大鬚生"],["四天后","四天後"],["四川师范大学","四川師範大學"],["四川师范学院","四川師範學院"],["四年制","四年制"],["四年制的大学","四年制的大學"],["四库禁毁书丛刋","四庫禁燬書叢刋"],["四弘誓愿","四弘誓願"],["四才子","四才子"],["四扎","四紮"],["四方八面","四方八面"],["四方台","四方臺"],["四方台区","四方臺區"],["四星彩","四星彩"],["四杯","四杯"],["四杰","四傑"],["四板","四板"],["四极","四極"],["四极管","四極管"],["四柜","四櫃"],["四核","四核"],["四洲志","四洲志"],["四海升平","四海昇平"],["四海皆准","四海皆准"],["四点钟","四點鐘"],["四百万","四百萬"],["四百个","四百個"],["四百多万","四百多萬"],["四秒钟","四秒鐘"],["四级三审制","四級三審制"],["四胡","四胡"],["四舍五入","四捨五入"],["四舍六入","四捨六入"],["四表","四表"],["四邻八舍","四鄰八舍"],["四部合唱","四部合唱"],["四部曲","四部曲"],["四里","四里"],["四面","四面"],["四面体","四面體"],["四面佛","四面佛"],["四面八方","四面八方"],["四面受困","四面受困"],["四面受敌","四面受敵"],["四面楚歌","四面楚歌"],["四面玲珑","四面玲瓏"],["四面见光","四面見光"],["四面钟","四面鐘"],["回九","回九"],["回乡","回鄉"],["回书","回書"],["回买","回買"],["回了","回了"],["回事","回事"],["回交","回交"],["回京","回京"],["回人","回人"],["回亿","回億"],["回传","回傳"],["回佣","回佣"],["回信","回信"],["回信地址","回信地址"],["回候","回候"],["回光返照","迴光返照"],["回光镜","回光鏡"],["回冲","回沖"],["回击","回擊"],["回函","回函"],["回到","回到"],["回力棒","回力棒"],["回力球","回力球"],["回动","回動"],["回匝","迴匝"],["回升","回升"],["回单","回單"],["回单儿","回單兒"],["回卷","回捲"],["回厂","回廠"],["回历","回曆"],["回去","回去"],["回口","回口"],["回台","回臺"],["回合","回合"],["回吐","回吐"],["回向","迴向"],["回告","回告"],["回味","回味"],["回味无穷","回味無窮"],["回和","回和"],["回咬","回咬"],["回响","迴響"],["回嗔作喜","回嗔作喜"],["回嘴","回嘴"],["回回","回回"],["回回历","回回曆"],["回回青","回回青"],["回回鼻子","回回鼻子"],["回国","回國"],["回圈","迴圈"],["回塘","回塘"],["回填","回填"],["回墨印","回墨印"],["回声","回聲"],["回声定位","回聲定位"],["回声探测","迴聲探測"],["回复","回覆","回復"],["回复青春","回復青春"],["回天","迴天"],["回天之力","回天之力"],["回天乏术","回天乏術"],["回头","回頭"],["回头一看","回頭一看"],["回头书","回頭書"],["回头人","回頭人"],["回头儿","回頭兒"],["回头客","回頭客"],["回头掣脑","回頭掣腦"],["回头是岸","回頭是岸"],["回头草","回頭草"],["回头见","回頭見"],["回头路","回頭路"],["回头车子","回頭車子"],["回奉","回奉"],["回娘家","回孃家"],["回子","回子"],["回字","回字"],["回定","回定"],["回家","回家"],["回家乐","回家樂"],["回家路","回家路"],["回家路上","回家路上"],["回家途中","回家途中"],["回容","回容"],["回山倒海","回山倒海"],["回师","回師"],["回帖","回帖"],["回带","迴帶"],["回席","回席"],["回应","迴應"],["回府","回府"],["回廊","迴廊"],["回弹","回彈"],["回归","迴歸"],["回归年","迴歸年"],["回归潮","迴歸潮"],["回归热","迴歸熱"],["回归线","迴歸線"],["回形夹","迴形夾"],["回得","回得"],["回得去","回得去"],["回得来","回得來"],["回心","迴心"],["回心转意","回心轉意"],["回忆","回憶"],["回忆录","回憶錄"],["回忆说","回憶說"],["回忆起","回憶起"],["回忌","回忌"],["回念","回念"],["回思","回思"],["回想","回想"],["回想到","回想到"],["回想起","回想起"],["回想起来","回想起來"],["回惶","回惶"],["回戏","回戲"],["回手","回手"],["回扣","回扣"],["回执","回執"],["回折格子","回折格子"],["回护","迴護"],["回报","回報"],["回报率","回報率"],["回拜","回拜"],["回拨","回撥"],["回掉","回掉"],["回援","回援"],["回收","回收"],["回收价值","回收價值"],["回收商","回收商"],["回收场","回收場"],["回收物","回收物"],["回收率","回收率"],["回收站","回收站"],["回收量","回收量"],["回放","回放"],["回敎会议组织","回教會議組織"],["回教","回教"],["回教世界","回教世界"],["回教人","回教人"],["回教信徒","回教信徒"],["回教党","回教黨"],["回教国","回教國"],["回教圣战","回教聖戰"],["回教帝国","回教帝國"],["回教开斋节","回教開齋節"],["回教徒","回教徒"],["回教忠孝节","回教忠孝節"],["回敬","回敬"],["回数票","回數票"],["回文","迴文"],["回文织锦","迴文織錦"],["回斡","迴斡"],["回旋","迴旋"],["回族","回族"],["回旨","回旨"],["回易","回易"],["回映","回映"],["回春","回春"],["回暖","回暖"],["回望","回望"],["回朝","回朝"],["回本","回本"],["回条","回條"],["回来","回來"],["回档","回檔"],["回梦","迴夢"],["回棋","回棋"],["回椎","回椎"],["回民","回民"],["回民区","回民區"],["回水","回水"],["回波","回波"],["回流","迴流"],["回清倒影","迴清倒影"],["回温","回溫"],["回港","回港"],["回游","迴游"],["回溯","回溯"],["回溯到","回溯到"],["回滩","回灘"],["回潮","回潮"],["回潮率","回潮率"],["回火","回火"],["回灯","回燈"],["回炉","回爐"],["回炉复帐","回爐復帳"],["回点","回點"],["回煞","回煞"],["回片","回片"],["回状","回狀"],["回环","迴環"],["回环转折","迴環轉折"],["回班","回班"],["回球","回球"],["回甘","回甘"],["回生","回生"],["回生乏术","回生乏術"],["回生起死","回生起死"],["回用","回用"],["回电","回電"],["回疆","回疆"],["回盘","回盤"],["回目","回目"],["回盲瓣","迴盲瓣"],["回看","回看"],["回眸","回眸"],["回眸一笑","回眸一笑"],["回着","回着"],["回示","回示"],["回礼","回禮"],["回神","回神"],["回票面","回票面"],["回禀","回稟"],["回禄","回祿"],["回禄之灾","回祿之災"],["回程","回程"],["回稳","回穩"],["回穴","迴穴"],["回空","回空"],["回笼","回籠"],["回答","回答"],["回答出来","回答出來"],["回答到","回答到"],["回答说","回答說"],["回籍","回籍"],["回纥","回紇"],["回纥兵","回紇兵"],["回纥军","回紇軍"],["回纳","回納"],["回纹针","迴紋針"],["回绕","迴繞"],["回绝","回絕"],["回翔","迴翔"],["回老家","回老家"],["回肠","迴腸"],["回肠九回","回腸九回"],["回肠九转","迴腸九轉"],["回肠伤气","迴腸傷氣"],["回肠寸断","迴腸寸斷"],["回肠荡气","迴腸蕩氣"],["回背","回背"],["回腕","迴腕"],["回航","回航"],["回航途中","回航途中"],["回船转舵","回船轉舵"],["回良玉","回良玉"],["回荡","迴盪"],["回落","回落"],["回补","回補"],["回西流","回西流"],["回见","回見"],["回访","回訪"],["回诊","回診"],["回话","回話"],["回诵","迴誦"],["回请","回請"],["回购","回購"],["回购额","回購額"],["回赎","回贖"],["回赠","回贈"],["回起","回起"],["回跌","回跌"],["回路","迴路"],["回身","回身"],["回车","回車"],["回车键","回車鍵"],["回转","迴轉"],["回转仪","迴轉儀"],["回转半径","回轉半徑"],["回转寿司","回轉壽司"],["回软","回軟"],["回过","回過"],["回过来","回過來"],["回过神","回過神"],["回返","回返"],["回还","回還"],["回送","回送"],["回递性","迴遞性"],["回途","回途"],["回遑","回遑"],["回道","回道"],["回避","迴避"],["回避学习","迴避學習"],["回邪","回邪"],["回邮","回郵"],["回邮信封","回郵信封"],["回部","回部"],["回采","回採"],["回銮","迴鑾"],["回销","回銷"],["回锅","回鍋"],["回锅油","回鍋油"],["回锅肉","回鍋肉"],["回锋","回鋒"],["回门","回門"],["回阑","回闌"],["回防","回防"],["回阳荡气","迴陽蕩氣"],["回雪","迴雪"],["回青","回青"],["回音","迴音"],["回顾","回顧"],["回风","迴風"],["回飙","迴飆"],["回飞棒","回飛棒"],["回馈","回饋"],["回首","回首"],["回马","回馬"],["回马枪","回馬槍"],["回驳","回駁"],["回魂仙梦","迴魂仙夢"],["回鱼箸","回魚箸"],["回鹘","回鶻"],["回鹘文","回鶻文"],["回黄倒皂","回黃倒皂"],["回黄转绿","回黃轉綠"],["因事制宜","因事制宜"],["因于","因於"],["因地制宜","因地制宜"],["因奸成孕","因姦成孕"],["因斯布鲁克","因斯布魯克"],["因时制宜","因時制宜"],["因果关系","因果關係"],["因缘巧合","因緣巧合"],["团丁","團丁"],["团主","團主"],["团书","團書"],["团伙","團伙"],["团体","團體"],["团体冠军","團體冠軍"],["团体协约","團體協約"],["团体奖","團體獎"],["团体性","團體性"],["团体意识","團體意識"],["团体操","團體操"],["团体治疗","團體治療"],["团体活动","團體活動"],["团体票","團體票"],["团体组","團體組"],["团体行","團體行"],["团体行动","團體行動"],["团体规范","團體規範"],["团体赛","團體賽"],["团体辅导","團體輔導"],["团保","團保"],["团剥","團剝"],["团勇","團勇"],["团匪","團匪"],["团名","團名"],["团员","團員"],["团团","團團"],["团团围住","團團圍住"],["团团转","團團轉"],["团围","團圍"],["团圆","團圓"],["团圆夜","團圓夜"],["团圆日","團圓日"],["团圆节","團圓節"],["团圆饭","團圓飯"],["团坐","團坐"],["团头","團頭"],["团头团脸","團頭團臉"],["团头聚面","團頭聚面"],["团契","團契"],["团委","團委"],["团子","糰子"],["团年","團年"],["团康","團康"],["团弄","團弄"],["团扇","團扇"],["团扇妾","團扇妾"],["团拜","團拜"],["团掿","團掿"],["团旗","團旗"],["团服","團服"],["团栾","團欒"],["团案","團案"],["团沙群岛","團沙羣島"],["团牌","團牌"],["团状","團狀"],["团瓢","團瓢"],["团矿","團礦"],["团社","團社"],["团空","團空"],["团管区","團管區"],["团粉","糰粉"],["团粒","團粒"],["团练","團練"],["团结","團結"],["团结一心","團結一心"],["团结一致","團結一致"],["团结就是力量","團結就是力量"],["团结工会","團結工會"],["团聚","團聚"],["团脐","團臍"],["团脸","團臉"],["团花","團花"],["团茶","團茶"],["团荷","團荷"],["团藻","團藻"],["团行","團行"],["团购","團購"],["团费","團費"],["团部","團部"],["团长","團長"],["团队","團隊"],["团队奖","團隊獎"],["团队报","團隊報"],["团队精神","團隊精神"],["团队赛","團隊賽"],["团音","團音"],["团风","團風"],["团风县","團風縣"],["团香扇","團香扇"],["团鱼","團魚"],["团龙","團龍"],["团龙儿","團龍兒"],["团𪢮","團圞"],["园游会","園遊會"],["园游券","園遊券"],["园里","園裏"],["困乏","睏乏"],["困了","困了"],["困于","困於"],["困人","困人"],["困住","困住"],["困倦","睏倦"],["困倦起来","困倦起來"],["困兽","困獸"],["困兽之斗","困獸之鬥"],["困兽犹斗","困獸猶鬥"],["困厄","困厄"],["困围","困圍"],["困在","困在"],["困境","困境"],["困处","困處"],["困处泥涂","困處泥塗"],["困学","困學"],["困守","困守"],["困局","困局"],["困心衡虑","困心衡慮"],["困惑","困惑"],["困惑不解","困惑不解"],["困惫","困憊"],["困意","睏意"],["困扰","困擾"],["困斗","困鬥"],["困歇","困歇"],["困滞","困滯"],["困畏","困畏"],["困知勉行","困知勉行"],["困穷","困窮"],["困窘","困窘"],["困竭","困竭"],["困腾腾","困騰騰"],["困苦","困苦"],["困觉","睏覺"],["困话","困話"],["困踬","困躓"],["困蹙","困蹙"],["困阨","困阨"],["困阻","困阻"],["困隘","困隘"],["困难","困難"],["困难在于","困難在於"],["困难度","困難度"],["困难点","困難點"],["困难重重","困難重重"],["困顿","困頓"],["围了","圍了"],["围困","圍困"],["围困在","圍困在"],["围场满族蒙古族自治县","圍場滿族蒙古族自治縣"],["围岩","圍巖"],["固于","固於"],["固定制","固定制"],["固定术","固定術"],["固定汇率","固定匯率"],["固征","固徵"],["国一制","國一制"],["国之桢干","國之楨榦"],["国乐团","國樂團"],["国于","國於"],["国仇","國仇"],["国会制","國會制"],["国共两党","國共兩黨"],["国共合作","國共合作"],["国别","國別"],["国别史","國別史"],["国剧团","國劇團"],["国务院台湾事务办公室","國務院臺灣事務辦公室"],["国务院法制局","國務院法制局"],["国历","國曆"],["国历年","國曆年"],["国发","國發"],["国发院","國發院"],["国台办","國臺辦"],["国台语","國臺語"],["国合会","國合會"],["国困民艰","國困民艱"],["国土规划","國土規劃"],["国土资讯系统","國土資訊系統"],["国外汇兑","國外匯兌"],["国大主席团","國大主席團"],["国大代表","國大代表"],["国大代表部","國大代表部"],["国大党","國大黨"],["国家党","國家黨"],["国家制度","國家制度"],["国家发展和改革委员会","國家發展和改革委員會"],["国家发展改革委","國家發展改革委"],["国家发展计划委员会","國家發展計劃委員會"],["国家外汇管理局","國家外匯管理局"],["国家开发银行","國家開發銀行"],["国家文物鉴定委员会","國家文物鑑定委員會"],["国家旅游度假区","國家旅遊度假區"],["国家杯","國家杯"],["国家标准","國家標準"],["国家标准中文交换码","國家標準中文交換碼"],["国家标准化管理委员会","國家標準化管理委員會"],["国家标准码","國家標準碼"],["国家栋梁","國家棟梁"],["国家永续发展论坛","國家永續發展論壇"],["国家空气品质标准","國家空氣品質標準"],["国家规范","國家規範"],["国家计划委员会","國家計劃委員會"],["国家食品药品监督管理局","國家食品藥品監督管理局"],["国建学术联谊会","國建學術聯誼會"],["国建计划","國建計劃"],["国戚","國戚"],["国戚皇亲","國戚皇親"],["国术","國術"],["国术团","國術團"],["国术社","國術社"],["国术馆","國術館"],["国梁","國樑"],["国民党","國民黨"],["国民党军队","國民黨軍隊"],["国民党员","國民黨員"],["国民党版","國民黨版"],["国民党籍","國民黨籍"],["国民常用字标准字体表","國民常用字標準字體表"],["国民生活须知","國民生活須知"],["国民礼仪范例","國民禮儀範例"],["国民裁判制","國民裁判制"],["国民革命党","國民革命黨"],["国泰综合医院","國泰綜合醫院"],["国王杯","國王杯"],["国社党","國社黨"],["国科会同步幅射研究中心","國科會同步幅射研究中心"],["国科会晶片设计制作中心","國科會晶片設計製作中心"],["国科会精密仪器发展中心","國科會精密儀器發展中心"],["国穷民困","國窮民困"],["国立历史博物馆","國立歷史博物館"],["国立台北科技大学","國立臺北科技大學"],["国立台湾博物馆","國立臺灣博物館"],["国立台湾图书馆","國立臺灣圖書館"],["国立台湾技术大学","國立臺灣技術大學"],["国立教育广播电台","國立教育廣播電臺"],["国胄","國胄"],["国药","國藥"],["国语注音符号第一式","國語注音符號第一式"],["国语注音符号第二式","國語注音符號第二式"],["国贸系","國貿系"],["国防体制","國防體制"],["国际人权标准","國際人權標準"],["国际体操联合会","國際體操聯合會"],["国际先驱论坛报","國際先驅論壇報"],["国际公制","國際公制"],["国际关系","國際關係"],["国际关系学院","國際關係學院"],["国际准备","國際準備"],["国际分工体制","國際分工體制"],["国际单位制","國際單位制"],["国际台","國際臺"],["国际合作","國際合作"],["国际合作节","國際合作節"],["国际奥林匹克委员会","國際奧林匹克委員會"],["国际学术网路","國際學術網路"],["国际学舍","國際學舍"],["国际开发总会","國際開發總會"],["国际柜","國際櫃"],["国际标准","國際標準"],["国际标准书码","國際標準書碼"],["国际标准化组织","國際標準化組織"],["国际标准舞","國際標準舞"],["国际水准","國際水準"],["国际漫游","國際漫遊"],["国际漫游拨接服务","國際漫遊撥接服務"],["国际电影制片人协会联盟","國際電影製片人協會聯盟"],["国际羽毛球联合会","國際羽毛球聯合會"],["国际舞台","國際舞臺"],["国际航空联合会","國際航空聯合會"],["国际讬管制度","國際託管制度"],["国际贷借","國際貸借"],["国际足球联合会","國際足球聯合會"],["图书巡回车","圖書巡迴車"],["图书目录","圖書目錄"],["图书餐饮复合式餐厅","圖書餐飲複合式餐廳"],["图书馆周","圖書館週"],["图亚克拜","圖亞克拜"],["图像用户介面","圖像用戶介面"],["图克","圖克"],["图录","圖錄"],["图形用户界面","圖形用戶界面"],["图形界面","圖形界面"],["图文并茂","圖文並茂"],["图木舒克","圖木舒克"],["图木舒克市","圖木舒克市"],["图板","圖板"],["图表","圖表"],["图表说明","圖表說明"],["图财致命","圖財致命"],["图资系统","圖資系統"],["图里","圖裏"],["图里亚夫","圖里亞夫"],["图鉴","圖鑑"],["图面","圖面"],["囿于","囿於"],["囿于一时","囿於一時"],["囿于成见","囿於成見"],["圆台","圓臺"],["圆周","圓周"],["圆周率","圓周率"],["圆周角","圓周角"],["圆周运动","圓周運動"],["圆形面包","圓形麪包"],["圆板","圓板"],["圆板状","圓板狀"],["圆柱面","圓柱面"],["圆舞曲","圓舞曲"],["圆锥台","圓錐臺"],["圆锥曲线","圓錐曲線"],["圆雕","圓雕"],["圆面大耳","圓面大耳"],["圆面积","圓面積"],["圆面饼","圓麪餅"],["圈占","圈佔"],["圈子里","圈子裏"],["圈扣","圈釦"],["圈杯","圈杯"],["圈梁","圈樑"],["圈里","圈裏"],["圈里人","圈裏人"],["土中曲蟮","土中曲蟮"],["土制","土製"],["土制品","土製品"],["土参","土參"],["土司面包","土司麪包"],["土地利用规划","土地利用規劃"],["土地征收","土地徵收"],["土地重划","土地重劃"],["土壤冲蚀","土壤沖蝕"],["土布","土布"],["土托鱼","土托魚"],["土托鱼羹","土托魚羹"],["土木工程学系","土木工程學系"],["土木系","土木系"],["土法炼钢","土法煉鋼"],["土洋并举","土洋並舉"],["土洋结合","土洋結合"],["土种","土種"],["土耳其进行曲","土耳其進行曲"],["土药","土藥"],["土谷祠","土穀祠"],["土里","土裏"],["土里土气","土裏土氣"],["土霉素","土黴素"],["圣修伯里","聖修伯里"],["圣克里斯多福","聖克里斯多福"],["圣克里斯托巴","聖克里斯托巴"],["圣克鲁斯","聖克魯斯"],["圣克鲁斯岛","聖克魯斯島"],["圣哈辛托","聖哈辛托"],["圣坛","聖壇"],["圣塔蒙尼加","聖塔蒙尼加"],["圣帕台风","聖帕颱風"],["圣帕强台","聖帕強颱"],["圣帕特里克","聖帕特里克"],["圣帕袭台","聖帕襲臺"],["圣德克旭贝里","聖德克旭貝里"],["圣拉蒙","聖拉蒙"],["圣杯","聖盃"],["圣杰门队","聖傑門隊"],["圣母升天节","聖母升天節"],["圣潘克勒斯站","聖潘克勒斯站"],["圣火台","聖火臺"],["圣皮埃尔和密克隆","聖皮埃爾和密克隆"],["圣神降临周","聖神降臨週"],["圣胡安","聖胡安"],["圣药","聖藥"],["圣诞叶","聖誕葉"],["圣诞百合","聖誕百合"],["圣迹","聖蹟"],["圣餐台","聖餐檯"],["圣餐布","聖餐布"],["在一定范围内","在一定範圍內"],["在下面","在下面"],["在世界范围内","在世界範圍內"],["在于","在於"],["在克制","在剋制"],["在全国范围","在全國範圍"],["在全国范围内","在全國範圍內"],["在全省范围内","在全省範圍內"],["在出","在出"],["在台","在臺"],["在台协会","在臺協會"],["在后","在後"],["在坛子胡同","在罈子胡同"],["在天愿做比翼鸟在地愿做连理枝","在天願做比翼鳥在地願做連理枝"],["在家修","在家修"],["在家出家","在家出家"],["在家千日好出门一时难","在家千日好出門一時難"],["在家靠父母出外靠朋友","在家靠父母出外靠朋友"],["在密切注意","在密切注意"],["在念","在念"],["在某种程度上","在某種程度上"],["在核","在覈"],["在桥梁工地上","在橋梁工地上"],["在此之后","在此之後"],["在此后","在此後"],["在泛","在泛"],["在眼里","在眼裏"],["在种","在種"],["在职干部","在職幹部"],["在职进修","在職進修"],["在范围内","在範圍內"],["在规范","在規範"],["在野党","在野黨"],["圭表","圭表"],["地一卷","地一捲"],["地下修文","地下修文"],["地下修文郎","地下修文郎"],["地下害虫","地下害蟲"],["地下工厂","地下工廠"],["地下开采","地下開採"],["地下水面","地下水面"],["地下电台","地下電臺"],["地下签赌","地下簽賭"],["地下通汇","地下通匯"],["地丑德齐","地醜德齊"],["地价","地價"],["地价公告","地價公告"],["地价税","地價稅"],["地克制","地剋制"],["地冲","地衝"],["地制法","地制法"],["地区党","地區黨"],["地区冲突","地區衝突"],["地区差价","地區差價"],["地占","地佔"],["地台","地臺"],["地坛","地壇"],["地塞米松","地塞米松"],["地复天翻","地覆天翻"],["地大物丰","地大物豐"],["地尽其利","地盡其利"],["地干吧","地幹吧"],["地平面","地平面"],["地当","地當"],["地志","地誌"],["地念","地念"],["地方志","地方誌"],["地方戏曲","地方戲曲"],["地方色彩","地方色彩"],["地无三里平","地無三里平"],["地板","地板"],["地板操","地板操"],["地板运动","地板運動"],["地极","地極"],["地核","地核"],["地灵人杰","地靈人傑"],["地热发电厂","地熱發電廠"],["地牛发威","地牛發威"],["地狱谷","地獄谷"],["地球同步轨道","地球同步軌道"],["地理极","地理極"],["地理资讯系统","地理資訊系統"],["地瓜叶","地瓜葉"],["地瓜签","地瓜籤"],["地瓜面","地瓜面"],["地缘关系","地緣關係"],["地缝里","地縫裏"],["地老天荒不了情","地老天荒不了情"],["地胄","地胄"],["地蜡","地蠟"],["地表","地表"],["地表水","地表水"],["地质年代表","地質年代表"],["地质年表","地質年表"],["地质编录","地質編錄"],["地里","地裏"],["地里鬼","地裏鬼"],["地面","地面"],["地面上","地面上"],["地面下","地面下"],["地面层","地面層"],["地面控制","地面控制"],["地面核爆炸","地面核爆炸"],["地面气压","地面氣壓"],["地面水","地面水"],["地面温度","地面溫度"],["地面灌溉","地面灌溉"],["地面站","地面站"],["地面部队","地面部隊"],["地面零点","地面零點"],["场合","場合"],["场记板","場記板"],["场面","場面"],["场面阔绰","場面闊綽"],["均一价","均一價"],["均权制度","均權制度"],["均田制","均田制"],["均田制度","均田制度"],["坊曲","坊曲"],["坍台","坍臺"],["坎塔布连","坎塔布連"],["坎塔布连山脉","坎塔布連山脈"],["坎塔布连海","坎塔布連海"],["坏了","壞了"],["坏了性命","壞了性命"],["坏于","壞於"],["坏家伙","壞傢伙"],["坏恶","壞惡"],["坐了","坐了"],["坐冷板凳","坐冷板凳"],["坐台","坐檯"],["坐台子","坐檯子"],["坐台小姐","坐檯小姐"],["坐回","坐回"],["坐困","坐困"],["坐困愁城","坐困愁城"],["坐如钟","坐如鐘"],["坐山观虎斗","坐山觀虎鬥"],["坐庄","坐莊"],["坐板疮","坐板瘡"],["坐标","座標"],["坐标系","座標系"],["坐致","坐致"],["坐药","坐藥"],["坐萝卜","坐蘿蔔"],["坐薪尝胆","坐薪嘗膽"],["坐蜡","坐蠟"],["坐钟","坐鐘"],["坐领干薪","坐領乾薪"],["坑蒙","坑蒙"],["坑里","坑裏"],["块肉馀生录","塊肉餘生錄"],["坚白同异","堅白同異"],["坚臥烟霞","堅臥煙霞"],["坚致","堅緻"],["坛佳酿","罈佳釀"],["坛兆","壇兆"],["坛台","壇臺"],["坛场","壇場"],["坛坛罐罐","罈罈罐罐"],["坛坫","壇坫"],["坛坫周旋","壇坫週旋"],["坛城","壇城"],["坛女儿红","罈女兒紅"],["坛好酒","罈好酒"],["坛子","罈子"],["坛宇","壇宇"],["坛烧刀子","罈燒刀子"],["坛燒刀子","罈燒刀子"],["坛白干","罈白干"],["坛美酒","罈美酒"],["坛老酒","罈老酒"],["坛陈年","罈陳年"],["坛騞","罈騞"],["坛高粱","罈高粱"],["坡布莱","坡布萊"],["坤极","坤極"],["坤范","坤範"],["坤表","坤錶"],["坦克","坦克"],["坦克兵","坦克兵"],["坦克型","坦克型"],["坦克车","坦克車"],["坦坦荡荡","坦坦蕩蕩"],["坦尚尼亚联合共和国","坦尚尼亞聯合共和國"],["坦涂","坦塗"],["坦荡","坦蕩"],["坦荡荡","坦蕩蕩"],["坨里","坨里"],["坯布","坯布"],["坱郁","坱鬱"],["垂了","垂了"],["垂了下去","垂了下去"],["垂了下来","垂了下來"],["垂于","垂於"],["垂于将来","垂於將來"],["垂发","垂髮"],["垂吊","垂吊"],["垂帘","垂簾"],["垂帘听政","垂簾聽政"],["垂念","垂念"],["垂死挣扎","垂死掙扎"],["垂注","垂注"],["垂涎欲滴","垂涎欲滴"],["垂直于","垂直於"],["垂直搜索","垂直搜索"],["垂直面","垂直面"],["垂范","垂範"],["垂范百世","垂範百世"],["垂裕后昆","垂裕後昆"],["垂面","垂面"],["垂馨千祀","垂馨千祀"],["垃圾回收","垃圾回收"],["垃圾虫","垃圾蟲"],["垄断价格","壟斷價格"],["垄断资产","壟斷資產"],["垄断集团","壟斷集團"],["型别","型別"],["型别转换","型別轉換"],["型录","型錄"],["型录式广告","型錄式廣告"],["型板","型板"],["型范","型範"],["垢面","垢面"],["垣曲","垣曲"],["垣曲县","垣曲縣"],["垦丁杯","墾丁盃"],["垦复","墾複"],["垦辟","墾闢"],["垫个","墊個"],["垫了","墊了"],["垫出","墊出"],["垫出去","墊出去"],["垫出来","墊出來"],["垫发","墊發"],["垫回","墊回"],["垫回去","墊回去"],["垫回来","墊回來"],["垫板","墊板"],["垮了","垮了"],["垮台","垮臺"],["垮向","垮向"],["埃克托","埃克托"],["埃克托柏辽兹","埃克托柏遼茲"],["埃及历","埃及曆"],["埃及历史","埃及歷史"],["埃及艳后","埃及豔后"],["埃夫伯里","埃夫伯里"],["埃布罗","埃布羅"],["埃布罗河","埃布羅河"],["埃德蒙顿","埃德蒙頓"],["埃拉托塞尼斯","埃拉托塞尼斯"],["埃格尔松","埃格爾松"],["埃荣冲","埃榮衝"],["埃里温","埃裏溫"],["埋了","埋了"],["埋头寻表","埋頭尋錶"],["埋头寻钟","埋頭尋鐘"],["埋头寻钟表","埋頭尋鐘錶"],["埋头苦干","埋頭苦幹"],["埋尸","埋屍"],["埋布","埋佈"],["埋杆竖柱","埋杆豎柱"],["埋没人才","埋沒人才"],["城市依赖症","城市依賴症"],["城市规划","城市規劃"],["城里","城裏"],["城雕","城雕"],["埔里","埔里"],["埔里社抚垦局","埔裏社撫墾局"],["埔里镇","埔里鎮"],["域名抢注","域名搶注"],["域名注册","域名註冊"],["域多利皇后","域多利皇后"],["埤塘里","埤塘里"],["培养出","培養出"],["培养出来","培養出來"],["培尔松","培爾松"],["培植出","培植出"],["培特曼赫鲁威克","培特曼赫魯威克"],["培美曲塞","培美曲塞"],["培育出","培育出"],["培育出来","培育出來"],["培里克利斯","培裏克利斯"],["培里克里斯","培里克里斯"],["基于","基於"],["基克维特","基克維特"],["基准","基準"],["基准兵","基準兵"],["基准日","基準日"],["基准法","基準法"],["基准点","基準點"],["基准线","基準線"],["基准面","基準面"],["基因修改","基因修改"],["基因技术","基因技術"],["基因表达","基因表達"],["基团","基團"],["基地台","基地臺"],["基尔库克","基爾庫克"],["基岩","基岩"],["基布兹","基布茲"],["基干","基幹"],["基度山恩仇记","基度山恩仇記"],["基性岩石","基性岩石"],["基本多文种平面","基本多文種平面"],["基本词汇","基本詞彙"],["基本面","基本面"],["基板","基板"],["基极","基極"],["基民党","基民黨"],["基里兰柯","基里蘭柯"],["基里巴斯","基里巴斯"],["基里巴斯共和国","基裏巴斯共和國"],["基面","基面"],["堂分姑娘","堂分姑娘"],["堂后官","堂後官"],["堂屋里挂草荐","堂屋裏掛草薦"],["堂布","堂布"],["堆了","堆了"],["堆案盈几","堆案盈几"],["堕云雾中","墮雲霧中"],["堕胎药","墮胎藥"],["堙淀","堙澱"],["堪为表率","堪爲表率"],["堪布","堪布"],["堪当","堪當"],["堪当重任","堪當重任"],["堪称典范","堪稱典範"],["堪舆术","堪輿術"],["塌台","塌臺"],["塑炼","塑煉"],["塑炼机","塑煉機"],["塑胶制","塑膠製"],["塑胶布","塑膠布"],["塑胶杯","塑膠杯"],["塑胶板","塑膠板"],["塑造出","塑造出"],["塔什干","塔什干"],["塔什库尔干乡","塔什庫爾干鄉"],["塔什库尔干塔吉克自治县","塔什庫爾干塔吉克自治縣"],["塔什库尔干自治县","塔什庫爾干自治縣"],["塔克","塔克"],["塔克拉玛干","塔克拉瑪干"],["塔克拉玛干沙漠","塔克拉瑪干沙漠"],["塔克拉马干","塔克拉馬干"],["塔克辛","塔克辛"],["塔台","塔臺"],["塔吉克","塔吉克"],["塔吉克人","塔吉克人"],["塔吉克共和国","塔吉克共和國"],["塔吉克斯坦","塔吉克斯坦"],["塔吉克族","塔吉克族"],["塔吊","塔吊"],["塔娜苏冈","塔娜蘇岡"],["塔娜苏甘","塔娜蘇甘"],["塔布","塔布"],["塔波兰尼克","塔波蘭尼克"],["塔罗维克","塔羅維克"],["塔里契亚努","塔里契亞努"],["塔里木","塔里木"],["塔里木河","塔里木河"],["塔里木盆地","塔里木盆地"],["塔里班","塔里班"],["塔钟","塔鐘"],["塞上曲","塞上曲"],["塞下曲","塞下曲"],["塞克","塞克"],["塞克森","塞克森"],["塞回","塞回"],["塞尔提克","塞爾提克"],["塞尔提克队","塞爾提克隊"],["塞尔维亚克罗地亚语","塞爾維亞克羅地亞語"],["塞尔维亚民主党","塞爾維亞民主黨"],["塞尔蒂克","塞爾蒂克"],["塞尔蒂克队","塞爾蒂克隊"],["塞瓦斯托波尔","塞瓦斯托波爾"],["塞耳盗钟","塞耳盜鐘"],["塞药","塞藥"],["塞莉佛维克","塞莉佛維克"],["塞车症候群","塞車症候羣"],["塞韦里诺","塞韋裏諾"],["填个","填個"],["填了","填了"],["填发","填發"],["填字游戏","填字遊戲"],["填表","填表"],["填表格","填表格"],["墓志","墓誌"],["墓志铭","墓誌銘"],["墓表","墓表"],["墙里","牆裏"],["墙面","牆面"],["墙面而立","牆面而立"],["增修","增修"],["增辟","增闢"],["增量参数","增量參數"],["墟里","墟里"],["墨卷","墨卷"],["墨斗","墨斗"],["墨斗鱼","墨斗魚"],["墨沈","墨沈"],["墨沈未干","墨瀋未乾"],["墨沈沈","墨沈沈"],["墨索里尼","墨索里尼"],["墨荡子","墨盪子"],["墨西哥合众国","墨西哥合衆國"],["墨迹未干","墨跡未乾"],["墩台","墩臺"],["墩布","墩布"],["壁志","壁誌"],["壁立千仞","壁立千仞"],["壁钟","壁鐘"],["壑谷","壑谷"],["士别三日","士別三日"],["士别三日刮目相待","士別三日刮目相待"],["士别多日","士別多日"],["士胄","士胄"],["壮室之秋","壯室之秋"],["壮志","壯志"],["壮志凌云","壯志凌雲"],["壮志凌霄","壯志凌霄"],["壮志未酬","壯志未酬"],["壮游","壯遊"],["壮阳药","壯陽藥"],["壮面","壯麪"],["声价","聲價"],["声价不凡","聲價不凡"],["声价十倍","聲價十倍"],["声如洪钟","聲如洪鐘"],["声彻云霄","聲徹雲霄"],["声情并茂","聲情並茂"],["声类系统","聲類系統"],["壳里","殼裏"],["壶口瀑布","壺口瀑布"],["壶范","壺範"],["壶里","壺裏"],["壶里乾坤","壺裏乾坤"],["壹个人","壹個人"],["壹周刊","壹週刊"],["壹败涂地","壹敗塗地"],["壹郁","壹鬱"],["处于","處於"],["处女表演","處女表演"],["处方药","處方藥"],["处理厂","處理廠"],["处理表","處理表"],["备尝","備嘗"],["备尝忧患","備嘗憂患"],["备尝艰苦","備嘗艱苦"],["备尝艰辛","備嘗艱辛"],["备尝辛苦","備嘗辛苦"],["备御","備禦"],["备忘录","備忘錄"],["备抵折旧","備抵折舊"],["备注","備註"],["备注栏","備註欄"],["复三","復三"],["复上","覆上"],["复业","復業"],["复习","複習"],["复习考","複習考"],["复书","復書"],["复交","復交"],["复亩珍","複畝珍"],["复仇","復仇"],["复仇者","復仇者"],["复仇记","復仇記"],["复仇雪耻","復仇雪恥"],["复仞年如","複仞年如"],["复以百万","複以百萬"],["复任","復任"],["复会","復會"],["复位","復位"],["复住","覆住"],["复信","覆信"],["复健","復健"],["复健中心","復健中心"],["复健医学","復健醫學"],["复健科","復健科"],["复健赛","復健賽"],["复元","復元"],["复元音","複元音"],["复共轭","複共軛"],["复兴","復興"],["复兴中学","復興中學"],["复兴乡","復興鄉"],["复兴党","復興黨"],["复兴剧校","復興劇校"],["复兴剧艺学校","復興劇藝學校"],["复兴北路","復興北路"],["复兴区","復興區"],["复兴南路","復興南路"],["复兴号","復興號"],["复兴基地","復興基地"],["复兴岗","復興崗"],["复兴岛","復興島"],["复兴工商","復興工商"],["复兴广播","復興廣播"],["复兴广播电台","復興廣播電臺"],["复兴时代","復興時代"],["复兴社","復興社"],["复兴路","復興路"],["复兴门","復興門"],["复兴馆","復興館"],["复兴高中","復興高中"],["复冒","覆冒"],["复写","複寫"],["复写纸","複寫紙"],["复军","覆軍"],["复军杀将","覆軍殺將"],["复冰","復冰"],["复决","複決"],["复决权","複決權"],["复出","復出"],["复函","覆函"],["复函数","複函數"],["复分数","複分數"],["复分析","複分析"],["复分解","複分解"],["复分解反应","複分解反應"],["复刊","復刊"],["复列","複列"],["复利","複利"],["复利法","複利法"],["复利率","複利率"],["复利计算","複利計算"],["复制","複製"],["复制下来","複製下來"],["复制出","複製出"],["复制品","複製品"],["复刻","復刻"],["复华","復華"],["复华金","復華金"],["复卒","復卒"],["复印","複印"],["复印品","複印品"],["复印机","複印機"],["复印纸","複印紙"],["复原","復原"],["复原期","復原期"],["复去翻来","覆去翻來"],["复发","復發"],["复发性","複發性"],["复发率","複發率"],["复变函数","複變函數"],["复变函数论","複變函數論"],["复古","復古"],["复古会","復古會"],["复古风","復古風"],["复句","複句"],["复叶","複葉"],["复合","複合"],["复合企业","複合企業"],["复合传动","複合傳動"],["复合体","複合體"],["复合元音","複合元音"],["复合光","複合光"],["复合包装","複合包裝"],["复合句","複合句"],["复合命题","複合命題"],["复合国","複合國"],["复合型","複合型"],["复合增长","複合增長"],["复合字","複合字"],["复合年","複合年"],["复合式","複合式"],["复合性","複合性"],["复合技","複合技"],["复合摄影","複合攝影"],["复合机","複合機"],["复合材料","複合材料"],["复合板","複合板"],["复合架","複合架"],["复合样式","複合樣式"],["复合概念","複合概念"],["复合模","複合模"],["复合母音","複合母音"],["复合民族国家","複合民族國家"],["复合物","複合物"],["复合管","複合管"],["复合肥料","複合肥料"],["复合膜","複合膜"],["复合药","複合藥"],["复合蛋白质","複合蛋白質"],["复合装甲","複合裝甲"],["复合词","複合詞"],["复合词素词","複合詞素詞"],["复合量词","複合量詞"],["复合金属","複合金屬"],["复合韵母","複合韻母"],["复名","複名"],["复名数","複名數"],["复名词","複名詞"],["复吸","復吸"],["复呈","覆呈"],["复员","復員"],["复员令","復員令"],["复员军人","複員軍人"],["复命","覆命"],["复品牌","複品牌"],["复回","復回"],["复国","復國"],["复圆","復圓"],["复土","復土"],["复圣","復聖"],["复在","覆在"],["复基因","複基因"],["复墓","覆墓"],["复壁","複壁"],["复壮","復壯"],["复复","複復"],["复始","復始"],["复姓","複姓"],["复婚","復婚"],["复婚制","複婚制"],["复子明辟","復子明辟"],["复字键","複字鍵"],["复学","復學"],["复学生","復學生"],["复宗","覆宗"],["复审","複審"],["复对数","複對數"],["复工","復工"],["复帐","覆帳"],["复帱","覆幬"],["复平面","複平面"],["复庇之恩","覆庇之恩"],["复康巴士","復康巴士"],["复建","復建"],["复建中心","復建中心"],["复式","複式"],["复式关税","複式關稅"],["复式教学","複式教學"],["复式路面","複式路面"],["复归","復歸"],["复役","復役"],["复循环发电","複循環發電"],["复思","復思"],["复意","複意"],["复成","覆成"],["复拍子","複拍子"],["复按","覆按"],["复政","復政"],["复数","複數"],["复数域","複數域"],["复数平面","複數平面"],["复数形","複數形"],["复数形式","複數形式"],["复文","覆文"],["复新","復新"],["复方","複方"],["复旦","復旦"],["复旦大学","復旦大學"],["复旦桥","復旦橋"],["复旧","復舊"],["复旧如新","復舊如新"],["复明","復明"],["复本","複本"],["复本位制度","複本位制度"],["复杂","複雜"],["复杂劳动","複雜勞動"],["复杂化","複雜化"],["复杂度","複雜度"],["复杂度理论","複雜度理論"],["复杂性","複雜性"],["复杂生产","複雜生產"],["复杂系统","複雜系統"],["复权","復權"],["复杯","覆杯"],["复果","複果"],["复查","複查"],["复査","複查"],["复校","覆校"],["复核","複覈"],["复案","復案"],["复检","複檢"],["复次","複次"],["复殖吸虫","複殖吸蟲"],["复殖目","複殖目"],["复比","複比"],["复比例","複比例"],["复氧能力","復氧能力"],["复水","覆水"],["复没","覆沒"],["复活","復活"],["复活岛","復活島"],["复活日","復活日"],["复活的军团","復活的軍團"],["复活节","復活節"],["复活节岛","復活節島"],["复活赛","復活賽"],["复流","複流"],["复测","複測"],["复海移山","覆海移山"],["复灭","覆滅"],["复燃","復燃"],["复现","復現"],["复瓿","覆瓿"],["复生","復生"],["复用","複用"],["复电","覆電"],["复盂","覆盂"],["复盂之固","覆盂之固"],["复盂之安","覆盂之安"],["复盆","覆盆"],["复盆之冤","覆盆之冤"],["复盆子","覆盆子"],["复盆难照","覆盆難照"],["复盐","複鹽"],["复盖","覆蓋"],["复盖住","覆蓋住"],["复盖率","覆蓋率"],["复盖面","覆蓋面"],["复盘","覆盤"],["复盘难照","覆盤難照"],["复目","複目"],["复相关","複相關"],["复眼","複眼"],["复礼","復禮"],["复礼克己","復禮克己"],["复种","複種"],["复种指数","複種指數"],["复称","複稱"],["复穴","複穴"],["复籍","復籍"],["复线","複線"],["复综语","複綜語"],["复耕","復耕"],["复职","復職"],["复肥","複肥"],["复育","覆育"],["复舟","覆舟"],["复舟载舟","覆舟載舟"],["复色","複色"],["复色光","複色光"],["复苏","復甦"],["复苏期","復甦期"],["复苏术","復甦術"],["复萌","復萌"],["复蔽","覆蔽"],["复蕉寻鹿","覆蕉尋鹿"],["复被","覆被"],["复襦","複襦"],["复视","複視"],["复训","複訓"],["复议","複議"],["复评","複評"],["复诊","複診"],["复词","複詞"],["复试","複試"],["复诵","複誦"],["复读","復讀"],["复读生","復讀生"],["复课","復課"],["复败","覆敗"],["复赛","複賽"],["复蹈其辙","復蹈其轍"],["复蹈前辙","復蹈前轍"],["复身","復身"],["复车","覆車"],["复车之戒","覆車之戒"],["复车之轨","覆車之軌"],["复车之辙","覆車之轍"],["复车之鉴","覆車之鑑"],["复车当戒","覆車當戒"],["复车继轨","覆車繼軌"],["复转","復轉"],["复载","覆載"],["复辅音","複輔音"],["复辙","覆轍"],["复辙重蹈","覆轍重蹈"],["复辟","復辟"],["复辟事件","復辟事件"],["复返","復返"],["复述","複述"],["复逆","覆逆"],["复选","複選"],["复选题","複選題"],["复道","複道"],["复酱瓿","覆醬瓿"],["复醒","復醒"],["复醢","覆醢"],["复钱","複錢"],["复阁","複閣"],["复阅","複閱"],["复除","復除"],["复雠","復讎"],["复雨翻云","覆雨翻雲"],["复露","覆露"],["复音","複音","覆音"],["复音形","複音形"],["复音词","複音詞"],["复韵","複韻"],["复韵母","複韻母"],["复频","複頻"],["复验","複驗"],["复魄","復魄"],["复鹿寻蕉","覆鹿尋蕉"],["复鹿遗蕉","覆鹿遺蕉"],["复鼎","覆鼎"],["复𫗧","覆餗"],["复𫗧之忧","覆餗之憂"],["复𫗧之患","覆餗之患"],["复𫗧之衅","覆餗之釁"],["夏于乔","夏于喬"],["夏于喬","夏于喬"],["夏历","夏曆"],["夏后氏","夏后氏"],["夏商周","夏商周"],["夏天里","夏天裏"],["夏姆锡克","夏姆錫克"],["夏川里美","夏川里美"],["夏布","夏布"],["夏日里","夏日裏"],["夏时制","夏時制"],["夏洛克","夏洛克"],["夏游","夏遊"],["夏炉冬扇","夏爐冬扇"],["夏秋","夏秋"],["夏种","夏種"],["夏虫","夏蟲"],["夏虫不可以语冰","夏蟲不可以語冰"],["夏虫不可语冰","夏蟲不可語冰"],["夏虫朝菌","夏蟲朝菌"],["夏里夫","夏里夫"],["夏鑪冬扇","夏鑪冬扇"],["夕烟","夕煙"],["外交代表","外交代表"],["外交关系","外交關係"],["外交关系理事会","外交關係理事會"],["外交团","外交團"],["外交系","外交系"],["外佣","外傭"],["外侧裂周区","外側裂周區"],["外借","外借"],["外出","外出"],["外出服","外出服"],["外出血","外出血"],["外出装","外出裝"],["外出访问","外出訪問"],["外制","外製"],["外厂","外廠"],["外发","外發"],["外合里差","外合裏差"],["外合里应","外合裏應"],["外后日","外後日"],["外向","外向"],["外向型","外向型"],["外国旅游者","外國旅遊者"],["外屋里的灶君爷","外屋裏的竈君爺"],["外弦","外弦"],["外强中干","外強中乾"],["外御其侮","外禦其侮"],["外戚","外戚"],["外才","外才"],["外挂","外掛"],["外挂式","外掛式"],["外文系","外文系"],["外明不知里暗","外明不知裏暗"],["外来物种","外來物種"],["外来种","外來種"],["外松内紧","外鬆內緊"],["外核","外核"],["外欲","外慾"],["外汇","外匯"],["外汇储备","外匯儲備"],["外汇兑换","外匯兌換"],["外汇存底","外匯存底"],["外汇定期存单","外匯定期存單"],["外汇局","外匯局"],["外汇市场","外匯市場"],["外汇收入","外匯收入"],["外汇汇率","外匯匯率"],["外汇管制","外匯管制"],["外汇银行","外匯銀行"],["外涂","外塗"],["外烟","外菸"],["外用药","外用藥"],["外科学系","外科學系"],["外科手术","外科手術"],["外聘制","外聘制"],["外舍","外舍"],["外蒙","外蒙"],["外蒙古","外蒙古"],["外表","外表"],["外表上","外表上"],["外语系","外語系"],["外调制","外調制"],["外部链接","外部鏈接"],["外面","外面"],["外面儿光","外面兒光"],["外面情","外面情"],["夙仇","夙仇"],["夙心往志","夙心往志"],["夙愿","夙願"],["夙愿以偿","夙願以償"],["多不胜数","多不勝數"],["多丑","多醜"],["多么","多麼"],["多义关系","多義關係"],["多事之秋","多事之秋"],["多事逞才","多事逞才"],["多于","多於"],["多云","多雲"],["多云偶","多雲偶"],["多云偶阵雨","多雲偶陣雨"],["多云偶雨","多雲偶雨"],["多云有雨","多雲有雨"],["多人聊天系统","多人聊天系統"],["多余","多餘"],["多侧面","多側面"],["多借","多借"],["多党","多黨"],["多党制","多黨制"],["多党选举","多黨選舉"],["多冲","多衝"],["多凶少吉","多凶少吉"],["多出","多出"],["多出来","多出來"],["多功能表","多功能表"],["多动症","多動症"],["多占","多佔"],["多原作艺术","多原作藝術"],["多发性","多發性"],["多发病","多發病"],["多只","多隻"],["多台","多臺"],["多吃多占","多吃多佔"],["多向","多向"],["多哈回合","多哈回合"],["多回","多回"],["多天后","多天後"],["多妻制","多妻制"],["多姿多彩","多姿多彩"],["多姿多采","多姿多采"],["多媒体杂志","多媒體雜誌"],["多媒体简报系统","多媒體簡報系統"],["多少只","多少隻"],["多层复","多層複"],["多层复迭","多層複迭"],["多干","多幹"],["多平台","多平臺"],["多平台环境","多平臺環境"],["多幸","多幸"],["多式综合语","多式綜合語"],["多当","多當"],["多彩","多彩"],["多彩多姿","多彩多姿"],["多情种子","多情種子"],["多才","多才"],["多才多艺","多才多藝"],["多拉尔蒙","多拉爾蒙"],["多指症","多指症"],["多数党","多數黨"],["多方面","多方面"],["多极化","多極化"],["多核","多核"],["多模光纤","多模光纖"],["多欲","多欲"],["多汗症","多汗症"],["多特蒙德","多特蒙德"],["多种","多種"],["多种多样","多種多樣"],["多种经营","多種經營"],["多种语言","多種語言"],["多种语言支持","多種語言支持"],["多管闲事","多管閒事"],["多米尼克","多米尼克"],["多粒子系统","多粒子系統"],["多蒙寄声","多蒙寄聲"],["多蒙推毂","多蒙推轂"],["多蒙药石","多蒙藥石"],["多表","多表"],["多轨录音","多軌錄音"],["多边合作","多邊合作"],["多采","多采"],["多采多姿","多采多姿"],["多面","多面"],["多面体","多面體"],["多面性","多面性"],["多面手","多面手"],["多面角","多面角"],["夜儿个","夜兒個"],["夜光云","夜光雲"],["夜光杯","夜光杯"],["夜光虫","夜光蟲"],["夜光表","夜光錶"],["夜半钟声","夜半鐘聲"],["夜台","夜臺"],["夜合","夜合"],["夜合花","夜合花"],["夜合钱","夜合錢"],["夜尿症","夜尿症"],["夜度娘","夜度娘"],["夜惊症","夜驚症"],["夜暗","夜暗"],["夜暗风高","夜暗風高"],["夜曲","夜曲"],["夜游","夜遊"],["夜游子","夜遊子"],["夜游神","夜遊神"],["夜游队","夜遊隊"],["夜盲症","夜盲症"],["夜色迷蒙","夜色迷濛"],["夜谭随录","夜譚隨錄"],["夜里","夜裏"],["夜雨秋灯录","夜雨秋燈錄"],["够了","夠了"],["够克制","夠剋制"],["够凶","夠兇"],["够出","夠出"],["够涂","夠塗"],["够种","夠種"],["够钟情","夠鍾情"],["够钟爱","夠鍾愛"],["夠面子","夠面子"],["大一统志","大一統誌"],["大不了","大不了"],["大不相同","大不相同"],["大不里士","大不里士"],["大丑","大丑"],["大专同学","大專同學"],["大专杯","大專盃"],["大业千秋","大業千秋"],["大个","大個"],["大个儿","大個兒"],["大个子","大個子"],["大丰","大豐"],["大丰市","大豐市"],["大丰收","大豐收"],["大丰簋","大豐簋"],["大义觉迷录","大義覺迷錄"],["大乌苏里岛","大烏蘇里島"],["大事化小小事化了","大事化小小事化了"],["大于","大於"],["大人药","大人藥"],["大仁药专","大仁藥專"],["大价钱","大價錢"],["大众捷运系统","大衆捷運系統"],["大伙","大夥"],["大伙人","大夥人"],["大伙儿","大夥兒"],["大余","大餘"],["大余县","大餘縣"],["大便干燥","大便乾燥"],["大修","大修"],["大修理","大修理"],["大修理基金","大修理基金"],["大修道院","大修道院"],["大修道院长","大修道院長"],["大借款","大借款"],["大傢伙儿","大傢伙兒"],["大元大一统志","大元大一統誌"],["大党","大黨"],["大兵团","大兵團"],["大冲","大沖"],["大减价","大減價"],["大凶","大凶"],["大出","大出"],["大出丧","大出喪"],["大出其汗","大出其汗"],["大出意料之外","大出意料之外"],["大出手","大出手"],["大出血","大出血"],["大出锋头","大出鋒頭"],["大出风头","大出風頭"],["大利面","大利麪"],["大别","大別"],["大别山","大別山"],["大别山脉","大別山脈"],["大制作","大製作"],["大力发展","大力發展"],["大动干戈","大動干戈"],["大千","大千"],["大千世界","大千世界"],["大华技术学院","大華技術學院"],["大协奏曲","大協奏曲"],["大单于","大單于"],["大卤面","大滷麪"],["大卷","大卷"],["大厂","大廠"],["大厂县","大廠縣"],["大厂回族自治县","大廠回族自治縣"],["大历","大曆"],["大历十才子","大曆十才子"],["大历史","大歷史"],["大厦栋梁","大廈棟梁"],["大发","大發"],["大发利市","大發利市"],["大发慈悲","大發慈悲"],["大发牢骚","大發牢騷"],["大发神威","大發神威"],["大发脾气","大發脾氣"],["大发雷霆","大發雷霆"],["大叔于田","大叔于田"],["大只","大隻"],["大台","大臺"],["大台北","大臺北"],["大台北区","大臺北區"],["大叶合欢","大葉合歡"],["大叶大学","大葉大學"],["大叶性肺炎","大葉性肺炎"],["大叶桉","大葉桉"],["大叶野百合","大葉野百合"],["大叹","大嘆"],["大合唱","大合唱"],["大同","大同"],["大同世界","大同世界"],["大同主义","大同主義"],["大同之世","大同之世"],["大同乡","大同鄉"],["大同书","大同書"],["大同区","大同區"],["大同县","大同縣"],["大同商专","大同商專"],["大同国中","大同國中"],["大同大学","大同大學"],["大同小异","大同小異"],["大同市","大同市"],["大同教","大同教"],["大同煤矿","大同煤礦"],["大同盆地","大同盆地"],["大同盟","大同盟"],["大同社会","大同社會"],["大同路","大同路"],["大后天","大後天"],["大后年","大後年"],["大后方","大後方"],["大周后","大周后"],["大周折","大週摺"],["大咸","大咸"],["大哗","大譁"],["大回","大回"],["大回朝","大回朝"],["大团","大團"],["大团圆","大團圓"],["大团白脸","大團白臉"],["大团结","大團結"],["大国家党","大國家黨"],["大地回春","大地回春"],["大地春回","大地春回"],["大场面","大場面"],["大型钟","大型鐘"],["大型钟表","大型鐘錶"],["大型钟表面","大型鐘表面"],["大型钟面","大型鐘面"],["大天后宫","大天后宮"],["大夫松","大夫松"],["大头症","大頭症"],["大头针","大頭針"],["大头面目","大頭面目"],["大夸","大誇"],["大奸","大奸"],["大奸似忠","大奸似忠"],["大姑娘","大姑娘"],["大姑娘坐花轿","大姑娘坐花轎"],["大娘","大娘"],["大娘子","大娘子"],["大家伙儿","大家夥兒"],["大家风范","大家風範"],["大尽","大盡"],["大山谷州立大学","大山谷州立大學"],["大岩桐","大巖桐"],["大峡谷","大峽谷"],["大布","大布"],["大布棚","大布棚"],["大干","大幹"],["大干一场","大幹一場"],["大干一票","大幹一票"],["大干特干","大幹特幹"],["大幸","大幸"],["大廉价","大廉價"],["大当","大當"],["大志","大志"],["大恶","大惡"],["大才","大才"],["大才小用","大才小用"],["大才槃槃","大才槃槃"],["大打出手","大打出手"],["大打折扣","大打折扣"],["大折儿","大摺兒"],["大抚台","大撫臺"],["大搜","大搜"],["大摆","大擺"],["大摆褶子","大擺褶子"],["大摇大摆","大搖大擺"],["大放异彩","大放異彩"],["大放异采","大放異采"],["大政方针","大政方針"],["大敌当前","大敵當前"],["大斗","大斗"],["大斗小秤","大斗小秤"],["大方向","大方向"],["大旱云霓","大旱雲霓"],["大旱望云霓","大旱望雲霓"],["大明历","大明曆"],["大明历史","大明歷史"],["大明大摆","大明大擺"],["大是不同","大是不同"],["大曲","大麴"],["大曲道","大曲道"],["大曲酒","大麴酒"],["大有分别","大有分別"],["大有斩获","大有斬獲"],["大本钟","大本鐘"],["大本钟敲","大本鐘敲"],["大来历","大來歷"],["大杯","大杯"],["大板","大板"],["大板根","大板根"],["大板车","大板車"],["大核","大核"],["大梁","大梁","大樑"],["大楼监控系统","大樓監控系統"],["大欲","大欲"],["大武仑","大武崙"],["大气团","大氣團"],["大气折射","大氣折射"],["大气系","大氣系"],["大水冲倒龙王庙","大水沖倒龍王廟"],["大水冲倒龙王殿","大水沖倒龍王殿"],["大水冲溺","大水沖溺"],["大汉技术学院","大漢技術學院"],["大汗淋漓","大汗淋漓"],["大海捞针","大海撈針"],["大润发","大潤發"],["大涨小回","大漲小回"],["大清一统志","大清一統志"],["大湄公河次区域合作","大湄公河次區域合作"],["大溪豆干","大溪豆幹"],["大烟","大煙"],["大爱台","大愛臺"],["大班制","大班制"],["大理岩","大理岩"],["大病初愈","大病初癒"],["大症","大症"],["大白日里借不出个干灯盏来","大白日裏借不出個乾燈盞來"],["大目干连","大目乾連"],["大目干连冥间救母变文","大目乾連冥間救母變文"],["大秋","大秋"],["大秋作物","大秋作物"],["大秋元","大秋元"],["大笨钟","大笨鐘"],["大笨钟敲","大笨鐘敲"],["大精彩","大精彩"],["大系","大系"],["大缸里翻油沿路拾芝麻","大缸裏翻油沿路拾芝麻"],["大老板","大老闆"],["大而无当","大而無當"],["大肆搜捕","大肆搜捕"],["大肠杆菌","大腸桿菌"],["大肠杆菌群","大腸桿菌羣"],["大胜","大勝"],["大胡子","大鬍子"],["大脑出血性中风","大腦出血性中風"],["大脚婆娘","大腳婆娘"],["大腔当","大腔當"],["大致","大致"],["大致上","大致上"],["大致说来","大致說來"],["大舍","大舍"],["大花面","大花面"],["大苏打","大蘇打"],["大英联合王国","大英聯合王國"],["大范围","大範圍"],["大获","大獲"],["大获全胜","大獲全勝"],["大虫","大蟲"],["大虫不吃伏肉","大蟲不吃伏肉"],["大虫口里倒涎","大蟲口裏倒涎"],["大虫吃小虫","大蟲吃小蟲"],["大虫头上做窠","大蟲頭上做窠"],["大蜡","大蜡"],["大衍历","大衍曆"],["大衍历史","大衍歷史"],["大表","大表"],["大表哥","大表哥"],["大表妹","大表妹"],["大表姊","大表姊"],["大表弟","大表弟"],["大表惊叹","大表驚歎"],["大裂谷","大裂谷"],["大角度俯冲轰炸","大角度俯衝轟炸"],["大言非夸","大言非夸"],["大谷","大谷"],["大象口里拔生牙","大象口裏拔生牙"],["大费周折","大費周折"],["大费周章","大費周章"],["大赞","大讚"],["大辟","大辟"],["大迦叶","大迦葉"],["大通回族土族自治县","大通回族土族自治縣"],["大通师范学堂","大通師範學堂"],["大采","大采"],["大里","大里"],["大里市","大里市"],["大里溪","大里溪"],["大金发苔","大金髮薹"],["大鉴","大鑒"],["大钟","大鐘"],["大锤","大錘"],["大门不出二门不迈","大門不出二門不邁"],["大陆冷气团","大陸冷氣團"],["大陆同胞","大陸同胞"],["大陆团","大陸團"],["大陆性气团","大陸性氣團"],["大陆板块","大陸板塊"],["大陆气团","大陸氣團"],["大陆法系","大陸法系"],["大陪审团","大陪審團"],["大难不死必有后禄","大難不死必有後祿"],["大难不死必有后福","大難不死必有後福"],["大集合","大集合"],["大雨如注","大雨如注"],["大面","大面"],["大面儿上","大面兒上"],["大面皮儿","大面皮兒"],["大风后","大風後"],["大风鉴","大風鑑"],["大食团","大食團"],["大马步挂","大馬步掛"],["大麦克","大麥克"],["大麦克指数","大麥克指數"],["大麻烟","大麻煙"],["大麻里","大麻里"],["大麻里乡","大麻里鄉"],["大黑松","大黑松"],["天下大势分久必合合久必分","天下大勢分久必合合久必分"],["天下安注意相天下危注意将","天下安注意相天下危注意將"],["天下无难事只怕有心人","天下無難事只怕有心人"],["天下杂志","天下雜誌"],["天不从人愿","天不從人願"],["天人合一","天人合一"],["天人永别","天人永別"],["天从人愿","天從人願"],["天价","天價"],["天作之合","天作之合"],["天克地冲","天剋地衝"],["天冬氨酸","天冬氨酸"],["天冬苯丙二肽酯","天冬苯丙二肽酯"],["天冬酰胺","天冬醯胺"],["天历","天曆"],["天发神谶碑","天發神讖碑"],["天台","天台","天臺"],["天台县","天台縣"],["天台女","天台女"],["天台宗","天台宗"],["天台山","天台山"],["天同","天同"],["天后","天后","天後"],["天后站","天后站"],["天后级","天后級"],["天团","天團"],["天地万物","天地萬物"],["天地为范","天地爲範"],["天地之别","天地之別"],["天地可表","天地可表"],["天地志狼","天地志狼"],["天坛","天壇"],["天坛座","天壇座"],["天壤之别","天壤之別"],["天复","天覆"],["天复地载","天覆地載"],["天妒英才","天妒英才"],["天孙娘娘","天孫娘娘"],["天差地别","天差地別"],["天干","天干"],["天干地支","天干地支"],["天干物燥","天乾物燥"],["天幸","天幸"],["天心和合","天心和合"],["天心岩","天心岩"],["天才","天才"],["天才儿童","天才兒童"],["天才出自勤奋","天才出自勤奮"],["天才型","天才型"],["天才教育","天才教育"],["天才横溢","天才橫溢"],["天才论","天才論"],["天文台","天文臺"],["天文学钟","天文學鐘"],["天文钟","天文鐘"],["天无三日晴地无三里平","天無三日晴地無三里平"],["天日之表","天日之表"],["天昏地暗","天昏地暗"],["天暗","天暗"],["天有不测风云","天有不測風雲"],["天有不测风云人有旦夕祸福","天有不測風雲人有旦夕禍福"],["天机云锦","天機雲錦"],["天津师范","天津師範"],["天津师范大学","天津師範大學"],["天渊之别","天淵之別"],["天潢贵胄","天潢貴胄"],["天然纤维","天然纖維"],["天生干","天生幹"],["天盟誓表现","天盟誓表現"],["天纳克","天納克"],["天纵之才","天縱之才"],["天缘凑合","天緣湊合"],["天缘巧合","天緣巧合"],["天缘注定","天緣注定"],["天翻地复","天翻地覆"],["天花板","天花板"],["天表","天表"],["天要下雨娘要嫁人","天要下雨孃要嫁人"],["天要落雨娘要嫁人","天要落雨孃要嫁人"],["天覆地载","天覆地載"],["天路历程","天路歷程"],["天门冬","天門冬"],["天门冬科","天門冬科"],["天随人愿","天隨人願"],["太乙神针","太乙神針"],["太仆","太僕"],["太仆寺","太僕寺"],["太仆寺卿","太僕寺卿"],["太仆寺旗","太僕寺旗"],["太公钓鱼愿者上钩","太公釣魚願者上鉤"],["太冲","太沖"],["太初历","太初曆"],["太初历史","太初歷史"],["太卜","太卜"],["太原师范学院","太原師範學院"],["太后","太后"],["太咸","太鹹"],["太好了","太好了"],["太子党","太子黨"],["太子舍人","太子舍人"],["太干","太乾"],["太平御览","太平御覽"],["太平洋周边","太平洋週邊"],["太平洋周邊","太平洋周邊"],["太平洋联合铁路","太平洋聯合鐵路"],["太扯了","太扯了"],["太松","太鬆"],["太极","太極"],["太极剑","太極劍"],["太极图","太極圖"],["太极图说","太極圖說"],["太极拳","太極拳"],["太极门","太極門"],["太皇太后","太皇太后"],["太空天文台","太空天文臺"],["太空游","太空遊"],["太空艺术","太空藝術"],["太谷","太谷"],["太谷县","太谷縣"],["太谷灯","太谷燈"],["太阳升","太陽升"],["太阳历","太陽曆"],["太阳微系统公司","太陽微系統公司"],["太阳照在桑干河上","太陽照在桑乾河上"],["太阳电池板","太陽電池板"],["太阳神计划","太陽神計劃"],["太阳系","太陽系"],["太阳能板","太陽能板"],["太阳谷","太陽谷"],["太阳黑子周","太陽黑子周"],["太阴历","太陰曆"],["太麻里","太麻里"],["太麻里乡","太麻里鄉"],["太麻里溪","太麻里溪"],["夫党","夫黨"],["夫力","伕力"],["夫妇关系","夫婦關係"],["夫妇合璧","夫婦合璧"],["夫妇好合","夫婦好合"],["夫妻关系","夫妻關係"],["夫娘","夫娘"],["夫子","夫子","伕子"],["夫役","伕役"],["夭折","夭折"],["央浼营干","央浼營幹"],["夯土建筑","夯土建築"],["夯干","夯幹"],["失之毫厘","失之毫釐"],["失之毫厘差之千里","失之毫釐差之千里"],["失之毫厘差以千里","失之毫釐差以千里"],["失之毫厘谬以千里","失之毫厘謬以千里"],["失于","失於"],["失体面","失體面"],["失信于人","失信於人"],["失修","失修"],["失准","失準"],["失出","失出"],["失张失志","失張失志"],["失当","失當"],["失忆症","失憶症"],["失志","失志"],["失据","失據"],["失智症","失智症"],["失眠症","失眠症"],["失而复得","失而復得"],["失语症","失語症"],["失读症","失讀症"],["失调症","失調症"],["失面子","失面子"],["失饥伤饱","失飢傷飽"],["头一回","頭一回"],["头上打一下脚底板响","頭上打一下腳底板響"],["头发","頭髮"],["头发上指","頭髮上指"],["头发了狂","頭發了狂"],["头发了疯","頭發了瘋"],["头发壳子","頭髮殼子"],["头发胡子一把抓","頭髮鬍子一把抓"],["头向前","頭向前"],["头回","頭回"],["头巾吊在水里","頭巾弔在水裏"],["头当","頭當"],["头彩","頭彩"],["头悬梁锥刺股","頭懸梁錐刺股"],["头昏眼暗","頭昏眼暗"],["头朝里","頭朝裏"],["头板","頭板"],["头柜","頭櫃"],["头破血出","頭破血出"],["头脑发胀","頭腦發脹"],["头脑简单四肢发达","頭腦簡單四肢發達"],["头花发","頭花髮"],["头足愿","頭足願"],["头里","頭裏"],["头面","頭面"],["头面人物","頭面人物"],["夷坚志","夷堅志"],["夸下海口","誇下海口"],["夸丽","夸麗"],["夸了","誇了"],["夸人","夸人"],["夸克","夸克"],["夸克星","夸克星"],["夸功","誇功"],["夸口","誇口"],["夸嘴","誇嘴"],["夸多斗靡","誇多鬥靡"],["夸大","誇大"],["夸大不实","誇大不實"],["夸大之词","誇大之詞"],["夸大其词","誇大其詞"],["夸大其辞","誇大其辭"],["夸大狂","誇大狂"],["夸夸","誇誇"],["夸夸其谈","誇誇其談"],["夸奖","誇獎"],["夸姣","夸姣"],["夸官","誇官"],["夸容","夸容"],["夸尔","夸爾"],["夸张","誇張"],["夸张其辞","誇張其辭"],["夸张法","誇張法"],["夸强说会","誇強說會"],["夸得","誇得"],["夸成","誇成"],["夸才卖智","誇才賣智"],["夸来夸去","誇來誇去"],["夸毗","夸毗"],["夸海口","誇海口"],["夸父","夸父"],["夸父逐日","夸父逐日"],["夸特","夸特"],["夸示","誇示"],["夸耀","誇耀"],["夸胜道强","誇勝道強"],["夸能斗智","誇能鬥智"],["夸脱","夸脫"],["夸诞","夸誕"],["夸诞不经","夸誕不經"],["夸诩","誇詡"],["夸说","誇說"],["夸赞","誇讚"],["夸起","誇起"],["夸起来","誇起來"],["夸辩","誇辯"],["夸过","誇過"],["夸饰","誇飾"],["夹个","夾個"],["夹了","夾了"],["夹克","夾克"],["夹布子","夾布子"],["夹当儿","夾當兒"],["夹彩塑","夾彩塑"],["夹心饼干","夾心餅乾"],["夹板","夾板"],["夹板气","夾板氣"],["夹板船","夾板船"],["夹注","夾註"],["夹注号","夾注號"],["夺回","奪回"],["夺回去","奪回去"],["夺回来","奪回來"],["夺彩","奪彩"],["夺志","奪志"],["夺斗","奪鬥"],["夺杯","奪盃"],["夺眶而出","奪眶而出"],["夺门而出","奪門而出"],["奇丑","奇醜"],["奇丑无比","奇醜無比"],["奇冤极枉","奇冤極枉"],["奇努克","奇努克"],["奇台","奇台"],["奇台县","奇臺縣"],["奇岩","奇巖"],["奇异夸克","奇異夸克"],["奇彩","奇彩"],["奇志","奇志"],["奇才","奇才"],["奇才异能","奇才異能"],["奇术","奇術"],["奇杯","奇盃"],["奇袭战术","奇襲戰術"],["奇迹","奇蹟"],["奇里安","奇里安"],["奈向","奈向"],["奉公克己","奉公剋己"],["奉别","奉別"],["奉复","奉復"],["奉干","奉干"],["奉毂后车","奉轂後車"],["奉献出","奉獻出"],["奉系","奉系"],["奉系军阀","奉系軍閥"],["奉苹蘩","奉蘋蘩"],["奉药","奉藥"],["奉蒸尝","奉蒸嘗"],["奉表","奉表"],["奉辛比克党","奉辛比克黨"],["奋勇向前","奮勇向前"],["奋勇当先","奮勇當先"],["奋发","奮發"],["奋发向上","奮發向上"],["奋发图强","奮發圖強"],["奋发有为","奮發有爲"],["奋发自强","奮發自強"],["奋发蹈厉","奮發蹈厲"],["奋志","奮志"],["奋斗","奮鬥"],["奋斗不懈","奮鬥不懈"],["奋斗到底","奮鬥到底"],["奋斗目标","奮鬥目標"],["奎尼匹克","奎尼匹克"],["奎松市","奎松市"],["奏了","奏了"],["奏于","奏於"],["奏出","奏出"],["奏出去","奏出去"],["奏出来","奏出來"],["奏折","奏摺"],["奏曲","奏曲"],["奏表","奏表"],["奏鸣曲","奏鳴曲"],["奏鸣曲式","奏鳴曲式"],["契努克","契努克"],["契合","契合"],["契合度","契合度"],["契合金兰","契合金蘭"],["契据","契據"],["契沙比克湾","契沙比克灣"],["奔出","奔出"],["奔向","奔向"],["奔回","奔回"],["奔回来","奔回來"],["奖借","獎借"],["奖励制度","獎勵制度"],["奖杯","獎盃"],["奖赞","獎贊"],["套个","套個"],["套了","套了"],["套出","套出"],["套出来","套出來"],["套曲","套曲"],["套板","套板"],["套汇","套匯"],["套种","套種"],["套装旅游","套裝旅遊"],["套问出","套問出"],["套马杆","套馬杆"],["奢念","奢念"],["奥万大","奧萬大"],["奥克兰","奧克蘭"],["奥克拉荷马","奧克拉荷馬"],["奥克拉荷马州","奧克拉荷馬州"],["奥克拉荷马市","奧克拉荷馬市"],["奥克斯纳德","奧克斯納德"],["奥克明","奧克明"],["奥克苏斯河","奧克蘇斯河"],["奥克蒙","奧克蒙"],["奥兰多布鲁","奧蘭多布魯"],["奥占","奧佔"],["奥士力克","奧士力克"],["奥妮克西亚","奧妮克西亞"],["奥密克戎","奧密克戎"],["奥尔布赖特","奧爾布賴特"],["奥布里","奧布里"],["奥德修斯","奧德修斯"],["奥托","奧托"],["奥托瓦兹","奧托瓦茲"],["奥拜克","奧拜克"],["奥杜伐峡谷","奧杜伐峽谷"],["奥林匹克","奧林匹克"],["奥林匹克世运","奧林匹克世運"],["奥林匹克体育场","奧林匹克體育場"],["奥林匹克日","奧林匹克日"],["奥林匹克精神","奧林匹克精神"],["奥林匹克运动会","奧林匹克運動會"],["奥林匹克运动会组织委员会","奧林匹克運動會組織委員會"],["奥特朗托","奧特朗托"],["奥特朗托海峡","奧特朗托海峽"],["奥运团","奧運團"],["奥迪修斯","奧迪修斯"],["奥里斯","奧里斯"],["奥里萨","奧里薩"],["奥里萨省","奧里薩省"],["奥里萨邦","奧里薩邦"],["奥里里亚","奧里里亞"],["奥陶系","奧陶系"],["奧克拉荷马州","奧克拉荷馬州"],["女丑","女丑"],["女丑剧场","女丑劇場"],["女中豪杰","女中豪傑"],["女乳症","女乳症"],["女人心海底针","女人心海底針"],["女仆","女僕"],["女仆部","女僕部"],["女佣","女傭"],["女佣人","女傭人"],["女修士","女修士"],["女修道","女修道"],["女修道张","女修道張"],["女修道院","女修道院"],["女同","女同"],["女同志","女同志"],["女同胞","女同胞"],["女大当嫁","女大當嫁"],["女大须嫁","女大須嫁"],["女娘","女娘"],["女子参政主义","女子參政主義"],["女子参政权","女子參政權"],["女宿舍","女宿舍"],["女尸","女屍"],["女御","女御"],["女性厌恶","女性厭惡"],["女性第二性征","女性第二性徵"],["女性艺术","女性藝術"],["女性艺术史","女性藝術史"],["女杰","女傑"],["女王杯","女王杯"],["女生外向","女生外嚮"],["女秀才","女秀才"],["女系家族","女系家族"],["女舍监","女舍監"],["女药头","女藥頭"],["女貌郎才","女貌郎才"],["女长须嫁","女長須嫁"],["奴仆","奴僕"],["奴儿干","奴兒干"],["奴儿干都司","奴兒干都司"],["奴才","奴才"],["奴隶制","奴隸制"],["奴隶制度","奴隸制度"],["奶制品","奶製品"],["奶卷","奶捲"],["奶妈怀里的孩子","奶媽懷裏的孩子"],["奶娘","奶孃"],["奸人","奸人"],["奸人之雄","奸人之雄"],["奸伏","姦伏"],["奸佞","奸佞"],["奸俏","奸俏"],["奸党","奸黨"],["奸凶","姦凶"],["奸刁","奸刁"],["奸匪","奸匪"],["奸同鬼蜮","奸同鬼蜮"],["奸商","奸商"],["奸夫","姦夫"],["奸夫淫妇","姦夫淫婦"],["奸妇","姦婦"],["奸宄","奸宄"],["奸官污吏","奸官污吏"],["奸尸","姦屍"],["奸巧","奸巧"],["奸徒","奸徒"],["奸恶","奸惡"],["奸情","姦情"],["奸慝","奸慝"],["奸杀","姦殺"],["奸棍","奸棍"],["奸毒","奸毒"],["奸污","姦污"],["奸淫","姦淫"],["奸淫掳掠","姦淫擄掠"],["奸滑","奸滑"],["奸狡","奸狡"],["奸猾","奸猾"],["奸盗邪淫","姦盜邪淫"],["奸笑","奸笑"],["奸细","奸細"],["奸胥猾吏","奸胥猾吏"],["奸臣","奸臣"],["奸言","奸言"],["奸计","奸計"],["奸诈","奸詐"],["奸诈不级","奸詐不級"],["奸谋","奸謀"],["奸贼","奸賊"],["奸通","姦通"],["奸邪","奸邪"],["奸险","奸險"],["奸雄","奸雄"],["奸非","姦非"],["奸顽","奸頑"],["奸骗","奸騙"],["奸黠","奸黠"],["她克制","她剋制"],["她准知","她準知"],["她出","她出"],["她出去","她出去"],["她出来","她出來"],["她念","她念"],["好一出","好一齣"],["好不了","好不了"],["好不容易才","好不容易纔"],["好丑","好醜"],["好个","好個"],["好了","好了"],["好了吗","好了嗎"],["好了吧","好了吧"],["好了歌","好了歌"],["好于","好於"],["好价","好價"],["好体面","好體面"],["好傢伙","好傢伙"],["好兵帅克","好兵帥克"],["好几","好幾"],["好几万","好幾萬"],["好几个","好幾個"],["好几亿","好幾億"],["好几十","好幾十"],["好几十万","好幾十萬"],["好几千","好幾千"],["好几千万","好幾千萬"],["好几天","好幾天"],["好几年","好幾年"],["好几百","好幾百"],["好几百万","好幾百萬"],["好凶","好凶"],["好出","好出"],["好出风头","好出風頭"],["好勇斗狠","好勇鬥狠"],["好合","好合"],["好向","好向"],["好咸","好鹹"],["好善嫉恶","好善嫉惡"],["好善恶恶","好善惡惡"],["好困","好睏"],["好困吧","好睏吧"],["好困啊","好睏啊"],["好多个","好多個"],["好好地干","好好地幹"],["好好学习天天向上","好好學習天天向上"],["好好干","好好幹"],["好家伙","好傢伙"],["好干","好乾"],["好当","好當"],["好彩头","好彩頭"],["好心倒做了驴肝肺","好心倒做了驢肝肺"],["好恶","好惡"],["好戏还在后头","好戲還在後頭"],["好戏连台","好戲連臺"],["好手如云","好手如雲"],["好斗","好鬥"],["好斗笠","好斗笠"],["好斗篷","好斗篷"],["好斗胆","好斗膽"],["好时是他人恶时是家人","好時是他人惡時是家人"],["好暗","好暗"],["好极了","好極了"],["好死不如恶活","好死不如惡活"],["好气万千","好氣萬千"],["好汉不怕出身低","好漢不怕出身低"],["好汉不论出身低","好漢不論出身低"],["好汉做事好汉当","好漢做事好漢當"],["好汉只怕病来磨","好漢只怕病來磨"],["好生恶杀","好生惡殺"],["好立克","好立克"],["好签","好籤"],["好管闲事","好管閒事"],["好胜","好勝"],["好胜心","好勝心"],["好自矜夸","好自矜誇"],["好话当作耳边风","好話當作耳邊風"],["好话说尽","好話說盡"],["好谀恶直","好諛惡直"],["好逸恶劳","好逸惡勞"],["好酒贪杯","好酒貪杯"],["好采头","好采頭"],["好面子","好面子"],["如不胜衣","如不勝衣"],["如临深谷","如臨深谷"],["如临渊谷","如臨淵谷"],["如于","如於"],["如云","如雲"],["如何干","如何幹"],["如入云端","如入雲端"],["如入宝山空手回","如入寶山空手回"],["如出一口","如出一口"],["如出一辙","如出一轍"],["如同","如同"],["如坐云雾","如坐雲霧"],["如坐针毡","如坐鍼氈"],["如堕五里雾中","如墮五里霧中"],["如堕烟雾","如墮煙霧"],["如干","如干"],["如愿","如願"],["如愿以偿","如願以償"],["如所周知","如所周知"],["如日东升","如日東昇"],["如日方升","如日方升"],["如有雷同","如有雷同"],["如果干","如果幹"],["如法泡制","如法泡製"],["如法炮制","如法炮製"],["如获珍宝","如獲珍寶"],["如获至宝","如獲至寶"],["如隔三秋","如隔三秋"],["如须","如須"],["如饥似渴","如飢似渴"],["如饥如渴","如飢如渴"],["妄念","妄念"],["妄想症","妄想症"],["妆台","妝臺"],["妇人生须","婦人生鬚"],["妇女团体","婦女團體"],["妇女杂志","婦女雜誌"],["妇女联合会","婦女聯合會"],["妊娠毒血症","妊娠毒血症"],["妖后","妖后"],["妖术","妖術"],["妖术惑众","妖術惑衆"],["妖术邪法","妖術邪法"],["妖气冲天","妖氣沖天"],["妖精谷","妖精谷"],["妖里妖气","妖里妖氣"],["妙发灵机","妙發靈機"],["妙妙熊历险记","妙妙熊歷險記"],["妙手回春","妙手回春"],["妙才","妙才"],["妙探寻凶","妙探尋兇"],["妙曲","妙曲"],["妙极","妙極"],["妙极了","妙極了"],["妙药","妙藥"],["妢胡","妢胡"],["妥当","妥當"],["妥当人","妥當人"],["妻党","妻黨"],["始于","始於"],["始愿","始願"],["姌袅","姌嫋"],["姑娘","姑娘"],["姑娘家","姑娘家"],["姑息养奸","姑息養奸"],["姑恶","姑惡"],["姑苏","姑蘇"],["姑表","姑表"],["姓岳","姓岳"],["姓系","姓系"],["委员制","委員制"],["委托","委託"],["委托书","委託書"],["委托人","委託人"],["委曲","委曲"],["委曲成全","委曲成全"],["委曲求全","委曲求全"],["委派代表","委派代表"],["委罪于人","委罪於人"],["姘出去","姘出去"],["姚俊杰","姚俊傑"],["姚升志","姚昇志"],["姚志源","姚志源"],["姚采颖","姚采穎"],["姜丝","薑絲"],["姜丰年","姜豐年"],["姜凤君","姜鳳君"],["姜切片","薑切片"],["姜夔","姜夔"],["姜大宇","姜大宇"],["姜太公","姜太公"],["姜嫄","姜嫄"],["姜子牙","姜子牙"],["姜家大被","姜家大被"],["姜宸英","姜宸英"],["姜尚","姜尚"],["姜就是老","薑就是老"],["姜建铭","姜建銘"],["姜愈老愈辣","薑愈老愈辣"],["姜文杰","姜文杰"],["姜是老","薑是老"],["姜是老的辣","薑是老的辣"],["姜末","薑末"],["姜桂","薑桂"],["姜桂老辣","薑桂老辣"],["姜母","薑母"],["姜母鸭","薑母鴨"],["姜汁","薑汁"],["姜汤","薑湯"],["姜沧源","姜滄源"],["姜片","薑片"],["姜石年","薑石年"],["姜竹祥","姜竹祥"],["姜糖","薑糖"],["姜维","姜維"],["姜维平","姜維平"],["姜老辣","薑老辣"],["姜至奂","姜至奐"],["姜芋","姜芋"],["姜茶","薑茶"],["姜蓉","薑蓉"],["姜越老越辣","薑越老越辣"],["姜辣","薑辣"],["姜辣素","薑辣素"],["姜还是老","薑還是老"],["姜还是老的辣","薑還是老的辣"],["姜远珍","姜遠珍"],["姜郁美","姜郁美"],["姜金龙","姜金龍"],["姜锡柱","姜錫柱"],["姜饼","薑餅"],["姜麻园","薑麻園"],["姜黄","薑黃"],["姜黄素","薑黃素"],["姜黄色","薑黃色"],["姨娘","姨娘","姨孃"],["姨表","姨表"],["姬姜","姬姜"],["姬松茸","姬松茸"],["姱修","姱修"],["姻党","姻黨"],["姻戚","姻戚"],["姿采","姿采"],["威克岛","威克島"],["威克斯","威克斯"],["威克森","威克森"],["威克菲尔","威克菲爾"],["威克菲尔德","威克菲爾德"],["威奇托","威奇托"],["威宁彝族回族苗族自治县","威寧彝族回族苗族自治縣"],["威尔生氏症","威爾生氏症"],["威布里吉","威布里吉"],["威廉亚历山大","威廉亞歷山大"],["威比苏诺","威比蘇諾"],["威氏注音法","威氏注音法"],["威里斯","威里斯"],["威风八面","威風八面"],["娇娘","嬌娘"],["娇嫩欲滴","嬌嫩欲滴"],["娇艳欲滴","嬌豔欲滴"],["娇袅不胜","嬌嫋不勝"],["娘亲","孃親"],["娘儿","孃兒"],["娘儿们","娘兒們"],["娘儿俩","孃兒倆"],["娘姨","孃姨"],["娘娘","娘娘"],["娘娘庙","娘娘廟"],["娘娘腔","娘娘腔"],["娘婆","娘婆"],["娘子","娘子"],["娘子关","娘子關"],["娘子军","娘子軍"],["娘家","孃家"],["娘家姓","孃家姓"],["娘母子","娘母子"],["娘的","孃的"],["娘老子","孃老子"],["娘胎","孃胎"],["娘舅","孃舅"],["娩出","娩出"],["娱乐台","娛樂臺"],["娴于","嫺於"],["娴于辞令","嫺於辭令"],["娶了","娶了"],["娶回","娶回"],["娶回家","娶回家"],["婆娘","婆娘"],["婆娘子","婆娘子"],["婚前婚后","婚前婚後"],["婚后","婚後"],["婚姻制度","婚姻制度"],["婢仆","婢僕"],["婴儿猝死症候群","嬰兒猝死症候羣"],["婴儿猝死综合症","嬰兒猝死綜合症"],["婶娘","嬸孃"],["媒人口无量斗","媒人口無量斗"],["媒人婆迷了路","媒人婆迷了路"],["媒体狂并潮","媒體狂併潮"],["媒体访问控制","媒體訪問控制"],["媒合","媒合"],["媚如秋月","媚如秋月"],["媮合苟容","媮合苟容"],["媵御","媵御"],["嫁个","嫁個"],["嫁个老公","嫁個老公"],["嫁了","嫁了"],["嫁于","嫁於"],["嫁出","嫁出"],["嫁出去","嫁出去"],["嫁出来","嫁出來"],["嫁祸于","嫁禍於"],["嫁祸于人","嫁禍於人"],["嫉恶","嫉惡"],["嫉恶好善","嫉惡好善"],["嫉恶如仇","嫉惡如仇"],["嫉恶若仇","嫉惡若仇"],["嫌凶","嫌兇"],["嫌好道丑","嫌好道醜"],["嫌好道恶","嫌好道惡"],["嫌恶","嫌惡"],["嫔御","嬪御"],["嫠忧宗周","嫠憂宗周"],["嫡出","嫡出"],["嫡系","嫡系"],["嫩叶","嫩葉"],["嬉游","嬉遊"],["嬖幸","嬖倖"],["嬴余","嬴餘"],["子之丰兮","子之丰兮"],["子云","子云"],["子叶","子葉"],["子姜炒鸡","子薑炒雞"],["子孙娘娘","子孫娘娘"],["子宫內膜异位症","子宮內膜異位症"],["子曰诗云","子曰詩云"],["子杰","子傑"],["子母钟","子母鐘"],["子游","子游"],["子癫前症","子癲前症"],["子目录","子目錄"],["子系统","子系統"],["子集合","子集合"],["孔明借箭","孔明借箭"],["孔章望斗","孔章望斗"],["孔虫","孔蟲"],["孕出","孕出"],["孕穗","孕穗"],["孕穗期","孕穗期"],["孕育出","孕育出"],["孖虫","孖蟲"],["字据","字據"],["字根合体字","字根合體字"],["字根表","字根表"],["字母表","字母表"],["字汇","字彙"],["字汇判断任务","字彙判斷任務"],["字码表","字碼表"],["字表","字表"],["字表输入法","字表輸入法"],["字里","字裏"],["字里行间","字裏行間"],["字面","字面"],["字面上","字面上"],["字面意义","字面意義"],["字面意思","字面意思"],["字面解释","字面解釋"],["字音表","字音表"],["存于","存於"],["存亡之秋","存亡之秋"],["存亡未卜","存亡未卜"],["存十一于千百","存十一於千百"],["存录","存錄"],["存念","存念"],["存托凭证","存託憑證"],["存托股","存托股"],["存扣","存扣"],["存折","存摺"],["存款准备率","存款準備率"],["存款准备金","存款準備金"],["存款准备金率","存款準備金率"],["孙协志","孫協志"],["孙大千","孫大千"],["孙杰","孫杰"],["孙胜男","孫勝男"],["孝布","孝布"],["孝重千斤日减一斤","孝重千斤日減一斤"],["孟什维克","孟什維克"],["孟冬","孟冬"],["孟姜女","孟姜女"],["孟小冬","孟小冬"],["孟尝君","孟嘗君"],["孟德尔松","孟德爾松"],["孟村回族自治县","孟村回族自治縣"],["孟秋","孟秋"],["孟获","孟獲"],["孢子叶","孢子葉"],["孢子虫","孢子蟲"],["季冬","季冬"],["季后","季後"],["季后赛","季後賽"],["季咸","季咸"],["季布","季布"],["季布一诺","季布一諾"],["季札挂剑","季札掛劍"],["季瑟雅克","季瑟雅克"],["季秋","季秋"],["季节洄游","季節洄游"],["孤云","孤雲"],["孤云野鹤","孤雲野鶴"],["孤儿药","孤兒藥"],["孤军奋斗","孤軍奮鬥"],["孤凄","孤悽"],["孤寡不谷","孤寡不穀"],["孤形只影","孤形隻影"],["孤形吊影","孤形吊影"],["孤征","孤征"],["孤拐","孤拐"],["孤拐面","孤拐面"],["孤注","孤注"],["孤注一掷","孤注一擲"],["孤涂","孤塗"],["孤游","孤遊"],["孤灯挑尽","孤燈挑盡"],["孤身只影","孤身隻影"],["孤辰合注","孤辰合注"],["学习团","學習團"],["学习曲线","學習曲線"],["学习范例","學習範例"],["学习计划","學習計劃"],["学了个不留","學了個不留"],["学以致用","學以致用"],["学优才赡","學優才贍"],["学位制度","學位制度"],["学分制","學分制"],["学制","學制"],["学力鉴定","學力鑑定"],["学区制","學區制"],["学历","學歷","學曆"],["学台","學臺"],["学名药","學名藥"],["学员制","學員制"],["学回","學回"],["学回去","學回去"],["学回来","學回來"],["学士后医学系","學士後醫學系"],["学徒制","學徒制"],["学术","學術"],["学术团体","學術團體"],["学术奖","學術獎"],["学术性","學術性"],["学术报告","學術報告"],["学术文化团体","學術文化團體"],["学术水平","學術水平"],["学术界","學術界"],["学术研究","學術研究"],["学术科","學術科"],["学术组","學術組"],["学术网路","學術網路"],["学术自由","學術自由"],["学校同学","學校同學"],["学浅才疏","學淺才疏"],["学然后知不足","學然後知不足"],["学疏才浅","學疏才淺"],["学籍表","學籍表"],["学系","學系"],["学经历","學經歷"],["学舍","學舍"],["学里","學裏"],["学长制","學長制"],["孩儿面","孩兒面"],["孬种","孬種"],["孱困","孱困"],["孵出","孵出"],["孵出来","孵出來"],["孽党","孽黨"],["孽种","孽種"],["孽障种子","孽障種子"],["宁个","寧個"],["宁中则","甯中則"],["宁夏回族","寧夏回族"],["宁夏回族自治区","寧夏回族自治區"],["宁庄子","甯莊子"],["宁当玉碎","寧當玉碎"],["宁悼子","甯悼子"],["宁惠子","甯惠子"],["宁愿","寧願"],["宁成子","甯成子"],["宁戚","甯戚"],["宁折不弯","寧折不彎"],["宁撞金钟一下不打破鼓三千","寧撞金鐘一下不打破鼓三千"],["宁斧成","甯斧成"],["宁武子","甯武子"],["宁浩","甯浩"],["宁猛力","甯猛力"],["宁调元","甯調元"],["宁越","甯越"],["宁静致远","寧靜致遠"],["宅舍","宅舍"],["宇宙云","宇宙雲"],["宇宙志","宇宙誌"],["守先待后","守先待後"],["守制","守制"],["守御","守禦"],["守正不回","守正不回"],["守舍","守舍"],["守节不回","守節不回"],["安万特","安萬特"],["安了","安了"],["安于","安於"],["安于一隅","安於一隅"],["安于泰山","安於泰山"],["安于现状","安於現狀"],["安仁鬓秋","安仁鬢秋"],["安克拉","安克拉"],["安克拉治","安克拉治"],["安克雷奇","安克雷奇"],["安全系数","安全係數"],["安全系统","安全系統"],["安全防范","安全防範"],["安可曲","安可曲"],["安吉里科","安吉里科"],["安地卡及巴布达","安地卡及巴布達"],["安山岩","安山岩"],["安布罗斯","安布羅斯"],["安席克","安席克"],["安扎","安扎"],["安提瓜和巴布达","安提瓜和巴布達"],["安杰","安傑"],["安格鲁萨克逊","安格魯薩克遜"],["安步当车","安步當車"],["安沈铁路","安瀋鐵路"],["安眠药","安眠藥"],["安纳托利亚","安納托利亞"],["安胎药","安胎藥"],["安胡","安胡"],["安营扎寨","安營紮寨"],["安萨里","安薩里"],["安适","安適"],["安适如常","安適如常"],["安钦云","安欽雲"],["安闲惬意","安閒愜意"],["安闲自在","安閒自在"],["安闲自得","安閒自得"],["安闲舒适","安閒舒適"],["安闲随意","安閒隨意"],["安魂弥撒","安魂彌撒"],["安魂曲","安魂曲"],["宋三彩","宋三彩"],["宋亨欣叶纯豪","宋亨欣葉純豪"],["宋克","宋克"],["宋板","宋板"],["完了","完了"],["完全叶","完全葉"],["完全愈复","完全癒復"],["完全正确","完全正確"],["完工后","完工後"],["完成后","完成後"],["完税价格","完稅價格"],["完税货价","完稅貨價"],["宏志","宏志"],["宏愿","宏願"],["宏碁集团","宏碁集團"],["宗周","宗周"],["宗周钟","宗周鐘"],["宗教团","宗教團"],["宗教团体","宗教團體"],["宗法制度","宗法制度"],["官不怕大只怕管","官不怕大只怕管"],["官价","官價"],["官兵一致","官兵一致"],["官准","官准"],["官制","官制"],["官卷","官卷"],["官历","官曆"],["官台木","官臺木"],["官商合办","官商合辦"],["官地为采","官地爲寀"],["官复原职","官復原職"],["官庄","官莊"],["官念","官念"],["官报私仇","官報私仇"],["官料药","官料藥"],["官板儿","官板兒"],["官私合营","官私合營"],["官能团","官能團"],["官能症","官能症"],["官舍","官舍"],["官面","官面"],["官面儿","官面兒"],["定义出","定義出"],["定义范围","定義範圍"],["定了","定了"],["定于","定於"],["定于一尊","定於一尊"],["定价","定價"],["定准","定準"],["定出","定出"],["定出来","定出來"],["定制","定製"],["定制化","定製化"],["定南针","定南針"],["定向","定向"],["定向培育","定向培育"],["定向天线","定向天線"],["定向越野","定向越野"],["定弦","定弦"],["定当","定當"],["定时号志","定時號誌"],["定时钟","定時鐘"],["定点厂","定點廠"],["定碳杯","定碳杯"],["定胜败","定勝敗"],["定范围","定範圍"],["定计划","定計劃"],["定都于","定都於"],["定风针","定風針"],["宛若游龙","宛若游龍"],["宛转周折","宛轉周折"],["宜丰","宜豐"],["宜丰县","宜豐縣"],["宜于","宜於"],["宜云","宜云"],["宝丰","寶丰","寶豐"],["宝丰县","寶豐縣"],["宝卷","寶卷"],["宝历","寶曆"],["宝山庄","寶山莊"],["宝山空回","寶山空回"],["宝庄","寶莊"],["宝志","寶誌"],["宝胄","寶胄"],["宝贝团","寶貝團"],["宝里宝气","寶里寶氣"],["宝鉴","寶鑑"],["宝钢集团","寶鋼集團"],["实业计划","實業計劃"],["实价","實價"],["实况录影","實況錄影"],["实况录音","實況錄音"],["实发","實發"],["实名制","實名制"],["实干","實幹"],["实干家","實幹家"],["实录","實錄"],["实才","實才"],["实据","實據"],["实时技术","實時技術"],["实用价值","實用價值"],["实症","實症"],["实质面","實質面"],["实践是检验真理的唯一标准","實踐是檢驗真理的唯一標準"],["实际范围","實際範圍"],["宠幸","寵幸"],["审囚刷卷","審囚刷卷"],["审干","審幹"],["审曲面势","審曲面勢"],["审核","審覈"],["审级制度","審級制度"],["审计范围","審計範圍"],["客串演出","客串演出"],["客制化","客製化"],["客制化服务","客製化服務"],["客如云集","客如雲集"],["客游","客遊"],["客舍","客舍"],["宣传周","宣傳週"],["宣卷","宣卷"],["宣室志","宣室志"],["宣布","宣佈"],["宣布无效","宣佈無效"],["宣布独立","宣佈獨立"],["宣布破产","宣佈破產"],["宣誓代表","宣誓代表"],["宣赞","宣贊"],["室內乐团","室內樂團"],["室里","室裏"],["宦游","宦遊"],["宪台","憲臺"],["宫里","宮裏"],["宫里蓝","宮里藍"],["宰制","宰制"],["害于","害於"],["害人虫","害人蟲"],["害发","害發"],["害虫","害蟲"],["宴游","宴遊"],["宵征","宵征"],["家丑","家醜"],["家丑不可外传","家醜不可外傳"],["家丑不可外传流言切莫轻信","家醜不可外傳流言切莫輕信"],["家丑不可外扬","家醜不可外揚"],["家什","傢什"],["家仆","家僕"],["家伙","傢伙"],["家佣","家傭"],["家俱","傢俱"],["家具","傢俱"],["家具行","傢俱行"],["家制","家制"],["家和万事兴","家和萬事興"],["家山药","家山藥"],["家庄","家莊"],["家庭制度","家庭制度"],["家庭计划","家庭計劃"],["家当","家當"],["家政系","家政系"],["家族同盟","家族同盟"],["家无斗储","家無斗儲"],["家机布","家機布"],["家私","傢俬"],["家种","家種"],["家系","家系"],["家财万贯","家財萬貫"],["家赀万贯","家貲萬貫"],["家里","家裏"],["家里的","家裏的"],["家长制","家長制"],["家长里短","家長裏短"],["家门不幸","家門不幸"],["家门有幸","家門有幸"],["宸极","宸極"],["宸游","宸遊"],["容于","容於"],["容光焕发","容光煥發"],["容克","容克"],["容后说明","容後說明"],["容容多后福","容容多後福"],["容幸","容幸"],["容范","容範"],["容表","容表"],["宽了","寬了"],["宽于","寬於"],["宽余","寬餘"],["宽宽松松","寬寬鬆鬆"],["宽打周遭","寬打周遭"],["宽松","寬鬆"],["宽泛","寬泛"],["宾主关系","賓主關係"],["宾主尽欢","賓主盡歡"],["宾客如云","賓客如雲"],["宾语关系从句","賓語關係從句"],["宿仇","宿仇"],["宿志","宿志"],["宿愿","宿願"],["宿愿已偿","宿願已償"],["宿愿得偿","宿願得償"],["宿松","宿松"],["宿松县","宿松縣"],["宿舍","宿舍"],["宿舍区","宿舍區"],["宿舍楼","宿舍樓"],["宿舍网路","宿舍網路"],["宿舍费","宿舍費"],["寂历","寂歷"],["寄了","寄了"],["寄于","寄於"],["寄出","寄出"],["寄出去","寄出去"],["寄发","寄發"],["寄回","寄回"],["寄托","寄託"],["寄托在","寄託在"],["寄托着","寄託着"],["寄挂号","寄掛號"],["寄挂号信","寄掛號信"],["寄生昆虫","寄生昆蟲"],["寄生虫","寄生蟲"],["寄生虫病","寄生蟲病"],["寅台","寅臺"],["密云","密雲"],["密云不雨","密雲不雨"],["密云县","密雲縣"],["密仑","密侖"],["密克罗尼西亚","密克羅尼西亞"],["密切关系","密切關係"],["密切注意","密切注意"],["密切注视","密切注視"],["密合","密合"],["密密扎扎","密密扎扎"],["密布","密佈"],["密折","密摺"],["密致","密緻"],["密苏里","密蘇里"],["密苏里州","密蘇里州"],["密苏里河","密蘇里河"],["寇仇","寇仇"],["寇准","寇準"],["富于","富於"],["富于想像","富於想像"],["富余","富餘"],["富兰克林","富蘭克林"],["富富有余","富富有餘"],["富布赖特","富布賴特"],["富春秋","富春秋"],["富维克","富維克"],["富色彩","富色彩"],["富贵如浮云","富貴如浮雲"],["富贵浮云","富貴浮雲"],["富里","富里"],["富里乡","富里鄉"],["寒于","寒於"],["寒假里","寒假裏"],["寒冬","寒冬"],["寒冬腊月","寒冬臘月"],["寒号虫","寒號蟲"],["寒暑表","寒暑表"],["寒栗","寒慄"],["寒武系","寒武系"],["寒波荡漾","寒波盪漾"],["寒症","寒症"],["寒秋","寒秋"],["寒舍","寒舍"],["寓于","寓於"],["寓兵于农","寓兵於農"],["寓教于乐","寓教於樂"],["寓禁于征","寓禁於征"],["寝丘之志","寢丘之志"],["察合台","察合臺"],["察合台汗国","察合臺汗國"],["察布查尔","察布查爾"],["察布查尔县","察布查爾縣"],["察核","察覈"],["察觉出","察覺出"],["寡占","寡佔"],["寡合","寡合"],["寡欲","寡慾"],["寥寥无几","寥寥無幾"],["寮采","寮寀"],["寸丝不挂","寸絲不掛"],["寸发千金","寸髮千金"],["对了","對了"],["对了槛儿","對了檻兒"],["对于","對於"],["对偶多面体","對偶多面體"],["对冲","對衝"],["对冲基金","對衝基金"],["对准","對準"],["对准目标","對準目標"],["对准表","對準錶"],["对准钟","對準鐘"],["对准钟表","對準鐘錶"],["对华发动","對華發動"],["对台","對臺"],["对台戏","對臺戲"],["对合","對合"],["对合起来","對合起來"],["对外关系","對外關係"],["对天发誓","對天發誓"],["对妻失语症","對妻失語症"],["对对胡","對對胡"],["对当","對當"],["对折","對摺"],["对数表","對數表"],["对杯","對杯"],["对流云系","對流雲系"],["对焦范围","對焦範圍"],["对照表","對照表"],["对症","對症"],["对症下药","對症下藥"],["对症发药","對症發藥"],["对着干","對着幹"],["对立面","對立面"],["对等关系","對等關係"],["对表","對錶"],["对酒当歌","對酒當歌"],["对针","對針"],["对面","對面"],["对面不见人","對面不見人"],["寺舍","寺舍"],["寺钟","寺鐘"],["寻仇","尋仇"],["寻出","尋出"],["寻回","尋回"],["寻幽探胜","尋幽探勝"],["寻幽访胜","尋幽訪勝"],["寻找出","尋找出"],["寻找出来","尋找出來"],["寻来范畴","尋來範疇"],["寻求出来","尋求出來"],["寻甸回族彝族自治县","尋甸回族彝族自治縣"],["寻获","尋獲"],["导出","導出"],["导出值","導出值"],["导出去","導出去"],["导出来","導出來"],["导向","導向"],["导向型","導向型"],["导向思考","導向思考"],["导向飞弹","導向飛彈"],["导向鱼雷","導向魚雷"],["导师制","導師制"],["导引之术","導引之術"],["导引系统","導引系統"],["导弹武器技术控制制度","導彈武器技術控制制度"],["导弹系统","導彈系統"],["导板","導板"],["导气之术","導氣之術"],["导流板","導流板"],["导游","導遊"],["导生制","導生制"],["导致","導致"],["导致死亡","導致死亡"],["导航系统","導航系統"],["导风板","導風板"],["寿丰","壽豐"],["寿丰乡","壽豐鄉"],["寿数已尽","壽數已盡"],["寿险责任准备金","壽險責任準備金"],["寿面","壽麪"],["封个","封個"],["封了","封了"],["封了火","封了火"],["封侯万里","封侯萬里"],["封台","封臺"],["封后","封后"],["封妻荫子","封妻廕子"],["封官许愿","封官許願"],["封建制度","封建制度"],["封建割据","封建割據"],["封弥","封彌"],["封杀出局","封殺出局"],["封檐板","封檐板"],["封胡羯末","封胡羯末"],["封胡遏末","封胡遏末"],["封蜡","封蠟"],["封里","封裏"],["封面","封面"],["封面人物","封面人物"],["封面女郎","封面女郎"],["封面设计","封面設計"],["封面里","封面裏"],["射不出","射不出"],["射了","射了"],["射准","射準"],["射出","射出"],["射出去","射出去"],["射出来","射出來"],["射向","射向"],["射回","射回"],["射回去","射回去"],["射回来","射回來"],["射复","射覆"],["射干","射干"],["射影几何","射影幾何"],["射影几何学","射影幾何學"],["射雕","射鵰"],["射雕手","射鵰手"],["射雕英雄传","射鵰英雄傳"],["射频干扰","射頻干擾"],["射频识别","射頻識別"],["将于","將於"],["将假当真","將假當真"],["将出","將出"],["将出去","將出去"],["将出来","將出來"],["将功折罪","將功折罪"],["将功折过","將功折過"],["将占","將佔"],["将占卜","將占卜"],["将回","將回"],["将回到","將回到"],["将回去","將回去"],["将回来","將回來"],["将尽","將盡"],["将尽未尽","將盡未盡"],["将才","將才"],["将无同","將無同"],["将相本无种","將相本無種"],["将遇良才","將遇良才"],["将门之后","將門之後"],["小丑","小丑","小醜"],["小丑丫鬟","小醜丫鬟"],["小丑跳梁","小醜跳樑"],["小丑鱼","小丑魚"],["小业种","小業種"],["小个","小個"],["小个子","小個子"],["小丰满发电厂","小豐滿發電廠"],["小了","小了"],["小于","小於"],["小云","小云"],["小人得志","小人得志"],["小仆","小僕"],["小价","小价"],["小众艺术","小衆藝術"],["小伙","小夥"],["小伙子","小夥子"],["小伙计","小夥計"],["小余","小余"],["小便斗","小便斗"],["小修","小修"],["小傢伙","小傢伙"],["小儿麻痹症","小兒麻痹症"],["小克","小克"],["小冬","小冬"],["小冲突","小衝突"],["小几","小几"],["小划子","小划子"],["小别","小別"],["小千","小千"],["小千世界","小千世界"],["小升","小升"],["小卷","小卷","小捲"],["小厂","小廠"],["小发","小發"],["小发财","小發財"],["小只","小隻"],["小叮当","小叮噹"],["小叶","小葉"],["小同乡","小同鄉"],["小后生","小後生"],["小周天","小週天"],["小回","小回"],["小场面","小場面"],["小型柜橱","小型櫃櫥"],["小型钟","小型鐘"],["小型钟表","小型鐘錶"],["小型钟表面","小型鐘表面"],["小型钟面","小型鐘面"],["小夜曲","小夜曲"],["小天后","小天后"],["小姑娘","小姑娘"],["小姑娘树","小姑娘樹"],["小娘","小娘"],["小娘子","小娘子"],["小子后生","小子後生"],["小尝","小嚐"],["小尽","小盡"],["小岩洞","小巖洞"],["小布","小布"],["小庵","小庵"],["小廉曲谨","小廉曲謹"],["小志","小志"],["小念","小念"],["小恶魔","小惡魔"],["小才大用","小才大用"],["小才子","小才子"],["小挂儿","小掛兒"],["小插曲","小插曲"],["小时了了","小時了了"],["小曲","小曲"],["小朱","小朱"],["小杯","小杯"],["小杰","小杰"],["小松","小松"],["小松糕","小鬆糕"],["小板","小板"],["小柜子","小櫃子"],["小栗旬","小栗旬"],["小步舞曲","小步舞曲"],["小毛虫","小毛蟲"],["小池百合子","小池百合子"],["小注","小注"],["小泽征尔","小澤征爾"],["小游","小遊"],["小瀑布","小瀑布"],["小班制","小班制"],["小秀才","小秀才"],["小秀才学堂","小秀才學堂"],["小秋","小秋"],["小秋收","小秋收"],["小种","小種"],["小穗","小穗"],["小筑","小築"],["小米面","小米麪"],["小系","小系"],["小红萝卜","小紅蘿蔔"],["小老板","小老闆"],["小胜","小勝"],["小胜利","小勝利"],["小胡子","小鬍子"],["小胡桃","小胡桃"],["小脏鬼","小髒鬼"],["小舍人","小舍人"],["小花远志","小花遠志"],["小苏","小蘇"],["小苏打","小蘇打"],["小苏打粉","小蘇打粉"],["小苹果","小蘋果"],["小范","小范"],["小范围","小範圍"],["小萝卜头","小蘿蔔頭"],["小虫","小蟲"],["小虫子","小蟲子"],["小行板","小行板"],["小表哥","小表哥"],["小表妹","小表妹"],["小表姊","小表姊"],["小表嫂","小表嫂"],["小表弟","小表弟"],["小里小气","小裏小氣"],["小针","小針"],["小针美容","小針美容"],["小钟","小鐘"],["小铲","小鏟"],["小铲子","小鏟子"],["小集团","小集團"],["小面包","小麪包"],["小须鲸","小鬚鯨"],["小鬼当家","小鬼當家"],["少不了","少不了"],["少了","少了"],["少于","少於"],["少冲","少衝"],["少出","少出"],["少占","少佔"],["少吊","少吊"],["少年才俊","少年才俊"],["少惹闲事","少惹閒事"],["少扣","少扣"],["少掌柜","少掌櫃"],["少数党","少數黨"],["少杰","少傑"],["少私寡欲","少私寡慾"],["少管闲事","少管閒事"],["少说几句","少說幾句"],["少采","少採"],["尔冬升","爾冬升"],["尔后","爾後"],["尔当","爾當"],["尔本周","爾本週"],["尖团","尖團"],["尖团字","尖團字"],["尖团音","尖團音"],["尖扎","尖扎"],["尖扎县","尖扎縣"],["尖管面","尖管麪"],["尖裂叶","尖裂葉"],["尘卷风","塵捲風"],["尘肺症","塵肺症"],["尘芥虫","塵芥蟲"],["尘表","塵表"],["尘襟尽涤","塵襟盡滌"],["尘饭涂羹","塵飯塗羹"],["尚余","尚餘"],["尚志","尚志"],["尚志市","尚志市"],["尚慕杰","尚慕傑"],["尚须","尚須"],["尝个","嚐個"],["尝了","嚐了"],["尝了一口","嚐了一口"],["尝了尝","嚐了嚐"],["尝了鲜","嚐了鮮"],["尝出","嚐出"],["尝到","嚐到"],["尝尝","嚐嚐"],["尝尝鲜","嚐嚐鮮"],["尝尽","嚐盡"],["尝巧","嘗巧"],["尝敌","嘗敵"],["尝新","嘗新"],["尝来尝去","嚐來嚐去"],["尝汤戏","嘗湯戲"],["尝点","嚐點"],["尝甜头","嘗甜頭"],["尝胆","嘗膽"],["尝胆臥薪","嘗膽臥薪"],["尝膳","嘗膳"],["尝草","嘗草"],["尝药","嘗藥"],["尝试","嘗試"],["尝试性","嘗試性"],["尝试错误学习","嘗試錯誤學習"],["尝起来","嚐起來"],["尝遍","嚐遍"],["尝酸","嘗酸"],["尝鲜","嚐鮮"],["尝鼎一脔","嘗鼎一臠"],["尤云殢雨","尤雲殢雨"],["尤克利斯","尤克利斯"],["尤克勒斯","尤克勒斯"],["尤克斯","尤克斯"],["尤克里斯","尤克里斯"],["尤克里里琴","尤克裏裏琴"],["尤基里斯","尤基里斯"],["尤班克斯","尤班克斯"],["尤秋兴","尤秋興"],["尤里","尤里"],["尤里斯伊文思","尤里斯伊文思"],["尤里比底斯","尤里比底斯"],["尤里西斯","尤里西斯"],["尤须","尤須"],["尧布","堯布"],["尨眉皓发","尨眉皓髮"],["就于","就於"],["就克制","就剋制"],["就出","就出"],["就出去","就出去"],["就出来","就出來"],["就吃干","就吃乾"],["就回","就回"],["就回去","就回去"],["就回来","就回來"],["就干一","就幹一"],["就干一杯","就乾一杯"],["就干吧","就幹吧"],["就干淨","就乾淨"],["就当","就當"],["就当作","就當作"],["就念","就念"],["就扣","就扣"],["就拿出","就拿出"],["就日瞻云","就日瞻雲"],["就是了","就是了"],["就晚了","就晚了"],["就汤下面","就湯下麪"],["就系","就係"],["就范","就範"],["就读于","就讀於"],["尸位","尸位"],["尸位素餐","尸位素餐"],["尸体","屍體"],["尸体剖检","屍體剖檢"],["尸体袋","屍體袋"],["尸体解剖","屍體解剖"],["尸僵","屍僵"],["尸利","尸利"],["尸变","屍變"],["尸块","屍塊"],["尸居余气","尸居餘氣"],["尸居龙见","尸居龍見"],["尸山血海","屍山血海"],["尸斑","屍斑"],["尸格","屍格"],["尸检","屍檢"],["尸榇","屍櫬"],["尸横遍野","屍橫遍野"],["尸灵","屍靈"],["尸祝","尸祝"],["尸祝代庖","尸祝代庖"],["尸禄","尸祿"],["尸禄素餐","尸祿素餐"],["尸臣","尸臣"],["尸蜡","屍蠟"],["尸衣","屍衣"],["尸解","尸解"],["尸谏","尸諫"],["尸身","屍身","尸身"],["尸陀林","尸陀林"],["尸饔","尸饔"],["尸首","屍首"],["尸骨","屍骨"],["尸骨无存","屍骨無存"],["尸骨早寒","屍骨早寒"],["尸骨未寒","屍骨未寒"],["尸骸","屍骸"],["尸鸠","尸鳩"],["尹秋君","尹秋君"],["尹邢避面","尹邢避面"],["尺二秀才","尺二秀才"],["尺寸千里","尺寸千里"],["尺寸斗粟","尺寸斗粟"],["尺布斗粟","尺布斗粟"],["尺幅千里","尺幅千里"],["尺板","尺板"],["尺板斗食","尺板斗食"],["尼亚加拉瀑布","尼亞加拉瀑布"],["尼克","尼克"],["尼克劳斯","尼克勞斯"],["尼克松","尼克松"],["尼克森","尼克森"],["尼克洛","尼克洛"],["尼克队","尼克隊"],["尼加拉瀑布","尼加拉瀑布"],["尼勒克","尼勒克"],["尼勒克县","尼勒克縣"],["尼坛","尼壇"],["尼坦雅胡","尼坦雅胡"],["尼姑庵","尼姑庵"],["尼布楚条约","尼布楚條約"],["尼布甲尼撒","尼布甲尼撒"],["尼庵","尼庵"],["尼采","尼采"],["尼龙布","尼龍布"],["尽世","盡世"],["尽义务","盡義務"],["尽了","盡了"],["尽些","盡些"],["尽享","盡享"],["尽人","盡人"],["尽人事","盡人事"],["尽人情","盡人情"],["尽人皆知","盡人皆知"],["尽付东流","盡付東流"],["尽付阙如","盡付闕如"],["尽信","盡信"],["尽做","盡做"],["尽做坏事","盡做壞事"],["尽先","儘先"],["尽全力","盡全力"],["尽全心","盡全心"],["尽兴","盡興"],["尽兴而归","盡興而歸"],["尽其","盡其"],["尽其在我","盡其在我"],["尽其所有","盡其所有"],["尽其所能","盡其所能"],["尽其所长","盡其所長"],["尽出","盡出"],["尽到","盡到"],["尽力","盡力"],["尽力去做","盡力去做"],["尽力而为","盡力而爲"],["尽去","盡去"],["尽可","儘可"],["尽可能","儘可能"],["尽命","盡命"],["尽善","盡善"],["尽善尽美","盡善盡美"],["尽在","盡在"],["尽场儿","盡場兒"],["尽够","儘夠"],["尽失","盡失"],["尽头","盡頭"],["尽头话","盡頭話"],["尽如","盡如"],["尽如人意","盡如人意"],["尽子","儘子"],["尽孝","盡孝"],["尽尽","儘儘"],["尽展所长","盡展所長"],["尽属","盡屬"],["尽己","盡己"],["尽带","盡帶"],["尽席","盡席"],["尽年","盡年"],["尽底下","儘底下"],["尽得","盡得"],["尽心","盡心"],["尽心图报","盡心圖報"],["尽心尽力","盡心盡力"],["尽心竭力","盡心竭力"],["尽心竭诚","盡心竭誠"],["尽忠","盡忠"],["尽忠报国","盡忠報國"],["尽忠竭力","盡忠竭力"],["尽忠职守","盡忠職守"],["尽快","儘快"],["尽快地","儘快地"],["尽态极妍","盡態極妍"],["尽性","儘性"],["尽情","盡情"],["尽情吐露","盡情吐露"],["尽情尽理","盡情盡理"],["尽情欢乐","盡情歡樂"],["尽情欢唱","盡情歡唱"],["尽情歌唱","盡情歌唱"],["尽情玩乐","盡情玩樂"],["尽想","儘想"],["尽意","盡意"],["尽意随心","儘意隨心"],["尽收","盡收"],["尽收眼底","盡收眼底"],["尽教","儘教"],["尽散","盡散"],["尽数","盡數"],["尽日","盡日"],["尽日穷夜","盡日窮夜"],["尽早","儘早"],["尽是","盡是"],["尽有可能","儘有可能"],["尽本分","盡本分"],["尽欢","盡歡"],["尽欢而散","盡歡而散"],["尽然","盡然"],["尽瘁","盡瘁"],["尽瘁鞠躬","盡瘁鞠躬"],["尽皆","盡皆"],["尽盘将军","盡盤將軍"],["尽礼","盡禮"],["尽端","盡端"],["尽管","儘管"],["尽管如此","儘管如此"],["尽美尽善","盡美盡善"],["尽职","盡職"],["尽职尽责","盡職盡責"],["尽能","盡能"],["尽自","儘自"],["尽致","盡致"],["尽节","盡節"],["尽节竭诚","盡節竭誠"],["尽若","盡若"],["尽落尾","儘落尾"],["尽要","盡要"],["尽览","盡覽"],["尽言","盡言"],["尽让","儘讓"],["尽诚竭节","盡誠竭節"],["尽读","盡讀"],["尽责","盡責"],["尽责任","盡責任"],["尽述","盡述"],["尽速","儘速"],["尽释前嫌","盡釋前嫌"],["尽里","儘裏"],["尽量","儘量"],["尽铅华","盡鉛華"],["尾注","尾註"],["尾身幸次","尾身幸次"],["尿崩症","尿崩症"],["尿布","尿布"],["尿布台","尿布臺"],["尿布疹","尿布疹"],["尿斗","尿斗"],["尿杯","尿杯"],["尿毒症","尿毒症"],["局促","侷促"],["局里","局裏"],["局限","侷限"],["局限于","侷限於"],["局面","局面"],["层云","層雲"],["层出","層出"],["层出不穷","層出不窮"],["层出叠见","層出疊見"],["层压板","層壓板"],["层台","層臺"],["层积云","層積雲"],["层见叠出","層見疊出"],["层见迭出","層見迭出"],["层面","層面"],["居于","居於"],["居住于","居住於"],["居心险恶","居心險惡"],["居里","居里"],["居里夫人","居里夫人"],["屈一伸万","屈一伸萬"],["屈万里","屈萬里"],["屈就于","屈就於"],["屈志","屈志"],["屈才","屈才"],["屈折","屈折"],["屈折语","屈折語"],["屈曲","屈曲"],["屈服于","屈服於"],["屋子里","屋子裏"],["屋梁","屋樑"],["屋舍","屋舍"],["屋里","屋裏"],["屋里人","屋裏人"],["屋里的","屋裏的"],["屋面","屋面"],["屋面板","屋面板"],["屋面瓦","屋面瓦"],["屏当","屏當"],["屏极","屏極"],["屏风后","屏風後"],["屑于","屑於"],["展出","展出"],["展卷","展卷"],["展台","展臺"],["展团","展團"],["展布","展布"],["展才","展才"],["展现出","展現出"],["展现出来","展現出來"],["展示出","展示出"],["展示柜","展示櫃"],["展采","展采"],["展露出","展露出"],["展露出来","展露出來"],["属于","屬於"],["属于偶","屬於偶"],["属意于","屬意於"],["属托","屬託"],["属毛离里","屬毛離裏"],["屠苏","屠蘇"],["屠苏酒","屠蘇酒"],["屡仆屡起","屢仆屢起"],["屡出新招","屢出新招"],["屡出狂言","屢出狂言"],["屡战屡胜","屢戰屢勝"],["屡顾尔仆","屢顧爾僕"],["履历","履歷"],["履历片","履歷片"],["履历表","履歷表"],["屯扎","屯紮"],["屯田制","屯田制"],["屯里","屯裏"],["山中无历日","山中無曆日"],["山中白云","山中白雲"],["山仔后","山仔后"],["山前山后","山前山後"],["山后","山後"],["山向","山向"],["山地同胞","山地同胞"],["山地管制区","山地管制區"],["山地管制游览区","山地管制遊覽區"],["山岩","山岩"],["山岳","山嶽"],["山崩钟应","山崩鐘應"],["山庄","山莊"],["山斗","山斗"],["山有扶苏","山有扶蘇"],["山栖谷隐","山棲谷隱"],["山栖谷饮","山棲谷飲"],["山梁","山樑"],["山洞里","山洞裏"],["山洪暴发","山洪暴發"],["山穷水尽","山窮水盡"],["山系","山系"],["山缪杰克森","山繆傑克森"],["山羊胡","山羊鬍"],["山羊胡子","山羊鬍子"],["山羊须","山羊鬚"],["山胡桃木","山胡桃木"],["山苏","山蘇"],["山药","山藥"],["山药蛋","山藥蛋"],["山谷","山谷"],["山谷地","山谷地"],["山里","山裏"],["山里站","山里站"],["山里红","山裏紅"],["山重水复","山重水複"],["山雨欲来","山雨欲來"],["山雨欲来风满楼","山雨欲來風滿樓"],["岁丰年稔","歲豐年稔"],["岁修","歲修"],["岁凶","歲凶"],["岁出","歲出"],["岁寒松柏","歲寒松柏"],["岁稔年丰","歲稔年豐"],["岁聿云暮","歲聿云暮"],["岁计余绌","歲計餘絀"],["岂只","豈只"],["岐周","岐周"],["岑参","岑參"],["岔曲","岔曲"],["岗台","崗臺"],["岚烟波影","嵐煙波影"],["岛链","島鏈"],["岩仓使节团","岩倉使節團"],["岩圈","岩圈"],["岩土","岩土"],["岩土体","岩土體"],["岩基","岩基"],["岩墙","巖牆"],["岩墙之下","巖牆之下"],["岩壁","巖壁"],["岩层","岩層"],["岩居","巖居"],["岩居穴处","巖居穴處"],["岩居谷饮","巖居谷飲"],["岩屑","岩屑"],["岩岩","巖巖"],["岩岸","巖岸"],["岩巉","巖巉"],["岩床","岩牀"],["岩徼","巖徼"],["岩心","岩心"],["岩手县","巖手縣"],["岩村","巖村"],["岩村明宪","岩村明憲"],["岩棉","岩棉"],["岩洞","巖洞"],["岩流圈","巖流圈"],["岩浆","岩漿"],["岩浆岩","岩漿岩"],["岩浆流","岩漿流"],["岩溶","岩溶"],["岩濑健","岩瀨健"],["岩画","巖畫"],["岩盐","岩鹽"],["岩石","岩石"],["岩石圈","岩石圈"],["岩石学","岩石學"],["岩石层","岩石層"],["岩石循环","岩石循環"],["岩礁","岩礁"],["岩穴","巖穴"],["岩穴之士","巖穴之士"],["岩羊","岩羊"],["岩脉","岩脈"],["岩蔷薇","巖薔薇"],["岩邑","巖邑"],["岩郎","巖郎"],["岩阻","巖阻"],["岩陛","巖陛"],["岫岩县","岫巖縣"],["岭表","嶺表"],["岱岳","岱嶽"],["岳丈","岳丈"],["岳云","岳雲"],["岳坟","岳墳"],["岳家","岳家"],["岳家军","岳家軍"],["岳岳","嶽嶽"],["岳庙","岳廟"],["岳母","岳母"],["岳氏","岳氏"],["岳父","岳父"],["岳珂","岳珂"],["岳阳","岳陽"],["岳阳县","岳陽縣"],["岳阳楼","岳陽樓"],["岳阳楼记","岳陽樓記"],["岳飞","岳飛"],["岳麓","嶽麓"],["峇峇娘惹","峇峇孃惹"],["峇里岛","峇里島"],["峡谷","峽谷"],["峰回","峯迴"],["峰回路转","峯迴路轉"],["峰岩","峯巖"],["峰火台","峯火臺"],["峻岭","峻嶺"],["峻极","峻極"],["崑仑","崑崙"],["崑仑奴","崑崙奴"],["崑仑奴传","崑崙奴傳"],["崑仑山","崑崙山"],["崑仑山脉","崑崙山脈"],["崑曲","崑曲"],["崔京周","崔京周"],["崔克索","崔克索"],["崔敬邕墓志铭","崔敬邕墓誌銘"],["崔涂","崔塗"],["崖广","崖广"],["崖谷","崖谷"],["崤谷","崤谷"],["崩症","崩症"],["嵌岩","嵌巖"],["嵚埼历落","嶔埼歷落"],["嵫厘","嵫釐"],["嶰谷","嶰谷"],["嶽云","嶽雲"],["巅崖峻谷","巔崖峻谷"],["巉岩","巉巖"],["巍巍荡荡","巍巍蕩蕩"],["川党参","川黨蔘"],["川后","川后"],["川埼症","川埼症"],["川杯","川杯"],["川汇区","川匯區"],["川谷","川穀"],["州同","州同"],["州里","州里"],["巡回","巡迴"],["巡回公演","巡迴公演"],["巡回剧团","巡迴劇團"],["巡回医疗","巡迴醫療"],["巡回图书馆","巡迴圖書館"],["巡回大使","巡迴大使"],["巡回学校","巡迴學校"],["巡回审判","巡迴審判"],["巡回展","巡迴展"],["巡回检査","巡迴檢查"],["巡回法庭","巡回法庭"],["巡回演出","巡迴演出"],["巡回演唱","巡迴演唱"],["巡回祭","巡迴祭"],["巡回赛","巡迴賽"],["巡回车","巡迴車"],["巡幸","巡幸"],["巡游","巡遊"],["工业体系","工業體系"],["工业团体","工業團體"],["工业技术","工業技術"],["工业民主制","工業民主制"],["工于","工於"],["工于心计","工於心計"],["工人党","工人黨"],["工价","工價"],["工余","工餘"],["工作制","工作制"],["工作制度","工作制度"],["工作台","工作臺"],["工作团","工作團"],["工作表","工作表"],["工作规范","工作規範"],["工作面","工作面"],["工党","工黨"],["工厂","工廠"],["工厂卫生","工廠衛生"],["工厂工业","工廠工業"],["工厂布置","工廠佈置"],["工厂权","工廠權"],["工厂法","工廠法"],["工厂自动化","工廠自動化"],["工商综合区","工商綜合區"],["工团","工團"],["工团主义","工團主義"],["工布江达","工布江達"],["工布江达县","工布江達縣"],["工欲善其事","工欲善其事"],["工矿炸药","工礦炸藥"],["工种","工種"],["工程学系","工程學系"],["工程系","工程系"],["工致","工緻"],["工艺美术","工藝美術"],["左云","左雲"],["左云县","左雲縣"],["左光斗","左光斗"],["左冲","左衝"],["左冲右突","左衝右突"],["左右前后","左右前後"],["左右摇摆","左右搖擺"],["左右采之","左右采之"],["左右采获","左右採獲"],["左后","左後"],["左后方","左後方"],["左向","左向"],["左手不托右手","左手不托右手"],["左拐","左拐"],["左氏春秋","左氏春秋"],["左邻右舍","左鄰右舍"],["左邻右里","左鄰右里"],["左里克","左里克"],["左面","左面"],["巧了","巧了"],["巧克力","巧克力"],["巧克力糖","巧克力糖"],["巧克力脆片","巧克力脆片"],["巧克力色","巧克力色"],["巧克力酱","巧克力醬"],["巧克莉","巧克莉"],["巧历","巧曆"],["巧发奇中","巧發奇中"],["巧合","巧合"],["巧同造化","巧同造化"],["巧干","巧幹"],["巧当儿","巧當兒"],["巨万","鉅萬"],["巨业","鉅業"],["巨亏","鉅虧"],["巨人症","巨人症"],["巨作","鉅作"],["巨债","鉅債"],["巨公","鉅公"],["巨制","鉅製"],["巨变","鉅變"],["巨商","鉅商"],["巨奖","鉅獎"],["巨奸","鉅奸"],["巨子","鉅子"],["巨富","鉅富"],["巨款","鉅款"],["巨献","鉅獻"],["巨祥","鉅祥"],["巨细","鉅細"],["巨脾症","巨脾症"],["巨舰","鉅艦"],["巨著","鉅著"],["巨贪","鉅貪"],["巨野","鉅野"],["巨额","鉅額"],["巨鹿","鉅鹿"],["巨黍","鉅黍"],["巫咸","巫咸"],["巫山云雨","巫山雲雨"],["巫术","巫術"],["差之千里","差之千里"],["差之毫厘","差之毫釐"],["差于","差於"],["差以毫厘","差以毫釐"],["差价","差價"],["差别","差別"],["差别待遇","差別待遇"],["差别费率","差別費率"],["差发","差發"],["差多了","差多了"],["差恶","差惡"],["差若豪厘","差若豪釐"],["己丑","己丑"],["己出","己出"],["己所不欲","己所不欲"],["己饥己溺","己飢己溺"],["已于","已於"],["已作出保","已作出保"],["已占","已佔"],["已占卜","已占卜"],["已占算","已占算"],["已对于","已對於"],["已扣","已扣"],["已极","已極"],["已系","已係"],["巴人下里","巴人下里"],["巴克","巴克"],["巴克利","巴克利"],["巴克南德","巴克南德"],["巴克夏猪","巴克夏豬"],["巴克礼","巴克禮"],["巴克科思","巴克科思"],["巴克莱","巴克萊"],["巴克莱银行","巴克萊銀行"],["巴克雷","巴克雷"],["巴克霍兹","巴克霍茲"],["巴别塔","巴別塔"],["巴前算后","巴前算後"],["巴厘岛","巴厘島"],["巴尔克嫩德","巴爾克嫩德"],["巴尔干","巴爾幹"],["巴尔干半岛","巴爾幹半島"],["巴尔干山","巴爾幹山"],["巴尔干山脉","巴爾幹山脈"],["巴尔扎克","巴爾扎克"],["巴尔札克","巴爾札克"],["巴尔舍夫斯基","巴爾舍夫斯基"],["巴尔贝里尼宫殿","巴爾貝里尼宮殿"],["巴尔赞","巴爾贊"],["巴尔陶克","巴爾陶克"],["巴尖儿好胜","巴尖兒好勝"],["巴布","巴布"],["巴布亚","巴布亞"],["巴布亚新几内亚","巴布亞新幾內亞"],["巴布亚省","巴布亞省"],["巴布亚纽","巴布亞紐"],["巴布亚纽几內亚","巴布亞紐幾內亞"],["巴布亚纽几内亚","巴布亞紐幾內亞"],["巴布尔","巴布爾"],["巴布延群岛","巴布延羣島"],["巴布拉族","巴布拉族"],["巴布狄伦","巴布狄倫"],["巴托丽","巴托麗"],["巴托莉","巴托莉"],["巴拉克","巴拉克"],["巴拉松","巴拉松"],["巴控克什米尔","巴控克什米爾"],["巴斗","巴斗"],["巴斯克","巴斯克"],["巴斯克人","巴斯克人"],["巴斯克语","巴斯克語"],["巴斯德菌症","巴斯德菌症"],["巴斯特纳克","巴斯特納克"],["巴松管","巴松管"],["巴比合金","巴比合金"],["巴比布朗","巴比布朗"],["巴比特合金","巴比特合金"],["巴氏杆菌","巴氏桿菌"],["巴洛克","巴洛克"],["巴洛克式","巴洛克式"],["巴洛克艺术","巴洛克藝術"],["巴洛克风格","巴洛克風格"],["巴洛马天文台","巴洛馬天文臺"],["巴游","巴游"],["巴瑞克","巴瑞克"],["巴罗克","巴羅克"],["巴胡提","巴胡提"],["巴舍莱","巴舍萊"],["巴贝克","巴貝克"],["巴贝西亚原虫病","巴貝西亞原蟲病"],["巴里","巴里"],["巴里坤","巴里坤"],["巴里坤县","巴裏坤縣"],["巴里坤哈萨克自治县","巴裏坤哈薩克自治縣"],["巴里坤草原","巴裏坤草原"],["巴里岛","巴里島"],["巴里库廷火山","巴里庫廷火山"],["巴里斯","巴里斯"],["巴金森氏症","巴金森氏症"],["巴音布克草原","巴音布克草原"],["巴马干酪","巴馬乾酪"],["巷里","巷裏"],["巾帼须眉","巾幗鬚眉"],["币别","幣別"],["币制","幣制"],["市不二价","市不二價"],["市不豫价","市不豫價"],["市价","市價"],["市党部","市黨部"],["市制","市制"],["市占","市佔"],["市占率","市佔率"],["市地重划","市地重劃"],["市场价","市場價"],["市场价格","市場價格"],["市场准入","市場準入"],["市场占有率","市場佔有率"],["市无二价","市無二價"],["市里","市裏"],["市长杯","市長盃"],["市面","市面"],["市面上","市面上"],["布一个","佈一個"],["布丁","布丁"],["布下","佈下"],["布丹","布丹"],["布于","佈於"],["布什","布什"],["布什尔","布什爾"],["布什尔省","布什爾省"],["布仑特","布侖特"],["布会","佈會"],["布伞","布傘"],["布伦","布倫"],["布伦尼","布倫尼"],["布伦托海","布倫托海"],["布伦森","布倫森"],["布伦特","布倫特"],["布佳迪","布佳迪"],["布依","布依"],["布依族","布依族"],["布偶","布偶"],["布偶戏","布偶戲"],["布克","布克"],["布克奖","布克獎"],["布兰","布蘭"],["布兰克","布蘭克"],["布兰妮","布蘭妮"],["布兰妮斯皮尔斯","布蘭妮斯皮爾斯"],["布兰德","布蘭德"],["布兰枯秀","布蘭枯秀"],["布兰森","布蘭森"],["布兰特","布蘭特"],["布兰琪","布蘭琪"],["布兰登堡","布蘭登堡"],["布兰登堡门","布蘭登堡門"],["布农","布農"],["布农族","布農族"],["布冯","布馮"],["布划","佈劃"],["布列","佈列"],["布列兹涅","布列茲涅"],["布列兹涅夫","布列茲涅夫"],["布列兹涅夫主义","布列茲涅夫主義"],["布列塔尼","布列塔尼"],["布利吉","布利吉"],["布利斯班","布利斯班"],["布利斯班市","布利斯班市"],["布加勒斯条约","布加勒斯條約"],["布加勒斯特","布加勒斯特"],["布劳恩","布勞恩"],["布势","佈勢"],["布勒斯特","布勒斯特"],["布包","布包"],["布匹","布匹"],["布匿战争","布匿戰爭"],["布卡拉","布卡拉"],["布叶","布葉"],["布合","布合"],["布吉河","布吉河"],["布吉纳法索","布吉納法索"],["布告","佈告"],["布告栏","布告欄"],["布告牌","布告牌"],["布哈拉","布哈拉"],["布哈林","布哈林"],["布哈林模式","布哈林模式"],["布哨","佈哨"],["布喀河","布喀河"],["布囊","布囊"],["布囊其口","佈囊其口"],["布坎南","布坎南"],["布基纳法索","布基納法索"],["布复","布覆"],["布头","布頭"],["布奇","布奇"],["布娃娃","布娃娃"],["布婚","布婚"],["布宁","布寧"],["布宜若","布宜若"],["布宜诺","布宜諾"],["布宜诺斯艾利斯","布宜諾斯艾利斯"],["布宪","布憲"],["布尔","布爾"],["布尔乔亚","布爾喬亞"],["布尔什维克","布爾什維克"],["布尔代数","布爾代數"],["布尔兹","布爾茲"],["布尔哥尼","布爾哥尼"],["布尔津","布爾津"],["布尔津县","布爾津縣"],["布尔省","布爾省"],["布尔诺","布爾諾"],["布尼亚病毒","布尼亞病毒"],["布局","佈局"],["布岗","佈崗"],["布巾","布巾"],["布布","布布"],["布帆","布帆"],["布帆无恙","布帆無恙"],["布希","布希"],["布希号","布希號"],["布希威克","布希威克"],["布希总统","布希總統"],["布希曼","布希曼"],["布帘","布簾"],["布帛","布帛"],["布帛菽粟","布帛菽粟"],["布幔","布幔"],["布幕","布幕"],["布干维尔","布干維爾"],["布干维尔岛","布干維爾島"],["布庄","布莊"],["布店","布店"],["布德","佈德"],["布德尔","布德爾"],["布德施仁","布德施仁"],["布德施惠","布德施惠"],["布慈","佈慈"],["布托","布托"],["布扣","佈扣"],["布拉","布拉"],["布拉克","布拉克"],["布拉加队","布拉加隊"],["布拉吉","布拉吉"],["布拉姆兹","布拉姆茲"],["布拉姆斯","布拉姆斯"],["布拉席耶利","布拉席耶利"],["布拉德","布拉德"],["布拉恰诺","布拉恰諾"],["布拉曼德","布拉曼德"],["布拉柴维尔","布拉柴維爾"],["布拉格","布拉格"],["布拉格定律","布拉格定律"],["布拉格队","布拉格隊"],["布拉欣","布拉欣"],["布拉索夫","布拉索夫"],["布拉萨市","布拉薩市"],["布拉谢","布拉謝"],["布拉迪斯拉发","布拉迪斯拉發"],["布拉马普得拉河","布拉馬普得拉河"],["布拖","布拖"],["布拖县","布拖縣"],["布招儿","布招兒"],["布掸子","布撣子"],["布摆","佈擺"],["布政","佈政"],["布政使","布政使"],["布政司","布政司"],["布教","佈教"],["布散","佈散"],["布料","布料"],["布施","佈施"],["布景","佈景"],["布朗","布朗"],["布朗克士","布朗克士"],["布朗克斯","布朗克斯"],["布朗士","布朗士"],["布朗夏","布朗夏"],["布朗大学","布朗大學"],["布朗妮","布朗妮"],["布朗宁","布朗寧"],["布朗德","布朗德"],["布朗族","布朗族"],["布朗森","布朗森"],["布朗特","布朗特"],["布朗贝克","布朗貝克"],["布朗费德","布朗費德"],["布朗运动","布朗運動"],["布望","布望"],["布条","布條"],["布来德史崔","布來德史崔"],["布林","布林"],["布林代数","布林代數"],["布林底希","布林底希"],["布林迪西","布林迪西"],["布格河","布格河"],["布桩","布樁"],["布梏","布梏"],["布氏杆菌","布氏桿菌"],["布氏杆菌病","布氏桿菌病"],["布氏菌苗","布氏菌苗"],["布氏非鲫","布氏非鯽"],["布气","布氣"],["布水","布水"],["布法罗","布法羅"],["布洒器","布灑器"],["布洛克","布洛克"],["布洛斯顿","布洛斯頓"],["布洛沙德","布洛沙德"],["布洛湾","布洛灣"],["布洛芬","布洛芬"],["布满","佈滿"],["布濩","布濩"],["布热津斯基","布熱津斯基"],["布特","布特"],["布特哈","布特哈"],["布特拉加亚","布特拉加亞"],["布班尼斯瓦","布班尼斯瓦"],["布琼布拉","布瓊布拉"],["布瑞","布瑞"],["布瑞尤","布瑞尤"],["布瑞斯特","布瑞斯特"],["布瑞特","布瑞特"],["布瑞顿","布瑞頓"],["布用填","布用填"],["布疋","布疋"],["布疑阵","佈疑陣"],["布痕瓦尔德","布痕瓦爾德"],["布白","布白"],["布立吞族","布立吞族"],["布算","布算"],["布篷","布篷"],["布素","布素"],["布累尔","布累爾"],["布纶堡","布綸堡"],["布纹纸","布紋紙"],["布线","佈線"],["布维岛","布維島"],["布缦","布縵"],["布网","佈網"],["布罗德赫斯特","布羅德赫斯特"],["布罗温斯文学","布羅溫斯文學"],["布罗迪","布羅迪"],["布置","佈置"],["布署","佈署"],["布耳","布耳"],["布胡会","布胡會"],["布臆","布臆"],["布色","布色"],["布荆","布荊"],["布草衣服","布草衣服"],["布莱","布萊"],["布莱克","布萊克"],["布莱克史密斯","布萊克史密斯"],["布莱克曼","布萊克曼"],["布莱克本","布萊克本"],["布莱尔","布萊爾"],["布莱尼","布萊尼"],["布莱希特","布萊希特"],["布莱德","布萊德"],["布莱德利","布萊德利"],["布莱德彼特","布萊德彼特"],["布莱德福","布萊德福"],["布莱德雷","布萊德雷"],["布莱恩","布萊恩"],["布莱恩特","布萊恩特"],["布莱恩狄帕玛","布萊恩狄帕瑪"],["布莱特","布萊特"],["布莱特妮墨菲","布萊特妮墨菲"],["布莱雅特蒙古","布萊雅特蒙古"],["布莱顿","布萊頓"],["布菜","佈菜"],["布萨","布薩"],["布衣","布衣"],["布衣之交","布衣之交"],["布衣之怒","布衣之怒"],["布衣交","布衣交"],["布衣卿相","布衣卿相"],["布衣小民","布衣小民"],["布衣粝食","布衣糲食"],["布衣苇带","布衣葦帶"],["布衣蔬食","布衣蔬食"],["布衣韦带","布衣韋帶"],["布衣黔首","布衣黔首"],["布衫","布衫"],["布袋","布袋"],["布袋和尚","布袋和尚"],["布袋安","布袋安"],["布袋戏","布袋戲"],["布袋戏偶","布袋戲偶"],["布袋戏馆","布袋戲館"],["布袋港","布袋港"],["布袋莲","布袋蓮"],["布袋装","布袋裝"],["布袋镇","布袋鎮"],["布袜青鞋","布襪青鞋"],["布被","布被"],["布被十年","布被十年"],["布裙荆钗","布裙荊釵"],["布褐","布褐"],["布西县","布西縣"],["布让","佈讓"],["布设","佈設"],["布谷","布穀"],["布谷鸟","布穀鳥"],["布谷鸟钟","布穀鳥鐘"],["布货","布貨"],["布边","布邊"],["布达","布達"],["布达佩斯","布達佩斯"],["布达式","布達式"],["布达拉宫","布達拉宮"],["布达拉寺","布達拉寺"],["布达拉山","布達拉山"],["布迪亚","布迪亞"],["布道","佈道"],["布道大会","佈道大會"],["布道所","佈道所"],["布那喀","布那喀"],["布里","布里"],["布里亚族","布里亞族"],["布里兹涅夫","布里茲涅夫"],["布里坦尼","布里坦尼"],["布里奇顿","布里奇頓"],["布里姬沃特","布里姬沃特"],["布里斯","布里斯"],["布里斯托","布里斯托"],["布里斯托尔","布裏斯托爾"],["布里斯托尔海峡","布里斯托爾海峽"],["布里斯本","布里斯本"],["布里斯本市","布里斯本市"],["布里斯本河","布里斯本河"],["布里斯班","布里斯班"],["布里迪雅","布里迪雅"],["布里迪雅通","布里迪雅通"],["布防","佈防"],["布防迎战","布防迎戰"],["布阵","佈陣"],["布阵安营","佈陣安營"],["布隆伯格","布隆伯格"],["布隆克特","布隆克特"],["布隆吉尔河","布隆吉爾河"],["布隆方丹","布隆方丹"],["布隆迪","布隆迪"],["布雅湾","布雅灣"],["布雪","佈雪"],["布雷","佈雷"],["布雷克","布雷克"],["布雷克磨","布雷克磨"],["布雷封锁","佈雷封鎖"],["布雷尔","布雷爾"],["布雷尔港","布雷爾港"],["布雷希特","布雷希特"],["布雷恩","布雷恩"],["布雷拉","布雷拉"],["布雷的","佈雷的"],["布雷舰","佈雷艦"],["布雷艇","佈雷艇"],["布雷蒙","布雷蒙"],["布雷迪","布雷迪"],["布雷速度","佈雷速度"],["布雷队","佈雷隊"],["布雷顿","布雷頓"],["布雷顿森林","佈雷頓森林"],["布雷默","布雷默"],["布面","布面"],["布面相片","布面相片"],["布鞋","布鞋"],["布须曼人","布須曼人"],["布马雪","布馬雪"],["布鲁","布魯"],["布鲁乐谷","布魯樂谷"],["布鲁克","布魯克"],["布鲁克斯","布魯克斯"],["布鲁克林","布魯克林"],["布鲁克林大桥","布魯克林大橋"],["布鲁克纳","布魯克納"],["布鲁克雪德丝","布魯克雪德絲"],["布鲁勒","布魯勒"],["布鲁塞尔","布魯塞爾"],["布鲁奈勒斯基","布魯奈勒斯基"],["布鲁姆费尔德","布魯姆費爾德"],["布鲁尼","布魯尼"],["布鲁托","布魯托"],["布鲁斯","布魯斯"],["布鲁斯史普林斯汀","布魯斯史普林斯汀"],["布鲁斯威利","布魯斯威利"],["布鲁斯特","布魯斯特"],["布鲁日","布魯日"],["布鲁氏菌","布魯氏菌"],["布鲁氏菌病","布魯氏菌病"],["布鲁珊","布魯珊"],["布鲁诺","布魯諾"],["布鲁金斯","布魯金斯"],["布鼓雷门","布鼓雷門"],["帅呆了","帥呆了"],["帆布","帆布"],["帆布包","帆布包"],["帆布椅","帆布椅"],["帆布牀","帆布牀"],["帆布袋","帆布袋"],["帆布鞋","帆布鞋"],["帆板","帆板"],["师云而云","師云而云"],["师出无名","師出無名"],["师出有名","師出有名"],["师团","師團"],["师娘","師孃"],["师徒合同","師徒合同"],["师杯","師杯"],["师生杯","師生盃"],["师范","師範"],["师范大学","師範大學"],["师范学校","師範學校"],["师范学院","師範學院"],["师范教育","師範教育"],["师范毕业","師範畢業"],["师范生","師範生"],["师范类","師範類"],["师范附小","師範附小"],["师范院校","師範院校"],["师表","師表"],["希伯来历","希伯來曆"],["希伯来历史","希伯來歷史"],["希克斯","希克斯"],["希区考克","希區考克"],["希布伦市","希布倫市"],["希拉克","希拉剋"],["希拉里","希拉里"],["希拉里克林顿","希拉裏克林頓"],["希斯仑","希斯崙"],["希斯莱杰","希斯萊傑"],["希斯雷杰","希斯雷傑"],["希格斯机制","希格斯機制"],["希腊建筑","希臘建築"],["帐面","帳面"],["帕丝齐克","帕絲齊克"],["帕修斯","帕修斯"],["帕克","帕克"],["帕台农","帕臺農"],["帕台农神庙","帕臺農神廟"],["帕拉马里博","帕拉馬裏博"],["帕特里克","帕特里克"],["帕特里夏","帕特里夏"],["帕穆克","帕穆克"],["帕索里尼","帕索里尼"],["帕累托最优","帕累托最優"],["帕累托法则","帕累托法則"],["帕罗贝克","帕羅貝克"],["帕谢克","帕謝克"],["帕金森氏症","帕金森氏症"],["帕金森症","帕金森症"],["帘子","簾子"],["帘子布","簾子布"],["帘子线","簾子線"],["帘官","簾官"],["帘布","簾布"],["帘帐","簾帳"],["帘帷","簾帷"],["帘幔","簾幔"],["帘幕","簾幕"],["帘幕式","簾幕式"],["帘幽梦","簾幽夢"],["帘栊","簾櫳"],["帘波","簾波"],["帝制","帝制"],["帝制时代","帝制時代"],["帝后","帝后"],["帝胄","帝胄"],["带丑闻","帶醜聞"],["带个","帶個"],["带个好","帶個好"],["带了","帶了"],["带凶","帶凶"],["带出","帶出"],["带出去","帶出去"],["带出来","帶出來"],["带发修行","帶髮修行"],["带同","帶同"],["带回","帶回"],["带回到","帶回到"],["带回去","帶回去"],["带回来","帶回來"],["带团","帶團"],["带团参加","帶團參加"],["带征","帶徵"],["带征银","帶徵銀"],["带扣","帶扣"],["带罪征收","帶罪徵收"],["带膆貂挂","帶膆貂掛"],["席丰履厚","席豐履厚"],["席卷","席捲"],["席卷一空","席捲一空"],["席卷亚洲","席捲亞洲"],["席卷天下","席捲天下"],["席卷而来","席捲而來"],["席卷而逃","席捲而逃"],["席哈克","席哈克"],["席志成","席誌成"],["席棚","蓆棚"],["席湘漓","席湘漓"],["席胜","席勝"],["席面","席面"],["帮不了","幫不了"],["帮个场子","幫個場子"],["帮伙","幫夥"],["帮佣","幫傭"],["帮冬","幫冬"],["帮凶","幫兇"],["帮别","幫別"],["帮懒钻闲","幫懶鑽閒"],["帮闲钻懒","幫閒鑽懶"],["帷薄不修","帷薄不修"],["常价","常價"],["常任代表","常任代表"],["常向","常向"],["常回","常回"],["常回去","常回去"],["常回来","常回來"],["常态分布","常態分佈"],["常用参考书","常用參考書"],["常绿阔叶","常綠闊葉"],["常绿阔叶林","常綠闊葉林"],["常胜","常勝"],["常胜军","常勝軍"],["常胜家","常勝家"],["常胜将军","常勝將軍"],["常衡制","常衡制"],["常见于","常見於"],["常须","常須"],["帽帘","帽簾"],["幅面","幅面"],["幕前幕后","幕前幕後"],["幕后","幕後"],["幕后人物","幕後人物"],["幕后新闻","幕後新聞"],["幕后消息","幕後消息"],["幕后花絮","幕後花絮"],["幕后英雄","幕後英雄"],["幕布","幕布"],["幡布","幡布"],["干一","幹一"],["干一坛","乾一罈"],["干一坛法","幹一壇法"],["干一杯","乾一杯"],["干一碗","乾一碗"],["干上","幹上"],["干下去","幹下去"],["干不","幹不"],["干不下","幹不下"],["干不了","幹不了"],["干不干","幹不幹"],["干不干净","乾不乾淨"],["干不干杯","乾不乾杯"],["干不成","幹不成"],["干与","干與"],["干丝","乾絲"],["干两年","幹兩年"],["干两杯","乾兩杯"],["干个","幹個"],["干个够","幹個夠"],["干么","幹麼"],["干乔","乾喬"],["干买卖","幹買賣"],["干了","幹了","乾了"],["干了杯","乾了杯"],["干了这一杯","乾了這一杯"],["干了这一瓶","乾了這一瓶"],["干了这杯","乾了這杯"],["干了这碗","乾了這碗"],["干事","幹事"],["干事会","幹事會"],["干事长","幹事長"],["干云蔽日","乾雲蔽日"],["干井","乾井"],["干些","幹些"],["干产","乾產"],["干亲","乾親"],["干人","幹人"],["干什","幹什"],["干什么","幹什麼"],["干他","幹他","干他"],["干仗","幹仗"],["干任何","幹任何"],["干休","干休"],["干休所","幹休所"],["干伸舌","乾伸舌"],["干何事","幹何事"],["干你","幹你","干你"],["干你娘","幹你孃"],["干傻事","幹傻事"],["干儿","乾兒"],["干儿子","乾兒子"],["干冒烟","乾冒煙"],["干农活","幹農活"],["干冰","乾冰"],["干冷","乾冷"],["干净","乾淨"],["干净俐落","乾淨俐落"],["干凉","乾涼"],["干几件","幹幾件"],["干几宗","幹幾宗"],["干几手","乾幾手"],["干几杯","乾幾杯"],["干几桩","幹幾樁"],["干几番","幹幾番"],["干几碗","乾幾碗"],["干几辈","幹幾輩"],["干凯文","干凱文"],["干出","幹出"],["干刍","乾芻"],["干別的","幹別的"],["干到","幹到"],["干制","乾製"],["干刻版","乾刻版"],["干剥剥","乾剝剝"],["干办","幹辦"],["干劲","幹勁"],["干劲儿","幹勁兒"],["干劲冲天","幹勁沖天"],["干劲十足","幹勁十足"],["干卦","乾卦"],["干卿何事","干卿何事"],["干卿底事","干卿底事"],["干又热","乾又熱"],["干台","乾颱"],["干号","乾號"],["干吊着下巴","乾吊着下巴"],["干吏","幹吏"],["干吗","幹嗎"],["干呕","乾嘔"],["干员","幹員"],["干和","乾和"],["干咳","乾咳"],["干咽","乾嚥"],["干咽唾","乾嚥唾"],["干哑","乾啞"],["干哕","乾噦"],["干哥","乾哥"],["干哥哥","乾哥哥"],["干哭","乾哭"],["干唱","乾唱"],["干啤","乾啤"],["干啥","幹啥"],["干啼","乾啼"],["干啼湿哭","乾啼溼哭"],["干嘛","幹嘛"],["干嚎","乾嚎"],["干回付","乾回付"],["干图","乾圖"],["干圆洁净","乾圓潔淨"],["干土","乾土"],["干地","乾地"],["干坏事","幹壞事"],["干坐着","乾坐着"],["干坛子","乾罈子"],["干坞","乾塢"],["干城","干城"],["干堂婶","乾堂嬸"],["干大事","幹大事"],["干头","幹頭"],["干女","乾女"],["干女儿","乾女兒"],["干女友","幹女友"],["干女同事","幹女同事"],["干女婿","乾女婿"],["干女教师","幹女教師"],["干奴才","乾奴才"],["干她","幹她","干她"],["干好","幹好"],["干妈","乾媽"],["干妹","乾妹"],["干妹妹","乾妹妹"],["干姊","乾姊"],["干姊姊","乾姊姊"],["干姐","乾姐"],["干姜","乾薑"],["干姬松茸","乾姬松茸"],["干娘","乾孃"],["干子","乾子"],["干季","乾季"],["干宅","乾宅"],["干完","幹完"],["干家","幹家"],["干将","干將"],["干将莫邪","干將莫邪"],["干就干","幹就幹"],["干尸","乾屍"],["干尽","幹盡"],["干尽一坛","乾盡一罈"],["干尽一壺","乾盡一壺"],["干尽一杯","乾盡一杯"],["干尽一碗","乾盡一碗"],["干屎橛","乾屎橛"],["干巴","乾巴"],["干巴巴","乾巴巴"],["干巴巴的","乾巴巴的"],["干布","乾布"],["干干","乾乾"],["干干儿的","乾乾兒的"],["干干净净","乾乾淨淨"],["干干巴巴","乾乾巴巴"],["干干干干","幹幹幹幹"],["干干淨淨","乾乾淨淨"],["干干爽爽","乾乾爽爽"],["干干瘦瘦","乾乾瘦瘦"],["干干的","乾乾的"],["干干脆脆","乾乾脆脆"],["干式","乾式"],["干弟","乾弟"],["干弟弟","乾弟弟"],["干强盗","幹強盜"],["干当","幹當"],["干得","幹得"],["干得一杯","乾得一杯"],["干得三杯","乾得三杯"],["干得两杯","乾得兩杯"],["干得了","幹得了"],["干得很","乾得很"],["干急","乾急"],["干性","乾性"],["干性油","乾性油"],["干性皮肤","乾性皮膚"],["干戈","干戈"],["干戈扰攘","干戈擾攘"],["干成","幹成"],["干我","幹我","干我"],["干戚","干鏚"],["干扁豆角","干扁豆角"],["干手净脚","乾手淨腳"],["干才","幹才"],["干打垒","乾打壘"],["干打雷","乾打雷"],["干扰","干擾"],["干扰到","干擾到"],["干扰力","干擾力"],["干扰素","干擾素"],["干折","乾折"],["干拎娘","幹拎娘"],["干挠","干撓"],["干掉","幹掉"],["干掉一杯","乾掉一杯"],["干掉一瓶","乾掉一瓶"],["干掉一碗","乾掉一碗"],["干掉这杯","乾掉這杯"],["干掉这碗","乾掉這碗"],["干掉那杯","乾掉那杯"],["干掉那碗","乾掉那碗"],["干探","幹探"],["干撂台","乾撂臺"],["干撇下","乾撇下"],["干擦","乾擦"],["干支","干支"],["干支剌","乾支剌"],["干支支","乾支支"],["干支沟","干支溝"],["干政","干政"],["干数杯","乾數杯"],["干料","乾料"],["干断","乾斷"],["干旦","乾旦"],["干旱","乾旱"],["干旱地区","乾旱地區"],["干时","干時"],["干暖","乾暖"],["干曜","乾曜"],["干材","乾材"],["干村沙","乾村沙"],["干杯","乾杯"],["干果","乾果"],["干枝","乾枝"],["干枯","乾枯"],["干架","幹架"],["干柴","乾柴"],["干柴烈火","乾柴烈火"],["干校","幹校"],["干梅","乾梅"],["干梅子","乾梅子"],["干正事","幹正事"],["干此坛","乾此罈"],["干此杯","乾此杯"],["干死","乾死"],["干毛巾","乾毛巾"],["干池","乾池"],["干沟","乾溝"],["干没","乾沒"],["干洗","乾洗"],["干洗店","乾洗店"],["干活","幹活"],["干活儿","幹活兒"],["干流","幹流"],["干济","幹濟"],["干涉","干涉"],["干涉仪","干涉儀"],["干涉现象","干涉現象"],["干涩","乾澀"],["干涸","乾涸"],["干淨","乾淨"],["干淨俐落","乾淨俐落"],["干渠","乾渠"],["干渴","乾渴"],["干湿","乾溼"],["干湿发","乾溼髮"],["干漆","乾漆"],["干灯盏","乾燈盞"],["干点","乾點","幹點"],["干烧","乾燒"],["干热","乾熱"],["干焦","乾焦"],["干煸","乾煸"],["干熬","乾熬"],["干熱","乾熱"],["干燥","乾燥"],["干燥剂","乾燥劑"],["干燥器","乾燥器"],["干燥机","乾燥機"],["干燥箱","乾燥箱"],["干父之蛊","幹父之蠱"],["干爸","乾爸"],["干爸爸","乾爸爸"],["干爹","乾爹"],["干爽","乾爽"],["干片","乾片"],["干犯","干犯"],["干犯法","幹犯法"],["干球温度","乾球溫度"],["干甚","幹甚"],["干甚么","幹甚麼"],["干生受","乾生受"],["干生子","乾生子"],["干生气","乾生氣"],["干田","乾田"],["干电","乾電"],["干电池","乾電池"],["干略","幹略"],["干疥","乾疥"],["干瘦","乾瘦"],["干瘪","乾癟"],["干瘪瘪","乾癟癟"],["干瘾","乾癮"],["干癣","乾癬"],["干癣性","乾癬性"],["干白","乾白"],["干白儿","乾白兒"],["干的","乾的"],["干的停当","幹的停當"],["干眼","乾眼"],["干眼病","乾眼病"],["干眼症","乾眼症"],["干着","幹着","乾着"],["干着急","乾着急"],["干瞪眼","乾瞪眼"],["干硬","乾硬"],["干碍","干礙"],["干礼","乾禮"],["干稿","乾稿"],["干站着","乾站着"],["干笑","乾笑"],["干等","乾等"],["干管","幹管"],["干篾片","乾篾片"],["干粉","乾粉"],["干粗活","幹粗活"],["干粮","乾糧"],["干粮袋","乾糧袋"],["干糇","乾餱"],["干系","干係"],["干細胞","幹細胞"],["干红","乾紅"],["干纲","乾綱"],["干纲不振","乾綱不振"],["干线","幹線"],["干练","幹練"],["干细胞","幹細胞"],["干结","乾結"],["干绷","乾繃"],["干绷儿","乾繃兒"],["干缺","幹缺"],["干群","幹羣"],["干群关系","幹羣關係"],["干耗","乾耗"],["干肉","乾肉"],["干肉片","乾肉片"],["干股","乾股"],["干肥","乾肥"],["干脆","乾脆"],["干脆利落","乾脆利落"],["干花","乾花"],["干苔","乾薹"],["干茨腊","乾茨臘"],["干茶钱","乾茶錢"],["干草","乾草"],["干草叉","乾草叉"],["干草堆","乾草堆"],["干草机","乾草機"],["干草粉","乾草粉"],["干菜","乾菜"],["干营生","幹營生"],["干落","乾落"],["干薪","乾薪"],["干虔","乾虔"],["干蛊","幹蠱"],["干血浆","乾血漿"],["干衣","乾衣"],["干衣机","乾衣機"],["干裂","乾裂"],["干警","幹警"],["干谒","干謁"],["干象","乾象"],["干贝","乾貝"],["干货","乾貨"],["干起","幹起"],["干起来","幹起來"],["干路","幹路"],["干躁","乾躁"],["干过","幹過"],["干过一杯","乾過一杯"],["干过杯","乾過杯"],["干过瘾","乾過癮"],["干这","幹這"],["干这一杯","乾這一杯"],["干这一行","幹這一行"],["干这杯","乾這杯"],["干这种事","幹這種事"],["干连","干連"],["干透","乾透"],["干造","乾造"],["干逼","乾逼"],["干道","幹道"],["干邑","干邑"],["干那","幹那"],["干那一杯","乾那一杯"],["干那杯","乾那杯"],["干部","幹部"],["干酪","乾酪"],["干酵母","乾酵母"],["干醋","乾醋"],["干重","乾重"],["干量","乾量"],["干闼婆","乾闥婆"],["干阿奶","乾阿奶"],["干雷","乾雷"],["干霍乱","乾霍亂"],["干面","乾麪"],["干革命","幹革命"],["干预","干預"],["干颡","乾顙"],["干饭","乾飯"],["干馆","乾館"],["干馏","乾餾"],["干馏法","乾餾法"],["干鱼","乾魚"],["干鲜","乾鮮"],["干麻","幹麻"],["干麻学","幹麻學"],["干麻阿","幹麻阿"],["平个","平個"],["平个人","平個人"],["平了","平了"],["平价","平價"],["平价住宅","平價住宅"],["平价供应中心","平價供應中心"],["平价商店","平價商店"],["平克佛洛伊德","平克佛洛伊德"],["平准","平準"],["平准基金","平準基金"],["平分秋色","平分秋色"],["平台","平臺"],["平台式扫描器","平臺式掃描器"],["平台数","平臺數"],["平台阶段","平臺階段"],["平地上起一个霹雳","平地上起一個霹靂"],["平地松林","平地松林"],["平地楼台","平地樓臺"],["平地青云","平地青雲"],["平均价","平均價"],["平均消费倾向","平均消費傾向"],["平均股价","平均股價"],["平复","平復"],["平复帖","平復帖"],["平复起来","平復起來"],["平头并进","平頭並進"],["平安里","平安裏"],["平定准噶尔回部得胜图","平定準噶爾回部得勝圖"],["平平当当","平平當當"],["平康里","平康里"],["平方公里","平方公里"],["平方千米","平方千米"],["平易谦冲","平易謙沖"],["平板","平板"],["平板仪","平板儀"],["平板玻璃","平板玻璃"],["平板车","平板車"],["平梁","平梁"],["平步青云","平步青雲"],["平泉庄","平泉莊"],["平胡","平胡"],["平行六面","平行六面"],["平行六面体","平行六面體"],["平行叶脉","平行葉脈"],["平行表亲","平行表親"],["平衡台","平衡臺"],["平表","平表"],["平谷","平谷"],["平谷区","平谷區"],["平谷县","平谷縣"],["平足症","平足症"],["平针缝","平針縫"],["平铲","平鏟"],["平雕","平雕"],["平面","平面"],["平面几何","平面幾何"],["平面图","平面圖"],["平面图形","平面圖形"],["平面媒体","平面媒體"],["平面描迹","平面描跡"],["平面曲线","平面曲線"],["平面段","平面段"],["平面波","平面波"],["平面测量","平面測量"],["平面艺术","平面藝術"],["平面角","平面角"],["平面镜","平面鏡"],["平面雕刻","平面雕刻"],["年久失修","年久失修"],["年代里","年代裏"],["年余","年餘"],["年几","年幾"],["年历","年曆"],["年台","年臺"],["年同","年同"],["年后","年後"],["年团子","年團子"],["年复一年","年復一年"],["年少得志","年少得志"],["年德并高","年德並高"],["年表","年表"],["年谷","年穀"],["年里","年裏"],["年金制度","年金制度"],["年鉴","年鑑"],["年龄特征","年齡特徵"],["并一不二","併一不二"],["并上","並上"],["并不","並不"],["并不会","並不會"],["并不在","並不在"],["并不在乎","並不在乎"],["并不并","併不併"],["并不是","並不是"],["并不能","並不能"],["并与","並與"],["并且","並且"],["并世","並世"],["并世无双","並世無雙"],["并为","併爲"],["并举","並舉"],["并于","並於"],["并产","併產"],["并介之人","並介之人"],["并先","並先"],["并入","併入"],["并兴","並興"],["并兼","併兼"],["并再","並再"],["并出","並出"],["并刀","並刀"],["并列","並列"],["并到","併到"],["并力","併力"],["并包","幷包"],["并卷机","併捲機"],["并发","併發"],["并发动","並發動"],["并发展","並發展"],["并发现","並發現"],["并发症","併發症"],["并发表","並發表"],["并叠","併疊"],["并口","並口"],["并可","並可"],["并可以","並可以"],["并合","併合"],["并同","並同"],["并名","併名"],["并吞","併吞"],["并吞下","併吞下"],["并回","並回"],["并回去","並回去"],["并回来","並回來"],["并在","並在"],["并坐","並坐"],["并垂不朽","並垂不朽"],["并处","並處"],["并头","並頭"],["并头之花","並頭之花"],["并头莲","並頭蓮"],["并存","並存"],["并存不悖","並存不悖"],["并存在","並存在"],["并寿","並壽"],["并将","並將"],["并州","幷州"],["并州剪","幷州剪"],["并州故乡","幷州故鄉"],["并当","並當"],["并往","並往"],["并得","並得"],["并成","併成"],["并把","並把"],["并拢","併攏"],["并排","並排"],["并排而坐","並排而坐"],["并无","並無"],["并无不可","並無不可"],["并无不当","並無不當"],["并无此事","並無此事"],["并日","並日"],["并日而食","並日而食"],["并时","並時"],["并是","並是"],["并曰入淀","並曰入澱"],["并有","並有"],["并未","並未"],["并条","並條"],["并案","併案"],["并案处理","併案處理"],["并概青云","並概青雲"],["并毂","並轂"],["并没","並沒"],["并没有","並沒有"],["并派","並派"],["并流","並流","併流"],["并激","並激"],["并火","併火"],["并然","並然"],["并爲","並爲"],["并用","並用"],["并由","並由"],["并禽","並禽"],["并科","併科"],["并称","並稱"],["并立","並立"],["并纱","併紗"],["并线","併線"],["并网","併網"],["并置","並置"],["并翼齐飞","並翼齊飛"],["并联","並聯"],["并肩","並肩"],["并肩作战","並肩作戰"],["并肩前进","並肩前進"],["并肩子","併肩子"],["并肩干","並肩幹"],["并肩而行","並肩而行"],["并能","並能"],["并能夠","並能夠"],["并蒂","並蒂"],["并蒂莲","並蒂蓮"],["并行","並行"],["并行不悖","並行不悖"],["并行口","並行口"],["并行程序","並行程序"],["并行计算","並行計算"],["并要","並要"],["并规范","並規範"],["并论","並論"],["并请","並請"],["并购","併購"],["并购买","併購買"],["并购案","併購案"],["并赃拿败","並贓拿敗"],["并赃拿贼","併贓拿賊"],["并赃治罪","併贓治罪"],["并起","並起"],["并跡","並跡"],["并躺","並躺"],["并躺在","並躺在"],["并轨","並軌"],["并辏","並輳"],["并辔","並轡"],["并过","並過"],["并过去","並過去"],["并过来","並過來"],["并进","並進"],["并进去","並進去"],["并进来","並進來"],["并迭","並迭"],["并邀","並邀"],["并邦","並邦"],["并邻","並鄰"],["并采","並採"],["并重","並重"],["并除","併除"],["并非","並非"],["并非在","並非在"],["并非是","並非是"],["并马","並馬"],["并驰","並馳"],["并驱","並驅"],["并驾","並駕"],["并驾齐驱","並駕齊驅"],["并骛","並騖"],["并骨","併骨"],["幸不辱命","幸不辱命"],["幸为先容","幸爲先容"],["幸事","幸事"],["幸于","幸於"],["幸于始者怠于终","幸於始者怠於終"],["幸亏","幸虧"],["幸亏在","幸虧在"],["幸亏是","幸虧是"],["幸亏有","幸虧有"],["幸会","幸會"],["幸位","幸位"],["幸倡","幸倡"],["幸免","倖免"],["幸免于难","倖免於難"],["幸发亭","幸發亭"],["幸喜","幸喜"],["幸好","幸好"],["幸好是","幸好是"],["幸好有","幸好有"],["幸子","幸子"],["幸存","倖存"],["幸存者","倖存者"],["幸幸","倖幸"],["幸得","幸得"],["幸感歌姬","倖感歌姬"],["幸未","幸未"],["幸村","幸村"],["幸次","幸次"],["幸民","幸民"],["幸灾乐祸","幸災樂禍"],["幸然","幸然"],["幸甚","幸甚"],["幸生","幸生"],["幸福","幸福"],["幸福女人小公主","幸福女人小公主"],["幸福学","幸福學"],["幸福家庭","幸福家庭"],["幸福感","幸福感"],["幸福戏院","幸福戲院"],["幸童","幸童"],["幸而","幸而"],["幸而是","幸而是"],["幸能","幸能"],["幸臣","倖臣"],["幸获识荆","幸獲識荊"],["幸蒙","幸蒙"],["幸运","幸運"],["幸运之星","幸運之星"],["幸运之神","幸運之神"],["幸运人","幸運人"],["幸运儿","幸運兒"],["幸运券","幸運券"],["幸运抽奖","幸運抽獎"],["幸运星","幸運星"],["幸运物","幸運物"],["幸运球","幸運球"],["幸运胡","幸運鬍"],["幸运色","幸運色"],["幸运草","幸運草"],["幸进","倖進"],["幸逢","幸逢"],["幺么小丑","幺麼小醜"],["幺并矢","幺並矢"],["幺麼小丑","幺麼小醜"],["幺麽小丑","幺麼小醜"],["幻出","幻出"],["幻念","幻念"],["幻想曲","幻想曲"],["幻术","幻術"],["幼发拉底","幼發拉底"],["幼发拉底河","幼發拉底河"],["幼发拉底河谷","幼發拉底河谷"],["幼托","幼托"],["幼虫","幼蟲"],["幽咽","幽咽"],["幽岩","幽巖"],["幽幽暗暗","幽幽暗暗"],["幽明录","幽明錄"],["幽暗","幽暗"],["幽栖岩谷","幽棲巖谷"],["幽谷","幽谷"],["幽门狭窄症","幽門狹窄症"],["幽闭恐惧症","幽閉恐懼症"],["广东住血吸虫","廣東住血吸蟲"],["广东炒面","廣東炒麪"],["广东药学院","廣東藥學院"],["广丰","廣豐"],["广丰县","廣豐縣"],["广厦万间","廣廈萬間"],["广发","廣發"],["广告曲","廣告曲"],["广告板","廣告板"],["广告系","廣告系"],["广场恐怖症","廣場恐怖症"],["广场恐惧症","廣場恐懼症"],["广布","廣佈"],["广征","廣徵"],["广播台","廣播臺"],["广播电台","廣播電臺"],["广播系统","廣播系統"],["广泛","廣泛"],["广舍","廣捨"],["广部","广部"],["广里","廣裏"],["庄上","莊上"],["庄严","莊嚴"],["庄主","莊主"],["庄农","莊農"],["庄员","莊員"],["庄周","莊周"],["庄周梦蝶","莊周夢蝶"],["庄园","莊園"],["庄园制度","莊園制度"],["庄士顿道","莊士頓道"],["庄子","莊子"],["庄客","莊客"],["庄家","莊家"],["庄志伟","莊志偉"],["庄户","莊戶"],["庄房","莊房"],["庄敬","莊敬"],["庄田","莊田"],["庄秋南","莊秋南"],["庄稼","莊稼"],["庄稼人","莊稼人"],["庄稼院","莊稼院"],["庄胜雄","莊勝雄"],["庄舄越吟","莊舄越吟"],["庄语","莊語"],["庄里","莊裏"],["庄重","莊重"],["庄院","莊院"],["庄骚","莊騷"],["庆丰","慶豐"],["庆云","慶雲"],["庆云县","慶雲縣"],["庆余","慶餘"],["庆历","慶曆"],["庆历新政","慶曆新政"],["庆吊","慶弔"],["庆幸","慶幸"],["庇荫","庇廕"],["庇里牛斯","庇里牛斯"],["庇里牛斯山","庇里牛斯山"],["床头柜","牀頭櫃"],["床席","牀蓆"],["床板","牀板"],["序升","序升"],["序录","序錄"],["序曲","序曲"],["庐山真面目","廬山真面目"],["庐山面目","廬山面目"],["庐舍","廬舍"],["库仑","庫侖"],["库仑定律","庫侖定律"],["库仑计","庫侖計"],["库克","庫克"],["库克山","庫克山"],["库克群岛","庫克羣島"],["库克船长","庫克船長"],["库尔德工人党","庫爾德工人黨"],["库尔斯克","庫爾斯克"],["库工党","庫工黨"],["库布里克","庫布裏克"],["库木吐拉千佛洞","庫木吐拉千佛洞"],["库瑞克","庫瑞克"],["库苏古尔湖","庫蘇古爾湖"],["库贝克","庫貝克"],["库贾氏症","庫賈氏症"],["库辛尼克","庫辛尼克"],["库里尔台","庫里爾臺"],["库里提巴","庫裏提巴"],["应付得当","應付得當"],["应付票据","應付票據"],["应克制","應剋制"],["应制","應制"],["应占","應占"],["应声虫","應聲蟲"],["应当","應當"],["应当会","應當會"],["应当在","應當在"],["应当是","應當是"],["应当有","應當有"],["应当能","應當能"],["应征","應徵"],["应征信","應徵信"],["应征稿","應徵稿"],["应征者","應徵者"],["应急出口","應急出口"],["应收帐款周转率","應收帳款週轉率"],["应收票据","應收票據"],["应时当令","應時當令"],["应有尽有","應有盡有"],["应用于","應用於"],["应用平台","應用平臺"],["应用技术","應用技術"],["应用范例","應用範例"],["应用范围","應用範圍"],["应运而出","應運而出"],["应钟","應鐘"],["应须","應須"],["底价","底價"],["底夸克","底夸克"],["底板","底板"],["底极","底極"],["底栖有孔虫","底棲有孔蟲"],["底格里斯","底格里斯"],["底格里斯河","底格里斯河"],["底脚里人","底腳裏人"],["底里","底裏"],["底面","底面"],["店伙","店夥"],["店里","店裏"],["店面","店面"],["店面广告","店面廣告"],["庙台","廟臺"],["庙里","廟裏"],["府兵制","府兵制"],["府台","府臺"],["府后","府後"],["府干","府幹"],["府谷","府谷"],["府谷县","府谷縣"],["庞克","龐克"],["庞克头","龐克頭"],["庞巴瓦克","龐巴瓦克"],["庞德维克","龐德維克"],["庞志龙","龐志龍"],["庞眉白发","龐眉白髮"],["庞眉皓发","龐眉皓髮"],["废了","廢了"],["废后","廢后"],["度假胜地","度假勝地"],["度搜","度搜"],["度曲","度曲"],["度身定制","度身定製"],["座钟","座鐘"],["庵主","庵主"],["庵儿","庵兒"],["庵堂","庵堂"],["庵婪","菴婪"],["庵寺","庵寺"],["庵庐","菴廬"],["庵庵","菴菴"],["庵罗树园","菴羅樹園"],["庵舍","菴舍"],["庵蔼","菴藹"],["庵观","庵觀"],["庶几","庶幾"],["庶几无愧","庶幾無愧"],["庶出","庶出"],["康乃狄克","康乃狄克"],["康乃狄克州","康乃狄克州"],["康回","康回"],["康复","康復"],["康复医学","康復醫學"],["康多莉扎赖斯","康多莉扎賴斯"],["康庄","康莊"],["康庄大道","康莊大道"],["康托尔","康托爾"],["康梁","康梁"],["康济录","康濟錄"],["康百克","康百克"],["康纳克立","康納克立"],["康采恩","康采恩"],["庸才","庸才"],["庸暗","庸闇"],["廉价","廉價"],["廉价品","廉價品"],["廉售价","廉售價"],["廉纤","廉纖"],["廖于诚","廖于誠"],["廖俊杰","廖俊傑"],["廖千莹","廖千瑩"],["廖志坚","廖志堅"],["廖本烟","廖本煙"],["廖本胜","廖本勝"],["廖英杰","廖英傑"],["廖金钟","廖金鐘"],["廛布","廛布"],["廢后","廢后"],["廪秋","廩秋"],["廪膳秀才","廩膳秀才"],["延伸出","延伸出"],["延修","延修"],["延厘","延釐"],["延发","延發"],["延后","延後"],["延地里","延地裏"],["延挨","延挨"],["延陵挂剑","延陵掛劍"],["廷争面折","廷爭面折"],["廷巴克图","廷巴克圖"],["廷布","廷布"],["建于","建於"],["建党","建黨"],["建党节","建黨節"],["建出","建出"],["建制","建制"],["建厂","建廠"],["建台","建臺"],["建教合作","建教合作"],["建教合作班","建教合作班"],["建极","建極"],["建立规范","建立規範"],["建筑","建築"],["建筑业","建築業"],["建筑商","建築商"],["建筑学","建築學"],["建筑容积管制","建築容積管制"],["建筑工业","建築工業"],["建筑工人","建築工人"],["建筑工地","建築工地"],["建筑工程","建築工程"],["建筑师","建築師"],["建筑执照","建築執照"],["建筑机械","建築機械"],["建筑材料","建築材料"],["建筑法规","建築法規"],["建筑物","建築物"],["建筑界","建築界"],["建筑科","建築科"],["建筑系","建築系"],["建筑结构","建築結構"],["建筑群","建築羣"],["建筑艺术","建築藝術"],["建筑节","建築節"],["建筑设计","建築設計"],["建筑起来","建築起來"],["建筑面积","建築面積"],["建造出","建造出"],["建都于","建都於"],["廿五万","廿五萬"],["开不了","開不了"],["开个","開個"],["开了","開了"],["开云见日","開雲見日"],["开价","開價"],["开伙","開伙"],["开元录","開元錄"],["开冬","開冬"],["开出","開出"],["开出去","開出去"],["开出来","開出來"],["开刀手术","開刀手術"],["开列于后","開列於後"],["开创出","開創出"],["开化党","開化黨"],["开卷","開卷"],["开卷有得","開卷有得"],["开卷有益","開卷有益"],["开卷考","開卷考"],["开厂","開廠"],["开发","開發"],["开发中","開發中"],["开发中国","開發中國"],["开发中国家","開發中國家"],["开发为","開發爲"],["开发井","開發井"],["开发人员","開發人員"],["开发出","開發出"],["开发出来","開發出來"],["开发区","開發區"],["开发周期","開發週期"],["开发商","開發商"],["开发国家","開發國家"],["开发基金","開發基金"],["开发局","開發局"],["开发成","開發成"],["开发案","開發案"],["开发法","開發法"],["开发环境","開發環境"],["开发署","開發署"],["开发者","開發者"],["开发过程","開發過程"],["开发金","開發金"],["开发银行","開發銀行"],["开台","開臺"],["开台圣王","開臺聖王"],["开台锣鼓","開臺鑼鼓"],["开吊","開弔"],["开后门","開後門"],["开向","開向"],["开哄","開鬨"],["开回","開回"],["开回去","開回去"],["开回来","開回來"],["开复","開復"],["开天辟地","開天闢地"],["开彩","開彩"],["开征","開徵"],["开支范围","開支範圍"],["开放式系统","開放式系統"],["开放性医疗制度","開放性醫療制度"],["开放系统","開放系統"],["开放系统互连","開放系統互連"],["开放舞台","開放舞臺"],["开新板","開新板"],["开明专制","開明專制"],["开杆","開杆"],["开杠","開槓"],["开棺验尸","開棺驗屍"],["开疆辟土","開疆闢土"],["开盘价","開盤價"],["开盘汇率","開盤匯率"],["开秋","開秋"],["开筑","開築"],["开膛手杰克","開膛手傑克"],["开药","開藥"],["开药方","開藥方"],["开蒙","開蒙"],["开诚布公","開誠佈公"],["开辟","開闢"],["开辟出来","開闢出來"],["开辟者","開闢者"],["开辟记","開闢記"],["开采","開採"],["开采权","開採權"],["开采法","開採法"],["开除党籍","開除黨籍"],["开面","開面"],["开齐合撮","開齊合撮"],["异中求同","異中求同"],["异于","異於"],["异动表","異動表"],["异口同声","異口同聲"],["异口同辞","異口同辭"],["异口同音","異口同音"],["异同","異同"],["异形叶","異形葉"],["异彩","異彩"],["异志","異志"],["异念","異念"],["异才","異才"],["异曲同工","異曲同工"],["异派同源","異派同源"],["异烟碱醯酸","異菸鹼醯酸"],["异种","異種"],["异苔同岑","異薹同岑"],["异路同归","異路同歸"],["异途同归","異途同歸"],["异采","異采"],["弃宗弄赞","棄宗弄贊"],["弃尸","棄屍"],["弃尸案","棄屍案"],["弃弓折箭","棄弓折箭"],["弃恶从善","棄惡從善"],["弃暗投明","棄暗投明"],["弃核","棄核"],["弃武修文","棄武修文"],["弃瑕录用","棄瑕錄用"],["弃舍","棄捨"],["弄丑","弄醜"],["弄僵","弄僵"],["弄出","弄出"],["弄出去","弄出去"],["弄出来","弄出來"],["弄坏了","弄壞了"],["弄干","弄乾"],["弄拧了","弄擰了"],["弄松","弄鬆"],["弄盏传杯","弄盞傳杯"],["弄粉调朱","弄粉調朱"],["弄脏","弄髒"],["弄面吃","弄麪吃"],["弄鬼吊猴","弄鬼弔猴"],["弈秋","弈秋"],["弊帚千金","弊帚千金"],["弊幸","弊倖"],["弊恶","弊惡"],["弋获","弋獲"],["弓不虚发","弓不虛發"],["弓弦","弓弦"],["弓影杯蛇","弓影杯蛇"],["弓影浮杯","弓影浮杯"],["弓折矢尽","弓折矢盡"],["弓折箭尽","弓折箭盡"],["弓极","弓極"],["弓浆虫","弓漿蟲"],["弓腰曲背","弓腰曲背"],["引人入胜","引人入勝"],["引人注意","引人注意"],["引人注目","引人注目"],["引以为鉴","引以爲鑑"],["引伸出","引伸出"],["引体向上","引體向上"],["引信系统","引信系統"],["引出","引出"],["引出去","引出去"],["引出来","引出來"],["引发","引發"],["引发出","引發出"],["引发物质","引發物質"],["引向","引向"],["引导出","引導出"],["引布","引布"],["引拉出","引拉出"],["引据","引據"],["引斗","引鬥"],["引渡回国","引渡回國"],["引牵出","引牽出"],["引种","引種"],["引线穿针","引線穿針"],["引经据典","引經據典"],["引经据古","引經據古"],["引而不发","引而不發"],["引致","引致"],["引蛇出洞","引蛇出洞"],["弗兰克","弗蘭克"],["弗洛里斯岛","弗洛裏斯島"],["弗罗里达","弗羅裏達"],["弗罗里达州","弗羅裏達州"],["弗里得里希","弗裏得裏希"],["弗里德里希","弗里德里希"],["弗里敦","弗里敦"],["弗里斯兰","弗里斯蘭"],["弗里曼","弗里曼"],["弗雷德里克","弗雷德裏克"],["弗雷德里克顿","弗雷德裏克頓"],["弘历","弘曆"],["弘愿","弘願"],["张三丰","張三丰"],["张世杰","張世傑"],["张了","張了"],["张云光","張雲光"],["张兆志","張兆志"],["张克帆","張克帆"],["张出","張出"],["张勇杰","張勇傑"],["张勋","張勳"],["张千","張千"],["张基郁","張基郁"],["张堪折辕","張堪折轅"],["张大千","張大千"],["张志","張志"],["张志和","張志和"],["张志家","張誌家"],["张志弘","張志弘"],["张志强","張志強"],["张志忠","張志忠"],["张志新","張志新"],["张志贤","張志賢"],["张志辉","張志輝"],["张志铭","張志銘"],["张扬出去","張揚出去"],["张扬出来","張揚出來"],["张挂","張掛"],["张挂在","張掛在"],["张挂起","張掛起"],["张挂起来","張掛起來"],["张文松","張文松"],["张斗辉","張斗輝"],["张智杰","張智傑"],["张木松","張木松"],["张杰","張傑"],["张栋梁","張棟樑"],["张灯挂彩","張燈掛彩"],["张灯结彩","張燈結綵"],["张玄墓志铭","張玄墓誌銘"],["张琴松","張琴松"],["张秋","張秋"],["张秋明","張秋明"],["张罗殆尽","張羅殆盡"],["张聪秋","張聰秋"],["张致","張致"],["张良借箸","張良借箸"],["张良慕赤松","張良慕赤松"],["张苙云","張苙雲"],["张荣发","張榮發"],["张金涂","張金塗"],["张飞穿针","張飛穿針"],["张黑女墓志铭","張黑女墓誌銘"],["弥久","彌久"],["弥习弥佳","彌習彌佳"],["弥事","彌事"],["弥勒","彌勒"],["弥勒佛","彌勒佛"],["弥勒县","彌勒縣"],["弥勒菩萨","彌勒菩薩"],["弥天","彌天"],["弥天亙地","彌天亙地"],["弥天大罪","彌天大罪"],["弥天大谎","彌天大謊"],["弥天案","彌天案"],["弥封","彌封"],["弥山遍野","瀰山遍野"],["弥年","彌年"],["弥弥","瀰瀰"],["弥撒","彌撒"],["弥撒曲","彌撒曲"],["弥撒经书","彌撒經書"],["弥敬","彌敬"],["弥时","彌時"],["弥月","彌月"],["弥月之喜","彌月之喜"],["弥月酒","彌月酒"],["弥望","彌望"],["弥渡县","彌渡縣"],["弥满","彌滿"],["弥漫","瀰漫"],["弥漫性","瀰漫性"],["弥漫着","瀰漫着"],["弥猴桃","彌猴桃"],["弥生文化","彌生文化"],["弥留","彌留"],["弥留之际","彌留之際"],["弥纶","彌綸"],["弥缝","彌縫"],["弥罗","彌羅"],["弥蒙","彌矇"],["弥补","彌補"],["弥赛亚","彌賽亞"],["弥足珍贵","彌足珍貴"],["弥迦书","彌迦書"],["弥陀","彌陀"],["弥陀乡","彌陀鄉"],["弦上","弦上"],["弦不虚发","弦不虛發"],["弦乐","絃樂"],["弦乐团","絃樂團"],["弦动","絃動"],["弦器","絃器"],["弦声","絃聲"],["弦子","弦子"],["弦弓","弦弓"],["弦拨","弦撥"],["弦断","絃斷"],["弦月","弦月"],["弦歌","絃歌"],["弦琴","絃琴"],["弦索","絃索"],["弦线","絃線"],["弦轴","絃軸"],["弦重","弦重"],["弦长","弦長"],["弦面板","弦面板"],["弦音","絃音"],["弯出去","彎出去"],["弯出来","彎出來"],["弯回","彎回"],["弯回去","彎回去"],["弯回来","彎回來"],["弯弯曲曲","彎彎曲曲"],["弯折","彎折"],["弯拐","彎拐"],["弯曲","彎曲"],["弯曲度","彎曲度"],["弯曲状","彎曲狀"],["弯曲空间","彎曲空間"],["弯管面","彎管麪"],["弱不胜衣","弱不勝衣"],["弱于","弱於"],["弱势团体","弱勢團體"],["弱智赖于涵","弱智賴于涵"],["弱水三千","弱水三千"],["弱音踏板","弱音踏板"],["弹不出","彈不出"],["弹了","彈了"],["弹出","彈出"],["弹出去","彈出去"],["弹出来","彈出來"],["弹升","彈升"],["弹回","彈回"],["弹回去","彈回去"],["弹回来","彈回來"],["弹奏出","彈奏出"],["弹子台","彈子檯"],["弹射出","彈射出"],["弹尽援绝","彈盡援絕"],["弹尽粮绝","彈盡糧絕"],["弹布尔","彈布爾"],["弹性制造系统","彈性製造系統"],["弹性控制","彈性控制"],["弹性纤维","彈性纖維"],["弹无虚发","彈無虛發"],["弹涂鱼","彈塗魚"],["弹珠台","彈珠檯"],["弹药","彈藥"],["弹药兵","彈藥兵"],["弹药库","彈藥庫"],["弹药箱","彈藥箱"],["弹药补给站","彈藥補給站"],["弹跳板","彈跳板"],["弹针","彈針"],["强了","強了"],["强于","強於"],["强借","強借"],["强制","強制"],["强制作用","強制作用"],["强制保险","強制保險"],["强制力","強制力"],["强制处分","強制處分"],["强制性","強制性"],["强制手段","強制手段"],["强制执行","強制執行"],["强制罪","強制罪"],["强制认领","強制認領"],["强制辩护","強制辯護"],["强制险","強制險"],["强力攻占","強力攻佔"],["强加于","強加於"],["强加于人","強加於人"],["强占","強佔"],["强占性","強佔性"],["强咽","強嚥"],["强奸","強姦"],["强奸民意","強姦民意"],["强奸犯","強姦犯"],["强奸罪","強姦罪"],["强干","強幹"],["强干弱枝","強幹弱枝"],["强征","強徵"],["强心针","強心針"],["强投松","強投松"],["强梁","強梁"],["强烈台风","強烈颱風"],["强烈愿望","強烈願望"],["强聒不舍","強聒不捨"],["强迫性储物症","強迫性儲物症"],["强迫症","強迫症"],["强音踏板","強音踏板"],["弼针","弼針"],["彊干弱枝","彊幹弱枝"],["彊御","彊禦"],["彊志","彊志"],["彊梁","彊梁"],["归于","歸於"],["归余","歸餘"],["归功于","歸功於"],["归向","歸向"],["归向导引","歸向導引"],["归咎于","歸咎於"],["归回","歸回"],["归因于","歸因於"],["归属于","歸屬於"],["归并","歸併"],["归并到","歸併到"],["归并在","歸併在"],["归烟","歸煙"],["归真反朴","歸真反樸"],["归类于","歸類於"],["归纳出","歸納出"],["归罪于","歸罪於"],["归虚谷","歸虛谷"],["归诸于","歸諸於"],["归里包堆","歸裏包堆"],["归随于","歸隨於"],["归面","歸面"],["归顺于","歸順於"],["当一回事","當一回事"],["当一声","噹一聲"],["当一当","當一當"],["当上","當上"],["当上去","當上去"],["当上来","當上來"],["当下","當下"],["当下去","當下去"],["当下来","當下來"],["当不上","當不上"],["当不了","當不了"],["当不得","當不得"],["当不成","當不成"],["当不来","當不來"],["当不起","當不起"],["当不过","當不過"],["当且仅当","當且僅當"],["当世","當世"],["当世之冠","當世之冠"],["当世儒宗","當世儒宗"],["当世冠","當世冠"],["当世才度","當世才度"],["当世无双","當世無雙"],["当世无敌","當世無敵"],["当个","當個"],["当中","當中"],["当为","當爲"],["当之无愧","當之無愧"],["当之有愧","當之有愧"],["当了","當了"],["当事","當事"],["当事人","當事人"],["当事国","當事國"],["当事者","當事者"],["当于","當於"],["当仁不让","當仁不讓"],["当今","當今"],["当今无辈","當今無輩"],["当代","當代"],["当代人","當代人"],["当代史","當代史"],["当代大师","當代大師"],["当代新儒家","當代新儒家"],["当令","當令"],["当众","當衆"],["当众宣布","當衆宣佈"],["当众表明","當衆表明"],["当众表示","當衆表示"],["当作","當作"],["当便","當便"],["当值","當值"],["当做","當做"],["当儿","當兒"],["当元","當元"],["当先","當先"],["当关","當關"],["当兵","當兵"],["当其冲","當其衝"],["当准","當準"],["当初","當初"],["当到","當到"],["当前","當前"],["当前之计","當前之計"],["当前季","當前季"],["当务之急","當務之急"],["当劳之急","當勞之急"],["当午","當午"],["当卢","當盧"],["当即","當即"],["当原","當原"],["当厨","當廚"],["当口","當口"],["当句对","當句對"],["当可","當可"],["当合","當合"],["当周","當週"],["当啷","噹啷"],["当啷落地","噹啷落地"],["当回事","當回事"],["当回事儿","當回事兒"],["当国","當國"],["当地","當地"],["当地人","當地人"],["当地化","當地化"],["当地居民","當地居民"],["当地时间","當地時間"],["当场","當場"],["当场出丑","當場出醜"],["当场出彩","當場出彩"],["当场只手","當場隻手"],["当场听到","當場聽到"],["当场抓到","當場抓到"],["当场献丑","當場獻醜"],["当场看到","當場看到"],["当坊土地","當坊土地"],["当垆","當壚"],["当堂","當堂"],["当堵","當堵"],["当夕","當夕"],["当夜","當夜"],["当天","當天"],["当天事当天毕","當天事當天畢"],["当头","當頭"],["当头一棒","當頭一棒"],["当头人","當頭人"],["当头棒喝","當頭棒喝"],["当头炮","當頭炮"],["当头阵","當頭陣"],["当完兵","當完兵"],["当官","當官"],["当官追究","當官追究"],["当室","當室"],["当家","當家"],["当家三年狗也嫌","當家三年狗也嫌"],["当家人","當家人"],["当家人恶水缸","當家人惡水缸"],["当家作主","當家作主"],["当家和尚","當家和尚"],["当家子","當家子"],["当家小生","當家小生"],["当家才知柴米价","當家纔知柴米價"],["当家方知柴米贵","當家方知柴米貴"],["当家的","當家的"],["当家立事","當家立事"],["当家花旦","當家花旦"],["当局","當局"],["当局称迷傍观必审","當局稱迷傍觀必審"],["当局者迷","當局者迷"],["当局者迷傍观者清","當局者迷傍觀者清"],["当局者迷旁观者清","當局者迷旁觀者清"],["当巡","當巡"],["当差","當差"],["当差的","當差的"],["当年","當年"],["当应","當應"],["当庭","當庭"],["当归","當歸"],["当归鸭","當歸鴨"],["当当","噹噹"],["当当丁丁","當當丁丁"],["当当当","噹噹噹"],["当当船","噹噹船"],["当当车","噹噹車"],["当役","當役"],["当待","當待"],["当得","當得"],["当得上","當得上"],["当得来","當得來"],["当得起","當得起"],["当心","當心"],["当意","當意"],["当成","當成"],["当手","當手"],["当拦","當攔"],["当掉","當掉"],["当撑","當撐"],["当政","當政"],["当政者","當政者"],["当敌","當敵"],["当断不断","當斷不斷"],["当断不断反受其乱","當斷不斷反受其亂"],["当日","當日"],["当日份","當日份"],["当时","當時"],["当时得令","當時得令"],["当时的","當時的"],["当时车","當時車"],["当是","當是"],["当晚","當晚"],["当曲河","當曲河"],["当月","當月"],["当月份","當月份"],["当朝","當朝"],["当朝宰相","當朝宰相"],["当期","當期"],["当机","當機"],["当机立断","當機立斷"],["当权","當權"],["当权派","當權派"],["当权者","當權者"],["当村","當村"],["当来","當來"],["当来当去","當來當去"],["当案","當案"],["当槽","當槽"],["当此","當此"],["当涂","當塗"],["当涂县","當塗縣"],["当演员","當演員"],["当灾","當災"],["当炉","當爐"],["当然","當然"],["当然会","當然會"],["当然在","當然在"],["当然是","當然是"],["当然有","當然有"],["当然继承主义","當然繼承主義"],["当牢节级","當牢節級"],["当班","當班"],["当班人员","當班人員"],["当用","當用"],["当用则用","當用則用"],["当番","當番"],["当的一响","噹的一響"],["当的一声","噹的一聲"],["当直","當直"],["当直巡逻","當直巡邏"],["当直的","當直的"],["当真","當真"],["当真假","當真假"],["当真的","當真的"],["当眼","當眼"],["当眼处","當眼處"],["当票","當票"],["当票子","當票子"],["当空","當空"],["当紧","當緊"],["当红","當紅"],["当罏","當罏"],["当罏红袖","當罏紅袖"],["当者披靡","當者披靡"],["当耳边风","當耳邊風"],["当舖","當舖"],["当艄拿舵","當艄拿舵"],["当艄顺","當艄順"],["当花","當花"],["当行","當行"],["当行出色","當行出色"],["当行家","當行家"],["当街","當街"],["当衣买酒喝","當衣買酒喝"],["当该","當該"],["当赌","當賭"],["当起","當起"],["当起来","當起來"],["当路","當路"],["当路子","當路子"],["当轴","當軸"],["当过","當過"],["当选","當選"],["当选为","當選爲"],["当选人","當選人"],["当选无效","當選無效"],["当选者","當選者"],["当道","當道"],["当道者","當道者"],["当量","當量"],["当量剂量","當量劑量"],["当量浓度","當量濃度"],["当铺","當鋪"],["当门对户","當門對戶"],["当门户","當門戶"],["当门抵户","當門抵戶"],["当门牙齿","當門牙齒"],["当间","當間"],["当阳","當陽"],["当阳市","當陽市"],["当院","當院"],["当雄","當雄"],["当雄县","當雄縣"],["当面","當面"],["当面唾骂","當面唾罵"],["当面对质","當面對質"],["当面言明","當面言明"],["当面银子对面钱","當面銀子對面錢"],["当面错过","當面錯過"],["当面锣对面鼓","當面鑼對面鼓"],["当面鼓对面锣","當面鼓對面鑼"],["当风秉烛","當風秉燭"],["录上","錄上"],["录上去","錄上去"],["录上来","錄上來"],["录下","錄下"],["录下去","錄下去"],["录下来","錄下來"],["录个","錄個"],["录了","錄了"],["录事","錄事"],["录供","錄供"],["录像","錄像"],["录像带","錄像帶"],["录像机","錄像機"],["录像片","錄像片"],["录到","錄到"],["录制","錄製"],["录取","錄取"],["录取人数","錄取人數"],["录取分数","錄取分數"],["录取名单","錄取名單"],["录取名额","錄取名額"],["录取率","錄取率"],["录取通知书","錄取通知書"],["录囚","錄囚"],["录在","錄在"],["录录","彔彔"],["录录歌","錄錄歌"],["录录音","錄錄音"],["录影","錄影"],["录影器","錄影器"],["录影带","錄影帶"],["录影带奖","錄影帶獎"],["录影机","錄影機"],["录影碟","錄影碟"],["录影节目","錄影節目"],["录得","錄得"],["录成","錄成"],["录放影机","錄放影機"],["录放音机","錄放音機"],["录歌","錄歌"],["录灌","錄灌"],["录点","錄點"],["录用","錄用"],["录的","錄的"],["录科","錄科"],["录起","錄起"],["录起来","錄起來"],["录载","錄載"],["录过","錄過"],["录遗","錄遺"],["录音","錄音"],["录音室","錄音室"],["录音师","錄音師"],["录音带","錄音帶"],["录音机","錄音機"],["录音电话","錄音電話"],["录音间","錄音間"],["录鬼簿","錄鬼簿"],["彗核","彗核"],["彗氾画涂","彗氾畫塗"],["形丑心善","形醜心善"],["形于","形於"],["形于色","形於色"],["形于言色","形於言色"],["形于辞色","形於辭色"],["形于颜色","形於顏色"],["形制","形制"],["形单影只","形單影隻"],["形只影单","形隻影單"],["形同","形同"],["形同具文","形同具文"],["形同虚设","形同虛設"],["形同陌路","形同陌路"],["形名参同","形名參同"],["形孤影只","形孤影隻"],["形容尽致","形容盡致"],["形影相吊","形影相弔"],["形态发生素","形態發生素"],["形疲神困","形疲神困"],["形胜","形勝"],["形象艺术","形象藝術"],["彤云","彤雲"],["彩云","彩雲"],["彩云国","彩雲國"],["彩云易散","彩雲易散"],["彩信","彩信"],["彩先达","彩先達"],["彩光","彩光"],["彩光板","彩光板"],["彩凤","綵鳳"],["彩凤随鸦","彩鳳隨鴉"],["彩券","彩券"],["彩券局","彩券局"],["彩券行","彩券行"],["彩印","彩印"],["彩卷","彩卷"],["彩叶芋","彩葉芋"],["彩叶草","彩葉草"],["彩号","彩號"],["彩喷","彩噴"],["彩图","彩圖"],["彩塑","彩塑"],["彩墨","彩墨"],["彩头","彩頭"],["彩女","綵女"],["彩妆","彩妝"],["彩妆保养化","彩妝保養化"],["彩妆品","彩妝品"],["彩妆师","彩妝師"],["彩市","彩市"],["彩带","綵帶"],["彩带舞","綵帶舞"],["彩度","彩度"],["彩弹","彩彈"],["彩影","彩影"],["彩扩","彩擴"],["彩排","彩排"],["彩旗","彩旗"],["彩旦","彩旦"],["彩条","彩條"],["彩棚","綵棚"],["彩楼","綵樓"],["彩楼配","綵樓配"],["彩民","彩民"],["彩池","彩池"],["彩灯","彩燈"],["彩照","彩照"],["彩牌楼","綵牌樓"],["彩球","綵球"],["彩瓷","彩瓷"],["彩电","彩電"],["彩电视","彩電視"],["彩画","彩畫"],["彩砖","彩磚"],["彩礼","彩禮"],["彩票","彩票"],["彩票卡","彩票卡"],["彩笔","彩筆"],["彩笔生","彩筆生"],["彩笔生花","綵筆生花"],["彩管生花","彩管生花"],["彩纸","彩紙"],["彩线","綵線"],["彩练","彩練"],["彩绘","彩繪"],["彩绸","綵綢"],["彩缎","綵緞"],["彩缯","綵繒"],["彩胜","綵勝"],["彩船","綵船"],["彩色","彩色"],["彩色世界","彩色世界"],["彩色正片","彩色正片"],["彩色照","彩色照"],["彩色照片","彩色照片"],["彩色片","彩色片"],["彩色版","彩色版"],["彩色玻璃","彩色玻璃"],["彩色电影","彩色電影"],["彩色电视","彩色電視"],["彩色电视机","彩色電視機"],["彩色笔","彩色筆"],["彩色米","彩色米"],["彩色缤纷","彩色繽紛"],["彩虹","彩虹"],["彩虹仙子","彩虹仙子"],["彩虹冰舖","彩虹冰舖"],["彩虹桥","彩虹橋"],["彩蛋","彩蛋"],["彩蝶","彩蝶"],["彩蝶谷","彩蝶谷"],["彩衣","綵衣"],["彩衣娱亲","綵衣娛親"],["彩调","彩調"],["彩车","彩車"],["彩轿","彩轎"],["彩迷","彩迷"],["彩釉","彩釉"],["彩金","彩金"],["彩钱","彩錢"],["彩铃","彩鈴"],["彩陶","彩陶"],["彩陶文化","彩陶文化"],["彩雕","彩雕"],["彩霞","彩霞"],["彩饰","彩飾"],["彩饰版","彩飾版"],["彩鸾","綵鸞"],["彩鹢","彩鷁"],["彪个子","彪個子"],["彪炳千古","彪炳千古"],["彭于晏","彭于晏"],["彭克港","彭克港"],["彭咸","彭咸"],["彭志光","彭志光"],["彭志华","彭志華"],["彭绍升","彭紹升"],["彭胜竹","彭勝竹"],["彭蒙","彭蒙"],["彰化师范大学","彰化師範大學"],["彰善瘅恶","彰善癉惡"],["彰彰可据","彰彰可據"],["彰显出","彰顯出"],["影像合成","影像合成"],["影像处理系统","影像處理系統"],["影占","影占"],["影只形单","影隻形單"],["影后","影后"],["影响不了","影響不了"],["影坛","影壇"],["影坛红星","影壇紅星"],["影评人周","影評人週"],["役于","役於"],["役于外物","役於外物"],["役别","役別"],["役种","役種"],["彻里彻外","徹裏徹外"],["彼得后书","彼得後書"],["彼得里皿","彼得里皿"],["彼此克制","彼此剋制"],["往上面","往上面"],["往下面","往下面"],["往事如烟","往事如煙"],["往前面","往前面"],["往后","往後"],["往后冲","往後衝"],["往后方","往後方"],["往后面","往後面"],["往回","往回"],["往复","往復"],["往复泵","往復泵"],["往复运动","往復運動"],["往外冲","往外衝"],["往外面","往外面"],["往日無仇","往日無讎"],["往来于","往來於"],["往泥里踩","往泥裏踩"],["往还于","往還於"],["往里","往裏"],["往里面","往裏面"],["往里面冲","往裏面衝"],["征了","徵了"],["征人","徵人"],["征令","徵令"],["征伐","征伐"],["征信","徵信"],["征信录","徵信錄"],["征信所","徵信所"],["征信社","徵信社"],["征候","徵候"],["征候群","徵候羣"],["征兆","徵兆"],["征兵","徵兵"],["征兵制","徵兵制"],["征兵制度","徵兵制度"],["征兵法","徵兵法"],["征兵站","徵兵站"],["征到","徵到"],["征剿","征剿"],["征募","徵募"],["征占","徵佔"],["征友","徵友"],["征友栏","徵友欄"],["征发","徵發"],["征召","徵召"],["征名责实","徵名責實"],["征吏","徵吏"],["征启","徵啓"],["征咎","徵咎"],["征圣","徵聖"],["征地","徵地"],["征士","徵士"],["征夫","征夫"],["征婚","徵婚"],["征实","徵實"],["征尘","征塵"],["征帆","征帆"],["征庸","徵庸"],["征引","徵引"],["征彸","征彸"],["征得","徵得"],["征怪","徵怪"],["征意见","徵意見"],["征戍","征戍"],["征战","征戰"],["征才","徵才"],["征招","徵招"],["征收","徵收"],["征收范围","徵收範圍"],["征收额","徵收額"],["征效","徵效"],["征敛","征斂"],["征敛无度","征斂無度"],["征文","徵文"],["征文启事","徵文啓事"],["征文比赛","徵文比賽"],["征旆","征旆"],["征服","征服"],["征服兵","征服兵"],["征服到地","征服到地"],["征服者","征服者"],["征求","徵求"],["征求启事","徵求啓事"],["征状","徵狀"],["征用","徵用"],["征程","征程"],["征税","徵稅"],["征税额","徵稅額"],["征稿","徵稿"],["征稿栏","徵稿欄"],["征答","徵答"],["征管","徵管"],["征粮","徵糧"],["征纳","徵納"],["征结","徵結"],["征缴","徵繳"],["征聘","徵聘"],["征聘人员","徵聘人員"],["征衣","征衣"],["征衫","征衫"],["征讨","征討"],["征训","徵訓"],["征询","徵詢"],["征调","徵調"],["征象","徵象"],["征购","徵購"],["征费","徵費"],["征车","徵車"],["征辟","徵辟"],["征迹","徵跡"],["征选","徵選"],["征逐","徵逐"],["征途","征途"],["征集","徵集"],["征集令","徵集令"],["征风召雨","徵風召雨"],["征马","征馬"],["征驾","征駕"],["征验","徵驗"],["征验出","徵驗出"],["径向","徑向"],["待了","待了"],["待价而沽","待價而沽"],["待价藏珠","待價藏珠"],["待制","待制"],["待发","待發"],["待在家里","待在家裏"],["待如己出","待如己出"],["待核","待覈"],["很丑","很醜"],["很僵","很僵"],["很凶","很兇"],["很咸","很鹹"],["很干","很乾"],["很干了","很乾了"],["很暗","很暗"],["很松","很鬆"],["律历志","律曆志"],["律师团","律師團"],["徐伟胜","徐偉勝"],["徐余伟","徐余偉"],["徐克","徐克"],["徐千惠","徐千惠"],["徐台荪","徐臺蓀"],["徐台荪宫仲毅","徐臺蓀宮仲毅"],["徐妃半面妆","徐妃半面妝"],["徐娘","徐娘"],["徐娘半老","徐娘半老"],["徐家汇","徐家彙"],["徐州师范大学","徐州師範大學"],["徐干","徐幹"],["徐志摩","徐志摩"],["徐汇","徐匯"],["徐汇区","徐彙區"],["徐清云","徐清雲"],["徐赞升","徐讚昇"],["徐霞客游记","徐霞客遊記"],["徒托空言","徒託空言"],["徒步当车","徒步當車"],["得了","得了"],["得了些颜色就开起染房来","得了些顏色就開起染房來"],["得于","得於"],["得偿所愿","得償所願"],["得克制","得剋制"],["得克萨斯州","得克薩斯州"],["得克萨斯州沃思堡电","得克薩斯州沃思堡電"],["得准不准","得準不準"],["得出","得出"],["得失参半","得失參半"],["得幸","得幸"],["得当","得當"],["得志","得志"],["得意之余","得意之餘"],["得放手时须放手","得放手時須放手"],["得未尝有","得未嘗有"],["得益于","得益於"],["得而复失","得而復失"],["得胜","得勝"],["得胜之兵","得勝之兵"],["得胜之师","得勝之師"],["得胜口","得勝口"],["得胜回朝","得勝回朝"],["得胜头回","得勝頭回"],["得胜的猫儿欢似虎","得勝的貓兒歡似虎"],["得胜课","得勝課"],["得道升天","得道昇天"],["得采","得采"],["得黄金百不如得季布诺","得黃金百不如得季布諾"],["得黄金百斤不如得季布一诺","得黃金百斤不如得季布一諾"],["徘回","徘迴"],["徘徊于","徘徊於"],["徜徉于","徜徉於"],["御世","御世"],["御书","御書"],["御书房","御書房"],["御人","御人"],["御仗","御仗"],["御侮","禦侮"],["御制","御製"],["御前","御前"],["御前会议","御前會議"],["御医","御醫"],["御博表","御博表"],["御厨","御廚"],["御史","御史"],["御史台","御史臺"],["御史大夫","御史大夫"],["御史雨","御史雨"],["御夫","御夫"],["御夫座","御夫座"],["御夫有术","御夫有術"],["御孙","御孫"],["御宅族","御宅族"],["御宇","御宇"],["御守","御守"],["御宝","御寶"],["御容","御容"],["御寇","禦寇"],["御寒","禦寒"],["御库","御庫"],["御庙","御廟"],["御府","御府"],["御弟","御弟"],["御所","御所"],["御手","御手"],["御手洗","御手洗"],["御敌","禦敵"],["御旨","御旨"],["御札","御札"],["御极","御極"],["御林军","御林軍"],["御案","御案"],["御气","御氣"],["御沟","御溝"],["御沟流叶","御溝流葉"],["御沟题叶","御溝題葉"],["御河","御河"],["御状","御狀"],["御用","御用"],["御碑亭","御碑亭"],["御窑","御窯"],["御笔","御筆"],["御者","御者"],["御膳","御膳"],["御膳房","御膳房"],["御花园","御花園"],["御苑","御苑"],["御览","御覽"],["御赐","御賜"],["御轮","御輪"],["御道","御道"],["御酒","御酒"],["御风","御風"],["御馔","御饌"],["御驾","御駕"],["御驾亲征","御駕親征"],["御龙","御龍"],["循环制","循環制"],["循环反复","循環反覆"],["循环往复","循環往復"],["循环系统","循環系統"],["循环赛制","循環賽制"],["微克","微克"],["微分几何","微分幾何"],["微分几何学","微分幾何學"],["微升","微升"],["微卷","微卷"],["微孔板","微孔板"],["微居里","微居里"],["微微的发烫","微微的發燙"],["微核","微核"],["微波倒送系统","微波倒送系統"],["微纤","微纖"],["微胶囊技术","微膠囊技術"],["微雕","微雕"],["徯幸","徯倖"],["德佛亚克","德佛亞克"],["德克萨斯","德克薩斯"],["德克萨斯州","德克薩斯州"],["德兰克林","德蘭克林"],["德勒巴克","德勒巴克"],["德占","德佔"],["德国学术交流总署","德國學術交流總署"],["德国杯","德國杯"],["德国统一社会党","德國統一社會黨"],["德国马克","德國馬克"],["德垂后裔","德垂後裔"],["德布勒森","德布勒森"],["德布西","德布西"],["德干","德干"],["德干高原","德干高原"],["德弗札克","德弗札克"],["德意志","德意志"],["德意志关税同盟","德意志關稅同盟"],["德意志学术交流中心","德意志學術交流中心"],["德意志民主共和国","德意志民主共和國"],["德意志联邦共和国","德意志聯邦共和國"],["德意志银行","德意志銀行"],["德意志革命","德意志革命"],["德才","德才"],["德才兼备","德才兼備"],["德拉克洛瓦","德拉克洛瓦"],["德拉克罗瓦","德拉克羅瓦"],["德文系","德文系"],["德沃夏克","德沃夏克"],["德法年鉴","德法年鑑"],["德润佣书","德潤傭書"],["德瑞克","德瑞克"],["德胜头回","德勝頭迴"],["德胜门","德勝門"],["德薄才疏","德薄才疏"],["德语系","德語系"],["德谟克利泰斯","德謨克利泰斯"],["德谟克拉西","德謨克拉西"],["德里","德里"],["德里达","德里達"],["德高而毁来","德高而譭來"],["徼幸","徼倖"],["心不甘情不愿","心不甘情不願"],["心于","心於"],["心余","心餘"],["心凉了半截","心涼了半截"],["心口合一","心口合一"],["心同此理","心同此理"],["心向","心向"],["心向往之","心嚮往之"],["心向祖国","心向祖國"],["心回意转","心回意轉"],["心头小鹿撞个不住","心頭小鹿撞個不住"],["心存侥幸","心存僥倖"],["心安神闲","心安神閒"],["心宽出少年","心寬出少年"],["心弦","心絃"],["心志","心志"],["心念","心念"],["心意回转","心意回轉"],["心愿","心願"],["心慈面软","心慈面軟"],["心折","心折"],["心折首肯","心折首肯"],["心曲","心曲"],["心有余力不足","心有餘力不足"],["心有余悸","心有餘悸"],["心有余而力不足","心有餘而力不足"],["心有戚戚","心有慼慼"],["心服情愿","心服情願"],["心术","心術"],["心术不正","心術不正"],["心杯","心杯"],["心欲专凿石穿","心欲專鑿石穿"],["心活面软","心活面軟"],["心游","心遊"],["心满愿足","心滿願足"],["心物合一","心物合一"],["心理学系","心理學系"],["心理系","心理系"],["心理面","心理面"],["心甘情愿","心甘情願"],["心相系","心相繫"],["心神专注","心神專注"],["心系","心繫"],["心细似发","心細似髮"],["心细如发","心細如髮"],["心肺复苏术","心肺復甦術"],["心脏","心臟"],["心脏地区","心臟地區"],["心脏复苏术","心臟復甦術"],["心脏学","心臟學"],["心脏按摩","心臟按摩"],["心脏搭桥手术","心臟搭橋手術"],["心脏收缩压","心臟收縮壓"],["心脏瓣","心臟瓣"],["心脏疾患","心臟疾患"],["心脏病","心臟病"],["心脏病发","心臟病發"],["心脏病史","心臟病史"],["心脏痲痹","心臟痲痹"],["心脏痲痺","心臟痲痺"],["心脏科","心臟科"],["心脏移植","心臟移植"],["心脏移殖","心臟移殖"],["心脏舒张压","心臟舒張壓"],["心脏节律器","心臟節律器"],["心脏衰竭","心臟衰竭"],["心脏计","心臟計"],["心脏镜","心臟鏡"],["心脏麻痹","心臟麻痹"],["心脏麻痺","心臟麻痺"],["心花怒发","心花怒發"],["心荡","心蕩"],["心荡神怡","心蕩神怡"],["心荡神摇","心蕩神搖"],["心荡神迷","心蕩神迷"],["心荡神驰","心蕩神馳"],["心药","心藥"],["心虔志诚","心虔志誠"],["心路历程","心路歷程"],["心里","心裏"],["心里不安","心裏不安"],["心里头","心裏頭"],["心里有个谱","心裏有個譜"],["心里有数","心裏有數"],["心里有谱","心裏有譜"],["心里有鬼","心裏有鬼"],["心里痒痒","心裏癢癢"],["心里美萝卜","心裏美蘿蔔"],["心里话","心裏話"],["心里面","心裏面"],["心长发短","心長髮短"],["心闲手敏","心閒手敏"],["心高遮了太阳","心高遮了太陽"],["必修","必修"],["必修科","必修科"],["必修课","必修課"],["必修课程","必修課程"],["必备良药","必備良藥"],["必当","必當"],["必死之症","必死之症"],["必胜","必勝"],["必胜客","必勝客"],["必须","必須"],["忆念","憶念"],["忌烟","忌菸"],["忍个","忍個"],["忍了","忍了"],["忍冬","忍冬"],["忍冬花","忍冬花"],["忍受不了","忍受不了"],["忍受得了","忍受得了"],["忍术","忍術"],["忍饥受渴","忍饑受渴"],["忍饥受饿","忍饑受餓"],["忍饥挨饿","忍飢挨餓"],["忏悔录","懺悔錄"],["忒恶","忒惡"],["忖前思后","忖前思後"],["志不可夺","志不可奪"],["志不可满","志不可滿"],["志不在此","志不在此"],["志业","志業"],["志丹","志丹"],["志丹县","志丹縣"],["志乃","志乃"],["志之不忘","誌之不忘"],["志书","志書"],["志事","志事"],["志于","志於"],["志仁","志仁"],["志伟","志偉"],["志保","志保"],["志冲斗牛","志沖斗牛"],["志分","志分"],["志同心合","志同心合"],["志同气合","志同氣合"],["志同道合","志同道合"],["志向","志向"],["志哀","誌哀"],["志喜","誌喜"],["志在","志在"],["志在千里","志在千里"],["志在四方","志在四方"],["志在必得","志在必得"],["志坚","志堅"],["志坚胆壮","志堅膽壯"],["志士","志士"],["志士仁人","志士仁人"],["志大心高","志大心高"],["志大才疏","志大才疏"],["志大才短","志大才短"],["志学","志學"],["志尚","志尚"],["志工","志工"],["志工团","志工團"],["志工队","志工隊"],["志广才疏","志廣才疏"],["志庆","誌慶"],["志度","志度"],["志异","誌異"],["志强","志強"],["志得意满","志得意滿"],["志心","志心"],["志怪","志怪"],["志怪小说","志怪小說"],["志悼","誌悼"],["志意","志意"],["志愿","志願"],["志愿书","志願書"],["志愿兵","志願兵"],["志愿军","志願軍"],["志愿卡","志願卡"],["志愿役","志願役"],["志愿者","志願者"],["志成","志成"],["志文","志文"],["志明","志明"],["志村健","志村健"],["志杰","志傑"],["志气","志氣"],["志气凌云","志氣凌雲"],["志清","志清"],["志满气得","志滿氣得"],["志玲","志玲"],["志田","志田"],["志留系","志留系"],["志留纪","志留紀"],["志略","志略"],["志能之士","志能之士"],["志航基地","志航基地"],["志节","志節"],["志英","志英"],["志行","志行"],["志诚","志誠"],["志诚君子","志誠君子"],["志贞","志貞"],["志趣","志趣"],["志趣相投","志趣相投"],["志足意满","志足意滿"],["志量","志量"],["志骄意满","志驕意滿"],["志高气扬","志高氣揚"],["忘不了","忘不了"],["忘了","忘了"],["忘忧谷","忘憂谷"],["忘生舍死","忘生捨死"],["忙不择价","忙不擇價"],["忙了手脚","忙了手腳"],["忙于","忙於"],["忙作一团","忙作一團"],["忙并","忙併"],["忙成一团","忙成一團"],["忙昏了头","忙昏了頭"],["忙进忙出","忙進忙出"],["忙里","忙裏"],["忙里偷闲","忙裏偷閒"],["忙里忙外","忙裏忙外"],["忠于","忠於"],["忠于国家","忠於國家"],["忠于职守","忠於職守"],["忠人之托","忠人之托"],["忠仆","忠僕"],["忧喜参半","憂喜參半"],["忧形于色","憂形於色"],["忧戚","憂戚"],["忧郁","憂鬱"],["忧郁剂","憂鬱劑"],["忧郁症","憂鬱症"],["快乐幸福","快樂幸福"],["快了","快了"],["快借","快借"],["快停了","快停了"],["快克","快克"],["快克制","快剋制"],["快出","快出"],["快出去","快出去"],["快出来","快出來"],["快升","快升"],["快去快回","快去快回"],["快吃干","快吃乾"],["快向","快向"],["快回","快回"],["快回到","快回到"],["快回去","快回去"],["快回来","快回來"],["快好了","快好了"],["快完了","快完了"],["快干","快乾"],["快干了","快乾了"],["快干杯","快乾杯"],["快干裂","快乾裂"],["快当","快當"],["快快当当","快快當當"],["快搜","快搜"],["快松下","快鬆下"],["快板","快板"],["快板儿","快板兒"],["快死了","快死了"],["快没了","快沒了"],["快满了","快滿了"],["快熟了","快熟了"],["快舍下","快捨下"],["快赢了","快贏了"],["快适","快適"],["快递杯","快遞杯"],["快速发展","快速發展"],["快速面","快速麪"],["念一","念一"],["念上","念上"],["念不","念不"],["念中","念中"],["念之","念之"],["念书","唸書"],["念了","唸了"],["念了一声","唸了一聲"],["念他","念他"],["念以","念以"],["念佛","唸佛"],["念作","唸作"],["念你","念你"],["念儿","念兒"],["念冰","念冰"],["念出","念出"],["念到","唸到"],["念力","念力"],["念及","念及"],["念叨","唸叨"],["念可","念可"],["念吧","唸吧"],["念和","念和"],["念咒","唸咒"],["念啊","唸啊"],["念在","念在"],["念头","念頭"],["念她","念她"],["念好","念好"],["念完","唸完"],["念对","唸對"],["念得","念得"],["念心","念心"],["念念","念念"],["念念有词","唸唸有詞"],["念情","念情"],["念想","念想"],["念慈","念慈"],["念成","念成"],["念我","念我"],["念日","念日"],["念旧","念舊"],["念是","念是"],["念曰","唸曰"],["念曲叫曲","念曲叫曲"],["念有","念有"],["念来","念來"],["念此","念此"],["念母","念母"],["念法","念法"],["念点","念點"],["念珠","念珠"],["念琛","念琛"],["念生","念生"],["念白","唸白"],["念的","唸的"],["念着","念着","唸着"],["念经","唸經"],["念给","念給"],["念诗","唸詩"],["念诵","唸誦"],["念起","念起"],["念过","念過"],["念这","念這"],["念道","念道"],["念都","念都"],["念错","唸錯"],["念青","念青"],["念鱼","念魚"],["忽前忽后","忽前忽後"],["忽明忽暗","忽明忽暗"],["忽舍下","忽捨下"],["忿发","忿發"],["怀了","懷了"],["怀宠尸位","懷寵尸位"],["怀忧丧志","懷憂喪志"],["怀念","懷念"],["怀恶不悛","懷惡不悛"],["怀才不遇","懷才不遇"],["怀才抱德","懷才抱德"],["怀表","懷錶"],["怀里","懷裏"],["怀钟","懷鐘"],["怎么","怎麼"],["怎么了","怎麼了"],["怎么回事","怎麼回事"],["怎么干","怎麼幹"],["怎么得了","怎麼得了"],["怎么着","怎麼着"],["怒于","怒於"],["怒从心上起恶向胆边生","怒從心上起惡向膽邊生"],["怒冲冲","怒衝衝"],["怒发冲冠","怒髮衝冠"],["怒发冲天","怒髮沖天"],["怒容满面","怒容滿面"],["怒形于色","怒形於色"],["怒恶","怒惡"],["怒气冲冲","怒氣衝衝"],["怒气冲发","怒氣沖發"],["怒气冲天","怒氣沖天"],["怒江大峡谷","怒江大峽谷"],["怒火万丈","怒火萬丈"],["怒火冲天","怒火沖天"],["怒目相向","怒目相向"],["怒臂当车","怒臂當車"],["怙恶不悛","怙惡不悛"],["怙恶不改","怙惡不改"],["怜才","憐才"],["思不出位","思不出位"],["思前思后","思前思後"],["思前想后","思前想後"],["思前算后","思前算後"],["思如泉涌","思如泉涌"],["思念","思念"],["思想体系","思想體系"],["思想准备","思想準備"],["思致","思致"],["思虑周详","思慮周詳"],["怠于","怠於"],["急于","急於"],["急于星火","急於星火"],["急于求成","急於求成"],["急人之困","急人之困"],["急冲","急衝"],["急冲而下","急衝而下"],["急升","急升"],["急并各邦","急並各邦"],["急征重敛","急征重斂"],["急松松","急鬆鬆"],["急水也有回头浪","急水也有回頭浪"],["急症","急症"],["急进党","急進黨"],["急重症","急重症"],["急须","急須"],["性丑闻","性醜聞"],["性价比","性價比"],["性伙伴","性夥伴"],["性倾向","性傾向"],["性冲动","性衝動"],["性别","性別"],["性别歧视","性別歧視"],["性别比","性別比"],["性别角色","性別角色"],["性发","性發"],["性取向","性取向"],["性向","性向"],["性向测验","性向測驗"],["性征","性徵"],["性恶","性惡"],["性恶说","性惡說"],["性指向","性指向"],["性格不合","性格不合"],["性欲","性慾"],["性欲高潮","性慾高潮"],["性泼凶顽","性潑凶頑"],["性神经症","性神經症"],["性荷尔蒙","性荷爾蒙"],["性饥渴","性飢渴"],["怨仇","怨仇"],["怨叹","怨嘆"],["怨念","怨念"],["怨气冲天","怨氣沖天"],["怪了","怪了"],["怪杰","怪傑"],["怪里怪气","怪里怪氣"],["怫郁","怫鬱"],["怯症","怯症"],["总会杯","總會杯"],["总体规划","總體規劃"],["总厂","總廠"],["总参谋部","總參謀部"],["总参谋长","總參謀長"],["总发","總髮"],["总台","總檯"],["总合","總合"],["总后勤部","總後勤部"],["总回报","總回報"],["总干事","總幹事"],["总批发","總批發"],["总方针","總方針"],["总星系","總星系"],["总机厂","總機廠"],["总杆数","總桿數"],["总杆赛","總桿賽"],["总汇","總彙"],["总统制","總統制"],["总统杯","總統盃"],["总裁制","總裁制"],["总量管制","總量管制"],["总面积","總面積"],["恂栗","恂慄"],["恃才傲物","恃才傲物"],["恃才矜己","恃才矜己"],["恃才自专","恃才自專"],["恋念","戀念"],["恋恋不舍","戀戀不捨"],["恋恋难舍","戀戀難捨"],["恋曲","戀曲"],["恋生恶死","戀生惡死"],["恋酒贪杯","戀酒貪杯"],["恐变症","恐變症"],["恐同症","恐同症"],["恐后争先","恐後爭先"],["恐怖症","恐怖症"],["恐惧症","恐懼症"],["恐慌症","恐慌症"],["恐旷症","恐曠症"],["恐水症","恐水症"],["恐法症","恐法症"],["恐韩症","恐韓症"],["恐高症","恐高症"],["恐鸡症","恐雞症"],["恒星周期","恆星週期"],["恒春野百合","恆春野百合"],["恒生指数","恆生指數"],["恒生股价指数","恆生股價指數"],["恒生银行","恆生銀行"],["恒言录","恆言錄"],["恕乏价催","恕乏价催"],["恙虫","恙蟲"],["恙虫病","恙蟲病"],["恢台","恢臺"],["恢复","恢復"],["恢复为","恢復爲"],["恢复到","恢復到"],["恢复原状","恢復原狀"],["恢复名誉","恢復名譽"],["恢复室","恢復室"],["恢复常态","恢復常態"],["恢复期","恢復期"],["恢复起来","恢復起來"],["恢复过来","恢復過來"],["恢恢有余","恢恢有餘"],["恣心所欲","恣心所欲"],["恣情纵欲","恣情縱欲"],["恤典","卹典"],["恤荒","卹荒"],["恤金","卹金"],["恨了","恨了"],["恨意尽消","恨意盡消"],["恨苦修行","恨苦修行"],["恨透了","恨透了"],["恩仇","恩仇"],["恩仇记","恩仇記"],["恩克巴雅尔","恩克巴雅爾"],["恩克鲁玛","恩克魯瑪"],["恩准","恩准"],["恩台","恩臺"],["恩同再造","恩同再造"],["恩同父母","恩同父母"],["恩培多克勒","恩培多克勒"],["恩威克","恩威克"],["恩威并施","恩威並施"],["恩威并济","恩威並濟"],["恩威并用","恩威並用"],["恩威并行","恩威並行"],["恩威并重","恩威並重"],["恩将仇报","恩將仇報"],["恩将仇报者","恩將仇報者"],["恩幸","恩幸"],["恩给制","恩給制"],["恩艾斯克","恩艾斯克"],["恬淡寡欲","恬淡寡欲"],["恬淡无欲","恬淡無欲"],["恬适","恬適"],["恭喜发财","恭喜發財"],["息交绝游","息交絕遊"],["息谷","息穀"],["恰克","恰克"],["恰克图","恰克圖"],["恰克图条约","恰克圖條約"],["恰当","恰當"],["恰才","恰纔"],["恳愿","懇願"],["恳托","懇託"],["恶业","惡業"],["恶习","惡習"],["恶习不改","惡習不改"],["恶事","惡事"],["恶事传千里","惡事傳千里"],["恶人","惡人"],["恶人先告状","惡人先告狀"],["恶人有恶报","惡人有惡報"],["恶人自有恶人磨","惡人自有惡人磨"],["恶仗","惡仗"],["恶作剧","惡作劇"],["恶作剧者","惡作劇者"],["恶例","惡例"],["恶俗","惡俗"],["恶兆","惡兆"],["恶党","惡黨"],["恶凶凶","惡兇兇"],["恶劣","惡劣"],["恶劣影响","惡劣影響"],["恶劣性","惡劣性"],["恶势力","惡勢力"],["恶化","惡化"],["恶化趋势","惡化趨勢"],["恶化顷向","惡化頃向"],["恶叉白赖","惡叉白賴"],["恶发","惡發"],["恶口","惡口"],["恶名","惡名"],["恶名儿","惡名兒"],["恶名昭彰","惡名昭彰"],["恶名昭著","惡名昭著"],["恶哏哏","惡哏哏"],["恶唑啉","噁唑啉"],["恶唑啉酮","噁唑啉酮"],["恶因","惡因"],["恶地","惡地"],["恶声","惡聲"],["恶女","惡女"],["恶女阿楚","惡女阿楚"],["恶妇","惡婦"],["恶婆","惡婆"],["恶嫌","惡嫌"],["恶子","惡子"],["恶孽","惡孽"],["恶客","惡客"],["恶寒","惡寒"],["恶少","惡少"],["恶岁","惡歲"],["恶形","惡形"],["恶形恶状","惡形惡狀"],["恶徒","惡徒"],["恶德","惡德"],["恶心","噁心"],["恶心感","噁心感"],["恶念","惡念"],["恶怜","惡憐"],["恶性","惡性"],["恶性不改","惡性不改"],["恶性倒闭","惡性倒閉"],["恶性循环","惡性循環"],["恶性疟原虫","惡性瘧原蟲"],["恶性瘤","惡性瘤"],["恶性竞争","惡性競爭"],["恶性肿瘤","惡性腫瘤"],["恶性补习","惡性補習"],["恶性贫血","惡性貧血"],["恶性通货膨胀","惡性通貨膨脹"],["恶恶","惡惡"],["恶恶从短","惡惡從短"],["恶恶实实","惡惡實實"],["恶意","惡意"],["恶意中伤","惡意中傷"],["恶意代码","惡意代碼"],["恶意毁谤","惡意譭謗"],["恶感","惡感"],["恶战","惡戰"],["恶报","惡報"],["恶搞","惡搞"],["恶搞文化","惡搞文化"],["恶支杀","惡支殺"],["恶政","惡政"],["恶斗","惡鬥"],["恶曜","惡曜"],["恶月","惡月"],["恶有","惡有"],["恶有善报","惡有善報"],["恶有恶报","惡有惡報"],["恶极","惡極"],["恶果","惡果"],["恶梦","惡夢"],["恶梦探侦","惡夢探偵"],["恶棍","惡棍"],["恶棍歹徒","惡棍歹徒"],["恶模恶样","惡模惡樣"],["恶毒","惡毒"],["恶气","惡氣"],["恶水","惡水"],["恶汉","惡漢"],["恶法","惡法"],["恶浊","惡濁"],["恶浪","惡浪"],["恶湿居下","惡溼居下"],["恶灵","惡靈"],["恶煞","惡煞"],["恶犬","惡犬"],["恶狗","惡狗"],["恶狠","惡狠"],["恶狠狠","惡狠狠"],["恶狼","惡狼"],["恶疮","惡瘡"],["恶疾","惡疾"],["恶病质","惡病質"],["恶癖","惡癖"],["恶直丑正","惡直醜正"],["恶相","惡相"],["恶眉恶眼","惡眉惡眼"],["恶神","惡神"],["恶积祸盈","惡積禍盈"],["恶稔祸盈","惡稔禍盈"],["恶稔罪盈","惡稔罪盈"],["恶稔贯盈","惡稔貫盈"],["恶紫夺朱","惡紫奪朱"],["恶终","惡終"],["恶缘恶业","惡緣惡業"],["恶耗","惡耗"],["恶臭","惡臭"],["恶臭味","惡臭味"],["恶臭性","惡臭性"],["恶臭扑鼻","惡臭撲鼻"],["恶行","惡行"],["恶衣恶食","惡衣惡食"],["恶衣粝食","惡衣糲食"],["恶衣菲食","惡衣菲食"],["恶衣蔬食","惡衣蔬食"],["恶补","惡補"],["恶言","惡言"],["恶言伤人","惡言傷人"],["恶言恶语","惡言惡語"],["恶言泼语","惡言潑語"],["恶言相向","惡言相向"],["恶言詈辞","惡言詈辭"],["恶讯","惡訊"],["恶识","惡識"],["恶诧","惡詫"],["恶语","惡語"],["恶语中伤","惡語中傷"],["恶语伤人","惡語傷人"],["恶语相向","惡語相向"],["恶质","惡質"],["恶质化","惡質化"],["恶贯满盈","惡貫滿盈"],["恶贯祸盈","惡貫禍盈"],["恶贼","惡賊"],["恶赖","惡賴"],["恶趣","惡趣"],["恶躁","惡躁"],["恶运","惡運"],["恶运当头","惡運當頭"],["恶迹","惡跡"],["恶逆","惡逆"],["恶道","惡道"],["恶醉强酒","惡醉強酒"],["恶阻","惡阻"],["恶限","惡限"],["恶障","惡障"],["恶露","惡露"],["恶霸","惡霸"],["恶霸地主","惡霸地主"],["恶霸成性","惡霸成性"],["恶风","惡風"],["恶食","惡食"],["恶马恶人骑","惡馬惡人騎"],["恶骂","惡罵"],["恶鬼","惡鬼"],["恶魔","惡魔"],["恶魔党","惡魔黨"],["恶魔岛","惡魔島"],["悍药","悍藥"],["悒郁","悒鬱"],["悒郁不忿","悒鬱不忿"],["悒郁寡欢","悒鬱寡歡"],["悔不当初","悔不當初"],["悖入悖出","悖入悖出"],["悚栗","悚慄"],["悟出","悟出"],["悟出来","悟出來"],["悠哉游哉","悠哉遊哉"],["悠悠荡荡","悠悠盪盪"],["悠暗","悠闇"],["悠活丽致","悠活麗緻"],["悠游","悠遊"],["悠游卡","悠遊卡"],["悠游表","悠遊錶"],["悠然自适","悠然自適"],["悠荡","悠盪"],["悠闲地","悠閒地"],["悠闲自在","悠閒自在"],["患难之交才是真正的朋友","患難之交纔是真正的朋友"],["您克制","您剋制"],["悬吊","懸吊"],["悬岩","懸巖"],["悬岩峭壁","懸巖峭壁"],["悬心吊胆","懸心吊膽"],["悬念","懸念"],["悬挂","懸掛"],["悬挂国旗","懸掛國旗"],["悬挂在","懸掛在"],["悬挂式滑翔","懸掛式滑翔"],["悬挂式滑翔机","懸掛式滑翔機"],["悬挂物","懸掛物"],["悬旌万里","懸旌萬里"],["悬梁","懸樑"],["悬梁刺股","懸樑刺股"],["悬梁自尽","懸樑自盡"],["悬河注水","懸河注水"],["悬河注火","懸河注火"],["悬灯结彩","懸燈結彩"],["悬肠挂肚","懸腸掛肚"],["悬胄","懸冑"],["悬臂梁","懸臂樑"],["悬车致仕","懸車致仕"],["悬针","懸針"],["悬针垂露","懸針垂露"],["悬钟","懸鐘"],["悭吝苦克","慳吝苦剋"],["悲不自胜","悲不自勝"],["悲凄","悲悽"],["悲叹","悲嘆"],["悲咽","悲咽"],["悲喜交并","悲喜交並"],["悲回风","悲回風"],["悲怆交响曲","悲愴交響曲"],["悲悲戚戚","悲悲慼慼"],["悲愿","悲願"],["悲戚","悲慼"],["悲欢合散","悲歡合散"],["悲欢离合","悲歡離合"],["悲歌当哭","悲歌當哭"],["悲泗淋漓","悲泗淋漓"],["悲犬咸阳","悲犬咸陽"],["悲痛欲绝","悲痛欲絕"],["悲秋","悲秋"],["悲秋伤春","悲秋傷春"],["悲筑","悲筑"],["悲谷","悲谷"],["悲郁","悲鬱"],["悸栗","悸慄"],["悼念","悼念"],["惄如调饥","惄如調饑"],["情不愿","情不願"],["情不自胜","情不自勝"],["情人眼里出西施","情人眼裏出西施"],["情人眼里有西施","情人眼裏有西施"],["情仇","情仇"],["情僧录","情僧錄"],["情况证据","情況證據"],["情同一家","情同一家"],["情同手足","情同手足"],["情同骨肉","情同骨肉"],["情同鱼水","情同魚水"],["情孚意合","情孚意合"],["情弦","情弦"],["情志","情志"],["情急了","情急了"],["情感冲动","情感衝動"],["情愿","情願"],["情投意合","情投意合"],["情报系统","情報系統"],["情文并茂","情文並茂"],["情有所钟","情有所鍾"],["情有独钟","情有獨鍾"],["情欲","情慾"],["情欲戏","情慾戲"],["情溢于表","情溢於表"],["情种","情種"],["情系","情繫"],["情至意尽","情至意盡"],["情致","情致"],["情采","情采"],["情面","情面"],["情面难却","情面難卻"],["惇朴","惇樸"],["惊叹","驚歎"],["惊恐万分","驚恐萬分"],["惊恐万状","驚恐萬狀"],["惊才绝艳","驚才絕豔"],["惊赞","驚讚"],["惊钟","驚鐘"],["惊闺叶","驚閨葉"],["惊险百出","驚險百出"],["惋叹","惋嘆"],["惏栗","惏慄"],["惑志","惑志"],["惑术","惑術"],["惕栗","惕慄"],["惜别","惜別"],["惜别会","惜別會"],["惟天可表","惟天可表"],["惠塔克","惠塔克"],["惠里香","惠里香"],["惠鉴","惠鑑"],["惦念","惦念"],["惦挂","惦掛"],["惧于","懼於"],["惧高症","懼高症"],["惨历","慘歷"],["惨戚","慘慼"],["惨栗","慘慄"],["惨遭不幸","慘遭不幸"],["惩前毖后","懲前毖後"],["惩忿窒欲","懲忿窒欲"],["惩恶劝善","懲惡勸善"],["惩恶奖善","懲惡獎善"],["惬当","愜當"],["惯于","慣於"],["惯性系","慣性系"],["惯摆","慣擺"],["想不出","想不出"],["想不出来","想不出來"],["想个","想個"],["想个办法","想個辦法"],["想个方法","想個方法"],["想也别想","想也別想"],["想了","想了"],["想了又想","想了又想"],["想借","想借"],["想像出","想像出"],["想像出来","想像出來"],["想克制","想剋制"],["想出","想出"],["想出去","想出去"],["想出来","想出來"],["想前顾后","想前顧後"],["想回","想回"],["想回去","想回去"],["想回来","想回來"],["想尽","想盡"],["想尽办法","想盡辦法"],["想尽方法","想盡方法"],["想干","想幹"],["想干什么","想幹什麼"],["想当然","想當然"],["想当然耳","想當然耳"],["想录","想錄"],["想念","想念"],["想说出","想說出"],["想都别想","想都別想"],["惴栗","惴慄"],["惹人注意","惹人注意"],["惹人注目","惹人注目"],["惹出","惹出"],["惹出来","惹出來"],["惹口面","惹口面"],["惺松","惺鬆"],["愁云","愁雲"],["愁云惨雾","愁雲慘霧"],["愁容满面","愁容滿面"],["愁布袋","愁布袋"],["愁戚戚","愁慼慼"],["愆面","愆面"],["愈出愈奇","愈出愈奇"],["愈发","愈發"],["愈合","癒合"],["意会出","意會出"],["意克制","意剋制"],["意出望外","意出望外"],["意切言尽","意切言盡"],["意切辞尽","意切辭盡"],["意前笔后","意前筆後"],["意占","意佔"],["意合情投","意合情投"],["意向","意向"],["意向书","意向書"],["意大利直面","意大利直麪"],["意大利面","意大利麪"],["意广才疏","意廣才疏"],["意得志满","意得志滿"],["意志","意志"],["意志力","意志力"],["意志消沈","意志消沈"],["意志消沉","意志消沉"],["意念","意念"],["意思表示","意思表示"],["意愿","意願"],["意欲","意欲"],["意气相合","意氣相合"],["意气风发","意氣風發"],["意满志得","意滿志得"],["意犹未尽","意猶未盡"],["意表","意表"],["意见不合","意見不合"],["意见调査表","意見調查表"],["意识历程","意識歷程"],["意转心回","意轉心回"],["意里意思","意裏意思"],["意面","意麪"],["愚公谷","愚公谷"],["愚暗","愚闇"],["愚者千虑必有一得","愚者千慮必有一得"],["愚蒙","愚蒙"],["感于","感於"],["感冒药","感冒藥"],["感化饼干","感化餅乾"],["感发","感發"],["感叹","感嘆"],["感同身受","感同身受"],["感念","感念"],["感恩不尽","感恩不盡"],["感慨万千","感慨萬千"],["感激万分","感激萬分"],["感激不尽","感激不盡"],["感觉出","感覺出"],["感觉出来","感覺出來"],["愤发","憤發"],["愤而行凶","憤而行兇"],["愧不敢当","愧不敢當"],["愧于","愧於"],["愿不愿","願不願"],["愿不愿意","願不願意"],["愿力","願力"],["愿天下有","願天下有"],["愿寘诚念","願寘誠念"],["愿干一杯","願乾一杯"],["愿干这杯","願乾這杯"],["愿干那杯","願乾那杯"],["愿心","願心"],["愿意","願意"],["愿意不愿意","願意不願意"],["愿意干","願意幹"],["愿景","願景"],["愿望","願望"],["愿朴","愿樸"],["愿者上钩","願者上鉤"],["愿而恭","愿而恭"],["愿行","願行"],["愿谨","願謹"],["愿闻其详","願聞其詳"],["慈云","慈雲"],["慈制","慈制"],["慈安太后","慈安太后"],["慈悲喜舍","慈悲喜捨"],["慈禧太后","慈禧太后"],["慌了","慌了"],["慌了手脚","慌了手腳"],["慌了神儿","慌了神兒"],["慌作一团","慌作一團"],["慌成一团","慌成一團"],["慌里慌张","慌里慌張"],["慢了","慢了"],["慢咽","慢嚥"],["慢工出巧匠","慢工出巧匠"],["慢工出细活","慢工出細活"],["慢工出细货","慢工出細貨"],["慢曲","慢曲"],["慢板","慢板"],["慢板情歌","慢板情歌"],["慢游","慢遊"],["慢表","慢表"],["慧种","慧種"],["慨叹","慨嘆"],["慰借","慰藉"],["慰情胜无","慰情勝無"],["憎恶","憎惡"],["懂了","懂了"],["懈松","懈鬆"],["懒于","懶於"],["懒惰虫","懶惰蟲"],["懒虫","懶蟲"],["懔栗","懍慄"],["懰栗","懰慄"],["懵药","懵藥"],["懵里懵懂","懵裏懵懂"],["懿戚","懿戚"],["懿范","懿範"],["懿范长昭","懿範長昭"],["戏剧台","戲劇臺"],["戏剧团","戲劇團"],["戏剧系","戲劇系"],["戏台","戲臺"],["戏团","戲團"],["戏彩娱亲","戲綵娛親"],["戏曲","戲曲"],["戏曲馆","戲曲館"],["戏法人人会变巧妙各有不同","戲法人人會變巧妙各有不同"],["戏谷","戲谷"],["戏里","戲裏"],["成不了","成不了"],["成个儿","成個兒"],["成了","成了"],["成于","成於"],["成于思","成於思"],["成交价","成交價"],["成仇","成仇"],["成兆才","成兆才"],["成功的男人后面必有一个奉献的女人","成功的男人後面必有一個奉獻的女人"],["成功范例","成功範例"],["成千","成千"],["成千上万","成千上萬"],["成千成万","成千成萬"],["成千成百","成千成百"],["成千累万","成千累萬"],["成千论万","成千論萬"],["成合","成合"],["成名曲","成名曲"],["成名术","成名術"],["成周","成周"],["成团打块","成團打塊"],["成套出售","成套出售"],["成岩作用","成岩作用"],["成批出售","成批出售"],["成本价","成本價"],["成核","成核"],["成百上千","成百上千"],["成群打伙","成羣打夥"],["成群结伙","成羣結夥"],["成群结党","成羣結黨"],["成药","成藥"],["成虫","成蟲"],["成衣厂","成衣廠"],["成都卖卜","成都賣卜"],["成骨不全症","成骨不全症"],["我们死后将会洪水滔天","我們死後將會洪水滔天"],["我克制","我剋制"],["我党","我黨"],["我只","我只"],["我只有","我只有"],["我向","我向"],["我回","我回"],["我回到","我回到"],["我回去","我回去"],["我回来","我回來"],["我干一杯","我乾一杯"],["我念","我念"],["我愿","我願"],["我愿意","我願意"],["我扣","我扣"],["我搜","我搜"],["我系","我係"],["我醉欲眠","我醉欲眠"],["戒坛","戒壇"],["戒涂","戒塗"],["戒烟","戒菸"],["戒烟法","戒菸法"],["或于","或於"],["或系之牛","或繫之牛"],["或采","或採"],["战个","戰個"],["战了","戰了"],["战云","戰雲"],["战云密布","戰雲密佈"],["战云浓密","戰雲濃密"],["战前战后","戰前戰後"],["战后","戰後"],["战团","戰團"],["战地钟声","戰地鐘聲"],["战士授田凭据","戰士授田憑據"],["战天斗地","戰天鬥地"],["战战栗栗","戰戰慄慄"],["战斗","戰鬥"],["战斗人员","戰鬥人員"],["战斗任务","戰鬥任務"],["战斗力","戰鬥力"],["战斗区","戰鬥區"],["战斗员","戰鬥員"],["战斗意志","戰鬥意志"],["战斗旅","戰鬥旅"],["战斗机","戰鬥機"],["战斗编组","戰鬥編組"],["战斗群","戰鬥羣"],["战斗者","戰鬥者"],["战斗舰","戰鬥艦"],["战斗英雄","戰鬥英雄"],["战斗营","戰鬥營"],["战斗行为","戰鬥行爲"],["战斗车","戰鬥車"],["战斗轰炸","戰鬥轟炸"],["战斗队形","戰鬥隊形"],["战无不克","戰無不克"],["战无不胜","戰無不勝"],["战无不胜攻无不克","戰無不勝攻無不克"],["战无不胜攻无不取","戰無不勝攻無不取"],["战术","戰術"],["战术导弹","戰術導彈"],["战术核武器","戰術核武器"],["战术轰炸","戰術轟炸"],["战栗","戰慄"],["战略伙伴","戰略伙伴"],["战略防御倡议","戰略防禦倡議"],["战胜","戰勝"],["战胜国","戰勝國"],["战表","戰表"],["戚串","戚串"],["戚党","戚黨"],["戚凯罗","戚凱羅"],["戚友","戚友"],["戚墅堰","慼墅堰"],["戚墅堰区","慼墅堰區"],["戚夫人","戚夫人"],["戚家军","戚家軍"],["戚容","戚容"],["戚属","戚屬"],["戚戚","慼慼"],["戚施","戚施"],["戚族","戚族"],["戚旧","戚舊"],["戚然","戚然"],["戚继光","戚繼光"],["戚谊","戚誼"],["戚里","戚里"],["戛云","戛雲"],["截发","截髮"],["截发留宾","截髮留賓"],["截板","截板"],["截然不同","截然不同"],["截获","截獲"],["截趾适履","截趾適履"],["截趾适屦","截趾適屨"],["截面","截面"],["截面图","截面圖"],["戬谷","戩穀"],["戮力同心","戮力同心"],["戮尸","戮屍"],["戳个儿","戳個兒"],["戳脊梁","戳脊樑"],["戳脊梁骨","戳脊梁骨"],["戴个","戴個"],["戴了","戴了"],["戴克","戴克"],["戴克拉克","戴克拉克"],["戴克辛","戴克辛"],["戴出","戴出"],["戴出去","戴出去"],["戴出来","戴出來"],["戴发含齿","戴髮含齒"],["戴天之仇","戴天之仇"],["戴姆勒克莱斯勒","戴姆勒克萊斯勒"],["戴希穆克","戴希穆克"],["戴瑞克罗","戴瑞克羅"],["戴维斯杯","戴維斯盃"],["戴胜益","戴勝益"],["戴胜通","戴勝通"],["戴蒙","戴蒙"],["戴蒙德","戴蒙德"],["戴表","戴錶"],["戴表元","戴表元"],["戴诚志","戴誠志"],["户口制","戶口制"],["户口制度","戶口制度"],["户对门当","戶對門當"],["戽斗","戽斗"],["房中术","房中術"],["房价","房價"],["房地产共同基金","房地產共同基金"],["房地价","房地價"],["房室结回路","房室結迴路"],["房屋修护","房屋修護"],["房屋修护费","房屋修護費"],["房屋里","房屋裏"],["房舍","房舍"],["房里","房裏"],["所云","所云"],["所云云","所云云"],["所余","所餘"],["所剩无几","所剩無幾"],["所占","所佔"],["所发现","所發現"],["所向","所向"],["所向披靡","所向披靡"],["所向无前","所向無前"],["所向无敌","所向無敵"],["所周知","所周知"],["所布之","所佈之"],["所布的","所佈的"],["所干","所幹"],["所幸","所幸"],["所念","所念"],["所托","所託"],["所扣","所扣"],["所有制","所有制"],["所系","所繫"],["所致","所致"],["所见略同","所見略同"],["所见而云","所見而云"],["所讥而云","所譏而云"],["所谓而云","所謂而云"],["扁担压不出个屁来","扁擔壓不出個屁來"],["扁拟谷盗虫","扁擬穀盜蟲"],["扁铲","扁鏟"],["扁锹形虫","扁鍬形蟲"],["扇叶蒲葵","扇葉蒲葵"],["扇面","扇面"],["扇面对","扇面對"],["扇面琴","扇面琴"],["手一卷","手一捲"],["手一松","手一鬆"],["手不松","手不鬆"],["手不释卷","手不釋卷"],["手写识别","手寫識別"],["手冢治虫","手冢治虫"],["手到回春","手到回春"],["手制","手製"],["手制动","手制動"],["手卷","手卷"],["手同脚","手同腳"],["手工台","手工檯"],["手彩儿","手彩兒"],["手心里","手心裏"],["手折","手摺"],["手挽手","手挽手"],["手掌多汗症","手掌多汗症"],["手摇杯","手搖杯"],["手擀面","手擀麪"],["手术","手術"],["手术刀","手術刀"],["手术台","手術檯"],["手术室","手術室"],["手术房","手術房"],["手术用","手術用"],["手术衣","手術衣"],["手术费","手術費"],["手松","手鬆"],["手板","手板"],["手板子","手板子"],["手板葫芦","手板葫蘆"],["手腕式指北针","手腕式指北針"],["手表","手錶"],["手表带","手錶帶"],["手足口症","手足口症"],["手酸","手痠"],["手采","手採"],["手里","手裏"],["手里余","手裏餘"],["手铲","手鏟"],["手链","手鍊","手鏈"],["手面","手面"],["手面赚吃","手面賺吃"],["才上到","纔上到"],["才上去","纔上去"],["才上来","纔上來"],["才下去","纔下去"],["才下来","纔下來"],["才不","纔不"],["才不会","纔不會"],["才不是","纔不是"],["才不能","纔不能"],["才为世出","才爲世出"],["才买","纔買"],["才人","才人"],["才会","纔會"],["才会到","纔會到"],["才会在","纔會在"],["才会有","纔會有"],["才俊","才俊"],["才信","纔信"],["才储八斗","才儲八斗"],["才像","纔像"],["才像是","纔像是"],["才具","才具"],["才兼文武","才兼文武"],["才再","纔再"],["才出","纔出"],["才出去","纔出去"],["才出来","纔出來"],["才分","才分"],["才则","纔則"],["才刚","纔剛"],["才到","纔到"],["才力","才力"],["才勇兼优","才勇兼優"],["才华","才華"],["才华出众","才華出衆"],["才华横溢","才華橫溢"],["才华洋溢","才華洋溢"],["才华盖世","才華蓋世"],["才去","纔去"],["才可","纔可"],["才可以","纔可以"],["才可容颜十五余","纔可容顏十五餘"],["才名","才名"],["才器","才器"],["才回","纔回"],["才回到","纔回到"],["才回去","纔回去"],["才回来","纔回來"],["才在","纔在"],["才士","才士"],["才多","纔多"],["才多出","纔多出"],["才够","纔夠"],["才大难用","才大難用"],["才女","才女"],["才好","纔好"],["才如史迁","才如史遷"],["才始","纔始"],["才媛","才媛"],["才子","才子"],["才子书","才子書"],["才子佳人","才子佳人"],["才学","才學"],["才学兼优","才學兼優"],["才守","才守"],["才定","才定"],["才对","纔對"],["才将","纔將"],["才干","才幹"],["才干旱","纔乾旱"],["才干杯","纔乾杯"],["才干淨","纔乾淨"],["才干透","纔乾透"],["才广妨身","才廣妨身"],["才开","纔開"],["才开出","纔開出"],["才开到","纔開到"],["才当曹斗","才當曹斗"],["才得两年","纔得兩年"],["才得到","纔得到"],["才微智浅","才微智淺"],["才德","才德"],["才德兼备","才德兼備"],["才思","才思"],["才思敏捷","才思敏捷"],["才怪","纔怪"],["才悟","才悟"],["才情","才情"],["才想","纔想"],["才打","纔打"],["才打出","纔打出"],["才打到","纔打到"],["才拿","纔拿"],["才拿出","纔拿出"],["才拿到","纔拿到"],["才敢","纔敢"],["才料","纔料"],["才是","纔是"],["才智","才智"],["才有","纔有"],["才望","才望"],["才来","纔來"],["才来到","纔來到"],["才松下","纔鬆下"],["才此","纔此"],["才气","才氣"],["才气无双","才氣無雙"],["才气纵横","才氣縱橫"],["才气过人","才氣過人"],["才没","纔沒"],["才没有","纔沒有"],["才没能","纔沒能"],["才派","纔派"],["才派人","纔派人"],["才爲","纔爲"],["才用","才用"],["才用到","纔用到"],["才略","才略"],["才略过人","才略過人"],["才疏学浅","才疏學淺"],["才疏德薄","才疏德薄"],["才疏志大","才疏志大"],["才疏意广","才疏意廣"],["才疏计拙","才疏計拙"],["才看","纔看"],["才看出","纔看出"],["才看到","纔看到"],["才短气粗","才短氣粗"],["才秀人微","才秀人微"],["才等","纔等"],["才等到","纔等到"],["才算","纔算"],["才算是","纔算是"],["才给","纔給"],["才能","才能","纔能"],["才能勇敢追","纔能勇敢追"],["才能夠","纔能夠"],["才能干济","才能幹濟"],["才能有","纔能有"],["才色","才色"],["才艺","才藝"],["才艺卓绝","才藝卓絕"],["才艺技能","才藝技能"],["才艺班","才藝班"],["才艺秀","才藝秀"],["才蔽识浅","才蔽識淺"],["才藻","才藻"],["才行","才行"],["才要","纔要"],["才讲","纔講"],["才识","才識"],["才识过人","才識過人"],["才语","才語"],["才读","纔讀"],["才读到","纔讀到"],["才貌","才貌"],["才貌出众","才貌出衆"],["才貌双全","才貌雙全"],["才贯二酉","才貫二酉"],["才资","才資"],["才起来","纔起來"],["才跟","纔跟"],["才轻德薄","才輕德薄"],["才过去","纔過去"],["才过子建","才過子建"],["才过屈宋","才過屈宋"],["才过来","纔過來"],["才非玉润","才非玉潤"],["才高八斗","才高八斗"],["才高意广","才高意廣"],["才高气傲","才高氣傲"],["才高行厚","才高行厚"],["才高行洁","才高行潔"],["扎上","紮上"],["扎上去","紮上去"],["扎上来","紮上來"],["扎下","紮下"],["扎下去","紮下去"],["扎下来","紮下來"],["扎乎","扎乎"],["扎了","紮了"],["扎伊尔","扎伊爾"],["扎住","扎住"],["扎兰屯","扎蘭屯"],["扎兰屯市","扎蘭屯市"],["扎到","扎到"],["扎卡维","扎卡維"],["扎啤","扎啤"],["扎嘴","扎嘴"],["扎囊","扎囊"],["扎囊县","扎囊縣"],["扎囮","紮囮"],["扎在","紮在"],["扎垫","扎墊"],["扎堆","扎堆"],["扎好","紮好"],["扎好底子","紮好底子"],["扎好根","紮好根"],["扎实","紮實"],["扎实推进","紮實推進"],["扎寨","紮寨"],["扎尔达里","扎爾達里"],["扎带","紮帶"],["扎带子","紮帶子"],["扎心","扎心"],["扎成","紮成"],["扎手","扎手"],["扎手舞脚","扎手舞腳"],["扎扎","扎扎"],["扎扎实实","紮紮實實"],["扎括","扎括"],["扎挣","扎掙"],["扎掂","扎掂"],["扎撒","扎撒"],["扎枪","扎槍"],["扎根","紮根"],["扎格罗斯","扎格羅斯"],["扎格罗斯山脉","扎格羅斯山脈"],["扎欧扎翁","紮歐紮翁"],["扎煞","扎煞"],["扎猛子","扎猛子"],["扎眉扎眼","扎眉扎眼"],["扎眼","扎眼"],["扎空枪","扎空槍"],["扎穿","扎穿"],["扎窝子","扎窩子"],["扎筏子","扎筏子"],["扎紧","紮緊"],["扎线带","紮線帶"],["扎结","紮結"],["扎缚","扎縛"],["扎罚子","扎罰子"],["扎耳朵","扎耳朵"],["扎脑门儿","扎腦門兒"],["扎脚","紮腳"],["扎花","扎花"],["扎草","扎草"],["扎营","紮營"],["扎裹","紮裹"],["扎诈","紮詐"],["扎赉特","扎賚特"],["扎赉特旗","扎賚特旗"],["扎起","紮起"],["扎起来","紮起來"],["扎针","扎針"],["扎铁","紮鐵"],["扎马剌丁","紮馬剌丁"],["扎马鲁丁","紮馬魯丁"],["扎鲁特","扎魯特"],["扎鲁特旗","扎魯特旗"],["扑个满怀","撲個滿懷"],["扑个空","撲個空"],["扑了","撲了"],["扑克","撲克"],["扑克牌","撲克牌"],["扑克脸","撲克臉"],["扑冬","撲鼕"],["扑冬冬","撲鼕鼕"],["扑出","撲出"],["扑出去","撲出去"],["扑出来","撲出來"],["扑同","撲同"],["扑向","撲向"],["扑复","撲復"],["扑灭蚊虫","撲滅蚊蟲"],["扑通通冬","撲通通冬"],["扑面","撲面"],["扑面而来","撲面而來"],["扒出","扒出"],["打一个吞","打一個吞"],["打个","打個"],["打个前失","打個前失"],["打个千儿","打個千兒"],["打个沉儿","打個沉兒"],["打个照会","打個照會"],["打个照面","打個照面"],["打个花","打個花"],["打个问号","打個問號"],["打中伙","打中伙"],["打了一个闷雷","打了一個悶雷"],["打了个千儿","打了個千兒"],["打了个盹儿","打了個盹兒"],["打了个落花流水","打了個落花流水"],["打了偏手","打了偏手"],["打了半跪","打了半跪"],["打了牙肚里嚥","打了牙肚裏嚥"],["打价","打價"],["打伙","打夥"],["打伙子穿靴","打夥子穿靴"],["打冲锋","打衝鋒"],["打出","打出"],["打出去","打出去"],["打出吊入","打出弔入"],["打出头棍","打出頭棍"],["打出头棒子","打出頭棒子"],["打出手","打出手"],["打出来","打出來"],["打击报复","打擊報復"],["打击板","打擊板"],["打制","打製"],["打制石器","打製石器"],["打千","打千"],["打卡钟","打卡鐘"],["打卤面","打滷麪"],["打印台","打印臺"],["打印范围","打印範圍"],["打参","打參"],["打发","打發"],["打发掉","打發掉"],["打发时间","打發時間"],["打合","打合"],["打向","打向"],["打听出","打聽出"],["打和哄","打和哄"],["打哄","打鬨"],["打回","打回"],["打回去","打回去"],["打回来","打回來"],["打回票","打回票"],["打团","打團"],["打墙板儿翻上下","打牆板兒翻上下"],["打夜胡","打夜胡"],["打太极","打太極"],["打太极拳","打太極拳"],["打完针","打完針"],["打家劫舍","打家劫舍"],["打对台","打對臺"],["打干","打幹"],["打干哕","打乾噦"],["打干淨毬儿","打乾淨毬兒"],["打并","打併"],["打开后门说","打開後門說"],["打开板壁讲亮话","打開板壁講亮話"],["打当","打當"],["打心眼里","打心眼裏"],["打恶心","打噁心"],["打成一团","打成一團"],["打扑克","打撲克"],["打折","打折"],["打折扣","打折扣"],["打折网","打折網"],["打报台","打報臺"],["打抽丰","打抽豐"],["打拐","打拐"],["打挨","打捱"],["打摆子","打擺子"],["打擂台","打擂臺"],["打斗","打鬥"],["打斗片","打鬥片"],["打暗号","打暗號"],["打来回","打來回"],["打板","打板"],["打板子","打板子"],["打桨杆","打槳桿"],["打棍出箱","打棍出箱"],["打没头坛","打沒頭壇"],["打淨捞干","打淨撈乾"],["打游击","打游擊"],["打游飞","打游飛"],["打照面","打照面"],["打狗不看主人面","打狗不看主人面"],["打狗也要看主人面","打狗也要看主人面"],["打狗看主人面","打狗看主人面"],["打破纪录","打破紀錄"],["打秋丰","打秋豐"],["打秋千","打鞦韆"],["打秋风","打秋風"],["打筋斗","打筋斗"],["打簧表","打簧錶"],["打紧板","打緊板"],["打绝板","打絕板"],["打翻了的牛奶而哭泣","打翻了的牛奶而哭泣"],["打老鼠伤了玉瓶","打老鼠傷了玉瓶"],["打耳刮子","打耳刮子"],["打胜","打勝"],["打胜仗","打勝仗"],["打胡哨","打胡哨"],["打花胡哨","打花胡哨"],["打药","打藥"],["打蛇不死后患无穷","打蛇不死後患無窮"],["打蜡","打蠟"],["打蜡机","打蠟機"],["打话不同","打話不同"],["打诨发科","打諢發科"],["打谷","打穀"],["打谷场","打穀場"],["打谷机","打穀機"],["打路庄板","打路莊板"],["打造出","打造出"],["打道回府","打道回府"],["打里打外","打裏打外"],["打里照外","打裏照外"],["打野胡","打野胡"],["打量出","打量出"],["打针","打針"],["打钟","打鐘"],["打靠后","打靠後"],["打风后","打風後"],["打饥荒","打饑荒"],["扔出","扔出"],["扔出去","扔出去"],["扔出来","扔出來"],["扔回","扔回"],["扔回去","扔回去"],["扔回来","扔回來"],["扔在脑后","扔在腦後"],["托买","託買"],["托了","託了"],["托事","託事"],["托交","託交"],["托人","託人"],["托人情","託人情"],["托付","託付"],["托住","托住"],["托儿","托兒"],["托儿所","託兒所"],["托克","托克"],["托克托","托克托"],["托克托县","托克托縣"],["托克逊","托克遜"],["托克逊县","托克遜縣"],["托出","托出"],["托利党人","托利黨人"],["托利米尔","托利米爾"],["托勒","托勒"],["托勒密","托勒密"],["托勒密王","托勒密王"],["托勒尔","托勒爾"],["托勒玫","托勒玫"],["托卖","託賣"],["托古讽今","託古諷今"],["托叶","托葉"],["托名","託名"],["托命","託命"],["托咎","託咎"],["托地","托地"],["托塔天王","托塔天王"],["托塞洛","托塞洛"],["托墨","托墨"],["托大","託大"],["托夫","托夫"],["托子","托子"],["托孤","託孤"],["托实","托實"],["托尔","托爾"],["托尔斯泰","托爾斯泰"],["托尔金","托爾金"],["托幼","托幼"],["托庇","託庇"],["托拉","托拉"],["托拉博拉","托拉博拉"],["托拉斯","托拉斯"],["托故","託故"],["托斯卡","托斯卡"],["托斯卡尼","托斯卡尼"],["托斯卡尼尼","托斯卡尼尼"],["托木尔","托木爾"],["托木尔峰","托木爾峯"],["托杯","托杯"],["托架","托架"],["托梦","託夢"],["托比亚斯","托比亞斯"],["托比麦奎尔","托比麥奎爾"],["托洛斯基","托洛斯基"],["托洛茨基","托洛茨基"],["托派","託派"],["托熟","托熟"],["托特","托特"],["托瑞丝","托瑞絲"],["托瑞赛","托瑞賽"],["托生","託生"],["托疾","託疾"],["托病","託病"],["托登汉队","托登漢隊"],["托盘","托盤"],["托盘区","托盤區"],["托福","託福"],["托福考","托福考"],["托福考试","托福考試"],["托管","託管"],["托管国","託管國"],["托米","托米"],["托米欧佳","托米歐佳"],["托维","托維"],["托罗斯山","托羅斯山"],["托老中心","托老中心"],["托老院","托老院"],["托育","托育"],["托胆","托膽"],["托胎","托胎"],["托腮","托腮"],["托色","托色"],["托荤咸食","托葷鹹食"],["托莱多","托萊多"],["托蒂","托蒂"],["托言","託言"],["托词","託詞"],["托赖","托賴"],["托起","托起"],["托起来","托起來"],["托足","托足"],["托足无门","托足無門"],["托身","託身"],["托辞","託辭"],["托辣斯","托辣斯"],["托辣斯法","托辣斯法"],["托过","託過"],["托运","託運"],["托运行李","托運行李"],["托里","托裏"],["托里县","托裏縣"],["托里拆利","托裏拆利"],["托鉢","托鉢"],["托钵人","托鉢人"],["托钵修会","托鉢修會"],["托钵僧","托鉢僧"],["托附","託附"],["托领","托領"],["托马","托馬"],["托马斯","托馬斯"],["托马斯阿奎纳","托馬斯阿奎納"],["扛了","扛了"],["扛出","扛出"],["扛出去","扛出去"],["扛出来","扛出來"],["扛大梁","扛大樑"],["扞御","扞禦"],["扣一","扣一"],["扣上","扣上"],["扣下","扣下"],["扣了","扣了"],["扣人","扣人"],["扣件","扣件"],["扣住","扣住"],["扣作","扣作"],["扣你","扣你"],["扣儿","扣兒"],["扣光","扣光"],["扣克","扣剋"],["扣入","扣入"],["扣减","扣減"],["扣出","扣出"],["扣击","扣擊"],["扣分","扣分"],["扣分标准","扣分標準"],["扣划","扣劃"],["扣到","扣到"],["扣动","扣動"],["扣压","扣壓"],["扣去","扣去"],["扣发","扣發"],["扣取","扣取"],["扣响","扣響"],["扣啊","扣啊"],["扣回","扣回"],["扣回去","扣回去"],["扣回来","扣回來"],["扣在","扣在"],["扣头","扣頭"],["扣女","扣女"],["扣好","扣好"],["扣子","釦子"],["扣完","扣完"],["扣将","扣將"],["扣带","扣帶"],["扣开","扣開"],["扣得","扣得"],["扣我","扣我"],["扣扣","扣扣"],["扣抵","扣抵"],["扣押","扣押"],["扣掉","扣掉"],["扣杀","扣殺"],["扣板","扣板"],["扣板机","扣板機"],["扣查","扣查"],["扣款","扣款"],["扣法","扣法"],["扣满","扣滿"],["扣点","扣點"],["扣牌","扣牌"],["扣牢","扣牢"],["扣率","扣率"],["扣环","釦環"],["扣球","扣球"],["扣留","扣留"],["扣的","扣的"],["扣眼","釦眼"],["扣着","扣着"],["扣税","扣稅"],["扣篮","扣籃"],["扣紧","扣緊"],["扣绊","扣絆"],["扣缴","扣繳"],["扣罚","扣罰"],["扣肉","扣肉"],["扣船","扣船"],["扣薪","扣薪"],["扣表","扣表"],["扣费","扣費"],["扣起","扣起"],["扣车","扣車"],["扣过","扣過"],["扣进","扣進"],["扣针","釦針"],["扣钩","扣鉤"],["扣钱","扣錢"],["扣锁","扣鎖"],["扣门","扣門"],["扣问","扣問"],["扣除","扣除"],["扣题","扣題"],["执念","執念"],["执政党","執政黨"],["执政团","執政團"],["执板","執板"],["执行面","執行面"],["扩厂","擴廠"],["扩厂计划","擴廠計劃"],["扩大范围","擴大範圍"],["扩建工厂","擴建工廠"],["扩张术","擴張術"],["扩散出来","擴散出來"],["扩音机系统","擴音機系統"],["扪参历井","捫參歷井"],["扪隙发罅","捫隙發罅"],["扫出","掃出"],["扫出去","掃出去"],["扫出来","掃出來"],["扫地俱尽","掃地俱盡"],["扫地出门","掃地出門"],["扫干淨","掃乾淨"],["扫晴娘","掃晴娘"],["扫田刮地","掃田刮地"],["扫眉才子","掃眉才子"],["扫荡","掃蕩"],["扫荡残敌","掃蕩殘敵"],["扬升","揚升"],["扬名后世","揚名後世"],["扬名立万","揚名立萬"],["扬善去恶","揚善去惡"],["扬善隐恶","揚善隱惡"],["扬州清曲","揚州清曲"],["扬州画舫录","揚州畫舫錄"],["扬己露才","揚己露才"],["扬谷","揚穀"],["扭出","扭出"],["扭出去","扭出去"],["扭出来","扭出來"],["扭别","扭別"],["扭头折颈","扭頭折頸"],["扭成一团","扭成一團"],["扭摆","扭擺"],["扭摆不停","扭擺不停"],["扭曲","扭曲"],["扭曲作直","扭曲作直"],["扭转乾坤","扭轉乾坤"],["扮装皇后","扮裝皇后"],["扯出","扯出"],["扯出去","扯出去"],["扯出来","扯出來"],["扯后腿","扯後腿"],["扯篷拉纤","扯篷拉縴"],["扯纤","扯縴"],["扯闲白","扯閒白"],["扯闲盘儿","扯閒盤兒"],["扯闲篇","扯閒篇"],["扯面","扯麪"],["扰流板","擾流板"],["扳回","扳回"],["扳回一城","扳回一城"],["扶了","扶了"],["扶余","扶余"],["扶余县","扶余縣"],["扶余国","扶餘國"],["扶出","扶出"],["扶出去","扶出去"],["扶出来","扶出來"],["扶危救困","扶危救困"],["扶危济困","扶危濟困"],["扶同","扶同"],["扶同硬证","扶同硬證"],["扶同诖误","扶同詿誤"],["扶善惩恶","扶善懲惡"],["扶幼周","扶幼週"],["扶手椅里","扶手椅裏"],["扶苏","扶蘇"],["扶贫济困","扶貧濟困"],["批价","批價"],["批准","批准"],["批准下来","批准下來"],["批准书","批准書"],["批准的","批准的"],["批出","批出"],["批出去","批出去"],["批出来","批出來"],["批发","批發"],["批发业","批發業"],["批发价","批發價"],["批发价格","批發價格"],["批发商","批發商"],["批发市场","批發市場"],["批发店","批發店"],["批回","批迴"],["批复","批覆"],["批尸","批屍"],["批斗","批鬥"],["批核","批覈"],["批汇","批匯"],["批注","批註"],["批荡","批蕩"],["扼制","扼制"],["找不准","找不準"],["找不出","找不出"],["找个","找個"],["找了","找了"],["找价","找價"],["找借口","找藉口"],["找出","找出"],["找出去","找出去"],["找出来","找出來"],["找出路","找出路"],["找台阶","找臺階"],["找台阶下","找臺階下"],["找台阶儿","找臺階兒"],["找回","找回"],["找回去","找回去"],["找回来","找回來"],["找寻出","找尋出"],["找面子","找面子"],["承修","承修"],["承先启后","承先啓後"],["承制","承製"],["承前启后","承前啓後"],["承受不了","承受不了"],["承宣布政使司","承宣布政使司"],["承平面","承平面"],["承当","承當"],["承当不起","承當不起"],["承蒙","承蒙"],["承蒙关照","承蒙關照"],["承蒙指教","承蒙指教"],["承销价差","承銷價差"],["承销团","承銷團"],["技术","技術"],["技术专科","技術專科"],["技术专科学校","技術專科學校"],["技术人员","技術人員"],["技术作物","技術作物"],["技术分析","技術分析"],["技术单位","技術單位"],["技术发展","技術發展"],["技术合作","技術合作"],["技术员","技術員"],["技术团","技術團"],["技术士","技術士"],["技术处","技術處"],["技术学院","技術學院"],["技术官","技術官"],["技术性","技術性"],["技术情报","技術情報"],["技术所限","技術所限"],["技术指导","技術指導"],["技术援助","技術援助"],["技术故障","技術故障"],["技术标准","技術標準"],["技术水准","技術水準"],["技术水平","技術水平"],["技术潜水","技術潛水"],["技术犯规","技術犯規"],["技术知识","技術知識"],["技术装备","技術裝備"],["技术规范","技術規範"],["技术部","技術部"],["技术部门","技術部門"],["技术降落","技術降落"],["技术面","技術面"],["技术革命","技術革命"],["技术革新","技術革新"],["技艺团","技藝團"],["抄发","抄發"],["抄台","抄臺"],["抄后路","抄後路"],["抄录","抄錄"],["抄录下来","抄錄下來"],["抄录在","抄錄在"],["抄录编目","抄錄編目"],["抄手游廊","抄手遊廊"],["抄扎","抄扎"],["抄获","抄獲"],["把上了","把上了"],["把个","把個"],["把了","把了"],["把你干","把你幹"],["把卷","把卷"],["把定了心","把定了心"],["把方才","把方纔"],["把脸一板","把臉一板"],["把饭叫饥","把飯叫饑"],["抑制","抑制"],["抑制作用","抑制作用"],["抑制剂","抑制劑"],["抑制器","抑制器"],["抑制栽培","抑制栽培"],["抑制酶","抑制酶"],["抑恶扬善","抑惡揚善"],["抑扬升降性","抑揚昇降性"],["抑郁","抑鬱"],["抑郁不平","抑鬱不平"],["抑郁寡欢","抑鬱寡歡"],["抑郁症","抑鬱症"],["抒发","抒發"],["抒情曲","抒情曲"],["抒情歌曲","抒情歌曲"],["抓不准","抓不準"],["抓准","抓準"],["抓出","抓出"],["抓出去","抓出去"],["抓出来","抓出來"],["抓周","抓週"],["抓回","抓回"],["抓回去","抓回去"],["抓回来","抓回來"],["抓奸","抓姦"],["抓彩","抓彩"],["抓斗","抓鬥"],["抓药","抓藥"],["抓获","抓獲"],["抔土未干","抔土未乾"],["投不准","投不準"],["投不出","投不出"],["投了","投了"],["投井自尽","投井自盡"],["投出","投出"],["投出去","投出去"],["投出来","投出來"],["投合","投合"],["投向","投向"],["投回","投回"],["投射出","投射出"],["投影几何","投影幾何"],["投影几何学","投影幾何學"],["投影面","投影面"],["投手板","投手板"],["投手防御率","投手防禦率"],["投托","投托"],["投梭折齿","投梭折齒"],["投河自尽","投河自盡"],["投注","投注"],["投注站","投注站"],["投潘岳果","投潘岳果"],["投环自尽","投環自盡"],["投票表决","投票表決"],["投药","投藥"],["投闲置散","投閒置散"],["抖了","抖了"],["抖了起来","抖了起來"],["抖出","抖出"],["抖出去","抖出去"],["抖出来","抖出來"],["抖搜精神","抖搜精神"],["抗了","抗了"],["抗噪","抗噪"],["抗干扰性","抗干擾性"],["抗御","抗禦"],["抗志","抗志"],["抗忧郁药","抗憂鬱藥"],["抗战歌曲","抗戰歌曲"],["抗战胜利","抗戰勝利"],["抗拒不了","抗拒不了"],["抗日救亡团体","抗日救亡團體"],["抗病品种","抗病品種"],["抗病毒药","抗病毒藥"],["抗癌药","抗癌藥"],["抗癌药物","抗癌藥物"],["抗组胺药","抗組胺藥"],["抗药","抗藥"],["抗药性","抗藥性"],["抗药能力","抗藥能力"],["抗菌药","抗菌藥"],["抗逆转录","抗逆轉錄"],["折上","折上"],["折上去","折上去"],["折上来","折上來"],["折下","折下"],["折下去","折下去"],["折下来","折下來"],["折不断","折不斷"],["折中","折中"],["折价","折價"],["折价出售","折價出售"],["折价券","折價券"],["折价卷","折價卷"],["折伤","折傷"],["折倒","折倒"],["折光","折光"],["折兑","折兌"],["折兑率","折兌率"],["折兵","折兵"],["折冲","折衝"],["折冲厌难","折衝厭難"],["折冲尊俎","折衝尊俎"],["折冲御侮","折衝禦侮"],["折冲樽俎","折衝樽俎"],["折刀","折刀"],["折刀儿","折刀兒"],["折券","折券"],["折剉","折剉"],["折半","折半"],["折半出售","折半出售"],["折卖","折賣"],["折受","折受"],["折变","折變"],["折叠","摺疊"],["折叠为","摺疊爲"],["折叠式","摺疊式"],["折叠扇","摺疊扇"],["折叠椅","摺疊椅"],["折叠牀","摺疊牀"],["折叠起来","摺疊起來"],["折台","折檯"],["折合","摺合"],["折合椅","摺合椅"],["折回","折回"],["折回去","折回去"],["折回来","折回來"],["折壁脚","折壁腳"],["折头","折頭"],["折奏","摺奏"],["折好","摺好"],["折子","摺子"],["折子戏","摺子戲"],["折实","折實"],["折对","折對"],["折寿","折壽"],["折射","折射"],["折射光","折射光"],["折射出","折射出"],["折射式望远镜","折射式望遠鏡"],["折射波","折射波"],["折射率","折射率"],["折射线","折射線"],["折射角","折射角"],["折尺","摺尺"],["折屐","折屐"],["折帐","折帳"],["折弯","折彎"],["折当","折當"],["折得","折得"],["折成","折成"],["折戟沈河","折戟沈河"],["折戟沉沙","折戟沉沙"],["折扇","摺扇"],["折扣","折扣"],["折扣价","折扣價"],["折扣战","折扣戰"],["折扣率","折扣率"],["折抵","折抵"],["折挫","折挫"],["折损","折損"],["折损率","折損率"],["折断","折斷"],["折旧","折舊"],["折旧基金","折舊基金"],["折旧率","折舊率"],["折旧费","折舊費"],["折服","折服"],["折本","折本"],["折杀","折殺"],["折枝","折枝"],["折柬","折柬"],["折柳","折柳"],["折柳攀花","折柳攀花"],["折桂","折桂"],["折桂攀蟾","折桂攀蟾"],["折梯","摺梯"],["折椅","摺椅"],["折狱","折獄"],["折现","折現"],["折现率","折現率"],["折痕","摺痕"],["折的","折的"],["折碗","折碗"],["折磨","折磨"],["折福","折福"],["折秤","折秤"],["折简","折簡"],["折算","折算"],["折算法","折算法"],["折算率","折算率"],["折箩","折籮"],["折箭","折箭"],["折箭为盟","折箭爲盟"],["折箭为誓","折箭爲誓"],["折篷","摺篷"],["折纸","摺紙"],["折纸工","摺紙工"],["折线","折線"],["折缝","折縫"],["折罚","折罰"],["折翼","折翼"],["折耗","折耗"],["折肱","折肱"],["折腰","折腰"],["折腰五斗","折腰五斗"],["折腰升斗","折腰升斗"],["折腰步","折腰步"],["折腾","折騰"],["折臂三公","折臂三公"],["折色","折色"],["折节","折節"],["折节下交","折節下交"],["折节下士","折節下士"],["折节向学","折節向學"],["折节待士","折節待士"],["折节礼士","折節禮士"],["折节读书","折節讀書"],["折莫","折莫"],["折行","折行"],["折衷","折衷"],["折衷主义","折衷主義"],["折衷家庭","折衷家庭"],["折衷方案","折衷方案"],["折衷法","折衷法"],["折衷鹦鹉","折衷鸚鵡"],["折裙","摺裙"],["折角","折角"],["折让","折讓"],["折证","折證"],["折账","折賬"],["折起","折起"],["折起来","折起來"],["折足复𫗧","折足覆餗"],["折跟头","折跟頭"],["折身","折身"],["折转","折轉"],["折辨","折辨"],["折辩","折辯"],["折辱","折辱"],["折过儿","折過兒"],["折返","折返"],["折返点","折返點"],["折进","折進"],["折进去","摺進去"],["折进来","摺進來"],["折钱","折錢"],["折长补短","折長補短"],["折页","摺頁"],["折鼎复𫗧","折鼎覆餗"],["抚台","撫臺"],["抚台街","撫臺街"],["抚尸","撫屍"],["抚尸恸哭","撫尸慟哭"],["抚尸痛哭","撫屍痛哭"],["抚恤","撫卹"],["抚松","撫松"],["抚松县","撫松縣"],["抚梁易柱","撫梁易柱"],["抚面","撫面"],["抚面痛哭","撫面痛哭"],["抛出","拋出"],["抛出去","拋出去"],["抛出来","拋出來"],["抛向","拋向"],["抛在脑后","拋在腦後"],["抛头露面","拋頭露面"],["抛妻别子","拋妻別子"],["抛尸露骨","拋屍露骨"],["抛摆","拋擺"],["抛物面","拋物面"],["抟击掀发","摶擊掀發"],["抟柱乘梁","摶柱乘梁"],["抟沙嚼蜡","摶沙嚼蠟"],["抟砂炼汞","摶砂煉汞"],["抟风板","摶風板"],["抠出","摳出"],["抠出来","摳出來"],["抢了","搶了"],["抢修","搶修"],["抢修工作","搶修工作"],["抢占","搶佔"],["抢回","搶回"],["抢尽","搶盡"],["抢尽锋头","搶盡鋒頭"],["抢救出来","搶救出來"],["抢杠","搶槓"],["抢种","搶種"],["护厂","護廠"],["护发","護髮"],["护发乳液","護髮乳液"],["护发素","護髮素"],["护向","護向"],["护壁板","護壁板"],["护念","護念"],["护板","護板"],["护理系","護理系"],["护面","護面"],["护面具","護面具"],["报仇","報仇"],["报仇雪恨","報仇雪恨"],["报仇雪耻","報仇雪恥"],["报价","報價"],["报价单","報價單"],["报修","報修"],["报值挂号","報值掛號"],["报出","報出"],["报出去","報出去"],["报出来","報出來"],["报刊杂志","報刊雜誌"],["报台","報臺"],["报名表","報名表"],["报告出来","報告出來"],["报团","報團"],["报国尽忠","報國盡忠"],["报复","報復"],["报复主义","報復主義"],["报复关税","報復關稅"],["报复性","報復性"],["报导出来","報導出來"],["报录人","報錄人"],["报税表","報稅表"],["报穷制裁","報窮制裁"],["报章杂志","報章雜誌"],["报系","報系"],["报表","報表"],["报表纸","報表紙"],["报表语言","報表語言"],["披云","披雲"],["披云雾睹青天","披雲霧睹青天"],["披卷","披卷"],["披发","披髮"],["披发入山","披髮入山"],["披发垢面","披髮垢面"],["披发左衽","披髮左衽"],["披发涂面","披髮塗面"],["披发缨冠","披髮纓冠"],["披发藻目","披髮藻目"],["披复","披覆"],["披头四乐团","披頭四樂團"],["披头四合唱团","披頭四合唱團"],["披头散发","披頭散髮"],["披挂","披掛"],["披挂上阵","披掛上陣"],["披挂绰鎗","披掛綽鎗"],["披榛采兰","披榛採蘭"],["披红挂彩","披紅掛綵"],["披肝挂胆","披肝掛膽"],["披针形叶","披針形葉"],["抬价","擡價"],["抬出","擡出"],["抬出去","擡出去"],["抬出来","擡出來"],["抬回","擡回"],["抬回去","擡回去"],["抬回来","擡回來"],["抬杠","擡槓"],["抬高身价","擡高身價"],["抱出","抱出"],["抱出去","抱出去"],["抱出来","抱出來"],["抱出笼","抱出籠"],["抱回","抱回"],["抱回家","抱回家"],["抱回来","抱回來"],["抱大足杆","抱大足桿"],["抱布贸丝","抱布貿絲"],["抱成一团","抱成一團"],["抱抱团","抱抱團"],["抱朴","抱朴"],["抱朴子","抱朴子"],["抱朴而长吟兮","抱朴而長吟兮"],["抱素怀朴","抱素懷樸"],["抱负水准","抱負水準"],["抵了","抵了"],["抵借","抵借"],["抵制","抵制"],["抵向","抵向"],["抵当","抵當"],["抵御","抵禦"],["抵御外侮","抵禦外侮"],["抵扣","抵扣"],["抵押借款","抵押借款"],["抵挡不了","抵擋不了"],["抵牾","牴牾"],["抵触","牴觸"],["抵针","抵針"],["抹了","抹了"],["抹布","抹布"],["抹干","抹乾"],["抹面","抹面"],["抻面","抻面"],["押出","押出"],["押回","押回"],["押回去","押回去"],["押回来","押回來"],["押当","押當"],["押柜","押櫃"],["押汇","押匯"],["押注","押注"],["押解回","押解回"],["抽丰","抽豐"],["抽公签","抽公籤"],["抽出","抽出"],["抽出去","抽出去"],["抽出来","抽出來"],["抽出空","抽出空"],["抽厘","抽釐"],["抽后腿","抽後腿"],["抽咽","抽咽"],["抽回","抽回"],["抽尽","抽盡"],["抽干","抽乾"],["抽斗","抽斗"],["抽油烟机","抽油煙機"],["抽烟","抽菸"],["抽烟室","抽菸室"],["抽穗","抽穗"],["抽穗期","抽穗期"],["抽签","抽籤"],["抽绎出","抽繹出"],["抽蓄发电","抽蓄發電"],["抿发","抿髮"],["拂弦","拂弦"],["拂荡","拂盪"],["拂钟无声","拂鐘無聲"],["拂面","拂面"],["拂面而来","拂面而來"],["拂须","拂鬚"],["担仔面","擔仔麪"],["担干系","擔干係"],["担干纪","擔干紀"],["担当","擔當"],["担当不起","擔當不起"],["担当不过","擔當不過"],["担当起来","擔當起來"],["担担面","擔擔麪"],["担水向河头卖","擔水向河頭賣"],["担饥受冻","擔飢受凍"],["拆伙","拆夥"],["拆借","拆借"],["拆出","拆出"],["拆出去","拆出去"],["拆出来","拆出來"],["拆台","拆臺"],["拆回","拆回"],["拆回去","拆回去"],["拆回来","拆回來"],["拆封后","拆封後"],["拆扣","拆扣"],["拆白党","拆白黨"],["拆迁范围","拆遷範圍"],["拈折","拈折"],["拈花摘叶","拈花摘葉"],["拈针指","拈針指"],["拈须","拈鬚"],["拉丁语系","拉丁語系"],["拉个手","拉個手"],["拉了","拉了"],["拉了一把","拉了一把"],["拉克施尔德钟","拉克施爾德鐘"],["拉克替醇","拉克替醇"],["拉克莫诺夫","拉克莫諾夫"],["拉出","拉出"],["拉出去","拉出去"],["拉出来","拉出來"],["拉制","拉制"],["拉升","拉昇"],["拉卜楞","拉卜楞"],["拉卜楞寺","拉卜楞寺"],["拉合子","拉合子"],["拉合尔","拉合爾"],["拉合尔市","拉合爾市"],["拉后腿","拉後腿"],["拉向","拉向"],["拉回","拉回"],["拉回去","拉回去"],["拉回来","拉回來"],["拉尔维克","拉爾維克"],["拉布","拉布"],["拉布拉","拉布拉"],["拉布拉他","拉布拉他"],["拉布拉他河","拉布拉他河"],["拉布拉多","拉布拉多"],["拉布拉多半岛","拉布拉多半島"],["拉布拉多寒流","拉布拉多寒流"],["拉布拉多犬","拉布拉多犬"],["拉德万斯卡","拉德萬斯卡"],["拉托维亚","拉托維亞"],["拉文克劳","拉文克勞"],["拉杆","拉桿"],["拉杆子","拉桿子"],["拉法叶","拉法葉"],["拉法叶舰","拉法葉艦"],["拉涅里","拉涅里"],["拉狄克","拉狄克"],["拉皮手术","拉皮手術"],["拉祖里","拉祖里"],["拉纤","拉縴"],["拉缆子摆渡","拉纜子擺渡"],["拉蒙","拉蒙"],["拉贾帕克萨","拉賈帕克薩"],["拉达克","拉達克"],["拉里","拉里"],["拉里加尼","拉里加尼"],["拉里拉尼","拉里拉尼"],["拉链","拉鍊"],["拉链工程","拉鍊工程"],["拉面","拉麪"],["拉面店","拉麪店"],["拌嘴斗舌","拌嘴鬥舌"],["拌折","拌折"],["拌种","拌種"],["拌面","拌麪"],["拍出","拍出"],["拍出去","拍出去"],["拍出好戏","拍齣好戲"],["拍出来","拍出來"],["拍卖价","拍賣價"],["拍发","拍發"],["拍台拍凳","拍檯拍凳"],["拍摄出","拍攝出"],["拍板","拍板"],["拏云","拏雲"],["拏云攫石","拏雲攫石"],["拐上","拐上"],["拐下","拐下"],["拐了","拐了"],["拐人","拐人"],["拐住","拐住"],["拐入","拐入"],["拐出","拐出"],["拐出去","拐出去"],["拐出来","拐出來"],["拐到","拐到"],["拐卖","拐賣"],["拐去","拐去"],["拐回","拐回"],["拐回去","拐回去"],["拐回来","拐回來"],["拐子","柺子"],["拐带","拐帶"],["拐弯","拐彎"],["拐得","拐得"],["拐杖","柺杖"],["拐来","拐來"],["拐枣","拐棗"],["拐棍","柺棍"],["拐棒","柺棒"],["拐点","拐點"],["拐着","拐着"],["拐臂","拐臂"],["拐角","拐角"],["拐诱","拐誘"],["拐走","拐走"],["拐跑","拐跑"],["拐过","拐過"],["拐进","拐進"],["拐骗","拐騙"],["拑制","拑制"],["拒于","拒於"],["拒人于","拒人於"],["拒人于千里之外","拒人於千里之外"],["拒烟","拒菸"],["拓朴","拓樸"],["拓朴学","拓樸學"],["拔不出","拔不出"],["拔不出腿来","拔不出腿來"],["拔个","拔個"],["拔了","拔了"],["拔了一个尖儿","拔了一個尖兒"],["拔了萝卜地皮宽","拔了蘿蔔地皮寬"],["拔出","拔出"],["拔出去","拔出去"],["拔出来","拔出來"],["拔发","拔髮"],["拔回","拔回"],["拔回去","拔回去"],["拔回来","拔回來"],["拔围出夫","拔圍出夫"],["拔地参天","拔地參天"],["拔宅上升","拔宅上昇"],["拔宅飞升","拔宅飛昇"],["拔山志","拔山志"],["拔山曲","拔山曲"],["拔群出类","拔羣出類"],["拔群出萃","拔羣出萃"],["拔萃出类","拔萃出類"],["拔萃出群","拔萃出羣"],["拔萝卜","拔蘿蔔"],["拔虎须","拔虎鬚"],["拔须","拔鬚"],["拖了","拖了"],["拖出","拖出"],["拖出去","拖出去"],["拖出来","拖出來"],["拖吊","拖吊"],["拖吊车","拖吊車"],["拖后腿","拖後腿"],["拖回","拖回"],["拖回去","拖回去"],["拖回来","拖回來"],["拖地板","拖地板"],["拖布","拖布"],["拖干淨","拖乾淨"],["拖延战术","拖延戰術"],["拖斗","拖斗"],["拖板","拖板"],["拖板车","拖板車"],["拖链","拖鏈"],["拖鞋柜","拖鞋櫃"],["拖麻拽布","拖麻拽布"],["拗别","拗彆"],["拗别搅炒","拗彆攪炒"],["拗曲作直","拗曲作直"],["拘于","拘於"],["拘出","拘出"],["拘板","拘板"],["拘泥于","拘泥於"],["拘系","拘繫"],["拙于","拙於"],["拙于言词","拙於言詞"],["拙于言辞","拙於言辭"],["拙朴","拙樸"],["拚命干","拚命幹"],["拚斗","拚鬥"],["拚生尽死","拚生盡死"],["拚舍","拚捨"],["招了","招了"],["招供出来","招供出來"],["招出","招出"],["招出来","招出來"],["招回","招回"],["招回去","招回去"],["招回来","招回來"],["招复","招復"],["招待不周","招待不週"],["招术","招術"],["招致","招致"],["拜冬","拜冬"],["拜别","拜別"],["拜占庭","拜占庭"],["拜占庭帝国","拜占庭帝國"],["拜占庭文化","拜占庭文化"],["拜台","拜臺"],["拜复","拜覆"],["拜岳","拜岳"],["拜托","拜託"],["拜斗","拜斗"],["拜科努尔航天发射基地","拜科努爾航天發射基地"],["拜表","拜表"],["拟于","擬於"],["拟于不伦","擬於不倫"],["拟出","擬出"],["拟制","擬製"],["拟卤素","擬鹵素"],["拟定出","擬定出"],["拟核","擬核"],["拟阿拖品药物","擬阿拖品藥物"],["拣出","揀出"],["拣别","揀別"],["拥向","擁向"],["拦前断后","攔前斷後"],["拦当","攔當"],["拦柜","攔櫃"],["拧了","擰了"],["拧干","擰乾"],["拧松","擰鬆"],["拧种","擰種"],["拨万论千","撥萬論千"],["拨万轮千","撥萬輪千"],["拨乱之才","撥亂之才"],["拨云撩雨","撥雲撩雨"],["拨云睹日","撥雲睹日"],["拨云见日","撥雲見日"],["拨出","撥出"],["拨出去","撥出去"],["拨出来","撥出來"],["拨发","撥發"],["拨号系统","撥號系統"],["拨回","撥回"],["拨回去","撥回去"],["拨回来","撥回來"],["拨开云雾见青天","撥開雲霧見青天"],["拨弦","撥絃"],["拨接式数据通信","撥接式數據通信"],["拨蜡法","撥蠟法"],["拨谷","撥穀"],["拨雨撩云","撥雨撩雲"],["括发","括髮"],["括弧里","括弧裏"],["拭干","拭乾"],["拮据","拮据"],["拱出","拱出"],["拱手而别","拱手而別"],["拱手让出","拱手讓出"],["拱托","拱托"],["拱极星","拱極星"],["拳击台","拳擊臺"],["拳坛","拳壇"],["拳曲","拳曲"],["拳术","拳術"],["拷克机","拷克機"],["拼了","拼了"],["拼了命","拼了命"],["拼凑出","拼湊出"],["拼出","拼出"],["拼出去","拼出去"],["拼出来","拼出來"],["拼列出","拼列出"],["拼合","拼合"],["拼合版画","拼合版畫"],["拼回","拼回"],["拼回去","拼回去"],["拼回来","拼回來"],["拼图游戏","拼圖遊戲"],["拼字游戏","拼字遊戲"],["拼布","拼布"],["拼布图形","拼布圖形"],["拼斗","拼鬥"],["拼板","拼板"],["拼板游戏","拼板遊戲"],["拼板玩具","拼板玩具"],["拼板胶","拼板膠"],["拼板舟","拼板舟"],["拼缀出","拼綴出"],["拼花地板","拼花地板"],["拼贴艺术","拼貼藝術"],["拽布披麻","拽布披麻"],["拽布拖麻","拽布拖麻"],["拽扎","拽扎"],["拾回","拾回"],["拾沈","拾瀋"],["拾穗","拾穗"],["拾获","拾獲"],["拿下表","拿下錶"],["拿下钟","拿下鐘"],["拿不了","拿不了"],["拿不准","拿不準"],["拿不出手","拿不出手"],["拿个","拿個"],["拿云手","拿雲手"],["拿云捉月","拿雲捉月"],["拿云握雾","拿雲握霧"],["拿准","拿準"],["拿出","拿出"],["拿出去","拿出去"],["拿出手","拿出手"],["拿出来","拿出來"],["拿回","拿回"],["拿回去","拿回去"],["拿回家","拿回家"],["拿回来","拿回來"],["拿坡里","拿坡里"],["拿坡里号","拿坡里號"],["拿板弄势","拿板弄勢"],["拿枪杆","拿槍桿"],["拿波里","拿波里"],["拿着鸡毛当令箭","拿着雞毛當令箭"],["拿破仑","拿破崙"],["拿破仑法典","拿破崙法典"],["拿破仑波拿巴","拿破侖波拿巴"],["拿笔杆","拿筆桿"],["拿药","拿藥"],["拿获","拿獲"],["拿贼要赃拿奸要双","拿賊要贓拿姦要雙"],["持不同政见","持不同政見"],["持不同政见者","持不同政見者"],["持胜","持勝"],["挂一挂","掛一掛"],["挂一漏万","掛一漏萬"],["挂一漏百","掛一漏百"],["挂上","掛上"],["挂上去","掛上去"],["挂上来","掛上來"],["挂上钩","掛上鉤"],["挂下","掛下"],["挂下去","掛下去"],["挂下来","掛下來"],["挂不上","掛不上"],["挂不下","掛不下"],["挂不住","掛不住"],["挂个","掛個"],["挂了","掛了"],["挂了幌子","掛了幌子"],["挂住","掛住"],["挂僵","掛僵"],["挂入","掛入"],["挂冠","掛冠"],["挂冠归里","掛冠歸里"],["挂冠求去","掛冠求去"],["挂冠而去","掛冠而去"],["挂出","掛出"],["挂出去","掛出去"],["挂出来","掛出來"],["挂到","掛到"],["挂勾","掛勾"],["挂千","掛千"],["挂单","掛單"],["挂印悬牌","掛印懸牌"],["挂印而逃","掛印而逃"],["挂历","掛曆"],["挂号","掛號"],["挂号信","掛號信"],["挂号处","掛號處"],["挂号证","掛號證"],["挂号费","掛號費"],["挂名","掛名"],["挂名夫妻","掛名夫妻"],["挂味儿","掛味兒"],["挂回","掛回"],["挂回去","掛回去"],["挂回来","掛回來"],["挂图","掛圖"],["挂图表","掛圖表"],["挂在","掛在"],["挂在口上","掛在口上"],["挂在嘴上","掛在嘴上"],["挂在嘴边","掛在嘴邊"],["挂坠盒","掛墜盒"],["挂失","掛失"],["挂失止付","掛失止付"],["挂头牌","掛頭牌"],["挂好","掛好"],["挂孝","掛孝"],["挂帅","掛帥"],["挂帅的社会","掛帥的社會"],["挂帐","掛帳"],["挂帘","掛簾"],["挂幌子","掛幌子"],["挂彩","掛彩"],["挂得","掛得"],["挂心","掛心"],["挂念","掛念"],["挂怀","掛懷"],["挂意","掛意"],["挂成","掛成"],["挂招牌","掛招牌"],["挂掉","掛掉"],["挂搭","掛搭"],["挂斗","掛斗"],["挂断","掛斷"],["挂有","掛有"],["挂来","掛來"],["挂来挂去","掛來掛去"],["挂杯架","掛杯架"],["挂架","掛架"],["挂满","掛滿"],["挂漏","掛漏"],["挂火","掛火"],["挂灯","掛燈"],["挂灯结彩","掛燈結綵"],["挂牌","掛牌"],["挂牌汇率","掛牌匯率"],["挂球蛋","掛球蛋"],["挂的","掛的"],["挂碍","掛礙"],["挂篮","掛籃"],["挂红","掛紅"],["挂红灯","掛紅燈"],["挂络儿","掛絡兒"],["挂羊头","掛羊頭"],["挂羊头卖狗肉","掛羊頭賣狗肉"],["挂羊头煮狗肉","掛羊頭煮狗肉"],["挂肚牵心","掛肚牽心"],["挂肚牵肠","掛肚牽腸"],["挂肠悬胆","掛腸懸膽"],["挂落儿","掛落兒"],["挂虑","掛慮"],["挂衣","掛衣"],["挂衣冠","掛衣冠"],["挂衣架","掛衣架"],["挂衣钩","掛衣鉤"],["挂表","掛錶"],["挂角读书","掛角讀書"],["挂记","掛記"],["挂账","掛賬"],["挂货铺","掛貨鋪"],["挂起","掛起"],["挂起来","掛起來"],["挂车","掛車"],["挂轴","掛軸"],["挂过","掛過"],["挂过去","掛過去"],["挂过来","掛過來"],["挂进","掛進"],["挂进去","掛進去"],["挂进来","掛進來"],["挂钟","掛鐘"],["挂钩","掛鉤"],["挂钩儿","掛鉤兒"],["挂钩子","掛鉤子"],["挂锁","掛鎖"],["挂镜儿","掛鏡兒"],["挂零","掛零"],["挂面","掛麪"],["挂齿","掛齒"],["挂龙雨","掛龍雨"],["指不胜屈","指不勝屈"],["指了","指了"],["指亲托故","指親托故"],["指出","指出"],["指北针","指北針"],["指南针","指南針"],["指向","指向"],["指向装置","指向裝置"],["指回","指回"],["指回去","指回去"],["指回来","指回來"],["指定曲","指定曲"],["指征","指徵"],["指手划脚","指手劃腳"],["指挥台","指揮台"],["指日高升","指日高升"],["指极星","指極星"],["指标体系","指標體系"],["指水盟松","指水盟松"],["指破迷团","指破迷團"],["指示板","指示板"],["指纹纪录","指紋紀錄"],["指纹鉴定","指紋鑑定"],["指认出","指認出"],["指证历历","指證歷歷"],["指针","指針"],["指针式","指針式"],["按下不表","按下不表"],["按了","按了"],["按出","按出"],["按出去","按出去"],["按出来","按出來"],["按回","按回"],["按回去","按回去"],["按回来","按回來"],["按扣","按扣"],["按时间先后","按時間先後"],["按照字面","按照字面"],["按照计划","按照計劃"],["按理出牌","按理出牌"],["按表操课","按表操課"],["按计划","按計劃"],["按质定价","按質定價"],["按需出版","按需出版"],["挌斗","挌鬥"],["挑了","挑了"],["挑了只","挑了隻"],["挑出","挑出"],["挑出去","挑出去"],["挑出来","挑出來"],["挑口板","挑口板"],["挑台","挑臺"],["挑大梁","挑大樑"],["挑尽","挑盡"],["挑得篮里便是菜","挑得籃裏便是菜"],["挑拣出","挑揀出"],["挑斗","挑鬥"],["挑正梁","挑正樑"],["挑选出","挑選出"],["挑选出来","挑選出來"],["挖出","挖出"],["挖出去","挖出去"],["挖出来","挖出來"],["挖心搜胆","挖心搜膽"],["挖掘出","挖掘出"],["挖掘出来","挖掘出來"],["挖耳当招","挖耳當招"],["挚而有别","摯而有別"],["挟制","挾制"],["挟朋树党","挾朋樹黨"],["挠折","撓折"],["挠曲","撓曲"],["挠直为曲","撓直爲曲"],["挡不了","擋不了"],["挡了","擋了"],["挡修","擋修"],["挡出","擋出"],["挡回","擋回"],["挡回去","擋回去"],["挡回来","擋回來"],["挡御","擋禦"],["挡板","擋板"],["挡泥板","擋泥板"],["挡雨板","擋雨板"],["挣出","掙出"],["挣扎","掙扎"],["挣扎表","掙扎表"],["挤了","擠了"],["挤兑出来","擠兌出來"],["挤出","擠出"],["挤出去","擠出去"],["挤出来","擠出來"],["挤占","擠佔"],["挤压出","擠壓出"],["挤向","擠向"],["挤成一团","擠成一團"],["挤昏了头","擠昏了頭"],["挤身于","擠身於"],["挥了","揮了"],["挥出","揮出"],["挥别","揮別"],["挥发","揮發"],["挥发性","揮發性"],["挥发性存储器","揮發性存儲器"],["挥发油","揮發油"],["挥发物","揮發物"],["挥戈回日","揮戈回日"],["挥手告别","揮手告別"],["挥手致意","揮手致意"],["挥杆","揮杆"],["挨三顶五","挨三頂五"],["挨三顶四","捱三頂四"],["挨上","捱上"],["挨上去","挨上去"],["挨不上","挨不上"],["挨个","挨個"],["挨个儿","挨個兒"],["挨了","捱了"],["挨了揍","捱了揍"],["挨了过去","捱了過去"],["挨了过来","捱了過來"],["挨亲儿","挨親兒"],["挨人儿","挨人兒"],["挨光","挨光"],["挨刀的","挨刀的"],["挨到","捱到"],["挨呲","挨呲"],["挨呲儿","挨呲兒"],["挨头子","挨頭子"],["挨家","挨家"],["挨家挨户","挨家挨戶"],["挨山塞海","挨山塞海"],["挨延","挨延"],["挨得","捱得"],["挨得住","捱得住"],["挨户","挨戶"],["挨打","捱打"],["挨打受气","挨打受氣"],["挨打受骂","挨打受罵"],["挨批","挨批"],["挨拿","挨拿"],["挨挤","挨擠"],["挨挨","挨挨"],["挨挨儿","挨挨兒"],["挨挨抢抢","挨挨搶搶"],["挨挨蹭蹭","挨挨蹭蹭"],["挨捕","挨捕"],["挨排","挨排"],["挨揍","捱揍"],["挨整","捱整"],["挨斗","挨鬥"],["挨日子","捱日子"],["挨时间","捱時間"],["挨板子","挨板子"],["挨棍子","挨棍子"],["挨次","挨次"],["挨满","捱滿"],["挨着","挨着"],["挨磨","捱磨"],["挨肩","挨肩"],["挨肩儿","挨肩兒"],["挨肩叠背","挨肩疊背"],["挨肩搭背","挨肩搭背"],["挨肩擦背","挨肩擦背"],["挨肩擦脸","挨肩擦臉"],["挨肩擦膀","挨肩擦膀"],["挨苦","捱苦"],["挨身","挨身"],["挨边","挨邊"],["挨边儿","挨邊兒"],["挨过","捱過"],["挨过去","捱過去"],["挨过来","捱過來"],["挨近","挨近"],["挨门","挨門"],["挨门挨户","挨門挨戶"],["挨门逐户","挨門逐戶"],["挨闹","挨鬧"],["挨靠","挨靠"],["挨风缉缝","挨風緝縫"],["挨饥抵饿","捱飢抵餓"],["挨饿","捱餓"],["挨饿受冻","挨餓受凍"],["挨骂","捱罵"],["挪借","挪借"],["挪出","挪出"],["挫折","挫折"],["挫折感","挫折感"],["振兴医疗复健中心","振興醫療復健中心"],["振杰","振杰"],["振聋发嘳","振聾發嘳"],["振聋发聩","振聾發聵"],["振荡","振盪"],["振荡器","振盪器"],["振荡电流","振盪電流"],["振荡电路","振盪電路"],["振衣千仞冈","振衣千仞岡"],["挹彼注兹","挹彼注茲"],["挹彼注此","挹彼注此"],["挹注","挹注"],["挺了","挺了"],["挺出","挺出"],["挺出去","挺出去"],["挺出来","挺出來"],["挺升","挺升"],["挺尸","挺屍"],["挺起腰板儿","挺起腰板兒"],["挺身而出","挺身而出"],["挽住","挽住"],["挽具","挽具"],["挽力","挽力"],["挽回","挽回"],["挽回不了","挽回不了"],["挽夫","輓夫"],["挽幛","挽幛"],["挽手","挽手"],["挽手儿","挽手兒"],["挽救","挽救"],["挽救不了","挽救不了"],["挽救儿童","挽救兒童"],["挽曲","輓曲"],["挽歌","輓歌"],["挽歌郎","輓歌郎"],["挽毂","挽轂"],["挽留","挽留"],["挽眉毛","挽眉毛"],["挽联","輓聯"],["挽聯","輓聯"],["挽脸师","挽臉師"],["挽袖","挽袖"],["挽詞","輓詞"],["挽詩","輓詩"],["挽词","輓詞"],["挽诗","輓詩"],["挽起","挽起"],["挽辞","挽辭"],["挽面","挽面"],["挽额","輓額"],["挽髻","挽髻"],["挽麦子","挽麥子"],["捅了","捅了"],["捅出","捅出"],["捆了","捆了"],["捆扎","捆紮"],["捉不准","捉不準"],["捉不胜捉","捉不勝捉"],["捉发","捉髮"],["捉奸","捉姦"],["捉奸党","捉奸黨"],["捉奸徒","捉奸徒"],["捉奸捉双","捉姦捉雙"],["捉奸细","捉奸細"],["捉奸见双","捉姦見雙"],["捉奸见床","捉姦見牀"],["捉奸贼","捉奸賊"],["捉摸不出","捉摸不出"],["捉获","捉獲"],["捉贼见赃捉奸见双","捉賊見贓捉姦見雙"],["捋虎须","捋虎鬚"],["捋采","捋采"],["捍御","捍禦"],["捏不准","捏不準"],["捏了一把冷汗","捏了一把冷汗"],["捏了一把汗","捏了一把汗"],["捏出","捏出"],["捏出水儿来的","捏出水兒來的"],["捏制","捏製"],["捏合","捏合"],["捏造出","捏造出"],["捏造出来","捏造出來"],["捏面人","捏麪人"],["捐出","捐出"],["捐出去","捐出去"],["捐出来","捐出來"],["捐益表","捐益表"],["捐赠盈余","捐贈盈餘"],["捕影系风","捕影繫風"],["捕获","捕獲"],["捕虏岩","捕虜岩"],["捕虫","捕蟲"],["捕虫叶","捕蟲葉"],["捕虫堇菜","捕蟲堇菜"],["捕虫植物","捕蟲植物"],["捕虫灯","捕蟲燈"],["捕虫网","捕蟲網"],["捕风系影","捕風繫影"],["捞出","撈出"],["捞干","撈乾"],["捞面","撈麪"],["损于","損於"],["损兵折将","損兵折將"],["损军折将","損軍折將"],["损将折兵","損將折兵"],["损折","損折"],["损益表","損益表"],["捡了","撿了"],["捡回","撿回"],["捡回去","撿回去"],["捡回来","撿回來"],["换个","換個"],["换个儿","換個兒"],["换了","換了"],["换借","換借"],["换出","換出"],["换出去","換出去"],["换出来","換出來"],["换厂","換廠"],["换发","換髮"],["换只","換隻"],["换台","換臺"],["换吊","換吊"],["换向","換向"],["换向器","換向器"],["换回","換回"],["换回去","換回去"],["换回来","換回來"],["换心手术","換心手術"],["换房旅游","換房旅遊"],["换扣","換扣"],["换挡杆","換擋桿"],["换板","換板"],["换档杆","換檔桿"],["换汇","換匯"],["换汤不换药","換湯不換藥"],["换签","換籤"],["换算无收获面积","換算無收穫面積"],["换算表","換算表"],["换系","換系"],["换肾手术","換腎手術"],["换药","換藥"],["捣针","搗針"],["捣鬼吊白","搗鬼弔白"],["捧出","捧出"],["捧出去","捧出去"],["捧出来","捧出來"],["捧回","捧回"],["捧杯","捧杯"],["据为己有","據爲己有"],["据义履方","據義履方"],["据了解","據瞭解"],["据云","據云"],["据以","據以"],["据传","據傳"],["据传说","據傳說"],["据估计","據估計"],["据信","據信"],["据守","據守"],["据守天险","據守天險"],["据实","據實"],["据实以报","據實以報"],["据实相告","據實相告"],["据常","據常"],["据干而窥井底","據榦而窺井底"],["据悉","據悉"],["据情办理","據情辦理"],["据我看","據我看"],["据报","據報"],["据报导","據報導"],["据报道","據報道"],["据有","據有"],["据此","據此"],["据点","據點"],["据牀指麾","據牀指麾"],["据理","據理"],["据理力争","據理力爭"],["据理而争","據理而爭"],["据称","據稱"],["据统计","據統計"],["据说","據說"],["据说在","據說在"],["据说是","據說是"],["据说有","據說有"],["据道","據道"],["据闻","據聞"],["据险固守","據險固守"],["据鞍","據鞍"],["捵面","捵麪"],["捶台拍凳","捶檯拍凳"],["捶炼","捶鍊"],["捷众药业","捷衆藥業"],["捷克","捷克"],["捷克人","捷克人"],["捷克共和国","捷克共和國"],["捷克斯拉夫","捷克斯拉夫"],["捷克斯洛伐克","捷克斯洛伐克"],["捷克暨斯洛伐克联邦共和国","捷克暨斯洛伐克聯邦共和國"],["捷克籍","捷克籍"],["捷克语","捷克語"],["捷克队","捷克隊"],["捷尔任斯克","捷爾任斯克"],["捷才","捷才"],["捷运系统","捷運系統"],["捻合","捻合"],["捻针","捻鍼"],["捻须","捻鬚"],["掀了","掀了"],["掀了开来","掀了開來"],["掀出","掀出"],["掀出去","掀出去"],["掀出来","掀出來"],["掀帘子","掀簾子"],["掂折","掂折"],["掂梢折本","掂梢折本"],["授权范围","授權範圍"],["掉个","掉個"],["掉了","掉了"],["掉价儿","掉價兒"],["掉出","掉出"],["掉出来","掉出來"],["掉发","掉髮"],["掉回头","掉回頭"],["掊克","掊克"],["掊斗折衡","掊斗折衡"],["掌柜","掌櫃"],["掌柜的","掌櫃的"],["掌状复叶","掌狀複葉"],["掏出","掏出"],["掏出来","掏出來"],["排兵布阵","排兵佈陣"],["排出","排出"],["排出体","排出體"],["排出作用","排出作用"],["排出去","排出去"],["排出来","排出來"],["排列组合","排列組合"],["排名表","排名表"],["排当","排當"],["排扣","排扣"],["排放出","排放出"],["排放系统","排放系統"],["排档杆","排檔桿"],["排水系统","排水系統"],["排泄系统","排泄系統"],["排烟","排煙"],["排版系统","排版系統"],["排表","排表"],["排门挨户","排門挨戶"],["排除万难","排除萬難"],["排须","排鬚"],["排骨面","排骨麪"],["掘出","掘出"],["掘出来","掘出來"],["掘墓鞭尸","掘墓鞭屍"],["探个究竟","探個究竟"],["探了","探了"],["探出","探出"],["探出去","探出去"],["探出来","探出來"],["探听出","探聽出"],["探奇访胜","探奇訪勝"],["探寻出","探尋出"],["探寻胜迹","探尋勝蹟"],["探幽访胜","探幽訪勝"],["探知欲","探知慾"],["探究出","探究出"],["探获","探獲"],["探询出","探詢出"],["探针","探針"],["探骊获珠","探驪獲珠"],["掣后腿","掣後腿"],["掣签","掣籤"],["掤扒吊栲","掤扒吊栲"],["接出","接出"],["接受不了","接受不了"],["接口规范","接口規範"],["接合","接合"],["接合上","接合上"],["接合处","接合處"],["接合点","接合點"],["接合生殖","接合生殖"],["接合菌纲","接合菌綱"],["接合起来","接合起來"],["接合面","接合面"],["接回","接回"],["接回去","接回去"],["接回来","接回來"],["接扣","接扣"],["接生术","接生術"],["接种","接種"],["接种率","接種率"],["接穗","接穗"],["接绍香烟","接紹香煙"],["接续香烟","接續香煙"],["接获","接獲"],["接触面","接觸面"],["接近于","接近於"],["接面","接面"],["控制","控制"],["控制不了","控制不了"],["控制住","控制住"],["控制力","控制力"],["控制区","控制區"],["控制单元","控制單元"],["控制卡","控制卡"],["控制台","控制檯"],["控制器","控制器"],["控制塔","控制塔"],["控制好","控制好"],["控制室","控制室"],["控制性","控制性"],["控制权","控制權"],["控制杆","控制桿"],["控制板","控制板"],["控制棒","控制棒"],["控制欲","控制慾"],["控制码","控制碼"],["控制站","控制站"],["控制组","控制組"],["控制范围","控制範圍"],["控制裕如","控制裕如"],["控制论","控制論"],["控制键","控制鍵"],["控卷","控捲"],["控御","控御"],["推倒了油瓶不扶","推倒了油瓶不扶"],["推出","推出"],["推出去","推出去"],["推出来","推出來"],["推升","推升"],["推后","推後"],["推向","推向"],["推回","推回"],["推回去","推回去"],["推回来","推回來"],["推定出来","推定出來"],["推干淨儿","推乾淨兒"],["推弦","推絃"],["推心致腹","推心致腹"],["推情准理","推情準理"],["推想出","推想出"],["推托","推託"],["推托之词","推托之詞"],["推挽","推輓"],["推断出","推斷出"],["推杆","推杆"],["推杯","推杯"],["推派出","推派出"],["推演出来","推演出來"],["推算出","推算出"],["推算出来","推算出來"],["推舟于陆","推舟於陸"],["推诚布信","推誠佈信"],["推诚布公","推誠佈公"],["推辇归里","推輦歸里"],["推销术","推銷術"],["推陈出新","推陳出新"],["推陈布新","推陳佈新"],["掩卷","掩卷"],["掩口卢胡","掩口盧胡"],["掩口胡卢","掩口胡盧"],["掩恶扬善","掩惡揚善"],["掩恶溢美","掩惡溢美"],["掩罪藏恶","掩罪藏惡"],["掩耳盗钟","掩耳盜鐘"],["掩面","掩面"],["掩面大哭","掩面大哭"],["掩面失色","掩面失色"],["掩面而泣","掩面而泣"],["掩面而过","掩面而過"],["措置失当","措置失當"],["措置得当","措置得當"],["措词不当","措詞不當"],["措辞不当","措辭不當"],["掰了","掰了"],["掳获","擄獲"],["掷出","擲出"],["掷杯","擲杯"],["掺合","摻合"],["揉合","揉合"],["揉成一团","揉成一團"],["揉面","揉麪"],["揍了","揍了"],["描了","描了"],["描写出","描寫出"],["描写出来","描寫出來"],["描出","描出"],["描出来","描出來"],["描涂","描塗"],["描绘出","描繪出"],["描绘出来","描繪出來"],["提不出","提不出"],["提个","提個"],["提了","提了"],["提价","提價"],["提克瑞提","提克瑞提"],["提克里特","提克里特"],["提出","提出"],["提出去","提出去"],["提出建议","提出建議"],["提出异议","提出異議"],["提出抗辩","提出抗辯"],["提出来","提出來"],["提制","提製"],["提升","提升"],["提升为","提升爲"],["提升到","提升到"],["提向","提向"],["提回","提回"],["提回去","提回去"],["提回来","提回來"],["提子干","提子乾"],["提学御史","提學御史"],["提干","提幹"],["提心吊胆","提心吊膽"],["提拉米苏","提拉米蘇"],["提摩太后书","提摩太後書"],["提梁","提樑"],["提炼","提煉"],["提炼出","提煉出"],["提甕出汲","提甕出汲"],["提纯复壮","提純復壯"],["提舍尼","提舍尼"],["插于","插於"],["插回","插回"],["插回去","插回去"],["插回来","插回來"],["插图卷","插圖卷"],["插扣","插扣"],["插曲","插曲"],["插架万轴","插架萬軸"],["插箭游营","插箭遊營"],["插足于","插足於"],["插针","插針"],["握不准","握不準"],["握云拿雾","握雲拿霧"],["握云携雨","握雲攜雨"],["握别","握別"],["握发","握髮"],["握发吐哺","握髮吐哺"],["握发吐餐","握髮吐餐"],["握手极欢","握手極歡"],["握手道别","握手道別"],["握雨携云","握雨攜雲"],["握雾拿云","握霧拿雲"],["揣合逢迎","揣合逢迎"],["揣在怀里","揣在懷裏"],["揣奸把猾","揣奸把猾"],["揩台抹凳","揩檯抹凳"],["揩干","揩乾"],["揪出","揪出"],["揪出去","揪出去"],["揪出来","揪出來"],["揪发","揪髮"],["揪斗","揪鬥"],["揪采","揪採"],["揪须","揪鬚"],["揭丑","揭醜"],["揭出","揭出"],["揭发","揭發"],["揭发出","揭發出"],["揭布","揭布"],["揭折","揭折"],["揭示板","揭示板"],["揭露出","揭露出"],["援据","援據"],["揽胜","攬勝"],["揽胜图","攬勝圖"],["揽闲事","攬閒事"],["搀伙","攙夥"],["搁板","擱板"],["搁脚板","擱腳板"],["搅合","攪合"],["搋在怀里","搋在懷裏"],["搋面","搋麪"],["搌布","搌布"],["搏斗","搏鬥"],["搏炼","搏煉"],["搏砂炼汞","搏砂煉汞"],["搓板","搓板"],["搓熟的汤团","搓熟的湯團"],["搓粉团朱","搓粉團朱"],["搓粉抟朱","搓粉摶朱"],["搜下","搜下"],["搜书","搜書"],["搜了","搜了"],["搜人","搜人"],["搜出","搜出"],["搜刮","搜刮"],["搜到","搜到"],["搜剿","搜剿"],["搜吧","搜吧"],["搜听","搜聽"],["搜啊","搜啊"],["搜图","搜圖"],["搜奇","搜奇"],["搜奇抉怪","搜奇抉怪"],["搜奇访古","搜奇訪古"],["搜奇选妙","搜奇選妙"],["搜宝","搜寶"],["搜客","搜客"],["搜寻","搜尋"],["搜寻到","搜尋到"],["搜寻引擎","搜尋引擎"],["搜寻软体","搜尋軟體"],["搜山","搜山"],["搜店","搜店"],["搜房","搜房"],["搜扬仄陋","搜揚仄陋"],["搜扬侧陋","搜揚側陋"],["搜括","蒐括"],["搜括一空","搜括一空"],["搜捕","搜捕"],["搜捕到","搜捕到"],["搜掠","搜掠"],["搜搜","搜搜"],["搜搜客","搜搜客"],["搜搜客网","搜搜客網"],["搜救","搜救"],["搜救犬","搜救犬"],["搜星","搜星"],["搜查","搜查"],["搜査证","搜查證"],["搜根剔齿","搜根剔齒"],["搜根究底","搜根究底"],["搜根问底","搜根問底"],["搜检","搜檢"],["搜歌","搜歌"],["搜求","搜求"],["搜游","搜遊"],["搜爆","搜爆"],["搜狐","搜狐"],["搜狐网","搜狐網"],["搜狗","搜狗"],["搜的","搜的"],["搜神","搜神"],["搜神记","搜神記"],["搜秀","搜秀"],["搜章擿句","搜章擿句"],["搜索","搜索"],["搜索到","搜索到"],["搜索前进","搜索前進"],["搜索半径","搜索半徑"],["搜索引擎","搜索引擎"],["搜索枯肠","搜索枯腸"],["搜索票","搜索票"],["搜索结果","搜索結果"],["搜索范围","搜索範圍"],["搜索队","搜索隊"],["搜缴","搜繳"],["搜网","搜網"],["搜罗","蒐羅"],["搜肠刮肚","搜腸刮肚"],["搜获","搜獲"],["搜藏","蒐藏"],["搜藏家","蒐藏家"],["搜虎","搜虎"],["搜证","蒐證"],["搜豹","搜豹"],["搜购","蒐購"],["搜走","搜走"],["搜身","搜身"],["搜遍","搜遍"],["搜酷","搜酷"],["搜集","蒐集","搜集"],["搜集到","蒐集到"],["搢绅录","搢紳錄"],["搪饥","搪飢"],["搬出","搬出"],["搬出去","搬出去"],["搬出来","搬出來"],["搬回","搬回"],["搬回去","搬回去"],["搬回来","搬回來"],["搬斗","搬鬥"],["搭个","搭個"],["搭伙","搭夥"],["搭克露","搭克露"],["搭出","搭出"],["搭干铺","搭乾鋪"],["搭扣","搭扣"],["搭机回","搭機回"],["搭面","搭面"],["搯出来","搯出來"],["携云挈雨","攜雲挈雨"],["携云握雨","攜雲握雨"],["携出","攜出"],["携同","攜同"],["携带式卫星通信系统","攜帶式衛星通信系統"],["携手合作","攜手合作"],["携手同心","攜手同心"],["携手并肩","攜手並肩"],["搽穰卷儿","搽穰捲兒"],["搽药","搽藥"],["摁扣","摁釦"],["摄于","攝於"],["摄制","攝製"],["摄制厂","攝製廠"],["摄制成","攝製成"],["摄录影机","攝錄影機"],["摄影术","攝影術"],["摄影艺术","攝影藝術"],["摄氏寒暑表","攝氏寒暑表"],["摆上","擺上"],["摆上去","擺上去"],["摆上来","擺上來"],["摆下","擺下"],["摆下去","擺下去"],["摆下来","擺下來"],["摆不下","擺不下"],["摆不平","擺不平"],["摆不开","擺不開"],["摆乌龙","擺烏龍"],["摆了一道","擺了一道"],["摆事实讲道理","擺事實講道理"],["摆云锣儿","擺雲鑼兒"],["摆供","擺供"],["摆出","擺出"],["摆出去","擺出去"],["摆出来","擺出來"],["摆划","擺劃"],["摆列","擺列"],["摆列出","擺列出"],["摆到","擺到"],["摆制","擺制"],["摆动","擺動"],["摆动波","擺動波"],["摆卖","擺賣"],["摆回","擺回"],["摆回去","擺回去"],["摆回来","擺回來"],["摆在","擺在"],["摆在心上","擺在心上"],["摆在眼前","擺在眼前"],["摆地摊","擺地攤"],["摆夷","擺夷"],["摆好","擺好"],["摆姿势","擺姿勢"],["摆子","擺子"],["摆官架子","擺官架子"],["摆尾","擺尾"],["摆尾摇头","擺尾搖頭"],["摆布","擺佈"],["摆席","擺席"],["摆平","擺平"],["摆开","擺開"],["摆开阵势","擺開陣勢"],["摆弄","擺弄"],["摆当","擺當"],["摆得","擺得"],["摆忙","擺忙"],["摆成","擺成"],["摆手","擺手"],["摆拨","擺撥"],["摆拨不下","擺撥不下"],["摆振","擺振"],["摆搠","擺搠"],["摆搭","擺搭"],["摆摆","擺擺"],["摆摆头","擺擺頭"],["摆摆手","擺擺手"],["摆摆摇摇","擺擺搖搖"],["摆摊","擺攤"],["摆摊儿","擺攤兒"],["摆摊子","擺攤子"],["摆撼","擺撼"],["摆擂台","擺擂臺"],["摆放","擺放"],["摆放在","擺放在"],["摆明","擺明"],["摆来","擺來"],["摆来摆去","擺來擺去"],["摆架子","擺架子"],["摆样","擺樣"],["摆样子","擺樣子"],["摆格","擺格"],["摆槊","擺槊"],["摆款","擺款"],["摆法","擺法"],["摆浪子","擺浪子"],["摆渡","擺渡"],["摆渡船","擺渡船"],["摆满","擺滿"],["摆点","擺點"],["摆番","擺番"],["摆空架子","擺空架子"],["摆站","擺站"],["摆线","擺線"],["摆置","擺置"],["摆脱","擺脫"],["摆脱不了","擺脫不了"],["摆脱到","擺脫到"],["摆脱危机","擺脫危機"],["摆花架子","擺花架子"],["摆荡","擺盪"],["摆荡吊环","擺蕩吊環"],["摆荡起来","擺盪起來"],["摆落","擺落"],["摆行阵","擺行陣"],["摆袖却金","擺袖卻金"],["摆设","擺設"],["摆设儿","擺設兒"],["摆请儿","擺請兒"],["摆谱","擺譜"],["摆谱儿","擺譜兒"],["摆起","擺起"],["摆起来","擺起來"],["摆轮","擺輪"],["摆进","擺進"],["摆进去","擺進去"],["摆进来","擺進來"],["摆酒","擺酒"],["摆酒席","擺酒席"],["摆针","擺針"],["摆钟","擺鐘"],["摆锤","擺錘"],["摆长","擺長"],["摆门子","擺門子"],["摆门面","擺門面"],["摆阔","擺闊"],["摆阔气","擺闊氣"],["摆阵","擺陣"],["摆露","擺露"],["摆饭","擺飯"],["摆饰","擺飾"],["摆齐","擺齊"],["摆龙门阵","擺龍門陣"],["摇了","搖了"],["摇了一下","搖了一下"],["摇头摆尾","搖頭擺尾"],["摇头摆脑","搖頭擺腦"],["摇摆","搖擺"],["摇摆不定","搖擺不定"],["摇摆乐","搖擺樂"],["摇摆舞","搖擺舞"],["摇摇摆摆","搖搖擺擺"],["摇摇欲坠","搖搖欲墜"],["摇摇荡荡","搖搖蕩蕩"],["摇杆","搖桿"],["摇板","搖板"],["摇滚乐团","搖滾樂團"],["摇滚团","搖滾團"],["摇篮曲","搖籃曲"],["摇荡","搖盪"],["摇荡不停","搖盪不停"],["摇车儿里的爷爷拄拐棍儿的孙子","搖車兒裏的爺爺拄拐棍兒的孫子"],["摇针","搖針"],["摊了","攤了"],["摊了事","攤了事"],["摊了人命","攤了人命"],["摊出","攤出"],["摊出去","攤出去"],["摊出来","攤出來"],["摊薄后每股盈利","攤薄後每股盈利"],["摒出","摒出"],["摔了","摔了"],["摔了一跤","摔了一跤"],["摔出","摔出"],["摔断了","摔斷了"],["摔断了腿","摔斷了腿"],["摔筋斗","摔筋斗"],["摔跟斗","摔跟斗"],["摘伏发隐","摘伏發隱"],["摘借","摘借"],["摘出","摘出"],["摘出去","摘出去"],["摘出来","摘出來"],["摘奸发伏","摘奸發伏"],["摘录","摘錄"],["摘录自","摘錄自"],["摘绵术","摘綿術"],["摛藻雕章","摛藻雕章"],["摧兰折玉","摧蘭折玉"],["摧坚获丑","摧堅獲醜"],["摧志屈道","摧志屈道"],["摧折","摧折"],["摧枯折腐","摧枯折腐"],["摧眉折腰","摧眉折腰"],["摩厉以须","摩厲以須"],["摩合罗","摩合羅"],["摩托","摩托"],["摩托化","摩托化"],["摩托罗垃","摩托羅垃"],["摩托罗拉","摩托羅拉"],["摩托船","摩托船"],["摩托车","摩托車"],["摩托车的士","摩托車的士"],["摩托车组","摩托車組"],["摩擦系数","摩擦係數"],["摩根费里曼","摩根費里曼"],["摩肩如云","摩肩如雲"],["摩苏尔","摩蘇爾"],["摩苏尔市","摩蘇爾市"],["摩诃迦叶","摩訶迦葉"],["摩里西斯","摩里西斯"],["摭采","摭採"],["摸不准","摸不準"],["摸了","摸了"],["摸出","摸出"],["摸出去","摸出去"],["摸出来","摸出來"],["摸彩","摸彩"],["摸彩券","摸彩券"],["摸彩品","摸彩品"],["摸彩箱","摸彩箱"],["摸秋","摸秋"],["摸索出","摸索出"],["摸钟","摸鐘"],["摹扎特","摹紮特"],["撂了","撂了"],["撇吊","撇弔"],["撑了","撐了"],["撑出","撐出"],["撑场面","撐場面"],["撑头获脑","撐頭獲腦"],["撑市面","撐市面"],["撑杆","撐杆"],["撑杆跳","撐杆跳"],["撑杆跳高","撐杆跳高"],["撑门面","撐門面"],["撒克逊","撒克遜"],["撒克逊人","撒克遜人"],["撒出","撒出"],["撒呓症","撒囈症"],["撒布","撒佈"],["撒极","撒極"],["撒种","撒種"],["撒马尔干","撒馬爾幹"],["撕了","撕了"],["撞个满怀","撞個滿懷"],["撞出","撞出"],["撞出去","撞出去"],["撞出来","撞出來"],["撞击式印表机","撞擊式印表機"],["撞向","撞向"],["撞尸","撞屍"],["撞府冲州","撞府沖州"],["撞木钟","撞木鐘"],["撞球台","撞球檯"],["撞球杆","撞球桿"],["撞警钟","撞警鐘"],["撞针","撞針"],["撞钟","撞鐘"],["撞钟太岁","撞鐘太歲"],["撞阵冲军","撞陣衝軍"],["撤出","撤出"],["撤出去","撤出去"],["撤出来","撤出來"],["撤后","撤後"],["撤回","撤回"],["撤回去","撤回去"],["撤回来","撤回來"],["撤帘","撤簾"],["撤并","撤併"],["撤柜","撤櫃"],["撤销记录","撤銷記錄"],["撧折","撧折"],["撩云拨雨","撩雲撥雨"],["撩斗","撩鬥"],["撩虎须","撩虎鬚"],["撬了","撬了"],["撬出去","撬出去"],["撬出来","撬出來"],["撬杠","撬槓"],["播于","播於"],["播出","播出"],["播出去","播出去"],["播出来","播出來"],["播出频道","播出頻道"],["播发","播發"],["播恶遗臭","播惡遺臭"],["播放列表","播放列表"],["播放歌曲","播放歌曲"],["播种","播種"],["播种期","播種期"],["播种机","播種機"],["播种法","播種法"],["播种面积","播種面積"],["播荡","播蕩"],["播越失据","播越失據"],["撮合","撮合"],["撮合山","撮合山"],["撮科打哄","撮科打哄"],["撮药","撮藥"],["撰出来","撰出來"],["撰录","撰錄"],["撵出","攆出"],["撵出去","攆出去"],["撵出来","攆出來"],["撺哄","攛哄"],["撺哄鸟乱","攛哄鳥亂"],["擀面","擀麪"],["擀面杖","擀麪杖"],["擂台","擂臺"],["擂台赛","擂臺賽"],["擂鼓交响曲","擂鼓交響曲"],["擅于","擅於"],["擅长于","擅長於"],["操作台","操作檯"],["操作系统","操作系統"],["操作规范","操作規範"],["操作钟","操作鐘"],["操同室之戈","操同室之戈"],["操纵台","操縱檯"],["操纵杆","操縱桿"],["操船术","操船術"],["擎拳合掌","擎拳合掌"],["擐系","擐繫"],["擒奸摘伏","擒奸摘伏"],["擒奸擿伏","擒奸擿伏"],["擒奸讨暴","擒奸討暴"],["擒获","擒獲"],["擘划","擘劃"],["擢升","擢升"],["擢发","擢髮"],["擢发抽肠","擢髮抽腸"],["擢发难数","擢髮難數"],["擦俊药","擦俊藥"],["擦出","擦出"],["擦出爱","擦出愛"],["擦刮","擦刮"],["擦布","擦布"],["擦干","擦乾"],["擦干净","擦乾淨"],["擦干淨","擦乾淨"],["擦碗布","擦碗布"],["擦药","擦藥"],["擦面子","擦面子"],["擿埴索涂","擿埴索塗"],["擿奸发伏","擿奸發伏"],["攀云","攀雲"],["攀亲引戚","攀親引戚"],["攀今吊古","攀今吊古"],["攀升","攀升"],["攀岩","攀巖"],["攀折","攀折"],["攀花折柳","攀花折柳"],["攀蟾折桂","攀蟾折桂"],["攧攧仆仆","攧攧仆仆"],["支出","支出"],["支出费用","支出費用"],["支划","支劃"],["支努干","支努干"],["支干","支幹"],["支当","支當"],["支撑不了","支撐不了"],["支杆","支桿"],["支烟","支菸"],["支系","支系"],["支系统","支系統"],["支胄","支胄"],["收了","收了"],["收出","收出"],["收出去","收出去"],["收出来","收出來"],["收发","收發"],["收发器","收發器"],["收发室","收發室"],["收发短信","收發短信"],["收发站","收發站"],["收回","收回"],["收回到","收回到"],["收回去","收回去"],["收回成命","收回成命"],["收回来","收回來"],["收复","收復"],["收复失土","收復失土"],["收复失地","收復失地"],["收复河山","收復河山"],["收尸","收屍"],["收录","收錄"],["收录两用机","收錄兩用機"],["收录在","收錄在"],["收录音机","收錄音機"],["收拾干淨","收拾乾淨"],["收据","收據"],["收款台","收款臺"],["收汇","收匯"],["收盘价","收盤價"],["收盘价格","收盤價格"],["收盘汇率","收盤匯率"],["收秋","收秋"],["收获","收穫"],["收获节","收穫節"],["收获量","收穫量"],["收购价","收購價"],["收购价格","收購價格"],["收针","收針"],["收银台","收銀臺"],["攸戚相关","攸慼相關"],["改不了","改不了"],["改个","改個"],["改了","改了"],["改了又改","改了又改"],["改于","改於"],["改修","改修"],["改制","改制","改製"],["改制为","改製爲"],["改变不了","改變不了"],["改向","改向"],["改回","改回"],["改头换面","改頭換面"],["改当","改當"],["改征","改徵"],["改念","改唸"],["改恶向善","改惡向善"],["改扣","改扣"],["改签","改簽"],["改良品种","改良品種"],["改良种","改良種"],["攻了","攻了"],["攻克","攻克"],["攻击范围","攻擊範圍"],["攻击面","攻擊面"],["攻占","攻佔"],["攻向","攻向"],["攻守同盟","攻守同盟"],["攻无不克","攻無不克"],["攻无不克战无不胜","攻無不克戰無不勝"],["放一百二十个心","放一百二十個心"],["放个","放個"],["放之四海皆准","放之四海皆準"],["放之四海而皆准","放之四海而皆準"],["放了","放了"],["放了屁儿却使手掩","放了屁兒卻使手掩"],["放党","放黨"],["放出","放出"],["放出去","放出去"],["放出手眼","放出手眼"],["放出来","放出來"],["放参","放參"],["放回","放回"],["放回去","放回去"],["放在心里","放在心裏"],["放在眼里","放在眼裏"],["放大系数","放大係數"],["放学后","放學後"],["放射出","放射出"],["放射出来","放射出來"],["放射性发光材料","放射性發光材料"],["放射性同位素","放射性同位素"],["放射性烟羽","放射性煙羽"],["放射虫","放射蟲"],["放尽","放盡"],["放屁虫","放屁蟲"],["放暗箭","放暗箭"],["放松","放鬆"],["放松管制","放松管制"],["放流水标准","放流水標準"],["放烟","放煙"],["放烟幕","放煙幕"],["放烟幕弹","放煙幕彈"],["放烟火","放煙火"],["放荡","放蕩"],["放荡不羁","放蕩不羈"],["放荡任气","放蕩任氣"],["放荡弛纵","放蕩弛縱"],["放蒙挣","放懞掙"],["放诸四海皆准","放諸四海皆準"],["放轻松","放輕鬆"],["放马后炮","放馬後炮"],["放马后砲","放馬後砲"],["政党","政黨"],["政党政治","政黨政治"],["政出多门","政出多門"],["政制","政制"],["政团","政團"],["政坛","政壇"],["政工干校","政工幹校"],["政府机关开放系统互连总则","政府機關開放系統互連總則"],["政教合一","政教合一"],["政治体制","政治體制"],["政治局面","政治局面"],["政治斗争","政治鬥爭"],["政治系","政治系"],["政治舞台","政治舞臺"],["政治面","政治面"],["政策面","政策面"],["政见发表","政見發表"],["故事里","故事裏"],["故于","故於"],["故云","故云"],["故出","故出"],["故地重游","故地重遊"],["故当","故當"],["故态复萌","故態復萌"],["故舍","故舍"],["故里","故里"],["效价能","效價能"],["敌党","敵黨"],["敌前敌后","敵前敵後"],["敌占区","敵佔區"],["敌台","敵臺"],["敌后","敵後"],["敌后伏击","敵後伏擊"],["敌后作战","敵後作戰"],["敌后工作","敵後工作"],["敌后工作人员","敵後工作人員"],["敌后方","敵後方"],["敌忾同仇","敵愾同仇"],["敌百虫","敵百蟲"],["敏于","敏於"],["敏于事而慎于言","敏於事而慎於言"],["敏于伎","敏於伎"],["救人一命胜造七级浮屠","救人一命勝造七級浮屠"],["救人须救彻","救人須救徹"],["救出","救出"],["救出去","救出去"],["救出来","救出來"],["救回","救回"],["救回去","救回去"],["救回来","救回來"],["救困扶危","救困扶危"],["救国团","救國團"],["救恩计划","救恩計劃"],["救生艇甲板","救生艇甲板"],["救药","救藥"],["敖游","敖遊"],["敖荡","敖盪"],["教个","教個"],["教了","教了"],["教于","教於"],["教准部","教準部"],["教出","教出"],["教团","教團"],["教坛","教壇"],["教外别传","教外別傳"],["教学示范","教學示範"],["教学计划","教學計劃"],["教学钟","教學鐘"],["教猱升木","教猱升木"],["教练团","教練團"],["教育出来","教育出來"],["教育制度","教育制度"],["教育团体","教育團體"],["教育方针","教育方針"],["教育系","教育系"],["教胄","教胄"],["教范","教範"],["敝帚千金","敝帚千金"],["敝舍","敝舍"],["敢于","敢於"],["敢作敢当","敢作敢當"],["敢借","敢借"],["敢做敢当","敢做敢當"],["敢出","敢出"],["敢出去","敢出去"],["敢出来","敢出來"],["敢向","敢向"],["敢干","敢幹"],["敢当","敢當"],["敢情欲","敢情欲"],["敢摆","敢擺"],["敢斗了胆","敢斗了膽"],["散于","散於"],["散伙","散夥"],["散兵游勇","散兵遊勇"],["散出","散出"],["散发","散發","散髮"],["散发传单","散發傳單"],["散发出","散發出"],["散发出来","散發出來"],["散尽","散盡"],["散布","散佈"],["散布开","散佈開"],["散布者","散佈者"],["散曲","散曲"],["散板","散板"],["散荡","散蕩"],["敦克尔克大撤退","敦克爾克大撤退"],["敦朴","敦樸"],["敦煌千佛洞","敦煌千佛洞"],["敦煌曲子","敦煌曲子"],["敬同","敬同"],["敬姜犹绩","敬姜猶績"],["敬挽","敬輓"],["敬烟","敬菸"],["敬鉴","敬鑒"],["数万","數萬"],["数万人","數萬人"],["数万元","數萬元"],["数不尽","數不盡"],["数不胜数","數不勝數"],["数与虏确","數與虜确"],["数了","數了"],["数以万计","數以萬計"],["数以万订","數以萬訂"],["数以千计","數以千計"],["数以百万计","數以百萬計"],["数位化录音带","數位化錄音帶"],["数位快速篆刻系统","數位快速篆刻系統"],["数位控制","數位控制"],["数位板","數位板"],["数位艺术","數位藝術"],["数借","數借"],["数值控制","數值控制"],["数值范围","數值範圍"],["数出","數出"],["数十万","數十萬"],["数千","數千"],["数千万","數千萬"],["数千亿","數千億"],["数周","數週"],["数天后","數天後"],["数字时钟","數字時鐘"],["数字系数","數字係數"],["数字钟","數字鐘"],["数字钟表","數字鐘錶"],["数学系","數學系"],["数据","數據"],["数据介面","數據介面"],["数据传输","數據傳輸"],["数据卡","數據卡"],["数据压缩","數據壓縮"],["数据处理","數據處理"],["数据库","數據庫"],["数据总线","數據總線"],["数据挖掘","數據挖掘"],["数据接口","數據接口"],["数据机","數據機"],["数据段","數據段"],["数据流","數據流"],["数据源","數據源"],["数据结构","數據結構"],["数据网络","數據網絡"],["数据调制解调器","數據調制解調器"],["数据资料","數據資料"],["数据通信","數據通信"],["数据通讯","數據通訊"],["数据链","數據鏈"],["数据链路","數據鏈路"],["数据链路层","數據鏈路層"],["数据链路连接识别码","數據鏈路連接識別碼"],["数术","數術"],["数杯","數杯"],["数百万","數百萬"],["数米志炊","數米志炊"],["数罪并罚","數罪併罰"],["敲丧钟","敲喪鐘"],["敲了","敲了"],["敲出","敲出"],["敲钟","敲鐘"],["整个","整個"],["整个人","整個人"],["整个地球","整個地球"],["整个月","整個月"],["整个来说","整個來說"],["整了","整了"],["整人游戏","整人遊戲"],["整修","整修"],["整修费","整修費"],["整党","整黨"],["整出剧","整齣劇"],["整出戏","整齣戲"],["整厂输出","整廠輸出"],["整发","整發"],["整发用品","整髮用品"],["整只","整隻"],["整叶","整葉"],["整合","整合"],["整合出","整合出"],["整合到","整合到"],["整合商","整合商"],["整合型","整合型"],["整合式","整合式"],["整合性","整合性"],["整合成","整合成"],["整合法","整合法"],["整合管理资讯化","整合管理資訊化"],["整合系统","整合系統"],["整合行销传播","整合行銷傳播"],["整周","整週"],["整型手术","整型手術"],["整型术","整型術"],["整容手术","整容手術"],["整容术","整容術"],["整庄","整莊"],["整形术","整形術"],["整数集合","整數集合"],["整杯","整杯"],["整杯水","整杯水"],["整杯茶","整杯茶"],["整杯酒","整杯酒"],["整柜","整櫃"],["整根烟","整根菸"],["整理出","整理出"],["整理出来","整理出來"],["整装待发","整裝待發"],["整面","整面"],["整风后","整風後"],["整齐划一","整齊劃一"],["整齐干淨","整齊乾淨"],["敷了","敷了"],["敷出","敷出"],["敷布","敷布"],["敷彩泥塑","敷彩泥塑"],["敷涂","敷塗"],["敷药","敷藥"],["敷衍了事","敷衍了事"],["敷面","敷面"],["敷面膜","敷面膜"],["敹一针","敹一針"],["文不尽意","文不盡意"],["文丑","文丑"],["文书鉴定","文書鑑定"],["文了","文了"],["文件旅游","文件旅遊"],["文件柜","文件櫃"],["文修武偃","文修武偃"],["文修武备","文修武備"],["文创志业","文創志業"],["文化体系","文化體系"],["文化冲击","文化衝擊"],["文化斗争","文化鬥爭"],["文化水准","文化水準"],["文同","文同"],["文君当垆","文君當壚"],["文坛","文壇"],["文坛人士","文壇人士"],["文复会","文復會"],["文学系","文學系"],["文彩","文彩"],["文征明","文徵明"],["文心雕龙","文心雕龍"],["文思泉涌","文思泉涌"],["文情并茂","文情並茂"],["文才","文才"],["文擅雕龙","文擅雕龍"],["文斯范恩","文斯范恩"],["文星和合","文星和合"],["文曲","文曲"],["文曲星","文曲星"],["文武全才","文武全才"],["文武合一","文武合一"],["文汇报","文匯報"],["文汇阁","文匯閣"],["文炳雕龙","文炳雕龍"],["文种","文種"],["文章星斗","文章星斗"],["文致","文致"],["文艺复兴","文藝復興"],["文艺演出","文藝演出"],["文表","文表"],["文身断发","文身斷髮"],["文选烂秀才半","文選爛秀才半"],["文采","文采"],["文采出众","文采出衆"],["文采郁郁","文采郁郁"],["文采风流","文采風流"],["文鉴","文鑑"],["文锦复阱","文錦覆阱"],["文面","文面"],["斋坛","齋壇"],["斋栗","齋慄"],["斋舍","齋舍"],["斐然向风","斐然向風"],["斑岩","斑岩"],["斗一斗","鬥一鬥"],["斗上","鬥上"],["斗上一斗","鬥上一鬥"],["斗不过","鬥不過"],["斗丽","鬥麗"],["斗了","鬥了"],["斗了一斗","鬥了一鬥"],["斗了起来","鬥了起來"],["斗争","鬥爭"],["斗争大会","鬥爭大會"],["斗争形式","鬥爭形式"],["斗争性","鬥爭性"],["斗争意志","鬥爭意志"],["斗争斗合","鬥爭鬥合"],["斗争方式","鬥爭方式"],["斗他一斗","鬥他一鬥"],["斗倒","鬥倒"],["斗储","斗儲"],["斗六","斗六"],["斗六市","斗六市"],["斗内力","鬥內力"],["斗分子","鬥分子"],["斗别气","鬥彆氣"],["斗力","鬥力"],["斗力不如斗智","鬥力不如鬥智"],["斗劲","鬥勁"],["斗十余","鬥十餘"],["斗升","斗升"],["斗升之水","斗升之水"],["斗升之禄","斗升之祿"],["斗南","斗南"],["斗南一人","斗南一人"],["斗南镇","斗南鎮"],["斗叠","鬥疊"],["斗口","鬥口"],["斗口齿","鬥口齒"],["斗叶儿","鬥葉兒"],["斗叶子","鬥葉子"],["斗合","鬥合"],["斗哄","鬥鬨"],["斗嘴","鬥嘴"],["斗地主","鬥地主"],["斗城","斗城"],["斗士","鬥士"],["斗大","斗大"],["斗大的手卷","斗大的手卷"],["斗大的馒头","斗大的饅頭"],["斗头","鬥頭"],["斗她一斗","鬥她一鬥"],["斗子","斗子"],["斗室","斗室"],["斗室生辉","斗室生輝"],["斗富","鬥富"],["斗小马","斗小馬"],["斗尾港","斗尾港"],["斗居","斗居"],["斗山","斗山"],["斗巧","鬥巧"],["斗巧争奇","鬥巧爭奇"],["斗帐","斗帳"],["斗幌子","鬥幌子"],["斗店","斗店"],["斗府","斗府"],["斗弄","鬥弄"],["斗引","鬥引"],["斗彩","鬥彩"],["斗很","鬥很"],["斗心眼","鬥心眼"],["斗志","鬥志"],["斗志昂扬","鬥志昂揚"],["斗志高昂","鬥志高昂"],["斗成","鬥成"],["斗打","鬥打"],["斗批改","鬥批改"],["斗技","鬥技"],["斗折蛇行","斗折蛇行"],["斗拱","斗拱"],["斗数","斗數"],["斗文","鬥文"],["斗斋","斗齋"],["斗斗","鬥鬥","斗斗"],["斗斗嘴","鬥鬥嘴"],["斗斛之禄","斗斛之祿"],["斗方","斗方"],["斗方名士","斗方名士"],["斗智","鬥智"],["斗智不斗力","鬥智不鬥力"],["斗智斗力","鬥智鬥力"],["斗暴","鬥暴"],["斗杓","斗杓"],["斗杓东指","斗杓東指"],["斗杓转势","斗杓轉勢"],["斗来斗去","鬥來鬥去"],["斗极","斗極"],["斗柄","斗柄"],["斗栱","斗栱"],["斗概","斗概"],["斗武","鬥武"],["斗殴","鬥毆"],["斗气","鬥氣"],["斗法","鬥法"],["斗渠","斗渠"],["斗灯","斗燈"],["斗烟丝","斗菸絲"],["斗然","斗然"],["斗牌","鬥牌"],["斗牙拌齿","鬥牙拌齒"],["斗牙斗齿","鬥牙鬥齒"],["斗牛","鬥牛"],["斗牛㹴","鬥牛㹴"],["斗牛之间","斗牛之間"],["斗牛场","鬥牛場"],["斗牛士","鬥牛士"],["斗牛士之歌","鬥牛士之歌"],["斗牛梗","鬥牛梗"],["斗牛赛","鬥牛賽"],["斗牛阵","鬥牛陣"],["斗犀台","鬥犀臺"],["斗犬","鬥犬"],["斗狠","鬥狠"],["斗百余","鬥百餘"],["斗百草","鬥百草"],["斗的","斗的"],["斗真","斗真"],["斗眼","鬥眼"],["斗私批修","鬥私批修"],["斗笠","斗笠"],["斗筲","斗筲"],["斗筲之人","斗筲之人"],["斗筲之器","斗筲之器"],["斗筲之徒","斗筲之徒"],["斗筲之才","斗筲之才"],["斗筲之材","斗筲之材"],["斗筲之辈","斗筲之輩"],["斗筲小器","斗筲小器"],["斗筲役","斗筲役"],["斗筲穿窬","斗筲穿窬"],["斗箕","斗箕"],["斗篷","斗篷"],["斗粟囊金","斗粟囊金"],["斗粟尺布","斗粟尺布"],["斗纹","斗紋"],["斗绝","斗絕"],["斗绝一隅","斗絕一隅"],["斗罗大陆","斗羅大陸"],["斗而铸兵","鬥而鑄兵"],["斗而铸锥","鬥而鑄錐"],["斗胆","斗膽"],["斗胜","鬥勝"],["斗脚","鬥腳"],["斗舰","鬥艦"],["斗艳","鬥豔"],["斗艳争芳","鬥豔爭芳"],["斗茶","鬥茶"],["斗草","鬥草"],["斗蓬装","斗蓬裝"],["斗薮","斗藪"],["斗蟋蟀","鬥蟋蟀"],["斗话","鬥話"],["斗起","鬥起"],["斗起来","鬥起來"],["斗趣","鬥趣"],["斗趣儿","鬥趣兒"],["斗车","斗車"],["斗转参横","斗轉參橫"],["斗转星移","斗轉星移"],["斗酒","斗酒"],["斗酒博凉州","斗酒博涼州"],["斗酒只鸡","斗酒隻雞"],["斗酒学士","斗酒學士"],["斗酒百篇","斗酒百篇"],["斗重山齐","斗重山齊"],["斗量","斗量"],["斗量车载","斗量車載"],["斗门","斗門"],["斗门区","斗門區"],["斗闲气","鬥閒氣"],["斗闷","鬥悶"],["斗闷子","鬥悶子"],["斗阵","鬥陣"],["斗雪红","鬥雪紅"],["斗顿","斗頓"],["斗风","鬥風"],["斗食","斗食"],["斗饤","鬥飣"],["斗香","斗香"],["斗魁","斗魁"],["斗鱼","鬥魚"],["斗鸡","鬥雞"],["斗鸡台","鬥雞臺"],["斗鸡场","鬥雞場"],["斗鸡眼","鬥雞眼"],["斗鸡走狗","鬥雞走狗"],["斗鸡走马","鬥雞走馬"],["斗鸭","鬥鴨"],["斗鹌鹑","鬥鵪鶉"],["料不准","料不準"],["料前不能料后","料前不能料後"],["料敌制胜","料敵制勝"],["料斗","料斗"],["斜了","斜了"],["斜对面","斜對面"],["斜座标系","斜座標系"],["斜曲","斜曲"],["斜杠","斜槓"],["斜管面","斜管麪"],["斜纹布","斜紋布"],["斜谷","斜谷"],["斜面","斜面"],["斤斗","斤斗"],["斥卤","斥鹵"],["斩尽","斬盡"],["斩尽杀绝","斬盡殺絕"],["斩获","斬獲"],["斫雕为朴","斫雕爲樸"],["断不了","斷不了"],["断了","斷了"],["断仇谷","斷仇谷"],["断发","斷髮"],["断发文身","斷髮文身"],["断后","斷後"],["断后路","斷後路"],["断头台","斷頭臺"],["断弦","斷絃"],["断念","斷念"],["断根绝种","斷根絕種"],["断烟","斷煙"],["断种","斷種"],["断纸余墨","斷紙余墨"],["断钗重合","斷釵重合"],["断雨残云","斷雨殘雲"],["断面","斷面"],["断面图","斷面圖"],["斯伯丁杯","斯伯丁盃"],["斯克","斯克"],["斯克里亚宾","斯克里亞賓"],["斯坦贝克","斯坦貝克"],["斯干","斯干"],["斯当东","斯當東"],["斯托","斯托"],["斯托肯立石圈","斯托肯立石圈"],["斯摩棱斯克","斯摩棱斯克"],["斯杯","斯杯"],["斯洛伐克","斯洛伐克"],["斯洛伐克共和国","斯洛伐克共和國"],["斯洛伐克语","斯洛伐克語"],["斯瓦希里","斯瓦希里"],["斯瓦希里语","斯瓦希里語"],["斯瓦特谷地","斯瓦特谷地"],["斯科普里","斯科普里"],["斯芬克士","斯芬克士"],["斯芬克斯","斯芬克斯"],["斯诺克","斯諾克"],["斯迪里","斯迪里"],["斯里","斯里"],["斯里兰卡","斯里蘭卡"],["斯里兰卡民主社会主义共和国","斯里蘭卡民主社會主義共和國"],["斯里兰卡电信","斯里蘭卡電信"],["斯里巴加湾港","斯里巴加灣港"],["斯里査潘","斯里查潘"],["斯雷布雷尼察","斯雷布雷尼察"],["斯须","斯須"],["新不伦瑞克","新不倫瑞克"],["新丰","新豐"],["新丰乡","新豐鄉"],["新丰县","新豐縣"],["新丰酒","新豐酒"],["新书看板","新書看板"],["新余","新餘"],["新余市","新餘市"],["新修本草","新修本草"],["新党","新黨"],["新几內亚","新幾內亞"],["新几內亚岛","新幾內亞島"],["新几内亚","新幾內亞"],["新出","新出"],["新出土","新出土"],["新出土儿","新出土兒"],["新出手儿","新出手兒"],["新出来","新出來"],["新出炉","新出爐"],["新出生","新出生"],["新制","新制"],["新制度","新制度"],["新剧同志会","新劇同志會"],["新单曲","新單曲"],["新历","新曆"],["新历史","新歷史"],["新发","新發"],["新发明","新發明"],["新发村","新發村"],["新台","新臺"],["新台币","新臺幣"],["新叶","新葉"],["新喀里多尼亚","新喀里多尼亞"],["新城电台","新城電臺"],["新娘","新娘"],["新娘子","新娘子"],["新娘花","新娘花"],["新娘车","新娘車"],["新娘进了房媒人扔过墙","新娘進了房媒人扔過牆"],["新婚不如远别","新婚不如遠別"],["新嫁娘","新嫁娘"],["新局面","新局面"],["新干","新干"],["新干县","新干縣"],["新干线","新幹線"],["新庄","新莊"],["新庄市","新莊市"],["新征","新徵"],["新德里","新德里"],["新慕道团","新慕道團"],["新扎","新紮"],["新技术","新技術"],["新报台","新報臺"],["新斯科舍","新斯科舍"],["新曲","新曲"],["新板特区","新板特區"],["新注音","新注音"],["新注音输入法","新注音輸入法"],["新潮流系","新潮流系"],["新疆回变","新疆回變"],["新疆师范大学","新疆師範大學"],["新秋","新秋"],["新竹师范学院","新竹師範學院"],["新系","新系"],["新纪录","新紀錄"],["新罕布什尔","新罕布什爾"],["新罕布什尔州","新罕布什爾州"],["新罕布夏","新罕布夏"],["新胜利","新勝利"],["新艺术","新藝術"],["新艺综合体","新藝綜合體"],["新芬党","新芬黨"],["新药","新藥"],["新莺出谷","新鶯出谷"],["新规范","新規範"],["新闻价值","新聞價值"],["新闻出版总署","新聞出版總署"],["新闻发布会","新聞發佈會"],["新闻发言人","新聞發言人"],["新闻台","新聞臺"],["新闻周刊","新聞週刊"],["新闻杂志","新聞雜誌"],["新闻系","新聞系"],["新集团","新集團"],["新面孔","新面孔"],["斲雕为朴","斲雕爲樸"],["方便面","方便麪"],["方公里","方公里"],["方几","方几"],["方向","方向"],["方向仪","方向儀"],["方向性","方向性"],["方向感","方向感"],["方向灯","方向燈"],["方向盘","方向盤"],["方向线","方向線"],["方向舵","方向舵"],["方圆十里","方圓十里"],["方岳","方岳"],["方彩绫","方彩綾"],["方志","方誌"],["方志友","方志友"],["方志贤","方志賢"],["方才","方纔"],["方斯蔑如","方斯蔑如"],["方方面面","方方面面"],["方术","方術"],["方济谷派","方濟谷派"],["方胜","方勝"],["方药","方藥"],["方言志","方言志"],["方里","方里"],["方针","方針"],["方面","方面"],["方面兼圻","方面兼圻"],["方面大耳","方面大耳"],["方面官","方面官"],["方面官员","方面官員"],["於夫罗","於夫羅"],["施于","施於"],["施仁布德","施仁佈德"],["施仁布恩","施仁佈恩"],["施仁布泽","施仁佈澤"],["施佳升","施佳昇"],["施出","施出"],["施恩布德","施恩佈德"],["施放烟火","施放煙火"],["施朱傅粉","施朱傅粉"],["施瓦布","施瓦布"],["施粥舍饭","施粥捨飯"],["施耐庵","施耐庵"],["施舍","施捨"],["施舍之道","施舍之道"],["施药","施藥"],["施诺布莉琪","施諾布莉琪"],["旁出","旁出"],["旁征","旁徵"],["旁征博引","旁徵博引"],["旁注","旁註"],["旁系","旁系"],["旁系亲","旁系親"],["旁系亲属","旁系親屬"],["旁系血亲","旁系血親"],["旁观者审当局者迷","旁觀者審當局者迷"],["旅历","旅歷"],["旅游","旅遊"],["旅游业","旅遊業"],["旅游书","旅遊書"],["旅游事业","旅遊事業"],["旅游区","旅遊區"],["旅游卡","旅遊卡"],["旅游史","旅遊史"],["旅游团","旅遊團"],["旅游城市","旅遊城市"],["旅游客","旅遊客"],["旅游局","旅遊局"],["旅游局长","旅遊局長"],["旅游展","旅遊展"],["旅游手冊","旅遊手冊"],["旅游景点","旅遊景點"],["旅游村","旅遊村"],["旅游点","旅遊點"],["旅游热点","旅遊熱點"],["旅游界","旅遊界"],["旅游社","旅遊社"],["旅游线","旅遊線"],["旅游网","旅遊網"],["旅游者","旅遊者"],["旅游胜地","旅遊勝地"],["旅游集散","旅遊集散"],["旅游馆","旅遊館"],["旅程表","旅程表"],["旅舍","旅舍"],["旅行剧团","旅行劇團"],["旅行团","旅行團"],["旋回","旋迴"],["旋干转坤","旋乾轉坤"],["旋松","旋鬆"],["旋毛虫","旋毛蟲"],["旋胡","旋胡"],["旋转乾坤","旋轉乾坤"],["旋转乾坤之力","旋轉乾坤之力"],["旋转台","旋轉臺"],["旋转曲面","旋轉曲面"],["旋转极","旋轉極"],["旋辟","旋辟"],["旋里","旋里"],["旌别","旌別"],["旌善惩恶","旌善懲惡"],["旌恤","旌卹"],["旌表","旌表"],["旍表","旍表"],["族党","族黨"],["族里","族裏"],["旗开得胜","旗開得勝"],["旗杆","旗杆"],["旗杆上绑鸡毛","旗杆上綁雞毛"],["旗鼓相当","旗鼓相當"],["旛胜","旛勝"],["无一幸免","無一倖免"],["无业游民","無業遊民"],["无业闲散","無業閒散"],["无主尸","無主屍"],["无了无休","無了無休"],["无云","無雲"],["无以复加","無以復加"],["无价","無價"],["无价之宝","無價之寶"],["无价事","無价事"],["无价宝","無價寶"],["无价珍珠","無價珍珠"],["无伴奏合唱","無伴奏合唱"],["无余","無餘"],["无偏无党","無偏無黨"],["无党","無黨"],["无党无偏","無黨無偏"],["无党无派","無黨無派"],["无党派","無黨派"],["无党派投票人","無黨派投票人"],["无党籍","無黨籍"],["无农药","無農藥"],["无冤无仇","無冤無仇"],["无冬无夏","無冬無夏"],["无几","無幾"],["无凭无据","無憑無據"],["无出","無出"],["无出其右","無出其右"],["无动于衷","無動於衷"],["无助于","無助於"],["无千大万","無千大萬"],["无千带数","無千帶數"],["无千无万","無千無萬"],["无厘头","無厘頭"],["无取胜希望者","無取勝希望者"],["无可救药","無可救藥"],["无后","無後"],["无后为大","無後爲大"],["无回豁","無回豁"],["无复孑遗","無復孑遺"],["无头愿","無頭願"],["无尽","無盡"],["无尽无休","無盡無休"],["无尽无穷","無盡無窮"],["无尽缘起","無盡緣起"],["无尽藏","無盡藏"],["无尿症","無尿症"],["无干","無干"],["无店面","無店面"],["无异于","無異於"],["无形输出","無形輸出"],["无征不信","無徵不信"],["无念","無念"],["无恶不作","無惡不作"],["无愧于","無愧於"],["无所不用其极","無所不用其極"],["无所牵挂","無所牽掛"],["无所适从","無所適從"],["无挂无碍","無掛無礙"],["无损于","無損於"],["无据","無據"],["无敌不克","無敵不克"],["无期别","無期別"],["无机化合物","無機化合物"],["无极","無極"],["无极县","無極縣"],["无核","無核"],["无梁","無樑"],["无梁斗","無樑斗"],["无梁楼盖","無樑樓蓋"],["无欲","無慾"],["无欲则刚","無欲則剛"],["无止尽","無止盡"],["无法克制","無法剋制"],["无法挽救","無法挽救"],["无济于事","無濟於事"],["无烟","無煙"],["无烟囱工业","無煙囪工業"],["无烟火药","無煙火藥"],["无烟炭","無煙炭"],["无烟焦煤","無煙焦煤"],["无烟煤","無煙煤"],["无牵无挂","無牽無掛"],["无畏于","無畏於"],["无畏布施","無畏佈施"],["无穷尽","無窮盡"],["无穷无尽","無窮無盡"],["无精打采","無精打采"],["无线电台","無線電臺"],["无缘见面","無緣見面"],["无药","無藥"],["无药可救","無藥可救"],["无补于世","無補於世"],["无补于事","無補於事"],["无补于时","無補於時"],["无表情","無表情"],["无视于","無視於"],["无计向","無計向"],["无足挂齿","無足掛齒"],["无适无莫","無適無莫"],["无针不引线","無針不引線"],["无针注射器","無針注射器"],["无钩绦虫","無鉤絛蟲"],["无限制","無限制"],["无面值邮票","無面值郵票"],["无面目","無面目"],["无须","無須"],["既得陇复望蜀","既得隴復望蜀"],["既有今日何必当初","既有今日何必當初"],["日久弥新","日久彌新"],["日出","日出"],["日出万言必有一伤","日出萬言必有一傷"],["日出三竿","日出三竿"],["日出日落","日出日落"],["日出而作","日出而作"],["日出而作日入而息","日出而作日入而息"],["日制","日製"],["日升","日升"],["日升月恒","日升月恆"],["日占","日佔"],["日历","日曆"],["日历年度","日曆年度"],["日历纸","日曆紙"],["日历表","日曆表"],["日后","日後"],["日均价","日均價"],["日复一日","日復一日"],["日头打西出来","日頭打西出來"],["日子里","日子裏"],["日干","日干"],["日干夜干","日幹夜幹"],["日御","日御"],["日志","日誌"],["日据","日據"],["日据时代","日據時代"],["日文系","日文系"],["日晒","日曬"],["日月升恒","日月升恆"],["日月参辰","日月參辰"],["日月合璧","日月合璧"],["日本共产党","日本共產黨"],["日本共同社","日本共同社"],["日本制","日本製"],["日本台","日本臺"],["日本团","日本團"],["日本国志","日本國誌"],["日本社会党","日本社會黨"],["日正当中","日正當中"],["日比谷公园","日比谷公園"],["日游","日遊"],["日理万机","日理萬機"],["日番谷","日番谷"],["日知录","日知錄"],["日程表","日程表"],["日系","日系"],["日行千里","日行千里"],["日表","日表"],["日试万言","日試萬言"],["日语系","日語系"],["日趋恶劣","日趨惡劣"],["日转千街","日轉千街"],["日转千阶","日轉千階"],["日进斗金","日進斗金"],["日里","日裏"],["日锻月炼","日鍛月煉"],["日食万钱","日食萬錢"],["旧公烟","舊公煙"],["旧制","舊制"],["旧制度","舊制度"],["旧厂","舊廠"],["旧历","舊曆"],["旧历史","舊歷史"],["旧历年","舊曆年"],["旧地重游","舊地重遊"],["旧庄","舊莊"],["旧念复萌","舊念復萌"],["旧态复萌","舊態復萌"],["旧恨新仇","舊恨新仇"],["旧恶","舊惡"],["旧游","舊遊"],["旧疾复发","舊疾復發"],["旧病复发","舊病復發"],["旧症","舊症"],["旧皇历","舊皇曆"],["旧药","舊藥"],["旧表","舊錶"],["旧钟","舊鐘"],["旧钟表","舊鐘錶"],["早了","早了"],["早于","早於"],["早借","早借"],["早借早还","早借早還"],["早出","早出"],["早出晚归","早出晚歸"],["早动手早收获","早動手早收穫"],["早占勿药","早占勿藥"],["早去早回","早去早回"],["早参","早參"],["早名必折","早名必折"],["早日康复","早日康復"],["早有计划","早有計劃"],["早知今日何必当初","早知今日何必當初"],["早知今日悔不当初","早知今日悔不當初"],["早秋","早秋"],["早自修","早自修"],["早起的鸟儿有虫吃","早起的鳥兒有蟲吃"],["旭日东升","旭日東昇"],["旭日初升","旭日初昇"],["旱干","旱乾"],["旱烟","旱菸"],["旱烟筒","旱菸筒"],["旱烟袋","旱菸袋"],["时代不同风尚不同","時代不同風尚不同"],["时代周刊","時代週刊"],["时价","時價"],["时刻准备","時刻準備"],["时刻表","時刻表"],["时后","時後"],["时和岁丰","時和歲豐"],["时和年丰","時和年豐"],["时宪历","時憲曆"],["时尚周","時尚週"],["时干下","時幹下"],["时念","時念"],["时报周刊","時報週刊"],["时报杂志","時報雜誌"],["时症","時症"],["时程表","時程表"],["时紧时松","時緊時鬆"],["时装周","時裝週"],["时装表演","時裝表演"],["时针","時針"],["时钟","時鐘"],["时钟座","時鐘座"],["时间电价","時間電價"],["时间艺术","時間藝術"],["时间范围","時間範圍"],["时间表","時間表"],["时间里","時間裏"],["旷世之才","曠世之才"],["旷世奇才","曠世奇才"],["旷世逸才","曠世逸才"],["旷日弥久","曠日彌久"],["旷若发蒙","曠若發矇"],["旷荡","曠蕩"],["旷课记录","曠課記錄"],["旸谷","暘谷"],["昂纳克","昂納克"],["昆仑","崑崙"],["昆仑山","崑崙山"],["昆仑山脉","崑崙山脈"],["昆剧","崑劇"],["昆宁佩克","昆寧佩克"],["昆山","崑山"],["昆布","昆布"],["昆曲","崑曲"],["昆腔","崑腔"],["昆苏","崑蘇"],["昆虫","昆蟲"],["昆虫学","昆蟲學"],["昆虫学家","昆蟲學家"],["昆虫纲","昆蟲綱"],["昆调","崑調"],["昆都仑","昆都侖"],["昆都仑区","昆都侖區"],["昊天不吊","昊天不弔"],["昊天罔极","昊天罔極"],["昌吉回族自治州","昌吉回族自治州"],["明中舍去暗中来","明中捨去暗中來"],["明了","明瞭"],["明争暗斗","明爭暗鬥"],["明于","明於"],["明于观人","明於觀人"],["明人不做暗事","明人不做暗事"],["明人不说暗话","明人不說暗話"],["明伙画供","明伙畫供"],["明修栈道","明修棧道"],["明修栈道暗渡陈仓","明修棧道暗渡陳倉"],["明升暗降","明升暗降"],["明华园歌剧团","明華園歌劇團"],["明发","明發"],["明台","明臺"],["明后","明後"],["明后天","明後天"],["明复","明覆"],["明夷待访录","明夷待訪錄"],["明媚闲雅","明媚閒雅"],["明实录","明實錄"],["明察暗访","明察暗訪"],["明察秋毫","明察秋毫"],["明尼苏大学","明尼蘇大學"],["明尼苏达","明尼蘇達"],["明尼苏达州","明尼蘇達州"],["明岗暗哨","明崗暗哨"],["明师出高徒","明師出高徒"],["明并日月","明並日月"],["明弃暗取","明棄暗取"],["明当","明當"],["明征","明徵"],["明志","明志"],["明志工专","明志工專"],["明志工业","明志工業"],["明志工业专科学校","明志工業專科學校"],["明扣","明釦"],["明据","明據"],["明摆","明擺"],["明摆着","明擺着"],["明斯克","明斯克"],["明是一盆火暗是一把刀","明是一盆火暗是一把刀"],["明暗","明暗"],["明暗不定","明暗不定"],["明月当空","明月當空"],["明杠","明槓"],["明来暗往","明來暗往"],["明板","明板"],["明枪好躲暗箭难防","明槍好躲暗箭難防"],["明枪易趓暗箭难防","明槍易趓暗箭難防"],["明枪易躲暗箭难防","明槍易躲暗箭難防"],["明枪暗箭","明槍暗箭"],["明查暗访","明查暗訪"],["明査暗访","明查暗訪"],["明欺暗骗","明欺暗騙"],["明沟暗渠","明溝暗渠"],["明潭抽蓄水力发电工程","明潭抽蓄水力發電工程"],["明珠暗投","明珠暗投"],["明白了当","明白了當"],["明目张胆","明目張膽"],["明知就里","明知就裏"],["明知山有虎偏向虎山行","明知山有虎偏向虎山行"],["明知山有虎故作采樵人","明知山有虎故作採樵人"],["明确","明確"],["明确性","明確性"],["明窗净几","明窗淨几"],["明窗彩户","明窗彩戶"],["明窗淨几","明窗淨几"],["明细表","明細表"],["明者视于无形聪者听于无声","明者視於無形聰者聽於無聲"],["明范","明範"],["明见万里","明見萬里"],["明里","明裏"],["明鉴","明鑑"],["明鉴万里","明鑑萬里"],["明鉴秋毫","明鑑秋毫"],["明鎗容易躲暗剑最难防","明鎗容易躲暗劍最難防"],["明鎗容易躲暗箭最难防","明鎗容易躲暗箭最難防"],["明鎗易躲暗箭难逃","明鎗易躲暗箭難逃"],["明降暗升","明降暗升"],["昏了","昏了"],["昏困","昏困"],["昏天暗地","昏天暗地"],["昏头转向","昏頭轉向"],["昏昏暗暗","昏昏暗暗"],["昏昏欲睡","昏昏欲睡"],["昏暗","昏暗"],["昏沈","昏沈"],["易于","易於"],["易于反掌","易於反掌"],["易克制","易剋制"],["易卜拉辛","易卜拉辛"],["易卜生","易卜生"],["易发难收","易發難收"],["易学启蒙","易學啓蒙"],["易容术","易容術"],["易游网","易遊網"],["易熔合金","易熔合金"],["星云","星雲"],["星占学","星占學"],["星历","星曆"],["星历表","星曆錶"],["星回","星迴"],["星团","星團"],["星巴克","星巴克"],["星彩","星彩"],["星彩正彩","星彩正彩"],["星斗","星斗"],["星期几","星期幾"],["星期后","星期後"],["星术","星術"],["星点弹涂","星點彈塗"],["星相术","星相術"],["星移斗换","星移斗換"],["星移斗转","星移斗轉"],["星系","星系"],["星罗云布","星羅雲佈"],["星罗云散","星羅雲散"],["星罗棋布","星羅棋佈"],["星落云散","星落雲散"],["星虫","星蟲"],["星表","星表"],["星象恶曜","星象惡曜"],["星辰表","星辰錶"],["星驰电发","星馳電發"],["映入眼帘","映入眼簾"],["映出","映出"],["映照出","映照出"],["映照出来","映照出來"],["春假里","春假裏"],["春兰秋菊","春蘭秋菊"],["春华秋实","春華秋實"],["春卷","春捲"],["春卷皮","春捲皮"],["春去秋来","春去秋來"],["春台","春臺"],["春回大地","春回大地"],["春困","春困"],["春困秋乏","春困秋乏"],["春夏秋冬","春夏秋冬"],["春天里","春天裏"],["春宵一刻值千金","春宵一刻值千金"],["春心荡漾","春心蕩漾"],["春日里","春日裏"],["春来秋去","春來秋去"],["春树暮云","春樹暮雲"],["春武里府","春武里府"],["春游","春遊"],["春生夏长秋收冬藏","春生夏長秋收冬藏"],["春生秋杀","春生秋殺"],["春祈秋报","春祈秋報"],["春秋","春秋"],["春秋三传","春秋三傳"],["春秋五霸","春秋五霸"],["春秋儿","春秋兒"],["春秋几何","春秋幾何"],["春秋大一统","春秋大一統"],["春秋大梦","春秋大夢"],["春秋左氏传","春秋左氏傳"],["春秋战国","春秋戰國"],["春秋战国时代","春秋戰國時代"],["春秋日高","春秋日高"],["春秋时代","春秋時代"],["春秋榜","春秋榜"],["春秋笔削","春秋筆削"],["春秋笔法","春秋筆法"],["春秋繁露","春秋繁露"],["春秋配","春秋配"],["春秋鼎盛","春秋鼎盛"],["春笋怒发","春筍怒發"],["春纤","春纖"],["春胜","春勝"],["春花秋月","春花秋月"],["春药","春藥"],["春蚓秋蛇","春蚓秋蛇"],["春露秋霜","春露秋霜"],["春风满面","春風滿面"],["春风面","春風面"],["春香斗学","春香鬥學"],["昧于","昧於"],["昧于事理","昧於事理"],["昧谷","昧谷"],["昨夜里","昨夜裏"],["昨天夜里","昨天夜裏"],["昭君出塞","昭君出塞"],["昭回","昭回"],["昭苏","昭蘇"],["昭苏县","昭蘇縣"],["是个","是個"],["是只","是隻"],["是念","是念"],["是罐子也有两个耳朵","是罐子也有兩個耳朵"],["是非只为多开口","是非只爲多開口"],["是非善恶","是非善惡"],["是非曲直","是非曲直"],["是须","是須"],["昴宿星团","昴宿星團"],["昴星团","昴星團"],["昼伏夜出","晝伏夜出"],["昼伏夜游","晝伏夜游"],["显出","顯出"],["显微手术","顯微手術"],["显摆","顯擺"],["显现出","顯現出"],["显现出来","顯現出來"],["显着标志","顯着標志"],["显示出","顯示出"],["显示出来","顯示出來"],["显示板","顯示板"],["显示表","顯示錶"],["显示钟","顯示鐘"],["显示钟表","顯示鐘錶"],["显著","顯著"],["显著标志","顯著標志"],["显露出","顯露出"],["显露出来","顯露出來"],["晃了","晃了"],["晃晃荡荡","晃晃蕩蕩"],["晃荡","晃盪"],["晋升","晉升"],["晋升为","晉升爲"],["晋阳秋","晉陽秋"],["晏几道","晏幾道"],["晏子春秋","晏子春秋"],["晒伤","曬傷"],["晒台","曬臺"],["晒图","曬圖"],["晒图纸","曬圖紙"],["晒干","曬乾"],["晒成","曬成"],["晒晒","曬曬"],["晒烟","曬菸"],["晒种","曬種"],["晒衣","曬衣"],["晒谷","曬穀"],["晒谷场","曬穀場"],["晒黑","曬黑"],["晕台","暈臺"],["晕头转向","暈頭轉向"],["晕船药","暈船藥"],["晕血症","暈血症"],["晕车药","暈車藥"],["晕针","暈針"],["晚于","晚於"],["晚参","晚參"],["晚娘","晚娘"],["晚娘的拳头云里的日头","晚娘的拳頭雲裏的日頭"],["晚娘面孔","晚娘面孔"],["晚期癌症","晚期癌症"],["晚生后学","晚生後學"],["晚秋","晚秋"],["晚秋作物","晚秋作物"],["晚秋时节","晚秋時節"],["晚钟","晚鐘"],["晚食当肉","晚食當肉"],["晞发","晞髮"],["晤面","晤面"],["晦暗","晦暗"],["晦蒙","晦蒙"],["晨参暮省","晨參暮省"],["晨参暮礼","晨參暮禮"],["晨钟","晨鐘"],["晨钟暮鼓","晨鐘暮鼓"],["普冬冬","普鼕鼕"],["普列谢茨克","普列謝茨克"],["普列谢茨克卫星发射场","普列謝茨克衛星發射場"],["普利艾托","普利艾托"],["普勒托利亚","普勒托利亞"],["普勒斯威克","普勒斯威克"],["普同文化","普同文化"],["普天同庆","普天同慶"],["普奥同盟","普奧同盟"],["普庵咒","普庵咒"],["普庵老祖","普庵老祖"],["普拉斯尼克","普拉斯尼克"],["普拉玛娜苏达","普拉瑪娜蘇達"],["普拉齐克","普拉齊克"],["普普艺术","普普藝術"],["普朗克","普朗克"],["普朗克常数","普朗克常數"],["普氏立克次体","普氏立克次體"],["普罗扎克","普羅扎克"],["普莱克斯","普萊克斯"],["普里","普里"],["普里什蒂纳","普裏什蒂納"],["普里切特","普里切特"],["普里斯特","普里斯特"],["普里斯特莱","普里斯特萊"],["普里斯莱","普里斯萊"],["普里斯蒂纳","普里斯蒂納"],["普里查德","普里查德"],["普里霍吉可","普里霍吉可"],["普隆克","普隆克"],["普雷克斯流程","普雷克斯流程"],["景云","景雲"],["景从云合","景從雲合"],["景从云集","景從雲集"],["景星庆云","景星慶雲"],["景胄","景胄"],["景致","景緻"],["景谷","景谷"],["景谷傣族彝族自治县","景谷傣族彝族自治縣"],["景谷县","景谷縣"],["晴了","晴了"],["晴云秋月","晴雲秋月"],["晴时多云","晴時多雲"],["晴空万里","晴空萬里"],["晴转多云","晴轉多雲"],["晴雨表","晴雨表"],["晶体三极体","晶體三極體"],["晶体三极管","晶體三極管"],["晶体二极体","晶體二極體"],["晶体二极管","晶體二極管"],["晶体振荡","晶體振盪"],["晶圆厂","晶圓廠"],["晶核","晶核"],["晶系","晶系"],["晶面","晶面"],["智周","智周"],["智囊团","智囊團"],["智尽能索","智盡能索"],["智慧型车辆暨公路系统","智慧型車輛暨公路系統"],["智慧板","智慧板"],["智术","智術"],["智者千虑必有一失","智者千慮必有一失"],["晾干","晾乾"],["暂于","暫於"],["暂借","暫借"],["暂别","暫別"],["暂升","暫升"],["暂并列","暫並列"],["暂扣","暫扣"],["暂染发慕丝","暫染髮慕絲"],["暌合","暌合"],["暑修","暑修"],["暑修班","暑修班"],["暑假里","暑假裏"],["暖云兜","暖雲兜"],["暖冬","暖冬"],["暖厂","暖廠"],["暖帘","暖簾"],["暖气团","暖氣團"],["暖种","暖種"],["暖色系","暖色系"],["暖荡撩锅","暖盪撩鍋"],["暗下去","暗下去"],["暗下来","暗下來"],["暗中","暗中"],["暗中作怪","暗中作怪"],["暗中摸索","暗中摸索"],["暗中监视","暗中監視"],["暗中行事","暗中行事"],["暗九","暗九"],["暗乱","闇亂"],["暗了","暗了"],["暗了下来","暗了下來"],["暗事","暗事"],["暗井","暗井"],["暗付","暗付"],["暗伤","暗傷"],["暗伦","闇倫"],["暗光鸟","暗光鳥"],["暗公鸟","暗公鳥"],["暗冥","闇冥"],["暗到","暗到"],["暗劣","闇劣"],["暗反应","暗反應"],["暗叫","暗叫"],["暗叫一声","暗叫一聲"],["暗号","暗號"],["暗号灯","暗號燈"],["暗叹","暗歎"],["暗吃一惊","暗吃一驚"],["暗合","暗合"],["暗含","暗含"],["暗喜","暗喜"],["暗喻","暗喻"],["暗器","暗器"],["暗地","暗地"],["暗地里","暗地裏"],["暗场","暗場"],["暗堡","暗堡"],["暗处","暗處"],["暗娼","暗娼"],["暗室","暗室"],["暗室不欺","暗室不欺"],["暗室亏心","暗室虧心"],["暗室可欺","暗室可欺"],["暗室私心","暗室私心"],["暗室逢灯","暗室逢燈"],["暗害","暗害"],["暗察明访","暗察明訪"],["暗射","暗射"],["暗射地图","暗射地圖"],["暗屋","暗屋"],["暗巷","暗巷"],["暗底下","暗底下"],["暗度陈仓","暗度陳倉"],["暗弱","闇弱"],["暗影","暗影"],["暗得","暗得"],["暗忖","暗忖"],["暗念","暗念"],["暗恋","暗戀"],["暗想","暗想"],["暗房","暗房"],["暗扣","暗釦"],["暗指","暗指"],["暗探","暗探"],["暗操贱业","暗操賤業"],["暗斗","暗鬥"],["暗无天日","暗無天日"],["暗昧","闇昧"],["暗暗","暗暗"],["暗暗淡淡","暗暗淡淡"],["暗杀","暗殺"],["暗杀党","暗殺黨"],["暗杀案","暗殺案"],["暗杠","暗槓"],["暗格","暗格"],["暗桩","暗樁"],["暗楼子","暗樓子"],["暗槓","暗槓"],["暗沈沈","暗沈沈"],["暗沉","暗沉"],["暗沟","暗溝"],["暗沟里","暗溝裏"],["暗河","暗河"],["暗泣","暗泣"],["暗流","暗流"],["暗浅","闇淺"],["暗涌","暗涌"],["暗淡","暗淡"],["暗淡无光","暗淡無光"],["暗渠","暗渠"],["暗渡陈仓","暗渡陳倉"],["暗滩","暗灘"],["暗潮","暗潮"],["暗潮汹涌","暗潮洶涌"],["暗澹","暗澹"],["暗火","闇火"],["暗灰色","暗灰色"],["暗然","闇然"],["暗然失色","暗然失色"],["暗电流","暗電流"],["暗疾","暗疾"],["暗的","暗的"],["暗盒","暗盒"],["暗盘","暗盤"],["暗盼","暗盼"],["暗码","暗碼"],["暗礁","暗礁"],["暗示","暗示"],["暗移","暗移"],["暗笑","暗笑"],["暗笑一声","暗笑一聲"],["暗算","暗算"],["暗管","暗管"],["暗箭","暗箭"],["暗箭中人","暗箭中人"],["暗箭伤人","暗箭傷人"],["暗箭明鎗","暗箭明鎗"],["暗箭难防","暗箭難防"],["暗箱","暗箱"],["暗箱操作","暗箱操作"],["暗紫色","暗紫色"],["暗红","暗紅"],["暗红色","暗紅色"],["暗线","暗線"],["暗线光谱","暗線光譜"],["暗练","暗練"],["暗结珠胎","暗結珠胎"],["暗自","暗自"],["暗自流泪","暗自流淚"],["暗自神伤","暗自神傷"],["暗自窃喜","暗自竊喜"],["暗色","暗色"],["暗色彩","暗色彩"],["暗花儿","暗花兒"],["暗莫","闇莫"],["暗蓝发","闇藍髮"],["暗蔼","暗藹"],["暗藏","暗藏"],["暗藏春色","暗藏春色"],["暗藏玄机","暗藏玄機"],["暗藏着","暗藏着"],["暗藏鬼胎","暗藏鬼胎"],["暗虚","暗虛"],["暗行","暗行"],["暗袋","暗袋"],["暗褐","暗褐"],["暗褐色","暗褐色"],["暗计","暗計"],["暗记","暗記"],["暗记儿","暗記兒"],["暗记在心","暗記在心"],["暗讽","暗諷"],["暗访","暗訪"],["暗语","暗語"],["暗诵","闇誦"],["暗跳","闇跳"],["暗转","暗轉"],["暗边","暗邊"],["暗送","暗送"],["暗送秋波","暗送秋波"],["暗适应","暗適應"],["暗通","暗通"],["暗通款曲","暗通款曲"],["暗道","暗道"],["暗部","暗部"],["暗里","暗裏"],["暗釦","暗釦"],["暗锁","暗鎖"],["暗门","暗門"],["暗门子","暗門子"],["暗问","暗問"],["暗间儿","暗間兒"],["暗顺应","暗順應"],["暗香","暗香"],["暗香疏影","暗香疏影"],["暗骂","暗罵"],["暗黑","暗黑"],["暗黑王","暗黑王"],["暗黝","暗黝"],["暮云亲舍","暮雲親舍"],["暮云春树","暮雲春樹"],["暮烟","暮煙"],["暮礼晨参","暮禮晨參"],["暮秋","暮秋"],["暮雨朝云","暮雨朝雲"],["暮鼓晨钟","暮鼓晨鐘"],["暴发","暴發"],["暴发出来","暴發出來"],["暴发户","暴發戶"],["暴君焚城录","暴君焚城錄"],["暴尸于市","暴屍於市"],["暴扣","暴扣"],["暴敛横征","暴斂橫徵"],["暴晒","暴曬"],["暴腌","暴醃"],["暴露出","暴露出"],["暴露出来","暴露出來"],["暴面","暴面"],["暴食症","暴食症"],["曙后星孤","曙後星孤"],["曝光表","曝光表"],["曝晒","曝曬"],["曝露出","曝露出"],["曰云","曰云"],["曲从","曲從"],["曲体","曲體"],["曲别针","曲別針"],["曲匝","曲匝"],["曲卷","曲捲"],["曲台","曲臺"],["曲名","曲名"],["曲周","曲周"],["曲周县","曲周縣"],["曲园","曲園"],["曲士","曲士"],["曲媚取容","曲媚取容"],["曲子","曲子"],["曲学","曲學"],["曲学诐行","曲學詖行"],["曲学阿世","曲學阿世"],["曲室","曲室"],["曲宴","曲宴"],["曲射炮","曲射炮"],["曲尘","麴塵"],["曲尺","曲尺"],["曲尺楼梯","曲尺樓梯"],["曲尽人情","曲盡人情"],["曲尽其妙","曲盡其妙"],["曲局","曲局"],["曲希瑞","曲希瑞"],["曲庇","曲庇"],["曲度","曲度"],["曲式","曲式"],["曲张","曲張"],["曲径","曲徑"],["曲径通幽","曲徑通幽"],["曲律","曲律"],["曲心矫肚","曲心矯肚"],["曲意","曲意"],["曲意俯就","曲意俯就"],["曲意奉承","曲意奉承"],["曲意逢迎","曲意逢迎"],["曲房","曲房"],["曲折","曲折"],["曲折离奇","曲折離奇"],["曲折萦纡","曲折縈紆"],["曲拐","曲拐"],["曲拗","曲拗"],["曲挠","曲撓"],["曲曲","曲曲"],["曲曲弯弯","曲曲彎彎"],["曲曲折折","曲曲折折"],["曲本","曲本"],["曲松","曲松"],["曲松县","曲松縣"],["曲柄","曲柄"],["曲柄笠","曲柄笠"],["曲柄钻","曲柄鑽"],["曲栏","曲欄"],["曲棍","曲棍"],["曲棍球","曲棍球"],["曲棍球员","曲棍球員"],["曲棍球赛","曲棍球賽"],["曲水","曲水"],["曲水县","曲水縣"],["曲水流觞","曲水流觴"],["曲江","曲江"],["曲江区","曲江區"],["曲江县","曲江縣"],["曲江宴","曲江宴"],["曲江池","曲江池"],["曲池穴","曲池穴"],["曲沃","曲沃"],["曲沃县","曲沃縣"],["曲流","曲流"],["曲牌","曲牌"],["曲率","曲率"],["曲率向量","曲率向量"],["曲球","曲球"],["曲琼","曲瓊"],["曲生","麴生"],["曲盖","曲蓋"],["曲目","曲目"],["曲直","曲直"],["曲直分明","曲直分明"],["曲礼","曲禮"],["曲秀才","麴秀才"],["曲突徙薪","曲突徙薪"],["曲笔","曲筆"],["曲笛","曲笛"],["曲线","曲線"],["曲线图","曲線圖"],["曲线拟合","曲線擬合"],["曲线板","曲線板"],["曲线美","曲線美"],["曲线论","曲線論"],["曲线运动","曲線運動"],["曲终人散","曲終人散"],["曲终奏雅","曲終奏雅"],["曲绕","曲繞"],["曲肱为枕","曲肱爲枕"],["曲肱之乐","曲肱之樂"],["曲肱而枕","曲肱而枕"],["曲背","曲背"],["曲膝礼","曲膝禮"],["曲臂","曲臂"],["曲致","曲致"],["曲艺","曲藝"],["曲艾玲","曲艾玲"],["曲菌","麴菌"],["曲薄","曲薄"],["曲蘖","麴櫱"],["曲蟮","曲蟮"],["曲裾","曲裾"],["曲解","曲解"],["曲话","曲話"],["曲说","曲說"],["曲调","曲調"],["曲谨","曲謹"],["曲谱","曲譜"],["曲赦","曲赦"],["曲躬躬","曲躬躬"],["曲车","麴車"],["曲轴","曲軸"],["曲辫子","曲辮子"],["曲道","曲道"],["曲道士","麴道士"],["曲道赛","曲道賽"],["曲酒","麴酒"],["曲里拐弯","曲裏拐彎"],["曲钱","麴錢"],["曲阜","曲阜"],["曲阜县","曲阜縣"],["曲阜孔庙","曲阜孔廟"],["曲阜市","曲阜市"],["曲阳","曲陽"],["曲阳县","曲陽縣"],["曲阻","曲阻"],["曲院","麴院"],["曲隐","曲隱"],["曲霉","麴黴"],["曲霉毒素","麴黴毒素"],["曲靖","曲靖"],["曲靖地区","曲靖地區"],["曲靖市","曲靖市"],["曲面","曲面"],["曲面论","曲面論"],["曲项目","曲項目"],["曲颈瓶","曲頸瓶"],["曲颈甑","曲頸甑"],["曲风","曲風"],["曲高和寡","曲高和寡"],["曲麻莱","曲麻萊"],["曲麻莱县","曲麻萊縣"],["曳尾泥涂","曳尾泥塗"],["曳尾涂中","曳尾塗中"],["更仆难数","更僕難數"],["更出","更出"],["更加规范","更加規範"],["更动表","更動表"],["更向","更向"],["更复","更復"],["更大范围","更大範圍"],["更当","更當"],["更待干罢","更待干罷"],["更愿","更願"],["更愿意","更願意"],["更甚于","更甚於"],["更签","更籤"],["更胜一筹","更勝一籌"],["更钟","更鐘"],["更须","更須"],["更鼓敲尽","更鼓敲盡"],["曷极","曷極"],["曹余章","曹餘章"],["曹参","曹參"],["曹郁芬","曹郁芬"],["曼尼托巴省","曼尼托巴省"],["曼苏尔","曼蘇爾"],["曼苏尔．达杜拉","曼蘇爾．達杜拉"],["曼谷","曼谷"],["曼谷人","曼谷人"],["曼谷包","曼谷包"],["曼谷市","曼谷市"],["曼谷邮报","曼谷郵報"],["曾于","曾於"],["曾几何时","曾幾何時"],["曾参","曾參"],["曾参杀人","曾參殺人"],["曾台霖","曾臺霖"],["曾孝谷","曾孝谷"],["曾志伟","曾志偉"],["曾志朗","曾志朗"],["曾朴","曾樸"],["曾母暗沙","曾母暗沙"],["曾砚闲","曾硯閒"],["最上面","最上面"],["最下面","最下面"],["最低价","最低價"],["最低谷","最低谷"],["最初几天","最初幾天"],["最初几年","最初幾年"],["最前面","最前面"],["最后","最後"],["最后一天","最後一天"],["最后审判","最後審判"],["最后晚餐","最後晚餐"],["最后更新","最後更新"],["最后期限","最後期限"],["最后的审判","最後的審判"],["最后的晚餐","最後的晚餐"],["最后胜利","最後勝利"],["最后通牒","最後通牒"],["最后面","最後面"],["最大范围","最大範圍"],["最小范围","最小範圍"],["最近几天","最近幾天"],["最近几年","最近幾年"],["最适化","最適化"],["最适合","最適合"],["最里面","最裏面"],["最须","最須"],["最高当局","最高當局"],["會干擾","會干擾"],["月中折桂","月中折桂"],["月丽于箕","月麗於箕"],["月余","月餘"],["月光曲","月光曲"],["月入数万","月入數萬"],["月出","月出"],["月历","月曆"],["月台","月臺"],["月台票","月臺票"],["月团","月團"],["月地云阶","月地雲階"],["月坠花折","月墜花折"],["月娘","月娘"],["月宫娘娘","月宮娘娘"],["月岩","月岩"],["月御","月御"],["月核","月核"],["月桂叶","月桂葉"],["月桂树叶","月桂樹葉"],["月牙铲","月牙鏟"],["月球表面","月球表面"],["月相表","月相錶"],["月离于毕","月離於畢"],["月经规则术","月經規則術"],["月色迷蒙","月色迷濛"],["月落参横","月落參橫"],["月里嫦娥","月裏嫦娥"],["月锻季炼","月鍛季煉"],["月面","月面"],["有一分心尽一分力","有一分心盡一分力"],["有个","有個"],["有个人","有個人"],["有个地洞钻了下去","有個地洞鑽了下去"],["有个好歹","有個好歹"],["有个屁用","有個屁用"],["有个数儿","有個數兒"],["有个说儿","有個說兒"],["有了","有了"],["有了人家","有了人家"],["有了存孝不显彦章","有了存孝不顯彥章"],["有了胎","有了胎"],["有事之无范","有事之無範"],["有云","有云"],["有仆","有僕"],["有仇","有仇"],["有仇不报非君子","有仇不報非君子"],["有仇必报","有仇必報"],["有价","有價"],["有价值","有價值"],["有价証券","有價証券"],["有价证券","有價證券"],["有何面目","有何面目"],["有余","有餘"],["有佛出世","有佛出世"],["有准","有準"],["有凭有据","有憑有據"],["有出入","有出入"],["有出好戏","有齣好戲"],["有出息","有出息"],["有利于","有利於"],["有别","有別"],["有别于","有別於"],["有刮划没是处","有刮劃沒是處"],["有力出力","有力出力"],["有助于","有助於"],["有助于记忆","有助於記憶"],["有勾当","有勾當"],["有去无回","有去無回"],["有发头陀寺","有髮頭陀寺"],["有只","有隻"],["有同情心","有同情心"],["有后","有後"],["有周","有周"],["有够赞","有夠讚"],["有奖征答","有獎徵答"],["有女同车","有女同車"],["有子万事足","有子萬事足"],["有孔虫","有孔蟲"],["有宝何必人前夸","有寶何必人前誇"],["有害于","有害於"],["有尽有让","有儘有讓"],["有幸","有幸"],["有当","有當"],["有征","有徵"],["有征无战","有征無戰"],["有志","有志"],["有志一同","有志一同"],["有志之士","有志之士"],["有志于","有志於"],["有志气","有志氣"],["有志竟成","有志竟成"],["有志者事竟成","有志者事竟成"],["有志难酬","有志難酬"],["有恒街","有恆街"],["有意志","有意志"],["有意栽花花不发无心插柳柳成阴","有意栽花花不發無心插柳柳成陰"],["有感于","有感於"],["有感而云","有感而云"],["有感而发","有感而發"],["有所不同","有所不同"],["有才","有才"],["有才干","有才幹"],["有才无命","有才無命"],["有把傢伙","有把傢伙"],["有损于","有損於"],["有效范围","有效範圍"],["有效面积","有效面積"],["有晚娘就有晚爷","有晚娘就有晚爺"],["有机化合","有機化合"],["有机化合物","有機化合物"],["有机合成","有機合成"],["有板有眼","有板有眼"],["有极","有極"],["有枝有叶","有枝有葉"],["有枝添叶","有枝添葉"],["有栖川","有棲川"],["有核","有核"],["有棱有角","有棱有角"],["有求于人","有求於人"],["有烟煤","有煙煤"],["有益于","有益於"],["有福同享","有福同享"],["有福同享有祸同当","有福同享有禍同當"],["有福同享有难同当","有福同享有難同當"],["有秋","有秋"],["有种","有種"],["有种人","有種人"],["有系统","有系統"],["有缘千里来相会","有緣千里來相會"],["有缘千里来相会无缘对面不相逢","有緣千里來相會無緣對面不相逢"],["有联系","有聯繫"],["有脸面","有臉面"],["有致","有致"],["有致癌","有致癌"],["有色人种","有色人種"],["有节制","有節制"],["有苦说不出","有苦說不出"],["有药瘾者","有藥癮者"],["有被种子植物纲","有被種子植物綱"],["有计划","有計劃"],["有赖于","有賴於"],["有进有出","有進有出"],["有采","有采"],["有鉴","有鑑"],["有鉴于","有鑑於"],["有鉴于此","有鑑於此"],["有钩绦虫","有鉤絛蟲"],["有钱不买半年闲","有錢不買半年閒"],["有钱出钱","有錢出錢"],["有钱有闲","有錢有閒"],["有难同当","有難同當"],["有面","有面"],["有面儿","有面兒"],["朋克","朋克"],["朋党","朋黨"],["朋党为奸","朋黨爲奸"],["朋党之争","朋黨之爭"],["朋党比周","朋黨比周"],["朋党论","朋黨論"],["朋奸","朋奸"],["朋比为奸","朋比爲奸"],["朋比作仇","朋比作仇"],["朋比作奸","朋比作奸"],["服了","服了"],["服于","服於"],["服从于","服從於"],["服制","服制"],["服务于","服務於"],["服务台","服務檯"],["服务周到","服務周到"],["服务团","服務團"],["服务范围","服務範圍"],["服务规范","服務規範"],["服御","服御"],["服毒自尽","服毒自盡"],["服用药","服用藥"],["服舍","服舍"],["服药","服藥"],["服药过量","服藥過量"],["服装周","服裝週"],["服饰周","服飾週"],["朔云","朔雲"],["朔党","朔黨"],["朗朗云天","朗朗雲天"],["望乡台","望鄉臺"],["望了望","望了望"],["望云","望雲"],["望云之情","望雲之情"],["望出去","望出去"],["望后石","望后石"],["望向","望向"],["望幸","望幸"],["望弥撒","望彌撒"],["望楼台","望樓臺"],["望眼欲穿","望眼欲穿"],["望秋先零","望秋先零"],["望穿秋水","望穿秋水"],["望胄","望胄"],["朝东面","朝東面"],["朝乾夕惕","朝乾夕惕"],["朝云","朝雲"],["朝云暮雨","朝雲暮雨"],["朝出夕改","朝出夕改"],["朝北面","朝北面"],["朝升暮合","朝升暮合"],["朝南面","朝南面"],["朝参暮礼","朝參暮禮"],["朝发夕至","朝發夕至"],["朝后","朝後"],["朝向","朝向"],["朝圣团","朝聖團"],["朝核","朝核"],["朝梁暮晋","朝梁暮晉"],["朝梁暮陈","朝梁暮陳"],["朝西面","朝西面"],["朝野两党","朝野兩黨"],["朝钟","朝鐘"],["朝钟暮鼓","朝鐘暮鼓"],["朝鲜冷面","朝鮮冷麪"],["朝鲜劳动党","朝鮮勞動黨"],["期货价","期貨價"],["朦在鼓里","朦在鼓裏"],["朦胧","朦朧"],["木偶戏扎","木偶戲紮"],["木制","木製"],["木制品","木製品"],["木厂","木廠"],["木叶","木葉"],["木垒哈萨克自治县","木壘哈薩克自治縣"],["木强则折","木強則折"],["木心板","木心板"],["木朽不雕","木朽不雕"],["木杆","木杆"],["木材干馏","木材乾餾"],["木杠","木槓"],["木板","木板"],["木板凳","木板凳"],["木板地","木板地"],["木板墙","木板牆"],["木板大鼓","木板大鼓"],["木板牀","木板牀"],["木板画","木板畫"],["木柜","木櫃"],["木梁","木樑"],["木芍药","木芍藥"],["木薯淀粉","木薯澱粉"],["木蜡","木蠟"],["木表法","木表法"],["木里藏族自治县","木裏藏族自治縣"],["木钟","木鐘"],["木铲","木鏟"],["木雕","木雕"],["木雕像","木雕像"],["木雕家","木雕家"],["木雕师","木雕師"],["木雕泥塑","木雕泥塑"],["木雕节","木雕節"],["未了","未了"],["未了公案","未了公案"],["未了因","未了因"],["未了情","未了情"],["未了缘","未了緣"],["未几","未幾"],["未出","未出"],["未出去","未出去"],["未出来","未出來"],["未出货","未出貨"],["未卜","未卜"],["未卜先知","未卜先知"],["未发货","未發貨"],["未可同日而语","未可同日而語"],["未嫁新娘","未嫁新娘"],["未尝","未嘗"],["未尝不可","未嘗不可"],["未尽","未盡"],["未尽事宜","未盡事宜"],["未干","未乾"],["未开发国家","未開發國家"],["未必尽然","未必盡然"],["未扣","未扣"],["未折现","未折現"],["未易才","未易才"],["未松下","未松下"],["未知万一","未知萬一"],["未确定","未確定"],["未竟之志","未竟之志"],["未签字者","未簽字者"],["未获","未獲"],["未获得","未獲得"],["未降反升","未降反升"],["末了","末了"],["末叶","末葉"],["末后","末後"],["末大必折","末大必折"],["末娘","末娘"],["末末了","末末了"],["末胄","末胄"],["末药","末藥"],["本价","本價"],["本位制","本位制"],["本党","本黨"],["本厂","本廠"],["本古里昂","本古里昂"],["本台","本臺"],["本台消息","本臺消息"],["本同末异","本同末異"],["本周","本週"],["本周一","本週一"],["本周三","本週三"],["本周二","本週二"],["本周五","本週五"],["本周六","本週六"],["本周四","本週四"],["本回","本回"],["本团","本團"],["本地管理界面","本地管理界面"],["本垒板","本壘板"],["本当","本當"],["本征","本徵"],["本征值","本徵值"],["本征向量","本徵向量"],["本志","本志"],["本愿","本願"],["本所同仁","本所同仁"],["本报台","本報臺"],["本期发生","本期發生"],["本期发生额","本期發生額"],["本机振荡","本機振盪"],["本来面目","本來面目"],["本杰明","本傑明"],["本杰明富兰克林","本傑明富蘭克林"],["本科系","本科系"],["本系","本系","本係"],["本色当行","本色當行"],["本草药学","本草藥學"],["本里","本里"],["札什伦布寺","札什倫布寺"],["札夸威","札夸威"],["札板儿","札板兒"],["札格拉布","札格拉布"],["札格瑞布","札格瑞布"],["术业有专攻","術業有專攻"],["术前","術前"],["术后","術後"],["术士","術士"],["术德兼修","術德兼修"],["术数","術數"],["术科","術科"],["术艺","術藝"],["术语","術語"],["术赤","朮赤"],["朱一贵","朱一貴"],["朱丝栏抄本","朱絲欄抄本"],["朱丹","朱丹"],["朱丽亚","朱麗亞"],["朱丽叶","朱麗葉"],["朱书麟","朱書麟"],["朱买臣","朱買臣"],["朱云折槛","朱雲折檻"],["朱云鹏","朱雲鵬"],["朱亥","朱亥"],["朱仑街","朱崙街"],["朱仙镇","朱仙鎮"],["朱俊","朱儁"],["朱俊彰","朱俊彰"],["朱俊晓","朱俊曉"],["朱允炆","朱允炆"],["朱元璋","朱元璋"],["朱元祥","朱元祥"],["朱先","朱先"],["朱光","朱光"],["朱全忠","朱全忠"],["朱兴荣","朱興榮"],["朱凤芝","朱鳳芝"],["朱利亚尼","朱利亞尼"],["朱利娅","朱利婭"],["朱利安","朱利安"],["朱利安尼","朱利安尼"],["朱华","朱華"],["朱印本","朱印本"],["朱卷","硃卷"],["朱口皓齿","朱口皓齒"],["朱古力","朱古力"],["朱古力糖","朱古力糖"],["朱古律糖","朱古律糖"],["朱咏薇","朱詠薇"],["朱哲琴","朱哲琴"],["朱唇","朱脣"],["朱唇皓齿","硃脣皓齒"],["朱培庆","朱培慶"],["朱墨","朱墨"],["朱墨本","朱墨本"],["朱墨烂然","朱墨爛然"],["朱士行","朱士行"],["朱天文","朱天文"],["朱姓","朱姓"],["朱婉琪","朱婉琪"],["朱子","朱子"],["朱子学","朱子學"],["朱子家训","朱子家訓"],["朱子治家格言","朱子治家格言"],["朱子语录","朱子語錄"],["朱子语类","朱子語類"],["朱孝天","朱孝天"],["朱学","朱學"],["朱宏瑜","朱宏瑜"],["朱宗庆","朱宗慶"],["朱实","朱實"],["朱家","朱家"],["朱家兴","朱家興"],["朱家彦","朱家彥"],["朱家欣","朱家欣"],["朱家鼎","朱家鼎"],["朱容基","朱容基"],["朱尉铭","朱尉銘"],["朱尔典","朱爾典"],["朱尔金","朱爾金"],["朱尼奥","朱尼奧"],["朱巴一","朱巴一"],["朱希真","朱希真"],["朱干玉戚","朱干玉鏚"],["朱广沪","朱廣滬"],["朱庆余","朱慶餘"],["朱庇特","朱庇特"],["朱延平","朱延平"],["朱弁","朱弁"],["朱弦","朱弦"],["朱弦玉磬","朱弦玉磬"],["朱德","朱德"],["朱执信","朱執信"],["朱批","硃批"],["朱拉隆功","朱拉隆功"],["朱提","朱提"],["朱敦儒","朱敦儒"],["朱敬一","朱敬一"],["朱文","朱文"],["朱文庆","朱文慶"],["朱明","朱明"],["朱智勳","朱智勳"],["朱朝亮","朱朝亮"],["朱木炎","朱木炎"],["朱朱","朱朱"],["朱权","朱權"],["朱柏庐","朱柏廬"],["朱标","朱標"],["朱棣","朱棣"],["朱槿","朱槿"],["朱比特","朱比特"],["朱永弘","朱永弘"],["朱泽民","朱澤民"],["朱洪武","朱洪武"],["朱淑真","朱淑真"],["朱温","朱溫"],["朱漆","朱漆"],["朱熔基","朱熔基"],["朱熹","朱熹"],["朱理安历","朱理安曆"],["朱理安历史","朱理安歷史"],["朱瑞","朱瑞"],["朱瑞特兹","朱瑞特茲"],["朱瓦碧甍","朱瓦碧甍"],["朱甍碧瓦","朱甍碧瓦"],["朱由校","朱由校"],["朱瞻基","朱瞻基"],["朱砂","硃砂"],["朱砂痣","硃砂痣"],["朱砂符","硃砂符"],["朱砂红","硃砂紅"],["朱祁钰","朱祁鈺"],["朱祁镇","朱祁鎮"],["朱祖谋","朱祖謀"],["朱穆","朱穆"],["朱立伦","朱立倫"],["朱笔","硃筆"],["朱筠","朱筠"],["朱紫","朱紫"],["朱紫难别","朱紫難別"],["朱红","硃紅"],["朱红灯","朱紅燈"],["朱红色","硃紅色"],["朱经武","朱經武"],["朱美","朱美"],["朱耷","朱耷"],["朱脣","朱脣"],["朱脣榴齿","朱脣榴齒"],["朱脣皓齿","朱脣皓齒"],["朱脣粉面","朱脣粉面"],["朱自清","朱自清"],["朱舜水","朱舜水"],["朱色","硃色"],["朱茵","朱茵"],["朱莉娅","朱莉婭"],["朱蒙","朱蒙"],["朱蕉","朱蕉"],["朱衣","朱衣"],["朱衣吏","朱衣吏"],["朱衣点头","朱衣點頭"],["朱衣神","朱衣神"],["朱记","朱記"],["朱诺","朱諾"],["朱谕","硃諭"],["朱贝尔","朱貝爾"],["朱轓皂盖","朱轓皂蓋"],["朱轩","朱軒"],["朱轮","朱輪"],["朱轮华毂","朱輪華轂"],["朱迪亚","朱迪亞"],["朱邸","朱邸"],["朱郁信","朱郁信"],["朱铭","朱銘"],["朱镕基","朱鎔基"],["朱门","朱門"],["朱门绣户","朱門繡戶"],["朱阁","朱閣"],["朱阁青楼","朱閣青樓"],["朱阿英","朱阿英"],["朱陆异同","朱陸異同"],["朱陈","朱陳"],["朱陈之好","朱陳之好"],["朱雀","朱雀"],["朱雀号","朱雀號"],["朱雀桥","朱雀橋"],["朱顶","朱頂"],["朱颜","朱顏"],["朱颜粉面","朱顏粉面"],["朱颜鹤发","朱顏鶴髮"],["朱马亚","朱馬亞"],["朱骏声","朱駿聲"],["朱高炽","朱高熾"],["朱鸟","朱鳥"],["朱鹭","朱鷺"],["朱鹮","朱䴉"],["朱黄","朱黃"],["朴世莉","朴世莉"],["朴京琳","朴京琳"],["朴仔树","朴仔樹"],["朴修斯","樸修斯"],["朴克牌","樸克牌"],["朴凤柱","朴鳳柱"],["朴刀","朴刀"],["朴厚","樸厚"],["朴吉渊","朴吉淵"],["朴周永","朴周永"],["朴子","朴子"],["朴子市","朴子市"],["朴子溪","朴子溪"],["朴学","樸學"],["朴实","樸實"],["朴实作风","樸實作風"],["朴实无华","樸實無華"],["朴宣英","朴宣英"],["朴志胤","朴志胤"],["朴忠","朴忠"],["朴念仁","樸念仁"],["朴恩惠","朴恩惠"],["朴拙","樸拙"],["朴新阳","朴新陽"],["朴智星","朴智星"],["朴树","朴樹"],["朴槿惠","朴槿惠"],["朴樕","樸樕"],["朴次茅斯","樸次茅斯"],["朴正恩","朴正恩"],["朴正熙","朴正熙"],["朴正祥","朴正祥"],["朴永训","朴永訓"],["朴泰桓","朴泰桓"],["朴父","朴父"],["朴璐美","朴璐美"],["朴直","樸直"],["朴真熙","朴真熙"],["朴硝","朴硝"],["朴素","樸素"],["朴素无华","樸素無華"],["朴茂","朴茂"],["朴茨茅斯","朴茨茅斯"],["朴茨茅斯队","朴茨茅斯隊"],["朴讷","樸訥"],["朴讷诚笃","樸訥誠篤"],["朴诗妍","朴詩妍"],["朴质","樸質"],["朴质无华","樸質無華"],["朴资茅斯","朴資茅斯"],["朴资茅斯条约","朴資茅斯條約"],["朴赞浩","朴贊浩"],["朴鄙","樸鄙"],["朴重","樸重"],["朴野","樸野"],["朴野无文","樸野無文"],["朴钝","樸鈍"],["朴陋","樸陋"],["朴马","樸馬"],["朴鲁","樸魯"],["朵云","朵雲"],["机修厂","機修廠"],["机关团体","機關團體"],["机关布景","機關佈景"],["机关用尽","機關用盡"],["机制","機制","機製"],["机发","機發"],["机台","機臺"],["机器压制","機器壓製"],["机壳厂","機殼廠"],["机板","機板"],["机柜","機櫃"],["机械学系","機械學系"],["机械系","機械系"],["机械表","機械錶"],["机械钟","機械鐘"],["机械钟表","機械鐘錶"],["机种","機種"],["机绣","機繡"],["机缘巧合","機緣巧合"],["机辟","機辟"],["朽木不雕","朽木不雕"],["朽木之才","朽木之才"],["朽木虫","朽木蟲"],["朽棘不雕","朽棘不雕"],["杀人须见血救人须救彻","殺人須見血救人須救徹"],["杀价","殺價"],["杀出","殺出"],["杀出去","殺出去"],["杀出来","殺出來"],["杀出重围","殺出重圍"],["杀千刀","殺千刀"],["杀千刀的","殺千刀的"],["杀才","殺才"],["杀敌致果","殺敵致果"],["杀虫","殺蟲"],["杀虫剂","殺蟲劑"],["杀虫器","殺蟲器"],["杀虫药","殺蟲藥"],["杀蠹药","殺蠹藥"],["杀身出生","殺身出生"],["杂交种","雜交種"],["杂交育种","雜交育種"],["杂合菜","雜合菜"],["杂合面儿","雜合麪兒"],["杂和面","雜和麪"],["杂和面儿","雜和麪兒"],["杂婚制","雜婚制"],["杂当","雜當"],["杂录","雜錄"],["杂志","雜誌"],["杂志奖","雜誌獎"],["杂志社","雜誌社"],["杂志纸","雜誌紙"],["杂念","雜念"],["杂技团","雜技團"],["杂技表演","雜技表演"],["杂板令","雜板令"],["杂症","雜症"],["杂种","雜種"],["杂种人","雜種人"],["杂种优势","雜種優勢"],["杂种后代","雜種後代"],["杂种狗","雜種狗"],["杂谷脑","雜谷腦"],["杂谷脑镇","雜谷腦鎮"],["杂酱面","雜醬麪"],["杂面","雜麪"],["权利请愿书","權利請願書"],["权制","權制"],["权力斗争","權力鬥爭"],["权力欲","權力慾"],["权变锋出","權變鋒出"],["权幸","權幸"],["权术","權術"],["权欲熏心","權慾薰心"],["权能划分","權能劃分"],["杆上","杆上"],["杆儿","杆兒","桿兒"],["杆刀","桿刀"],["杆塔","杆塔"],["杆子","杆子","桿子"],["杆状","桿狀"],["杆直","桿直"],["杆秤","桿秤"],["杆茵","桿茵"],["杆菌","桿菌"],["杆菌性","桿菌性"],["杆菌类","桿菌類"],["杆菌素","桿菌素"],["杈杆儿","杈桿兒"],["李万进","李萬進"],["李三娘","李三娘"],["李丰永","李豐永"],["李云光","李雲光"],["李云娜","李雲娜"],["李代桃僵","李代桃僵"],["李修贤","李修賢"],["李克强","李克強"],["李克昂","李克昂"],["李克齐","李克齊"],["李公朴","李公樸"],["李准基","李準基"],["李千娜","李千娜"],["李卜克內西","李卜克內西"],["李卜克内西","李卜克內西"],["李叔同","李叔同"],["李后主","李後主"],["李咸阳","李咸陽"],["李国修","李國修"],["李圣杰","李聖傑"],["李复兴","李復興"],["李复甸","李復甸"],["李大同","李大同"],["李安修","李安修"],["李家同","李家同"],["李布瑞斯库","李布瑞斯庫"],["李干龙","李乾龍"],["李开复","李開復"],["李志勳","李志勳"],["李志宏","李志宏"],["李志强","李志強"],["李念","李念"],["李斯特氏杆菌","李斯特氏桿菌"],["李杰","李傑"],["李洪志","李洪志"],["李炳千","李炳千"],["李百药","李百藥"],["李盟干","李盟乾"],["李秋静","李秋靜"],["李胜琛","李勝琛"],["李连杰","李連杰"],["李連杰","李連杰"],["李郭同舟","李郭同舟"],["李鉴原","李鑑原"],["李钟奭","李鐘奭"],["李钟郁","李鍾郁"],["李链福","李鍊福"],["李锺郁","李鍾郁"],["杏坛","杏壇"],["杏干儿","杏乾兒"],["杏核","杏核"],["杏雨梨云","杏雨梨雲"],["材干","材幹"],["材料系","材料系"],["材疏志大","材疏志大"],["材种","材種"],["材积表","材積表"],["村子里","村子裏"],["村干事","村幹事"],["村庄","村莊"],["村胄","村胄"],["村舍","村舍"],["村里","村裏"],["村里长","村裏長"],["杜丽娘","杜麗娘"],["杜克","杜克"],["杜寅杰","杜寅傑"],["杜尔伯特蒙古族自治县","杜爾伯特蒙古族自治縣"],["杜尚别","杜尚別"],["杜尼克","杜尼克"],["杜布林斯基","杜布林斯基"],["杜布罗夫尼克","杜布羅夫尼克"],["杜斯特布拉吉","杜斯特布拉吉"],["杜杰利","杜傑利"],["杜杰尔","杜傑爾"],["杜松子酒","杜松子酒"],["杜正胜","杜正勝"],["杜秋娘","杜秋娘"],["杜秋娘歌","杜秋娘歌"],["杜绝后患","杜絕後患"],["杜老志道","杜老誌道"],["杜门不出","杜門不出"],["杜雅里克","杜雅里克"],["杞宋无征","杞宋無徵"],["杞梁","杞梁"],["杞梁妻","杞梁妻"],["束修","束脩"],["束发","束髮"],["束发封帛","束髮封帛"],["束发金冠","束髮金冠"],["束矢难折","束矢難折"],["束身修行","束身修行"],["束身自修","束身自修"],["杠上","槓上"],["杠头","槓頭"],["杠子","槓子"],["杠杆","槓桿"],["杠杆收购","槓桿收購"],["杠杠","槓槓"],["杠牌","槓牌"],["杠着","槓着"],["杠起","槓起"],["杠铃","槓鈴"],["杠龟","槓龜"],["条几","條几"],["条干","條幹"],["条据","條據"],["条板箱","條板箱"],["条纹布","條紋布"],["来个","來個"],["来了","來了"],["来于","來於"],["来千去万","來千去萬"],["来历","來歷"],["来历不明","來歷不明"],["来发","來發"],["来台","來臺"],["来台访问","來臺訪問"],["来叶","來葉"],["来回","來回"],["来回来去","來回來去"],["来回来去地","來回來去地"],["来回的话","來回的話"],["来回票","來回票"],["来复","來複"],["来复日","來復日"],["来复枪","來複槍"],["来复线","來複線"],["来宾致词","來賓致詞"],["来念","來念"],["来来回回","來來回回"],["来杯","來杯"],["来自于","來自於"],["来苏","來蘇"],["来苏水","來蘇水"],["来苏糖","來蘇糖"],["杨万发","楊萬發"],["杨万里","楊萬里"],["杨云龙","楊雲龍"],["杨俊胜","楊俊勝"],["杨修","楊修"],["杨凌示范区","楊淩示範區"],["杨千霈","楊千霈"],["杨叶窜儿","楊葉竄兒"],["杨士梁","楊士樑"],["杨宏志","楊宏志"],["杨志卖刀","楊志賣刀"],["杨文志","楊文誌"],["杨日松","楊日松"],["杨朱","楊朱"],["杨松","楊松"],["杨松弦","楊松弦"],["杨氏系数","楊氏係數"],["杨秋兴","楊秋興"],["杨胜帆","楊勝帆"],["杨胜旭","楊勝旭"],["杨致远","楊致遠"],["杨苏棣","楊甦棣"],["杨采妮","楊採妮"],["杨雅筑","楊雅筑"],["杪秋","杪秋"],["杭丁顿舞蹈症","杭丁頓舞蹈症"],["杭州师范学院","杭州師範學院"],["杭州萝卜绍兴种","杭州蘿蔔紹興種"],["杭锦后旗","杭錦後旗"],["杯上","杯上"],["杯中","杯中"],["杯中之物","杯中之物"],["杯中物","杯中物"],["杯了","杯了"],["杯具","杯具"],["杯内","杯內"],["杯前","杯前"],["杯口","杯口"],["杯台","杯臺"],["杯后","杯後"],["杯和","杯和"],["杯垫","杯墊"],["杯壁","杯壁"],["杯套","杯套"],["杯子","杯子"],["杯布","杯佈"],["杯干","杯乾"],["杯底","杯底"],["杯底不可饲金鱼","杯底不可飼金魚"],["杯座","杯座"],["杯弓蛇影","杯弓蛇影"],["杯换","杯換"],["杯是","杯是"],["杯杯","杯杯"],["杯水","杯水"],["杯水之谢","杯水之謝"],["杯水粒粟","杯水粒粟"],["杯水车薪","杯水車薪"],["杯沿","杯沿"],["杯状","杯狀"],["杯白干","杯白乾"],["杯的","杯的"],["杯盏","杯盞"],["杯盖","杯蓋"],["杯盘","杯盤"],["杯盘狼藉","杯盤狼藉"],["杯盘舞","杯盤舞"],["杯碟","杯碟"],["杯突","杯突"],["杯羹","杯羹"],["杯茶","杯茶"],["杯葛","杯葛"],["杯葛运动","杯葛運動"],["杯蛇鬼车","杯蛇鬼車"],["杯装","杯裝"],["杯觥交错","杯觥交錯"],["杯赛","盃賽"],["杯身","杯身"],["杯酒","杯酒"],["杯酒戈矛","杯酒戈矛"],["杯酒解怨","杯酒解怨"],["杯酒言欢","杯酒言歡"],["杯酒释兵权","杯酒釋兵權"],["杯里","杯裏"],["杯面","杯麪"],["杰乐米","傑樂米"],["杰伊汉港","傑伊漢港"],["杰伦","杰倫"],["杰佛兹","傑佛茲"],["杰佛利","傑佛利"],["杰佛士","傑佛士"],["杰佛森","傑佛森"],["杰佛瑞","傑佛瑞"],["杰佛逊","傑佛遜"],["杰作","傑作"],["杰克","傑克"],["杰克伦敦","傑克倫敦"],["杰克尼克逊","傑克尼克遜"],["杰克德米","傑克德米"],["杰克森","傑克森"],["杰克盖伦海","傑克蓋倫海"],["杰克葛伦霍","傑克葛倫霍"],["杰克逊","傑克遜"],["杰出","傑出"],["杰利","傑利"],["杰卡伯","傑卡伯"],["杰哈德巴特勒","傑哈德巴特勒"],["杰哈德巴狄厄","傑哈德巴狄厄"],["杰士派","傑士派"],["杰夫","傑夫"],["杰奎琳","傑奎琳"],["杰奎琳肯尼迪","傑奎琳肯尼迪"],["杰尔","傑爾"],["杰尔村","傑爾村"],["杰尼斯","傑尼斯"],["杰弗逊","傑弗遜"],["杰弗里乔叟","傑弗里喬叟"],["杰拉","傑拉"],["杰拉尔德","傑拉爾德"],["杰拉德","傑拉德"],["杰斯","傑斯"],["杰杰","傑傑"],["杰森","傑森"],["杰森包恩","傑森包恩"],["杰森史塔森","傑森史塔森"],["杰特","杰特"],["杰瑞","傑瑞"],["杰福斯","傑福斯"],["杰福瑞","傑福瑞"],["杰米","傑米"],["杰米森","傑米森"],["杰米福克斯","傑米福克斯"],["杰西","傑西"],["杰西卡","傑西卡"],["杰西卡艾尔芭","傑西卡艾爾芭"],["杰西詹姆斯","傑西詹姆斯"],["杰迪卓","傑迪卓"],["杰里森","傑里森"],["杰里科","傑里科"],["杰里米","傑里米"],["杳无人烟","杳無人煙"],["松一下","鬆一下"],["松一些","鬆一些"],["松一口气","鬆一口氣"],["松一松","鬆一鬆"],["松下","松下"],["松下一口","鬆下一口"],["松下了","鬆下了"],["松下公司","松下公司"],["松下来","鬆下來"],["松下电器","松下電器"],["松下电机","松下電機"],["松下电气工业","松下電氣工業"],["松不开","鬆不開"],["松不松","鬆不鬆"],["松不紧","鬆不緊"],["松丘","松丘"],["松乔","松喬"],["松乔之寿","松喬之壽"],["松了","鬆了"],["松了一口气","鬆了一口氣"],["松了松","鬆了鬆"],["松井秀","松井秀"],["松井秀喜","松井秀喜"],["松些","鬆些"],["松仁","松仁"],["松元音","鬆元音"],["松冈","松岡"],["松冈利胜","松岡利勝"],["松出一","鬆出一"],["松出口","鬆出口"],["松动","鬆動"],["松劲","鬆勁"],["松化石","松化石"],["松北","松北"],["松北区","松北區"],["松原","松原"],["松原市","松原市"],["松口","鬆口"],["松口气","鬆口氣"],["松口蘑","松口蘑"],["松叶","松葉"],["松叶牡丹","松葉牡丹"],["松叶蕨","松葉蕨"],["松喉","鬆喉"],["松土","鬆土"],["松土机","鬆土機"],["松垮","鬆垮"],["松大辅","松大輔"],["松子","松子"],["松宽","鬆寬"],["松尾芭蕉","松尾芭蕉"],["松山","松山"],["松山区","松山區"],["松山庄","松山莊"],["松山机场","松山機場"],["松岭","松嶺"],["松岭区","松嶺區"],["松巴哇","松巴哇"],["松巴哇岛","松巴哇島"],["松开","鬆開"],["松弛","鬆弛"],["松弛下来","鬆弛下來"],["松弛到","鬆弛到"],["松弛剂","鬆弛劑"],["松弛法","鬆弛法"],["松得多","鬆得多"],["松快","鬆快"],["松懈","鬆懈"],["松懈下","鬆懈下"],["松懈下来","鬆懈下來"],["松手","鬆手"],["松扣","鬆釦"],["松指部","松指部"],["松掉","鬆掉"],["松放","鬆放"],["松散","鬆散"],["松散物料","鬆散物料"],["松明","松明"],["松智路","松智路"],["松木","松木"],["松本","松本"],["松本仞","松本仞"],["松本润","松本潤"],["松本秀树","松本秀樹"],["松材线虫","松材線蟲"],["松松","鬆鬆"],["松松垮垮","鬆鬆垮垮"],["松松散散","鬆鬆散散"],["松松脆脆","鬆鬆脆脆"],["松松软软","鬆鬆軟軟"],["松林","松林"],["松果","松果"],["松果体","松果體"],["松果腺","松果腺"],["松枝","松枝"],["松柏","松柏"],["松柏之坚","松柏之堅"],["松柏之寿","松柏之壽"],["松柏之茂","松柏之茂"],["松柏后凋","松柏後凋"],["松柏园","松柏園"],["松柏节操","松柏節操"],["松柏长青","松柏長青"],["松柏长青茶","松柏長青茶"],["松柔","鬆柔"],["松树","松樹"],["松桃县","松桃縣"],["松桃苗族自治县","松桃苗族自治縣"],["松毛","松毛"],["松毛松翼","鬆毛鬆翼"],["松毛虫","松毛蟲"],["松毬","松毬"],["松气","鬆氣"],["松江","松江"],["松江区","松江區"],["松江省","松江省"],["松江路","松江路"],["松油","松油"],["松油管","鬆油管"],["松油门","鬆油門"],["松浦","松浦"],["松浦亚","松浦亞"],["松浮","鬆浮"],["松涛","松濤"],["松溪","松溪"],["松溪县","松溪縣"],["松滋","鬆滋"],["松滋市","鬆滋市"],["松漠","松漠"],["松潘","松潘"],["松潘县","松潘縣"],["松烟","松煙"],["松烟墨","松煙墨"],["松焦油","松焦油"],["松煤","松煤"],["松狮犬","松獅犬"],["松球","松球"],["松球鱼","松球魚"],["松瓤","松瓤"],["松田","松田"],["松田圣子","松田聖子"],["松皮癣","松皮癬"],["松石","松石"],["松科","松科"],["松竹","松竹"],["松竹梅","松竹梅"],["松竹路","松竹路"],["松筠之操","松筠之操"],["松筠之节","松筠之節"],["松篁交翠","松篁交翠"],["松类","松類"],["松糕","鬆糕"],["松紧","鬆緊"],["松紧带","鬆緊帶"],["松纹","松紋"],["松绑","鬆綁"],["松缓","鬆緩"],["松胶","松膠"],["松脂","松脂"],["松脂石","松脂石"],["松脆","鬆脆"],["松脆饼","鬆脆餅"],["松脱","鬆脫"],["松节油","松節油"],["松节油精","松節油精"],["松花","松花"],["松花江","松花江"],["松花江平原","松花江平原"],["松花砚","松花硯"],["松花纸","松花紙"],["松花蛋","松花蛋"],["松花饼","松花餅"],["松茸","松茸"],["松菌","松菌"],["松萝","松蘿"],["松萝共倚","松蘿共倚"],["松蕈","松蕈"],["松蕊","松蕊"],["松藻虫","松藻蟲"],["松蘑","松蘑"],["松蛋","鬆蛋"],["松蛋包","鬆蛋包"],["松解","鬆解"],["松赞干布","松贊干布"],["松赞干布陵","松贊干布陵"],["松起","鬆起"],["松起来","鬆起來"],["松软","鬆軟"],["松软适口","鬆軟適口"],["松辽平原","松遼平原"],["松通","鬆通"],["松针","松針"],["松阳","松陽"],["松阳县","松陽縣"],["松隆子","松隆子"],["松雪泰子","松雪泰子"],["松露","松露"],["松露猪","松露豬"],["松青","松青"],["松风","松風"],["松风水月","松風水月"],["松风流","松風流"],["松饼","鬆餅"],["松香","松香"],["松香水","松香水"],["松香油","松香油"],["松高路","松高路"],["松鱼","松魚"],["松鸡","松雞"],["松鸦","松鴉"],["松鹤","松鶴"],["松鹤延年","松鶴延年"],["松鹤遐龄","松鶴遐齡"],["松鼠","松鼠"],["松鼠猴","松鼠猴"],["板上钉钉","板上釘釘"],["板书","板書"],["板儿","板兒"],["板凳","板凳"],["板凳区","板凳區"],["板刷","板刷"],["板块","板塊"],["板块构造","板塊構造"],["板块理论","板塊理論"],["板壁","板壁"],["板子","板子"],["板岩","板岩"],["板式","板式"],["板式塔","板式塔"],["板房","板房"],["板擦","板擦"],["板擦儿","板擦兒"],["板斧","板斧"],["板本","板本"],["板机","板機"],["板材","板材"],["板条","板條"],["板条箱","板條箱"],["板板","闆闆"],["板板六十四","板板六十四"],["板极","板極"],["板栗","板栗"],["板桥","板橋"],["板桥中学","板橋中學"],["板桥国中","板橋國中"],["板桥国小","板橋國小"],["板桥市","板橋市"],["板桩","板樁"],["板梁桥","板梁橋"],["板油","板油"],["板滞","板滯"],["板烟","板煙"],["板牙","板牙"],["板状","板狀"],["板球","板球"],["板画","板畫"],["板皮","板皮"],["板眼","板眼"],["板着脸","板着臉"],["板纸","板紙"],["板结","板結"],["板羽球","板羽球"],["板胡","板胡"],["板脸","板臉"],["板荡","板蕩"],["板蓝根","板藍根"],["板规","板規"],["板起","板起"],["板起面孔","板起面孔"],["板车","板車"],["板金","板金"],["板金工","板金工"],["板门店","板門店"],["板门店停战村","板門店停戰村"],["板鸭","板鴨"],["板鼓","板鼓"],["极不","極不"],["极为庞大","極爲龐大"],["极乐","極樂"],["极乐世界","極樂世界"],["极乐舞","極樂舞"],["极乐鸟","極樂鳥"],["极了","極了"],["极低","極低"],["极低频辐射","極低頻輻射"],["极佳","極佳"],["极便当","極便當"],["极值","極值"],["极光","極光"],["极其","極其"],["极具","極具"],["极冠","極冠"],["极切瞻韩","極切瞻韓"],["极刑","極刑"],["极力","極力"],["极力争取","極力爭取"],["极化","極化"],["极口","極口"],["极右","極右"],["极右份子","極右份子"],["极右派","極右派"],["极右翼","極右翼"],["极品","極品"],["极圈","極圈"],["极地","極地"],["极地年","極地年"],["极地气候","極地氣候"],["极地狐","極地狐"],["极坐标","極座標"],["极坐标系","極座標系"],["极处","極處"],["极大","極大"],["极大值","極大值"],["极大期","極大期"],["极头麻化","極頭麻化"],["极好","極好"],["极婺联辉","極婺聯輝"],["极富","極富"],["极小","極小"],["极小值","極小值"],["极少","極少"],["极少数","極少數"],["极尽","極盡"],["极左","極左"],["极左份子","極左份子"],["极左派","極左派"],["极带","極帶"],["极带地区","極帶地區"],["极度","極度"],["极微","極微"],["极性","極性"],["极性键","極性鍵"],["极恶","極惡"],["极愿","極願"],["极早","極早"],["极有可能","極有可能"],["极权","極權"],["极权主义","極權主義"],["极权国家","極權國家"],["极权政治","極權政治"],["极板","極板"],["极核","極核"],["极深研几","極深研幾"],["极点","極點"],["极爲","極爲"],["极盛","極盛"],["极盛时期","極盛時期"],["极目","極目"],["极目望去","極目望去"],["极目远望","極目遠望"],["极目远眺","極目遠眺"],["极短篇","極短篇"],["极移","極移"],["极端","極端"],["极端主义","極端主義"],["极端份子","極端份子"],["极端派","極端派"],["极细小","極細小"],["极至","極至"],["极致","極致"],["极色","極色"],["极表同情","極表同情"],["极轴","極軸"],["极选","極選"],["极量","極量"],["极锋","極鋒"],["极间电容","極間電容"],["极限","極限"],["极限体育","極限體育"],["极限值","極限值"],["极限强度","極限強度"],["极高","極高"],["极高点","極高點"],["构筑","構築"],["构筑工事","構築工事"],["构筑物","構築物"],["析出","析出"],["析毫剖厘","析毫剖釐"],["枕借","枕藉"],["枕岩漱流","枕巖漱流"],["枕席","枕蓆"],["枕戈尝胆","枕戈嘗膽"],["枕状玄武岩","枕狀玄武岩"],["林下风致","林下風致"],["林下风范","林下風範"],["林丰正","林豐正"],["林义杰","林義傑"],["林云","林雲"],["林云阁","林雲閣"],["林俊杰","林俊杰"],["林克","林克"],["林克平大学","林克平大學"],["林克海德","林克海德"],["林克谟","林克謨"],["林克谦","林克謙"],["林冲","林沖"],["林冲夜奔","林沖夜奔"],["林占梅","林占梅"],["林口台地","林口臺地"],["林合隆","林合隆"],["林周","林周"],["林周县","林周縣"],["林国梁","林國樑"],["林宏岳","林宏嶽"],["林布兰","林布蘭"],["林干闵","林乾閔"],["林德布拉德","林德布拉德"],["林志嘉","林志嘉"],["林志坚","林志堅"],["林志声","林志聲"],["林志杰","林志傑"],["林志炫","林志炫"],["林志玲","林志玲"],["林志翔","林志翔"],["林志辉","林志輝"],["林志隆","林志隆"],["林志雄","林志雄"],["林志颖","林志穎"],["林恢复","林恢復"],["林承志","林承志"],["林振丰","林振豐"],["林敬杰","林敬傑"],["林智胜","林智勝"],["林木参天","林木參天"],["林杰梁","林杰樑"],["林杰闵","林傑閔"],["林松","林松"],["林松焕","林松煥"],["林正杰","林正杰"],["林永发","林永發"],["林秀合","林秀合"],["林秋","林秋"],["林秋桂","林秋桂"],["林群志","林羣志"],["林致光","林致光"],["林芳郁","林芳郁"],["林英杰","林英傑"],["林荣松","林榮松"],["林表","林表"],["林谷桦","林谷樺"],["林谷芳","林谷芳"],["林郁方","林郁方"],["林钟","林鐘"],["林靖杰","林靖傑"],["林颖穗","林穎穗"],["林默娘","林默娘"],["枚卜","枚卜"],["果于","果於"],["果子干","果子乾"],["果子干儿","果子乾兒"],["果子药","果子藥"],["果干","果乾"],["果杯","果杯"],["果核","果核"],["果穗","果穗"],["枝不得大于干","枝不得大於榦"],["枝叶","枝葉"],["枝叶扶疏","枝葉扶疏"],["枝叶茂盛","枝葉茂盛"],["枝干","枝幹"],["枝干断折","枝幹斷折"],["枝繁叶茂","枝繁葉茂"],["枝胄","枝胄"],["枝针","枝針"],["枣庄","棗莊"],["枣核","棗核"],["枪打出头鸟","槍打出頭鳥"],["枪托","槍托"],["枪术","槍術"],["枪杆","槍桿"],["枪杆儿","槍桿兒"],["枪杆子","槍桿子"],["枪枝弹药","槍枝彈藥"],["枪械弹药","槍械彈藥"],["枫之谷","楓之谷"],["枫叶","楓葉"],["枯叶","枯葉"],["枯叶蝶","枯葉蝶"],["枯干","枯乾"],["枯草杆菌","枯草桿菌"],["架个","架個"],["架了","架了"],["架出","架出"],["架出去","架出去"],["架出来","架出來"],["架回","架回"],["架回去","架回去"],["架回来","架回來"],["架梁","架樑"],["架海金梁","架海金梁"],["架钟","架鐘"],["枷板","枷板"],["柏克","柏克"],["柏克曼温度计","柏克曼溫度計"],["柏克莱","柏克萊"],["柏克郡","柏克郡"],["柏克里克千佛洞","柏克里克千佛洞"],["柏南克","柏南克"],["柏卡里","柏卡里"],["柏台","柏臺"],["柏台乌府","柏臺烏府"],["柏戴克","柏戴克"],["柏林剧团","柏林劇團"],["柏梁体","柏梁體"],["柏梁台","柏梁臺"],["柏梁诗","柏梁詩"],["柏纳马修兹","柏納馬修茲"],["柏罗米修斯","柏羅米修斯"],["柏节松操","柏節松操"],["柏里斯","柏里斯"],["某个","某個"],["某个人","某個人"],["某只","某隻"],["某方面","某方面"],["某种","某種"],["某种人","某種人"],["某舍","某舍"],["某面","某面"],["染发","染髮"],["染发剂","染髮劑"],["染布","染布"],["染干","染干"],["染指于","染指於"],["染指于鼎","染指於鼎"],["染殿后","染殿後"],["染织厂","染織廠"],["柔克","柔克"],["柔情万千","柔情萬千"],["柔情万种","柔情萬種"],["柔术","柔術"],["柔枝嫩叶","柔枝嫩葉"],["柔能克刚","柔能克剛"],["柔能制刚","柔能制剛"],["柜上","櫃上"],["柜买中心","櫃買中心"],["柜位","櫃位"],["柜台","櫃檯"],["柜台委讬","櫃檯委託"],["柜员机","櫃員機"],["柜坊赌局","櫃坊賭局"],["柜子","櫃子"],["柜房","櫃房"],["柜柳","柜柳"],["柜橱","櫃櫥"],["柜身子","櫃身子"],["柜里","櫃裏"],["柜面儿","櫃面兒"],["查克拉","查克拉"],["查克瑞","查克瑞"],["查准率","查準率"],["查出","查出"],["查扣","查扣"],["查核","查覈"],["查获","查獲"],["柬埔寨人民党","柬埔寨人民黨"],["柯克","柯克"],["柯克斯","柯克斯"],["柯尔克孜","柯爾克孜"],["柯尔克孜族","柯爾克孜族"],["柯尔克孜语","柯爾克孜語"],["柯普里亚诺夫","柯普里亞諾夫"],["柯札克","柯札克"],["柯里","柯里"],["柱梁","柱樑"],["柳升耀","柳昇耀"],["柳叶","柳葉"],["柳叶儿","柳葉兒"],["柳叶刀","柳葉刀"],["柳叶描","柳葉描"],["柳叶眉","柳葉眉"],["柳叶鱼","柳葉魚"],["柳斌杰","柳斌杰"],["柳暗花明","柳暗花明"],["柳暗花明又一村","柳暗花明又一村"],["柳烟花雾","柳煙花霧"],["柳诒征","柳詒徵"],["柴埼幸","柴埼幸"],["柴油发动机","柴油發動機"],["柴胡","柴胡"],["査不出","查不出"],["査价","查價"],["査修","查修"],["査克拉","查克拉"],["査兑克","查兌克"],["査出","查出"],["査出来","查出來"],["査卷","查卷"],["査号台","查號臺"],["査回","查回"],["査回去","查回去"],["査回来","查回來"],["査找周期","查找周期"],["査报表","查報表"],["査无实据","查無實據"],["査获","查獲"],["査表","查表"],["査询台","查詢檯"],["査问出","查問出"],["栅极","柵極"],["标价","標價"],["标准","標準"],["标准值","標準值"],["标准偏差","標準偏差"],["标准像","標準像"],["标准元音","標準元音"],["标准公顷","標準公頃"],["标准制","標準制"],["标准动作","標準動作"],["标准化","標準化"],["标准单位","標準單位"],["标准号码","標準號碼"],["标准型","標準型"],["标准大气","標準大氣"],["标准字体","標準字體"],["标准尺寸","標準尺寸"],["标准局","標準局"],["标准工资","標準工資"],["标准差","標準差"],["标准接口","標準接口"],["标准时","標準時"],["标准时区","標準時區"],["标准时间","標準時間"],["标准普尔","標準普爾"],["标准木","標準木"],["标准杆","標準桿"],["标准模型","標準模型"],["标准气压","標準氣壓"],["标准溶液","標準溶液"],["标准版","標準版"],["标准状况","標準狀況"],["标准状态","標準狀態"],["标准电阻","標準電阻"],["标准组","標準組"],["标准组织","標準組織"],["标准细分表","標準細分表"],["标准舞","標準舞"],["标准规","標準規"],["标准规格","標準規格"],["标准规范","標準規範"],["标准语","標準語"],["标准镜头","標準鏡頭"],["标准间","標準間"],["标准音","標準音"],["标准题名","標準題名"],["标出","標出"],["标出去","標出去"],["标出来","標出來"],["标占","標占"],["标同伐异","標同伐異"],["标志","標誌"],["标志性","標誌性"],["标志着","標誌着"],["标本同治","標本同治"],["标本虫","標本蟲"],["标杆","標杆"],["标标致致","標標致致"],["标注","標註"],["标示出","標示出"],["标签","標籤"],["标致","標緻"],["标表","標表"],["标记识别","標記識別"],["栈板","棧板"],["栉发工","櫛髮工"],["栋折榱崩","棟折榱崩"],["栋梁","棟樑"],["栋梁之任","棟樑之任"],["栋梁之材","棟樑之材"],["栋梁之臣","棟樑之臣"],["栏干","欄干"],["栏杆","欄杆"],["栏板","欄板"],["栏柜","欄櫃"],["树党","樹黨"],["树叶","樹葉"],["树干","樹幹"],["树干断","樹幹斷"],["树德技术学院","樹德技術學院"],["树梁","樹樑"],["树欲息而风不停","樹欲息而風不停"],["树欲静而风不止","樹欲靜而風不止"],["树种","樹種"],["树虫子","樹蟲子"],["树高千丈落叶归根","樹高千丈落葉歸根"],["栖于","棲於"],["栖栖皇皇","棲棲皇皇"],["栗冽","慄冽"],["栗凿","栗鑿"],["栗喇","栗喇"],["栗子","栗子"],["栗尾","栗尾"],["栗暴","栗暴"],["栗栗","慄慄"],["栗栗不安","慄慄不安"],["栗栗危惧","慄慄危懼"],["栗烈","栗烈"],["栗然","慄然"],["栗爆","栗爆"],["栗田雄介","栗田雄介"],["栗碌","栗碌"],["栗色","栗色"],["栗苞","栗苞"],["栗薪","栗薪"],["栗鼠","栗鼠"],["校准","校準"],["校园骨干","校園骨幹"],["校核","校覈"],["校舍","校舍"],["样板","樣板"],["样板戏","樣板戲"],["样范","樣範"],["核下","核下"],["核二厂","核二廠"],["核人","核人"],["核仁","核仁"],["核以","核以"],["核价","覈價"],["核体","核體"],["核保","覈保"],["核僵持","核僵持"],["核儿","核兒"],["核冬天","核冬天"],["核准","覈准"],["核准的","覈准的"],["核减","覈減"],["核出口控制","核出口控制"],["核力","核力"],["核办","核辦"],["核化","核化"],["核区","核區"],["核发","核發"],["核发电","核發電"],["核发电厂","核發電廠"],["核可","核可"],["核合成","核合成"],["核和","核和"],["核四","核四"],["核型","核型"],["核复","覈覆"],["核子","核子"],["核子厂","核子廠"],["核孔","核孔"],["核字","覈字"],["核定","覈定"],["核实","覈實"],["核审","覈審"],["核对","覈對"],["核对表","覈對表"],["核岛","核島"],["核工","核工"],["核弹","核彈"],["核当量","核當量"],["核心","核心"],["核战","核戰"],["核战斗部","核戰斗部"],["核批","覈批"],["核技术","核技術"],["核报","覈報"],["核拨","覈撥"],["核收","覈收"],["核数","核數"],["核是","核是"],["核有","核有"],["核果","核果"],["核查","覈查"],["核查制度","核查制度"],["核桃","核桃"],["核武","核武"],["核火箭发动机","核火箭發動機"],["核炫","核炫"],["核点","核點"],["核燃料后处理","核燃料後處理"],["核爆","核爆"],["核爆炸烟云","核爆炸煙雲"],["核状","核狀"],["核球","核球"],["核甘","核甘"],["核电","核電"],["核电厂","核電廠"],["核电磁脉冲","核電磁脈衝"],["核的","核的"],["核磁","核磁"],["核示","覈示"],["核种","核種"],["核突","核突"],["核算","覈算"],["核粒","核粒"],["核糖","核糖"],["核糖核酸","核糖核酸"],["核素","核素"],["核线","核線"],["核编","覈編"],["核能","核能"],["核能发电","核能發電"],["核能发电厂","核能發電廠"],["核能技术","核能技術"],["核能电厂","核能電廠"],["核膜","核膜"],["核苷","核苷"],["核菌","核菌"],["核融合","核融合"],["核融合发电","核融合發電"],["核解","核解"],["核计","覈計"],["核计划","核計劃"],["核试","核試"],["核谈","核談"],["核质","核質"],["核资","覈資"],["核载","核載"],["核配","核配"],["核酪","核酪"],["核酶","核酶"],["核酸","核酸"],["核销","覈銷"],["核防御","核防禦"],["核验","覈驗"],["根壮叶茂","根壯葉茂"],["根据","根據"],["根据上表","根據上表"],["根据地","根據地"],["根据规定","根據規定"],["根深叶茂","根深葉茂"],["根烟","根菸"],["根目录","根目錄"],["根系","根系"],["根茎叶","根莖葉"],["根须","根鬚"],["格丹斯克","格丹斯克"],["格于","格於"],["格于成例","格於成例"],["格于环境","格於環境"],["格但斯克","格但斯克"],["格兰杰","格蘭傑"],["格列佛游记","格列佛遊記"],["格列高利历","格列高利曆"],["格别乌","格別烏"],["格勒诺布尔","格勒諾布爾"],["格子布","格子布"],["格子棉布","格子棉布"],["格拉哥里字母","格拉哥里字母"],["格斗","格鬥"],["格斗王","格鬥王"],["格斗者","格鬥者"],["格斗赛","格鬥賽"],["格林威治天文台","格林威治天文臺"],["格林威治标准时间","格林威治標準時間"],["格林尼治标准时间","格林尼治標準時間"],["格物致知","格物致知"],["格瑞诺布","格瑞諾布"],["格致","格致"],["格致中学","格致中學"],["格致国中","格致國中"],["格致诚正修齐","格致誠正修齊"],["格范","格範"],["格里","格里"],["格里历","格里曆"],["格里姆斯塔","格里姆斯塔"],["格里高利","格里高利"],["格里高利历","格里高利曆"],["栽种","栽種"],["栽种机","栽種機"],["栽种法","栽種法"],["栽觔斗","栽觔斗"],["栽跟斗","栽跟斗"],["桂仔云","桂仔云"],["桂圆干","桂圓乾"],["桂林团","桂林團"],["桂秋","桂秋"],["桂系军阀","桂系軍閥"],["桃叶歌","桃葉歌"],["桃叶渡","桃葉渡"],["桃叶珊瑚","桃葉珊瑚"],["桃园中坜台地","桃園中壢臺地"],["桃核","桃核"],["桃核雕","桃核雕"],["桃花人面","桃花人面"],["桃花面","桃花面"],["桃金娘","桃金娘"],["桃金娘科","桃金娘科"],["桅杆","桅杆"],["框出","框出"],["框出来","框出來"],["案准","案准"],["案几","案几"],["案卷","案卷"],["案发","案發"],["案发前","案發前"],["案发后","案發後"],["案发时","案發時"],["案头柜","案頭櫃"],["案据","案據"],["案板","案板"],["桉叶油","桉葉油"],["桌几","桌几"],["桌别林","桌別林"],["桌历","桌曆"],["桌布","桌布"],["桌椅板凳","桌椅板凳"],["桌面","桌面"],["桌面上","桌面上"],["桌面儿","桌面兒"],["桌面儿上","桌面兒上"],["桌面系统","桌面系統"],["桐叶知秋","桐葉知秋"],["桐花烟","桐花煙"],["桑叶","桑葉"],["桑定党","桑定黨"],["桑布森","桑布森"],["桑干","桑乾"],["桑干河","桑乾河"],["桑干盆地","桑乾盆地"],["桑托斯","桑托斯"],["桑托荣","桑托榮"],["桑托里尼岛","桑托里尼島"],["桑杰士","桑傑士"],["桑蓬之志","桑蓬之志"],["桑虫","桑蟲"],["桑针","桑針"],["桓台","桓臺"],["桓台县","桓臺縣"],["桓表","桓表"],["桢干","楨幹"],["档卷","檔卷"],["档案传输系统","檔案傳輸系統"],["档案搜寻系统","檔案搜尋系統"],["档案柜","檔案櫃"],["桥台","橋臺"],["桥梁","橋樑"],["桥梁工事","橋樑工事"],["桥梁工程","橋樑工程"],["桥面","橋面"],["桥面上","橋面上"],["桶里","桶裏"],["桶里射鱼","桶裏射魚"],["梁上","樑上"],["梁上君子","樑上君子"],["梁世煌","梁世煌"],["梁丽","梁麗"],["梁书","梁書"],["梁仙台","梁仙臺"],["梁任公","梁任公"],["梁伟聪","梁偉聰"],["梁伟铭","梁偉銘"],["梁修身","梁修身"],["梁元帝","梁元帝"],["梁又琳","梁又琳"],["梁启超","梁啓超"],["梁咏琪","梁詠琪"],["梁唐晋汉周书","梁唐晉漢周書"],["梁园","梁園"],["梁园区","梁園區"],["梁园宴雪","梁園宴雪"],["梁园虽好不是久恋之家","梁園雖好不是久戀之家"],["梁国荣","梁國榮"],["梁太祖","梁太祖"],["梁姓","梁姓"],["梁子","樑子"],["梁子湖","梁子湖"],["梁子湖区","梁子湖區"],["梁孟","梁孟"],["梁实秋","梁實秋"],["梁家辉","梁家輝"],["梁容银","梁容銀"],["梁山","梁山"],["梁山伯","梁山伯"],["梁山伯与祝英台","梁山伯與祝英臺"],["梁山伯祝英台","梁山伯祝英臺"],["梁山县","梁山縣"],["梁山市","梁山市"],["梁山泊","梁山泊"],["梁州","梁州"],["梁平","梁平"],["梁平县","梁平縣"],["梁建伟","梁建偉"],["梁德馨","梁德馨"],["梁心颐","梁心頤"],["梁惠王","梁惠王"],["梁敬帝","梁敬帝"],["梁文冲","梁文沖"],["梁文音","梁文音"],["梁文骐","梁文騏"],["梁朝伟","梁朝偉"],["梁木","梁木"],["梁木其坏","樑木其壞"],["梁架","樑架"],["梁柱","樑柱"],["梁栋","樑棟"],["梁案","梁案"],["梁楷","梁楷"],["梁次震","梁次震"],["梁武帝","梁武帝"],["梁氏","梁氏"],["梁河","梁河"],["梁河县","梁河縣"],["梁漱溟","梁漱溟"],["梁父吟","梁父吟"],["梁狱上书","梁獄上書"],["梁玉芳","梁玉芳"],["梁皇宝忏","梁皇寶懺"],["梁皇忏","梁皇懺"],["梁祝","梁祝"],["梁简文帝","梁簡文帝"],["梁红玉","梁紅玉"],["梁经伦","梁經倫"],["梁羽生","梁羽生"],["梁茜雯","梁茜雯"],["梁赞","梁贊"],["梁辀","梁輈"],["梁辰鱼","梁辰魚"],["梁锦兴","梁錦興"],["梁静茹","梁靜茹"],["梁靜茹","梁靜茹"],["梁鸿","梁鴻"],["梁鸿五噫","梁鴻五噫"],["梁龙","樑龍"],["梅克","梅克"],["梅克尔","梅克爾"],["梅尼尔氏症","梅尼爾氏症"],["梅布托","梅布托"],["梅干","梅乾"],["梅干菜","梅乾菜"],["梅德韦杰夫","梅德韋傑夫"],["梅杰","梅傑"],["梅核","梅核"],["梅花小娘","梅花小娘"],["梅西叶","梅西葉"],["梅西叶星表","梅西葉星表"],["梅西耶星表","梅西耶星表"],["梅里","梅里"],["梅里亚","梅里亞"],["梅里亚姆韦伯斯特","梅里亞姆韋伯斯特"],["梅里斯","梅里斯"],["梅里斯区","梅里斯區"],["梅里斯达斡尔族区","梅里斯達斡爾族區"],["梅里美","梅里美"],["梅里雪山","梅里雪山"],["梓里","梓里"],["梢云","梢雲"],["梦云","夢雲"],["梦兰叶吉","夢蘭叶吉"],["梦卜","夢卜"],["梦周公","夢周公"],["梦回","夢迴"],["梦工厂","夢工廠"],["梦工厂动画","夢工廠動畫"],["梦往神游","夢往神遊"],["梦有五不占","夢有五不占"],["梦游","夢遊"],["梦游症","夢遊症"],["梦粱录","夢粱錄"],["梦系","夢繫"],["梦行症","夢行症"],["梦里","夢裏"],["梦里蝴蝶","夢裏蝴蝶"],["梨云","梨雲"],["梨干","梨乾"],["梨干儿","梨乾兒"],["梯冲","梯衝"],["梯度回波","梯度回波"],["梯恩梯当量","梯恩梯當量"],["梯板","梯板"],["械斗","械鬥"],["械系","械繫"],["梳了","梳了"],["梳发","梳髮"],["梳头发","梳頭髮"],["梳妆台","梳妝檯"],["梵册贝叶","梵冊貝葉"],["梵谷","梵谷"],["检修","檢修"],["检出","檢出"],["检复","檢覆"],["检字表","檢字表"],["检尸","檢屍"],["检录","檢錄"],["检査出","檢查出"],["检査出来","檢查出來"],["检核","檢核"],["检核表","檢核表"],["检测出","檢測出"],["检测出来","檢測出來"],["检索系统","檢索系統"],["检警合一","檢警合一"],["检阅台","檢閱臺"],["检验出","檢驗出"],["检验出来","檢驗出來"],["棉制","棉製"],["棉卷","棉卷"],["棉厂","棉廠"],["棉布","棉布"],["棉布婚","棉布婚"],["棉签","棉籤"],["棉纤维","棉纖維"],["棉纺厂","棉紡廠"],["棉花布","棉花布"],["棉花店里歇工","棉花店裏歇工"],["棉花火药","棉花火藥"],["棉药签","棉藥籤"],["棉铃虫","棉鈴蟲"],["棋布","棋佈"],["棋布星罗","棋佈星羅"],["棋杯","棋杯"],["棋罗星布","棋羅星佈"],["棋逢对手将遇良才","棋逢對手將遇良才"],["棒下出孝子","棒下出孝子"],["棒坛","棒壇"],["棒头出孝子","棒頭出孝子"],["棒子面","棒子麪"],["棒曲霉素","棒麴黴素"],["棒极了","棒極了"],["棒状杆菌","棒狀桿菌"],["棒针","棒針"],["棒针衫","棒針衫"],["棕色种","棕色種"],["棘针","棘針"],["棘针科","棘針科"],["棘针门","棘針門"],["棫朴","棫樸"],["森林学系","森林學系"],["森林抚育采伐","森林撫育採伐"],["森林游乐区","森林遊樂區"],["森林生态系","森林生態系"],["森林里","森林裏"],["森罗万象","森羅萬象"],["棱体","棱體"],["棱台","棱臺"],["棱层","棱層"],["棱等登","棱等登"],["棱线","棱線"],["棱缝","棱縫"],["棱锥","棱錐"],["棱锥台","棱錐臺"],["棱镜","棱鏡"],["棺材出了讨挽歌郎钱","棺材出了討挽歌郎錢"],["棺材板","棺材板"],["棺材里","棺材裏"],["棺材里伸手","棺材裏伸手"],["椅里","椅裏"],["植党","植黨"],["植党营私","植黨營私"],["植发","植髮"],["植基于","植基於"],["植根于","植根於"],["植物区系","植物區系"],["植物志","植物誌"],["植物纤维","植物纖維"],["植病系","植病系"],["植皮手术","植皮手術"],["椭圆面","橢圓面"],["椰枣干","椰棗乾"],["椰胡","椰胡"],["椰雕","椰雕"],["椽梁","椽梁"],["椿萱并茂","椿萱並茂"],["楚庄王","楚莊王"],["楚庄绝缨","楚莊絕纓"],["楚庄问鼎","楚莊問鼎"],["楚汉春秋","楚漢春秋"],["楚霸王困垓下","楚霸王困垓下"],["楞了楞","楞了楞"],["楣运当头","楣運當頭"],["楮叶","楮葉"],["楼台","樓臺"],["楼台亭阁","樓臺亭閣"],["楼台会","樓臺會"],["楼板","樓板"],["楼梯台","樓梯臺"],["楼梯平台","樓梯平臺"],["楼阁亭台","樓閣亭臺"],["楼面","樓面"],["概念","概念"],["榆叶梅","榆葉梅"],["榔板","榔板"],["榕坛问业","榕壇問業"],["榨干","榨乾"],["榨油厂","榨油廠"],["榻布","榻布"],["槃才","槃才"],["槃槃大才","槃槃大才"],["槓杆","槓桿"],["槓杆原理","槓桿原理"],["槭叶止血草","槭葉止血草"],["樊于期","樊於期"],["樛曲","樛曲"],["模制","模製"],["模制品","模製品"],["模块板","模塊板"],["模型板","模型板"],["模式种","模式種"],["模拟出","模擬出"],["模板","模板"],["模板工","模板工"],["模糊集合理论","模糊集合理論"],["模组厂","模組廠"],["模网论坛","模網論壇"],["模胡","模胡"],["模范","模範"],["模范丈夫","模範丈夫"],["模范人物","模範人物"],["模范作用","模範作用"],["模范区","模範區"],["模范城市","模範城市"],["模范大音阶","模範大音階"],["模范学生","模範學生"],["模范带头","模範帶頭"],["模范带头作用","模範帶頭作用"],["模范教师","模範教師"],["模范村","模範村"],["模范棒棒堂","模範棒棒堂"],["模范生","模範生"],["模范省","模範省"],["模范章","模範章"],["模范行动","模範行動"],["模表","模表"],["模里西斯","模里西斯"],["模里西斯共和国","模里西斯共和國"],["横了心","橫了心"],["横冲","橫衝"],["横冲直撞","橫衝直撞"],["横出","橫出"],["横切面","橫切面"],["横剖面","橫剖面"],["横向","橫向"],["横尸","橫屍"],["横尸遍野","橫屍遍野"],["横征暴敛","橫徵暴斂"],["横截面","橫截面"],["横打鼻梁儿","橫打鼻梁兒"],["横扫千军","橫掃千軍"],["横折","橫折"],["横摆","橫擺"],["横断面","橫斷面"],["横杆","橫杆"],["横杠","橫槓"],["横梁","橫樑"],["横眉冷对千夫指","橫眉冷對千夫指"],["横秋","橫秋"],["横筋斗","橫筋斗"],["横舍","橫舍"],["横面","橫面"],["横须贺","橫須賀"],["横须贺市","橫須賀市"],["樱花杯","櫻花盃"],["樵苏","樵蘇"],["樵苏不爨","樵蘇不爨"],["樵采","樵採"],["橄榄岩","橄欖岩"],["橘核","橘核"],["橡子面","橡子麪"],["橡子面儿","橡子麪兒"],["橡斗","橡斗"],["橡木叶","橡木葉"],["橦布","橦布"],["橫亘","橫亙"],["橱柜","櫥櫃"],["檀板","檀板"],["欠当","欠當"],["欠据","欠據"],["次一个","次一個"],["次于","次於"],["次分面","次分面"],["次后","次後"],["次级团体","次級團體"],["欢乐谷","歡樂谷"],["欢喜欲狂","歡喜欲狂"],["欣喜欲狂","欣喜欲狂"],["欣戚","欣戚"],["欣欣向荣","欣欣向榮"],["欣然同意","欣然同意"],["欣生恶死","欣生惡死"],["欧伯托","歐伯托"],["欧佩克","歐佩克"],["欧克","歐克"],["欧克曼","歐克曼"],["欧克莱","歐克萊"],["欧几里得","歐幾里得"],["欧几里得原理","歐幾里得原理"],["欧几里德","歐幾里德"],["欧化倾向","歐化傾向"],["欧布拉多","歐布拉多"],["欧布莱特","歐布萊特"],["欧式几何","歐式幾何"],["欧式几何学","歐式幾何學"],["欧式建筑","歐式建築"],["欧战后","歐戰後"],["欧拉朱万","歐拉朱萬"],["欧普艺术","歐普藝術"],["欧氏几何学","歐氏幾何學"],["欧洲共同体","歐洲共同體"],["欧洲共同市场","歐洲共同市場"],["欧洲复兴计画","歐洲復興計畫"],["欧洲安全与合作组织","歐洲安全與合作組織"],["欧洲安全和合作组织","歐洲安全和合作組織"],["欧洲杯","歐洲盃"],["欧洲火药库","歐洲火藥庫"],["欧洲货币体系","歐洲貨幣體系"],["欧游","歐遊"],["欧游之行","歐遊之行"],["欧游记趣","歐遊記趣"],["欧特里尼","歐特里尼"],["欧秋雅","歐秋雅"],["欧系","歐系"],["欧罗巴人种","歐羅巴人種"],["欧胡岛","歐胡島"],["欧萨苏纳","歐薩蘇納"],["欧足联杯","歐足聯杯"],["欧里庇得斯","歐里庇得斯"],["欧里桑","歐里桑"],["欧阳修","歐陽修"],["欧雷克","歐雷克"],["欲不可从","欲不可從"],["欲人不知莫若勿为","欲人不知莫若勿爲"],["欲令智昏","慾令智昏"],["欲加之罪","欲加之罪"],["欲加之罪何患无词","慾加之罪何患無詞"],["欲加之罪何患无辞","欲加之罪何患無辭"],["欲取固与","欲取固與"],["欲取姑与","欲取姑與"],["欲取姑予","欲取姑予"],["欲哭无泪","欲哭無淚"],["欲善其事必先利其器","慾善其事必先利其器"],["欲堑","欲塹"],["欲壑难填","慾壑難填"],["欲壑难饱","欲壑難飽"],["欲女","慾女"],["欲就还推","欲就還推"],["欲待","欲待"],["欲得","欲得"],["欲念","慾念"],["欲振乏力","欲振乏力"],["欲擒故纵","欲擒故縱"],["欲望","慾望"],["欲求","欲求"],["欲求不满","慾求不滿"],["欲海","慾海"],["欲海难填","欲海難填"],["欲深谿壑","欲深谿壑"],["欲火","慾火"],["欲火焚身","慾火焚身"],["欲炙之色","欲炙之色"],["欲界","欲界"],["欲益反损","欲益反損"],["欲盖弥彰","欲蓋彌彰"],["欲穷千里目","欲窮千里目"],["欲绝","欲絕"],["欲罢不能","欲罷不能"],["欲裂","欲裂"],["欲言又止","欲言又止"],["欲语还休","欲語還休"],["欲说还休","欲說還休"],["欲购从速","欲購從速"],["欲速不达","欲速不達"],["欲速则不达","欲速則不達"],["欲速而不达","欲速而不達"],["欲障","慾障"],["欷吁","欷吁"],["欸乃曲","欸乃曲"],["欹嵚历落","欹嶔歷落"],["欺善怕恶","欺善怕惡"],["欺敌战术","欺敵戰術"],["欺蒙","欺矇"],["款冬","款冬"],["款曲","款曲"],["歇了","歇了"],["歇后","歇後"],["歇后语","歇後語"],["歇斯底里","歇斯底里"],["歇洛克福尔摩斯","歇洛克福爾摩斯"],["歇马杯","歇馬杯"],["歌仔戏团","歌仔戲團"],["歌剧团","歌劇團"],["歌台舞榭","歌臺舞榭"],["歌后","歌后"],["歌坛","歌壇"],["歌坛上","歌壇上"],["歌坛新秀","歌壇新秀"],["歌声绕梁","歌聲繞梁"],["歌曲","歌曲"],["歌板","歌板"],["歌舞升平","歌舞昇平"],["歌舞团","歌舞團"],["歌钟","歌鐘"],["歌风台","歌風臺"],["歎吁","歎吁"],["歛出来","歛出來"],["止不了","止不了"],["止于","止於"],["止于至善","止於至善"],["止咳药","止咳藥"],["止恶扬善","止惡揚善"],["止泻药","止瀉藥"],["止涨回跌","止漲回跌"],["止痛药","止痛藥"],["止血药","止血藥"],["止谤莫如自修","止謗莫如自脩"],["止跌回升","止跌回升"],["止饥","止飢"],["正义党","正義黨"],["正义发展党","正義發展黨"],["正义斗争","正義鬥爭"],["正于","正於"],["正修工专","正修工專"],["正凶","正凶"],["正出","正出"],["正则参数","正則參數"],["正反两面","正反兩面"],["正反合","正反合"],["正反面","正反面"],["正合","正合"],["正合我意","正合我意"],["正合适","正合適"],["正后","正後"],["正后像","正後像"],["正后方","正後方"],["正向","正向"],["正向前看","正向前看"],["正处于","正處於"],["正多面体","正多面體"],["正头娘子","正頭娘子"],["正官庄","正官莊"],["正宫娘娘","正宮娘娘"],["正对面","正對面"],["正常范围","正常範圍"],["正弦","正弦"],["正弦曲线","正弦曲線"],["正当","正當"],["正当中","正當中"],["正当化","正當化"],["正当性","正當性"],["正当时","正當時"],["正当理由","正當理由"],["正当行为","正當行爲"],["正当防卫","正當防衛"],["正当防卫行为","正當防衛行爲"],["正念","正念"],["正手板","正手板"],["正方向","正方向"],["正方晶系","正方晶系"],["正极","正極"],["正枝正叶","正枝正葉"],["正梁","正樑"],["正正当当","正正當當"],["正正确确","正正確確"],["正电子发射体层","正電子發射體層"],["正电子发射层析","正電子發射層析"],["正电子发射断层照相术","正電子發射斷層照相術"],["正电子发射计算机断层","正電子發射計算機斷層"],["正电极","正電極"],["正确","正確"],["正确处理","正確處理"],["正确处理人民内部矛盾","正確處理人民內部矛盾"],["正确度","正確度"],["正确性","正確性"],["正确路线","正確路線"],["正误表","正誤表"],["正集团","正集團"],["正面","正面"],["正面人物","正面人物"],["正面图","正面圖"],["正面攻击","正面攻擊"],["此仆彼起","此仆彼起"],["此发彼应","此發彼應"],["此后","此後"],["此系","此係"],["步人后尘","步人後塵"],["步兵团","步兵團"],["步出","步出"],["步后尘","步後塵"],["步向","步向"],["步斗踏罡","步斗踏罡"],["步月登云","步月登雲"],["步枪团","步槍團"],["步步行凶","步步行兇"],["步步高升","步步高昇"],["步线行针","步線行針"],["步罡踏斗","步罡踏斗"],["步行虫","步行蟲"],["步调一致","步調一致"],["步进制","步進制"],["步青云","步青雲"],["步飞烟传","步飛煙傳"],["武丑","武丑"],["武偃文修","武偃文修"],["武后","武后"],["武器系统","武器系統"],["武器级别材料","武器級別材料"],["武坛","武壇"],["武大郎吃毒药","武大郎吃毒藥"],["武当","武當"],["武当山","武當山"],["武当派","武當派"],["武斗","武鬥"],["武曲星","武曲星"],["武术","武術"],["武术指导","武術指導"],["武术比赛","武術比賽"],["武术竞赛","武術競賽"],["武松","武松"],["武松打虎","武松打虎"],["武梁祠画像","武梁祠畫像"],["武胜关","武勝關"],["武胜县","武勝縣"],["武装冲突","武裝衝突"],["武装斗争","武裝鬥爭"],["武里省","武里省"],["歧出","歧出"],["歪向","歪向"],["歪才","歪才"],["歪摆布","歪擺佈"],["歪曲","歪曲"],["歪曲事实","歪曲事實"],["歹念","歹念"],["歹斗","歹鬥"],["死不了","死不了"],["死不了心","死不了心"],["死了","死了"],["死于","死於"],["死于安乐","死於安樂"],["死于非命","死於非命"],["死伤枕借","死傷枕藉"],["死伤相借","死傷相藉"],["死党","死黨"],["死别","死別"],["死别生离","死別生離"],["死后","死後"],["死后多年","死後多年"],["死命挣扎","死命掙扎"],["死定了","死定了"],["死尸","死屍"],["死当","死當"],["死扣","死扣"],["死有余辜","死有餘辜"],["死有重于泰山轻于鸿毛","死有重於泰山輕於鴻毛"],["死板","死板"],["死板板","死板板"],["死气沈沈","死氣沈沈"],["死海古卷","死海古卷"],["死海经卷","死海經卷"],["死灰复然","死灰復然"],["死灰复燃","死灰復燃"],["死灰复燎","死灰復燎"],["死生未卜","死生未卜"],["死症","死症"],["死知府不如一个活老鼠","死知府不如一個活老鼠"],["死而不僵","死而不僵"],["死而后已","死而後已"],["死而后止","死而後止"],["死而复活","死而復活"],["死而复生","死而復生"],["死而复苏","死而復甦"],["死胡同","死衚衕"],["死要面子","死要面子"],["死谷","死谷"],["死里求生","死裏求生"],["死里逃生","死裏逃生"],["死难同胞","死難同胞"],["死面","死麪","死面"],["死马当活马医","死馬當活馬醫"],["死马当活马治","死馬當活馬治"],["殆尽","殆盡"],["殊别","殊別"],["殊域周咨录","殊域周咨錄"],["殊属不当","殊屬不當"],["殊方同致","殊方同致"],["殊涂一致","殊塗一致"],["殊涂同会","殊塗同會"],["殊涂同归","殊塗同歸"],["殊涂同致","殊塗同致"],["殊胜","殊勝"],["殊致","殊致"],["殊致同归","殊致同歸"],["殊路同归","殊路同歸"],["殊途同归","殊途同歸"],["残余","殘餘"],["残余沾染","殘餘沾染"],["残余物","殘餘物"],["残党","殘黨"],["残冬","殘冬"],["残冬腊月","殘冬臘月"],["残卷","殘卷"],["残干","殘幹"],["残废后","殘廢後"],["残念","殘念"],["残春雾雨余","殘春霧雨餘"],["残杯冷炙","殘杯冷炙"],["残秋","殘秋"],["残肴","殘餚"],["殖谷","殖穀"],["殚尽","殫盡"],["殚思极虑","殫思極慮"],["殚精极思","殫精極思"],["殚精极虑","殫精極慮"],["殡舍","殯舍"],["殢云尤雨","殢雲尤雨"],["殢雨尤云","殢雨尤雲"],["殴斗","毆鬥"],["段皇云","段皇雲"],["殷同","殷同"],["殷墟卜辞","殷墟卜辭"],["殷师牛斗","殷師牛鬥"],["殷鉴","殷鑑"],["殷鉴不远","殷鑑不遠"],["殿后","殿後"],["殿钟自鸣","殿鐘自鳴"],["毁了","毀了"],["毁于","毀於"],["毁于一旦","毀於一旦"],["毁尸灭迹","毀屍滅跡"],["毁廉蔑耻","毀廉蔑恥"],["毁弃","譭棄"],["毁方瓦合","毀方瓦合"],["毁炎","燬炎"],["毁犀","燬犀"],["毁誉","譭譽"],["毁誉参半","譭譽參半"],["毁诬","譭誣"],["毁钟为铎","譭鐘爲鐸"],["毋贻后患","毋貽後患"],["毋须","毋須"],["毋须乎","毋須乎"],["母丑","母醜"],["母乳喂养","母乳餵養"],["母党","母黨"],["母后","母后"],["母大虫","母大蟲"],["母权制","母權制"],["母板","母板"],["母系","母系"],["母系亲属","母系親屬"],["母系制度","母系制度"],["母系社会","母系社會"],["母范","母範"],["母钟","母鐘"],["母音表","母音表"],["每一个人","每一個人"],["每一个人都有美中不足的地方","每一個人都有美中不足的地方"],["每个","每個"],["每个人","每個人"],["每个月","每個月"],["每于","每於"],["每公里","每公里"],["每分钟","每分鐘"],["每只","每隻"],["每周","每週"],["每周一次","每週一次"],["每回","每回"],["每当","每當"],["每战必胜","每戰必勝"],["每日限价","每日限價"],["每杯","每杯"],["每每只","每每只"],["每种","每種"],["每秒钟","每秒鐘"],["每端口价格","每端口價格"],["每面","每面"],["毒僵指","毒殭指"],["毒症","毒症"],["毒药","毒藥"],["毒药苦口","毒藥苦口"],["毒药苦口利于病","毒藥苦口利於病"],["毒虫","毒蟲"],["毒针","毒針"],["比上不足比下有余","比上不足比下有餘"],["比不了","比不了"],["比个","比個"],["比个大哥二哥","比個大哥二哥"],["比个高下","比個高下"],["比个高低","比個高低"],["比了","比了"],["比什凯克","比什凱克"],["比价","比價"],["比众不同","比衆不同"],["比例代表制","比例代表制"],["比出","比出"],["比划","比劃"],["比合","比合"],["比周","比周"],["比喻失当","比喻失當"],["比干","比干"],["比并","比並"],["比手划脚","比手劃腳"],["比才","比才"],["比杆赛","比桿賽"],["比约克曼","比約克曼"],["比舍","比舍"],["比表面","比表面"],["比较规范","比較規範"],["毕业于","畢業於"],["毕于","畢於"],["毕其功于一役","畢其功於一役"],["毕力同心","畢力同心"],["毕升","畢昇"],["毕宿星团","畢宿星團"],["毕生发展","畢生發展"],["毕翠克丝","畢翠克絲"],["毗婆尸佛","毗婆尸佛"],["毗舍婆佛","毗舍婆佛"],["毙而后已","斃而後已"],["毚欲","毚欲"],["毛了","毛了"],["毛了手脚","毛了手腳"],["毛出在羊身上","毛出在羊身上"],["毛卷","毛卷"],["毛厕里砖儿","毛廁裏磚兒"],["毛发","毛髮"],["毛发之功","毛髮之功"],["毛发俱竖","毛髮俱豎"],["毛发倒竖","毛髮倒豎"],["毛发悚然","毛髮悚然"],["毛发森竖","毛髮森豎"],["毛发皆竖","毛髮皆豎"],["毛发耸然","毛髮聳然"],["毛司里砖儿","毛司裏磚兒"],["毛囊虫","毛囊蟲"],["毛团","毛團"],["毛团把戏","毛團把戲"],["毛坑没后壁","毛坑沒後壁"],["毛姜","毛薑"],["毛巾布","毛巾布"],["毛布","毛布"],["毛板","毛板"],["毛栗子","毛栗子"],["毛毛虫","毛毛蟲"],["毛毯里","毛毯裏"],["毛纺厂","毛紡廠"],["毛线针","毛線針"],["毛织布","毛織布"],["毛虫","毛蟲"],["毛语录","毛語錄"],["毛里塔尼亚","毛里塔尼亞"],["毛里拖毡","毛裏拖氈"],["毛里求斯","毛里求斯"],["毫不相干","毫不相干"],["毫仑目","毫侖目"],["毫克","毫克"],["毫升","毫升"],["毫厘","毫釐"],["毫厘不差","毫釐不差"],["毫厘不爽","毫釐不爽"],["毫厘之差","毫釐之差"],["毫厘千里","毫釐千里"],["毫发","毫髮"],["毫发不差","毫髮不差"],["毫发不爽","毫髮不爽"],["毫发之差","毫髮之差"],["毫发无损","毫髮無損"],["毫发未伤","毫髮未傷"],["毫居里","毫居里"],["毫无二致","毫無二致"],["毫无价值","毫無價值"],["毫无准备","毫無準備"],["毫无根据","毫無根據"],["毫无节制","毫無節制"],["毫针","毫針"],["毯里","毯裏"],["氏症","氏症"],["氏胄","氏胄"],["民丰","民豐"],["民丰县","民豐縣"],["民主党","民主黨"],["民主党人","民主黨人"],["民主党员","民主黨員"],["民主党派","民主黨派"],["民主党籍","民主黨籍"],["民主制度","民主制度"],["民主进步党","民主進步黨"],["民主进步党籍","民主進步黨籍"],["民主集中制","民主集中制"],["民众代表","民衆代表"],["民众党","民衆黨"],["民众团体","民衆團體"],["民俗曲艺","民俗曲藝"],["民党","民黨"],["民和回族土族自治县","民和回族土族自治縣"],["民和年丰","民和年豐"],["民团","民團"],["民坠涂炭","民墜塗炭"],["民心向背","民心向背"],["民心所向","民心所向"],["民心趋向","民心趨向"],["民志","民志"],["民怨盈涂","民怨盈塗"],["民意代表","民意代表"],["民意向背","民意向背"],["民政里","民政里"],["民族党","民族黨"],["民族同化","民族同化"],["民族团结","民族團結"],["民族复兴运动","民族復興運動"],["民族志","民族誌"],["民族色彩","民族色彩"],["民极","民極"],["民生涂炭","民生塗炭"],["民生雕敝","民生雕敝"],["民用建筑","民用建築"],["民用航空器适航证书","民用航空器適航證書"],["民社党","民社黨"],["民穷财尽","民窮財盡"],["民谣歌曲","民謠歌曲"],["民进党","民進黨"],["民进党员","民進黨員"],["民进党团","民進黨團"],["民进党版","民進黨版"],["民进党籍","民進黨籍"],["民间合会","民間合會"],["民间团体","民間團體"],["民间艺术","民間藝術"],["民风淳朴","民風淳樸"],["民风纯朴","民風純樸"],["气一冲","氣一衝"],["气了","氣了"],["气充志定","氣充志定"],["气充志骄","氣充志驕"],["气克斗牛","氣克斗牛"],["气冲冲","氣沖沖"],["气冲斗牛","氣衝斗牛"],["气冲牛斗","氣衝牛斗"],["气冲霄汉","氣衝霄漢"],["气出","氣出"],["气力用尽","氣力用盡"],["气动控制","氣動控制"],["气势熏灼","氣勢熏灼"],["气压表","氣壓表"],["气吁吁","氣吁吁"],["气吞牛斗","氣吞牛斗"],["气味相合","氣味相合"],["气喘吁吁","氣喘吁吁"],["气团","氣團"],["气在心里","氣在心裏"],["气定神闲","氣定神閒"],["气尽","氣盡"],["气帘","氣簾"],["气扬采飞","氣揚采飛"],["气数已尽","氣數已盡"],["气极败坏","氣極敗壞"],["气满志得","氣滿志得"],["气满志骄","氣滿志驕"],["气焰熏天","氣焰熏天"],["气燄万丈","氣燄萬丈"],["气管切开术","氣管切開術"],["气管插管术","氣管插管術"],["气若游丝","氣若游絲"],["气象万千","氣象萬千"],["气象台","氣象臺"],["气郁","氣鬱"],["气铲","氣鏟"],["气骄志满","氣驕志滿"],["氘核","氘核"],["氢净合成油","氫淨合成油"],["氢卤酸","氫鹵酸"],["氤郁","氤鬱"],["氨基甲酸酯类化合物","氨基甲酸酯類化合物"],["氮血症","氮血症"],["水一冲","水一衝"],["水上摩托车","水上摩托車"],["水俣症","水俁症"],["水光云影","水光雲影"],["水再冲","水再衝"],["水准","水準"],["水准仪","水準儀"],["水准器","水準器"],["水准图","水準圖"],["水准测量","水準測量"],["水利制","水利制"],["水力发电","水力發電"],["水力发电站","水力發電站"],["水厂","水廠"],["水又冲","水又衝"],["水合","水合"],["水合物","水合物"],["水团","水團"],["水尽山穷","水盡山窮"],["水尽鹅飞","水盡鵝飛"],["水已冲","水已衝"],["水已干","水已乾"],["水帘","水簾"],["水帘洞","水簾洞"],["水干","水乾"],["水干尽","水乾盡"],["水干掉","水乾掉"],["水平面","水平面"],["水底写字板","水底寫字板"],["水底捞针","水底撈針"],["水当当","水噹噹"],["水彩","水彩"],["水彩画","水彩畫"],["水彩画家","水彩畫家"],["水彩笔","水彩筆"],["水彩颜料","水彩顏料"],["水急冲","水急衝"],["水成岩","水成岩"],["水才干","水纔乾"],["水斗","水斗"],["水斧虫","水斧蟲"],["水晶杯","水晶杯"],["水曲","水曲"],["水曲柳","水曲柳"],["水来汤里去","水來湯裏去"],["水杯","水杯"],["水柜","水櫃"],["水波荡漾","水波盪漾"],["水泥厂","水泥廠"],["水泥板","水泥板"],["水注","水注"],["水流內布袋戏台","水流內布袋戲臺"],["水浒后传","水滸後傳"],["水清可鉴","水清可鑑"],["水温表","水溫表"],["水烟","水煙"],["水烟袋","水菸袋"],["水磨腔曲子","水磨腔曲子"],["水秋千","水鞦韆"],["水穷山尽","水窮山盡"],["水管系","水管系"],["水管面","水管麪"],["水精帘","水精簾"],["水系","水系"],["水经注","水經注"],["水落石出","水落石出"],["水蜡树","水蠟樹"],["水蜡虫","水蠟蟲"],["水表","水錶"],["水谷","水谷"],["水谷之海","水穀之海"],["水谷隼","水谷隼"],["水轮发动","水輪發動"],["水轮发动机","水輪發動機"],["水轮发电","水輪發電"],["水逝云卷","水逝雲卷"],["水里","水裏"],["水里乡","水里鄉"],["水里水里来火里火里去","水裏水裏來火裏火裏去"],["水里纳瓜","水裏納瓜"],["水里鄉","水里鄉"],["水鉴","水鑑"],["水陆并进","水陸並進"],["水面","水面"],["水面上","水面上"],["水面系数","水面係數"],["水面舰","水面艦"],["水面舰艇","水面艦艇"],["水龙卷","水龍捲"],["永不录用","永不錄用"],["永丰","永豐"],["永丰余","永豐餘"],["永丰县","永豐縣"],["永丰堂","永豐堂"],["永丰舰","永豐艦"],["永丰舰事件","永豐艦事件"],["永丰金","永豐金"],["永修县","永修縣"],["永别","永別"],["永别酒","永別酒"],["永历","永曆"],["永发","永發"],["永志","永志"],["永志不忘","永誌不忘"],["永结同心","永結同心"],["永续发展","永續發展"],["永胜","永勝"],["永胜县","永勝縣"],["汀曲","汀曲"],["求借","求借"],["求出","求出"],["求助于","求助於"],["求助于人","求助於人"],["求古录","求古錄"],["求同","求同"],["求同存异","求同存異"],["求才","求才"],["求才若渴","求才若渴"],["求教于","求教於"],["求死愿望","求死願望"],["求生意志","求生意志"],["求田问舍","求田問舍"],["求知欲","求知慾"],["求神问卜","求神問卜"],["求签","求籤"],["求胜","求勝"],["求胜心","求勝心"],["求过于供","求過於供"],["求道于盲","求道於盲"],["汇业","匯業"],["汇业财经集团","匯業財經集團"],["汇业银行","匯業銀行"],["汇丰","匯豐"],["汇丰银行","匯豐銀行"],["汇付","匯付"],["汇价","匯價"],["汇信","匯信"],["汇兑","匯兌"],["汇入","匯入"],["汇出","匯出"],["汇出行","匯出行"],["汇刊","彙刊"],["汇划","匯劃"],["汇到","匯到"],["汇合","匯合"],["汇回","匯回"],["汇寄","匯寄"],["汇展","匯展"],["汇川区","匯川區"],["汇差","匯差"],["汇市","匯市"],["汇总","彙總"],["汇成","匯成"],["汇报","彙報"],["汇拢","匯攏"],["汇改","匯改"],["汇整","彙整"],["汇映","彙映"],["汇款","匯款"],["汇款人","匯款人"],["汇款单","匯款單"],["汇水","匯水"],["汇流","匯流"],["汇流处","匯流處"],["汇流排","匯流排"],["汇流点","匯流點"],["汇流环","匯流環"],["汇演","匯演"],["汇点","匯點"],["汇爲","匯爲"],["汇率","匯率"],["汇率制","匯率制"],["汇率差额","匯率差額"],["汇电","匯電"],["汇票","匯票"],["汇算","彙算"],["汇纂","彙纂"],["汇给","匯給"],["汇编","彙編"],["汇编语言","彙編語言"],["汇聚","匯聚"],["汇至","匯至"],["汇费","匯費"],["汇辑","彙輯"],["汇进","匯進"],["汇通","匯通"],["汇金","匯金"],["汇钱","匯錢"],["汇银","匯銀"],["汇集","彙集"],["汇集点","匯集點"],["汉书艺文志","漢書藝文志"],["汉克","漢克"],["汉克阿伦","漢克阿倫"],["汉台","漢臺"],["汉台区","漢臺區"],["汉城特别市","漢城特別市"],["汉奸","漢奸"],["汉奸走狗","漢奸走狗"],["汉学系","漢學系"],["汉宫秋","漢宮秋"],["汉宫秋月","漢宮秋月"],["汉弥尔顿","漢彌爾頓"],["汉弥登钟","漢彌登鐘"],["汉弥登钟表公司","漢彌登鐘錶公司"],["汉志","漢志"],["汉杰","漢傑"],["汉满蒙回藏","漢滿蒙回藏"],["汉药方","漢藥方"],["汉萨同盟","漢薩同盟"],["汉藏语系","漢藏語系"],["汗出如浆","汗出如漿"],["汗出如雨","汗出如雨"],["汗洽股栗","汗洽股慄"],["汗流满面","汗流滿面"],["汗腾格里","汗騰格里"],["汙蔑","污衊"],["汞合金","汞合金"],["江云渭树","江雲渭樹"],["江南四大才子","江南四大才子"],["江南机器制造局","江南機器製造局"],["江参","江參"],["江宏杰","江宏傑"],["江干","江干"],["江干区","江乾區"],["江志雄","江志雄"],["江村销夏录","江村銷夏錄"],["江海同归","江海同歸"],["江淹才尽","江淹才盡"],["江湖术士","江湖術士"],["江湖术语","江湖術語"],["江苏","江蘇"],["江苏人","江蘇人"],["江苏南钢","江蘇南鋼"],["江苏省","江蘇省"],["江苏队","江蘇隊"],["江表","江表"],["江西师范大学","江西師範大學"],["江郎才尽","江郎才盡"],["江采苹","江采蘋"],["江面","江面"],["江面上","江面上"],["江韦仑","江韋侖"],["池里","池裏"],["污水处理厂","污水處理廠"],["污蔑","污衊"],["汤下面","湯下麪"],["汤加里罗","湯加里羅"],["汤团","湯糰"],["汤姆历险记","湯姆歷險記"],["汤姆斯杯","湯姆斯杯"],["汤姆汉克","湯姆漢克"],["汤姆索亚历险记","湯姆索亞歷險記"],["汤杯","湯杯"],["汤药","湯藥"],["汤里来水里去","湯裏來水裏去"],["汤面","湯麪"],["汪少杰","汪少傑"],["汪曲克","汪曲克"],["汲于","汲於"],["汲汲于","汲汲於"],["汴梁","汴梁"],["汹涌","洶涌"],["汽电共生系统","汽電共生系統"],["汽表","汽表"],["汽车厂","汽車廠"],["汽轮发电","汽輪發電"],["汽轮发电机","汽輪發電機"],["沃依采克","沃依采克"],["沃兹尼克","沃茲尼克"],["沃枝叶不如培根本","沃枝葉不如培根本"],["沃达丰","沃達豐"],["沃野千里","沃野千里"],["沈下","沈下"],["沈不住气","沈不住氣"],["沈世宏","沈世宏"],["沈世朋","沈世朋"],["沈丘县","沈丘縣"],["沈云英","沈雲英"],["沈亚之","沈亞之"],["沈从文","沈從文"],["沈伟豪","沈偉豪"],["沈传芷","沈傳芷"],["沈住气","沈住氣"],["沈佳颖","沈佳穎"],["沈佺期","沈佺期"],["沈兼士","沈兼士"],["沈冤","沈冤"],["沈勇","沈勇"],["沈北新","沈北新"],["沈北新区","沈北新區"],["沈厚","沈厚"],["沈吉线","瀋吉線"],["沈吟","沈吟"],["沈周","沈周"],["沈哲鲲","沈哲鯤"],["沈国放","沈國放"],["沈塔尼","沈塔尼"],["沈复","沈復"],["沈天俞","沈天俞"],["沈如峰","沈如峯"],["沈家诚","沈家誠"],["沈寂","沈寂"],["沈富雄","沈富雄"],["沈尹默","沈尹默"],["沈山线","瀋山線"],["沈崇诲","沈崇誨"],["沈州","瀋州"],["沈庆京","沈慶京"],["沈庆光","沈慶光"],["沈建宏","沈建宏"],["沈得住气","沈得住氣"],["沈思","沈思"],["沈思往事","沈思往事"],["沈惠珍","沈惠珍"],["沈括","沈括"],["沈振来","沈振來"],["沈文台","沈文臺"],["沈文成","沈文成"],["沈明伦","沈明倫"],["沈春华","沈春華"],["沈昭铭","沈昭銘"],["沈柏苍","沈柏蒼"],["沈殿霞","沈殿霞"],["沈水","瀋水"],["沈没","沈沒"],["沈沦","沈淪"],["沈河","瀋河"],["沈河区","瀋河區"],["沈浊","沈濁"],["沈浮","沈浮"],["沈海","瀋海"],["沈海铁路","瀋海鐵路"],["沈浸","沈浸"],["沈淀","沈澱"],["沈淀出来","沈澱出來"],["沈淀法","沈澱法"],["沈淀物","沈澱物"],["沈淑敏","沈淑敏"],["沈湎","沈湎"],["沈湎酒色","沈湎酒色"],["沈溺","沈溺"],["沈滞","沈滯"],["沈滞性","沈滯性"],["沈玉琳","沈玉琳"],["沈璀庭","沈璀庭"],["沈甸甸","沈甸甸"],["沈疔","沈疔"],["沈疴","沈痾"],["沈痛","沈痛"],["沈痼","沈痼"],["沈睡","沈睡"],["沈睡不醒","沈睡不醒"],["沈砂池","沈砂池"],["沈积","沈積"],["沈积岩","沈積岩"],["沈积石","沈積石"],["沈筒","沈筒"],["沈筱珺","沈筱珺"],["沈约","沈約"],["沈继昌","沈繼昌"],["沈腰","沈腰"],["沈腰潘鬓","沈腰潘鬢"],["沈船","沈船"],["沈落","沈落"],["沈葆桢","沈葆楨"],["沈葆祯","沈葆禎"],["沈诗钧","沈詩鈞"],["沈迷","沈迷"],["沈迷不醒","沈迷不醒"],["沈郁","沈鬱"],["沈醉","沈醉"],["沈重","沈重"],["沈钧启","沈鈞啓"],["沈钰杰","沈鈺傑"],["沈闷","沈悶"],["沈阳","瀋陽"],["沈阳市","瀋陽市"],["沈阳师范","瀋陽師範"],["沈阳师范大学","瀋陽師範大學"],["沈降","沈降"],["沈陷","沈陷"],["沈雁冰","沈雁冰"],["沈雨庭","沈雨庭"],["沈静","沈靜"],["沈静下来","沈靜下來"],["沈靳扬","沈靳揚"],["沈香","沈香"],["沈鱼落雁","沈魚落雁"],["沈默","沈默"],["沈默不语","沈默不語"],["沈默寡言","沈默寡言"],["沉浸于","沉浸於"],["沉淀","沉澱"],["沉淀剂","沉澱劑"],["沉淀法","沉澱法"],["沉淀物","沉澱物"],["沉渐刚克","沉漸剛克"],["沉湎于","沉湎於"],["沉溺于","沉溺於"],["沉潜刚克","沉潛剛克"],["沉积岩","沉積岩"],["沉迷于","沉迷於"],["沉郁","沉鬱"],["沉郁顿挫","沉鬱頓挫"],["沉醉于","沉醉於"],["沉陷于","沉陷於"],["沓合","沓合"],["沙仑","沙崙"],["沙依巴克","沙依巴克"],["沙依巴克区","沙依巴克區"],["沙克","沙克"],["沙克疫苗","沙克疫苗"],["沙参","沙蔘"],["沙发","沙發"],["沙发垫","沙發墊"],["沙发椅","沙發椅"],["沙发牀","沙發牀"],["沙坑杆","沙坑桿"],["沙岩","沙岩"],["沙弥","沙彌"],["沙弥戒","沙彌戒"],["沙洛培克","沙洛培克"],["沙漠生态系","沙漠生態系"],["沙茶面","沙茶麪"],["沙里夫","沙里夫"],["沙里淘金","沙裏淘金"],["沙雕","沙雕"],["沙雕赛","沙雕賽"],["沟谷","溝谷"],["没个出豁","沒個出豁"],["没个好结果","沒個好結果"],["没个开交","沒個開交"],["没个是处","沒個是處"],["没个见识","沒個見識"],["没个里儿表儿","沒個裏兒表兒"],["没个黑家白日的","沒個黑家白日的"],["没乱里","沒亂裏"],["没了","沒了"],["没了主意","沒了主意"],["没了当","沒了當"],["没了指望","沒了指望"],["没了期","沒了期"],["没了法","沒了法"],["没了王的蜜蜂","沒了王的蜜蜂"],["没了经纬","沒了經緯"],["没了结处","沒了結處"],["没了落","沒了落"],["没事干","沒事幹"],["没人烟","沒人煙"],["没件好当眼的","沒件好當眼的"],["没体面","沒體面"],["没借","沒借"],["没做摆布","沒做擺佈"],["没关系","沒關係"],["没准","沒準"],["没准儿","沒準兒"],["没准头","沒準頭"],["没出","沒出"],["没出去","沒出去"],["没出息","沒出息"],["没出来","沒出來"],["没出豁","沒出豁"],["没出豁处","沒出豁處"],["没出长","沒出長"],["没升","沒升"],["没合杀","沒合殺"],["没合煞","沒合煞"],["没合眼儿","沒合眼兒"],["没后","沒後"],["没后跟","沒後跟"],["没向","沒向"],["没回","沒回"],["没回去","沒回去"],["没回来","沒回來"],["没地里","沒地里"],["没地里巡检","沒地裏巡檢"],["没处出豁","沒處出豁"],["没头当","沒頭當"],["没完没了","沒完沒了"],["没家亲引不出外鬼来","沒家親引不出外鬼來"],["没干","沒幹"],["没干头","沒幹頭"],["没干没净","沒乾沒淨"],["没干没淨","沒乾沒淨"],["没干淨","沒幹淨"],["没幸","沒幸"],["没张没致","沒張沒致"],["没当","沒當"],["没当家花花","沒當家花花"],["没志气","沒志氣"],["没志行","沒志行"],["没念","沒念"],["没意志","沒意志"],["没折至","沒摺至"],["没担当","沒擔當"],["没摆布处","沒擺佈處"],["没有人烟","沒有人煙"],["没有准儿","沒有準兒"],["没有差别","沒有差別"],["没有来历","沒有來歷"],["没有联系","沒有聯繫"],["没有面目","沒有面目"],["没来历","沒來歷"],["没来回","沒來回"],["没松下","沒鬆下"],["没极奈何","沒極奈何"],["没样范","沒樣範"],["没梁桶","沒梁桶"],["没梢干","沒梢幹"],["没爷娘的祖宗","沒爺孃的祖宗"],["没爹没娘","沒爹沒孃"],["没种","沒種"],["没签","沒簽"],["没算当","沒算當"],["没精打彩","沒精打彩"],["没精打采","沒精打采"],["没脊梁","沒脊樑"],["没脸面","沒臉面"],["没药","沒藥"],["没见世面","沒見世面"],["没见食面","沒見食面"],["没讨个空处","沒討個空處"],["没说出","沒說出"],["没造化的种子","沒造化的種子"],["没采","沒采"],["没里没外","沒裏沒外"],["没量斗","沒量斗"],["没雕当","沒雕當"],["没面子","沒面子"],["没面皮","沒面皮"],["没面目","沒面目"],["沤郁","漚鬱"],["沥干","瀝乾"],["沥血之仇","瀝血之仇"],["沦于","淪於"],["沮舍","沮舍"],["河不出图","河不出圖"],["河升镇","河昇鎮"],["河岳","河嶽"],["河干","河干"],["河曲","河曲"],["河曲县","河曲縣"],["河曲智叟","河曲智叟"],["河梁","河梁"],["河流汇集","河流匯集"],["河涸海干","河涸海乾"],["河系","河系"],["河落海干","河落海乾"],["河谷","河谷"],["河里","河裏"],["河里孩儿岸上娘","河裏孩兒岸上孃"],["河里淹死是会水的","河裏淹死是會水的"],["河面","河面"],["河面上","河面上"],["油价","油價"],["油伙儿","油夥兒"],["油光满面","油光滿面"],["油厂","油廠"],["油回磨转","油回磨轉"],["油头粉面","油頭粉面"],["油尽灯枯","油盡燈枯"],["油布","油布"],["油当量","油當量"],["油彩","油彩"],["油斗","油鬥"],["油杯","油杯"],["油松","油松"],["油漆未干","油漆未乾"],["油烟","油煙"],["油烟机","油煙機"],["油电混合车","油電混合車"],["油花卜","油花卜"],["油茶面儿","油茶麪兒"],["油表","油表"],["油里滑","油裏滑"],["油面","油麪"],["油页岩","油頁岩"],["治了","治了"],["治愈","治癒"],["治术","治術"],["治疗炎症","治療炎症"],["沽名吊誉","沽名吊譽"],["沽名干誉","沽名干譽"],["沽酒当炉","沽酒當爐"],["沾染控制","沾染控制"],["沿才授职","沿才授職"],["沿门托钵","沿門托鉢"],["沿门挨户","沿門挨戶"],["泄了","泄了"],["泄出","泄出"],["泄出去","泄出去"],["泄出来","泄出來"],["泄欲","泄慾"],["泅游","泅遊"],["泉台","泉臺"],["泉州师范学院","泉州師範學院"],["泊松","泊松"],["泊松分布","泊松分佈"],["泌尿系统","泌尿系統"],["泌水乐饥","泌水樂飢"],["泐复","泐覆"],["泐布","泐布"],["法书要录","法書要錄"],["法云","法雲"],["法云地","法雲地"],["法克斯","法克斯"],["法兰克","法蘭克"],["法兰克林","法蘭克林"],["法兰克欧兹","法蘭克歐茲"],["法兰克福","法蘭克福"],["法兰克福学派","法蘭克福學派"],["法兰克福汇报","法蘭克福匯報"],["法兰克福证券交易所","法蘭克福證券交易所"],["法兰克福车展","法蘭克福車展"],["法出多门","法出多門"],["法制","法制"],["法制办公室","法制辦公室"],["法制化","法制化"],["法制局","法制局"],["法制日报","法制日報"],["法占","法佔"],["法台","法臺"],["法向量","法向量"],["法因于敝而成于过","法因於敝而成於過"],["法国共产党","法國共產黨"],["法国杯","法國杯"],["法坛","法壇"],["法定准备率","法定準備率"],["法布尔","法布爾"],["法布施","法佈施"],["法律制裁","法律制裁"],["法律学系","法律學系"],["法律系","法律系"],["法律规范","法律規範"],["法律面","法律面"],["法念","法念"],["法拉托","法拉托"],["法文系","法文系"],["法曲","法曲"],["法术","法術"],["法术无边","法術無邊"],["法柜奇兵","法櫃奇兵"],["法系","法系"],["法西斯党","法西斯黨"],["法语系","法語系"],["法身舍利","法身舍利"],["法鲁克","法魯克"],["泛了","泛了"],["泛亚","泛亞"],["泛亮","泛亮"],["泛光","泛光"],["泛出","泛出"],["泛出来","泛出來"],["泛函","泛函"],["泛动","泛動"],["泛化","泛化"],["泛区","泛區"],["泛听","泛聽"],["泛味","泛味"],["泛地","泛地"],["泛型","泛型"],["泛微","泛微"],["泛指","泛指"],["泛欧","泛歐"],["泛水","泛水"],["泛水凌山","汎水淩山"],["泛池","泛池"],["泛油","泛油"],["泛泛","泛泛"],["泛泰","泛泰"],["泛海","泛海"],["泛游","泛遊"],["泛湖","泛湖"],["泛滥","氾濫"],["泛点","泛點"],["泛爱","泛愛"],["泛现","泛現"],["泛珠","泛珠"],["泛白","泛白"],["泛的","泛的"],["泛着","泛着"],["泛称","泛稱"],["泛素","泛素"],["泛红","泛紅"],["泛绿","泛綠"],["泛美","泛美"],["泛舟","泛舟"],["泛蓝","泛藍"],["泛览","泛覽"],["泛论","泛論"],["泛读","泛讀"],["泛谈","泛談"],["泛起","泛起"],["泛酸","泛酸"],["泛青","泛青"],["泛非","泛非"],["泛音","泛音"],["泛黄","泛黃"],["泡出","泡出"],["泡制","泡製"],["泡杯","泡杯"],["泡沫发胶","泡沫髮膠"],["泡面","泡麪"],["泡面哲学","泡麪哲學"],["泡面市场","泡麪市場"],["波光荡漾","波光盪漾"],["波克夏","波克夏"],["波克特","波克特"],["波兰舞曲","波蘭舞曲"],["波勒瓦裘克","波勒瓦裘克"],["波发藻","波髮藻"],["波哥里卡","波哥里卡"],["波塞冬","波塞冬"],["波士顿艺术博物馆","波士頓藝術博物館"],["波多马克河","波多馬克河"],["波娘","波娘"],["波尔卡舞曲","波爾卡舞曲"],["波尔布特","波爾布特"],["波尔干","波爾干"],["波尔干地区","波爾干地區"],["波布政权","波布政權"],["波布那","波布那"],["波布那共和国","波布那共和國"],["波形板","波形板"],["波托马克河","波托馬克河"],["波折","波折"],["波拉克","波拉克"],["波斯里亚","波斯里亞"],["波来克","波來克"],["波杰曼","波傑曼"],["波棱菜","波棱菜"],["波洛克","波洛克"],["波浪周期","波浪週期"],["波涌云乱","波涌雲亂"],["波状云","波狀雲"],["波荡","波盪"],["波诡云谲","波詭雲譎"],["波谲云诡","波譎雲詭"],["波谷","波谷"],["波里","波里"],["波里尼西亚","波里尼西亞"],["波里尼西亚人","波里尼西亞人"],["波里斯","波里斯"],["波雷罗舞曲","波雷羅舞曲"],["波面","波面"],["泣别","泣別"],["泣别虞姬","泣別虞姬"],["泥于","泥於"],["泥土面","泥土面"],["泥塑木雕","泥塑木雕"],["泥封函谷","泥封函谷"],["泥岩","泥岩"],["泥板","泥板"],["泥板岩","泥板岩"],["泥涂","泥塗"],["泥灰岩","泥灰岩"],["泥质岩","泥質岩"],["泥质页岩","泥質頁岩"],["泥铲","泥鏟"],["注上","註上"],["注中奖","注中獎"],["注云","注云"],["注儿","注兒"],["注入","注入"],["注入式敎学法","注入式教學法"],["注冊","註冊"],["注冊主任","註冊主任"],["注冊单","註冊單"],["注冊商标","註冊商標"],["注冊手续","註冊手續"],["注冊日","註冊日"],["注冊用户","注冊用戶"],["注冊码","註冊碼"],["注冊组","註冊組"],["注冊费","註冊費"],["注册","註冊"],["注册人","註冊人"],["注册商标","註冊商標"],["注册表","註冊表"],["注到","注到"],["注名","註名"],["注塑","注塑"],["注失","註失"],["注子","注子"],["注定","註定"],["注射","注射"],["注射剂","注射劑"],["注射器","注射器"],["注射液","注射液"],["注射筒","注射筒"],["注射针","注射針"],["注射针头","注射針頭"],["注心","注心"],["注意","注意"],["注意事项","注意事項"],["注意到","注意到"],["注意力","注意力"],["注意力缺陷过动症","注意力缺陷過動症"],["注意看","注意看"],["注慕","注慕"],["注批","註批"],["注文","註文"],["注明","註明"],["注本","注本"],["注标","註標"],["注水","注水"],["注油","注油"],["注消","注消"],["注满","注滿"],["注生娘娘","註生娘娘"],["注疏","註疏"],["注目","注目"],["注目礼","注目禮"],["注脚","註腳"],["注色","注色"],["注视","注視"],["注解","註解"],["注记","註記"],["注译","註譯"],["注资","注資"],["注释","註釋"],["注重","注重"],["注销","註銷"],["注音","注音"],["注音一式","注音一式"],["注音字母","注音字母"],["注音文","注音文"],["注音法","注音法"],["注音符号","注音符號"],["泪出痛肠","淚出痛腸"],["泪如泉涌","淚如泉涌"],["泪容满面","淚容滿面"],["泪干","淚乾"],["泪干肠断","淚乾腸斷"],["泪流满面","淚流滿面"],["泪眼蒙眬","淚眼矇矓"],["泪蜡","淚蠟"],["泫然欲泣","泫然欲泣"],["泫然欲泪","泫然欲淚"],["泰克","泰克"],["泰勒制度","泰勒制度"],["泰国新娘","泰國新娘"],["泰坛","泰壇"],["泰坦尼克号","泰坦尼克號"],["泰山北斗","泰山北斗"],["泰山娘娘","泰山娘娘"],["泰山梁木","泰山梁木"],["泰斗","泰斗"],["泰极而否","泰極而否"],["泰极还生否乐处又逢悲","泰極還生否樂處又逢悲"],["泰爱泰党","泰愛泰黨"],["泰特斯安德洛尼克斯","泰特斯安德洛尼克斯"],["泰特美术馆","泰特美術館"],["泰系各族","泰系各族"],["泱郁","泱鬱"],["泳坛","泳壇"],["泳气钟","泳氣鐘"],["泻了","瀉了"],["泻出","瀉出"],["泻出去","瀉出去"],["泻出来","瀉出來"],["泻药","瀉藥"],["泼出","潑出"],["泼出去","潑出去"],["泼出来","潑出來"],["泼出胆子","潑出膽子"],["泼才","潑才"],["泼毛团","潑毛團"],["泼烟花","潑煙花"],["泼脏水","潑髒水"],["泼花团","潑花團"],["泼贱烟花","潑賤煙花"],["泽卤","澤鹵"],["泽当","澤當"],["泽当镇","澤當鎮"],["泽梁","澤梁"],["泽渗漓而下降","澤滲灕而下降"],["泽里可","澤里可"],["洁面乳","潔面乳"],["洁面露","潔面露"],["洄暗","洄闇"],["洄游","洄游"],["洋参","洋蔘"],["洋场恶少","洋場惡少"],["洋布","洋布"],["洋干漆","洋乾漆"],["洋浦经济开发区","洋浦經濟開發區"],["洋烟","洋菸"],["洋相尽出","洋相盡出"],["洋相百出","洋相百出"],["洋紫苏","洋紫蘇"],["洋药","洋藥"],["洋蜡","洋蠟"],["洋面","洋麪"],["洒出","灑出"],["洒向","灑向"],["洒扫","灑掃"],["洒水","灑水"],["洒洒","灑灑"],["洒涤","灑滌"],["洒淅","灑淅"],["洒濯","灑濯"],["洒然","灑然"],["洒脱","灑脫"],["洗了","洗了"],["洗冤集录","洗冤集錄"],["洗出","洗出"],["洗出作用","洗出作用"],["洗出去","洗出去"],["洗出来","洗出來"],["洗刮","洗刮"],["洗发","洗髮"],["洗发乳","洗髮乳"],["洗发剂","洗髮劑"],["洗发动机","洗發動機"],["洗发水","洗髮水"],["洗发水儿","洗髮水兒"],["洗发皂","洗髮皂"],["洗发粉","洗髮粉"],["洗发精","洗髮精"],["洗发膏","洗髮膏"],["洗发露","洗髮露"],["洗地板","洗地板"],["洗头发","洗頭髮"],["洗干淨","洗乾淨"],["洗心革志","洗心革志"],["洗心革面","洗心革面"],["洗手不干","洗手不幹"],["洗手台","洗手檯"],["洗炼","洗煉"],["洗练","洗練"],["洗脑术","洗腦術"],["洗脸台","洗臉檯"],["洗荡","洗盪"],["洗衣板","洗衣板"],["洗钱防制法","洗錢防制法"],["洗面","洗面"],["洗面乳","洗面乳"],["洗面奶","洗面奶"],["洗面皂","洗面皂"],["洗面革心","洗面革心"],["洛克","洛克"],["洛克希德","洛克希德"],["洛克希德马丁","洛克希德馬丁"],["洛克斐勒","洛克斐勒"],["洛克比","洛克比"],["洛克菲勒","洛克菲勒"],["洛克西德","洛克西德"],["洛党","洛黨"],["洛可可美术","洛可可美術"],["洛扎","洛扎"],["洛扎县","洛扎縣"],["洛皮塔瀑布","洛皮塔瀑布"],["洛迪克","洛迪克"],["洛钟东应","洛鐘東應"],["洛阳师范学院","洛陽師範學院"],["洛阳才子","洛陽才子"],["洞察其奸","洞察其奸"],["洞山良价","洞山良价"],["洞烛其奸","洞燭其奸"],["洞烛奸邪","洞燭奸邪"],["洞窟美术","洞窟美術"],["洞见症结","洞見癥結"],["洞鉴","洞鑑"],["洞鉴古今","洞鑑古今"],["津发","津發"],["津巴布韦","津巴布韋"],["津梁","津樑"],["津贴制度","津貼制度"],["洪万春","洪萬春"],["洪信杰","洪信傑"],["洪升","洪昇"],["洪士杰","洪士杰"],["洪复","洪覆"],["洪宪帝制","洪憲帝制"],["洪志善","洪志善"],["洪志宏","洪志宏"],["洪杰鸿","洪傑鴻"],["洪泛","洪泛"],["洪炉燎发","洪爐燎髮"],["洪胄","洪胄"],["洪若朴","洪若樸"],["洪范","洪範"],["洪适","洪适"],["洪都百炼生","洪都百鍊生"],["洪钟","洪鐘"],["洲际杯","洲際盃"],["洴澼药","洴澼藥"],["活不了","活不了"],["活了","活了"],["活体肝脏移植","活體肝臟移植"],["活出","活出"],["活动于","活動於"],["活动曲尺","活動曲尺"],["活动桌面","活動桌面"],["活动看板","活動看板"],["活动范围","活動範圍"],["活厂经营","活廠經營"],["活塞杆","活塞桿"],["活干","活幹"],["活扣","活釦"],["活泛","活泛"],["活饥荒","活饑荒"],["派克","派克"],["派克大衣","派克大衣"],["派克斯顿","派克斯頓"],["派出","派出"],["派出去","派出去"],["派出所","派出所"],["派出机关","派出機關"],["派出来","派出來"],["派别","派別"],["派发","派發"],["派团","派團"],["派团参加","派團參加"],["派屈克","派屈克"],["派屈克节","派屈克節"],["派崔克","派崔克"],["派彩","派彩"],["派拉蒙","派拉蒙"],["派拉蒙影","派拉蒙影"],["派系","派系"],["派翠克","派翠克"],["流个","流個"],["流了","流了"],["流于","流於"],["流于形式","流於形式"],["流云","流雲"],["流亡曲","流亡曲"],["流传于世","流傳於世"],["流传后世","流傳後世"],["流体冶金术","流體冶金術"],["流出","流出"],["流出去","流出去"],["流出来","流出來"],["流别","流別"],["流向","流向"],["流回","流回"],["流回去","流回去"],["流回来","流回來"],["流域面积","流域面積"],["流尽","流盡"],["流布","流佈"],["流干","流乾"],["流当","流當"],["流当品","流當品"],["流征","流徵"],["流氓集团","流氓集團"],["流水板","流水板"],["流水行云","流水行雲"],["流泄出来","流泄出來"],["流泛","流泛"],["流注","流注"],["流涎症","流涎症"],["流理台","流理臺"],["流离遇合","流離遇合"],["流程表","流程表"],["流纹岩","流紋岩"],["流芳后世","流芳後世"],["流苏","流蘇"],["流苏帐","流蘇帳"],["流苏髻","流蘇髻"],["流荡","流蕩"],["流荡忘反","流蕩忘反"],["流血冲突","流血衝突"],["流血千里","流血千里"],["流血浮尸","流血浮尸"],["流血漂卤","流血漂鹵"],["流行于","流行於"],["流行曲","流行曲"],["流行歌曲","流行歌曲"],["流行症","流行症"],["流觞曲水","流觴曲水"],["流通出来","流通出來"],["流里流气","流裏流氣"],["流量表","流量表"],["流露出","流露出"],["流露出来","流露出來"],["流风余","流風餘"],["流风余俗","流風餘俗"],["流风余韵","流風餘韻"],["流风回雪","流風迴雪"],["流鱼出听","流魚出聽"],["浅尝","淺嘗","淺嚐"],["浅尝则止","淺嘗則止"],["浅尝者","淺嘗者"],["浅尝辄止","淺嘗輒止"],["浅浮雕","淺浮雕"],["浅淀","淺澱"],["浅雕","淺雕"],["浇制","澆製"],["浇注","澆注"],["浇漓","澆漓"],["浇筑","澆築"],["浊积岩","濁積岩"],["浊臭熏天","濁臭熏天"],["测不准","測不準"],["测光表","測光表"],["测出","測出"],["测出来","測出來"],["测地曲率","測地曲率"],["测地线曲率","測地線曲率"],["测录到","測錄到"],["测量出","測量出"],["测量术","測量術"],["测量杆","測量桿"],["测量范围","測量範圍"],["测验卷","測驗卷"],["济世之才","濟世之才"],["济困","濟困"],["济困扶危","濟困扶危"],["济州特别自治道","濟州特別自治道"],["济恶","濟惡"],["济胜之具","濟勝之具"],["浑个","渾個"],["浑仪注","渾儀註"],["浑朴","渾樸"],["浑朴自然","渾樸自然"],["浑身发抖","渾身發抖"],["浑身发软","渾身發軟"],["浑闲事","渾閒事"],["浓于","濃於"],["浓云","濃雲"],["浓云密布","濃雲密佈"],["浓发","濃髮"],["浓墨重彩","濃墨重彩"],["浓暗","濃暗"],["浓淡适中","濃淡適中"],["浓烟","濃煙"],["浓血症","濃血症"],["浓郁","濃郁"],["浓雾密布","濃霧密佈"],["浙江天台县","浙江天台縣"],["浙江师范大学","浙江師範大學"],["浥注","浥注"],["浦发","浦發"],["浩克","浩克"],["浩叹","浩嘆"],["浩如烟气","浩如煙氣"],["浩如烟海","浩如煙海"],["浩浩荡荡","浩浩蕩蕩"],["浩荡","浩蕩"],["浪冲","浪衝"],["浪又冲","浪又衝"],["浪子回头","浪子回頭"],["浪子回头金不换","浪子回頭金不換"],["浪板","浪板"],["浪游","浪遊"],["浪漫曲","浪漫曲"],["浪琴表","浪琴錶"],["浪荡","浪蕩"],["浪荡乾坤","浪蕩乾坤"],["浪荡子","浪蕩子"],["浪荡子式","浪蕩子式"],["浪荡灯","浪蕩燈"],["浪蝶游蜂","浪蝶游蜂"],["浮于","浮於"],["浮云","浮雲"],["浮云富贵","浮雲富貴"],["浮云惊龙","浮雲驚龍"],["浮云朝露","浮雲朝露"],["浮云游子","浮雲遊子"],["浮云翳日","浮雲翳日"],["浮云蔽日","浮雲蔽日"],["浮借","浮借"],["浮出","浮出"],["浮动汇率","浮動匯率"],["浮台","浮臺"],["浮吊","浮吊"],["浮夸","浮誇"],["浮尸","浮屍"],["浮托","浮托"],["浮松","浮鬆"],["浮梁","浮樑"],["浮梁县","浮樑縣"],["浮沈","浮沈"],["浮泛","浮泛"],["浮游","浮游"],["浮游动物","浮游動物"],["浮游植物","浮游植物"],["浮游生物","浮游生物"],["浮现出","浮現出"],["浮现出来","浮現出來"],["浮签","浮簽"],["浮荡","浮蕩"],["浮词曲说","浮詞曲說"],["浮雕","浮雕"],["浮雕像","浮雕像"],["浮雕墙纸","浮雕牆紙"],["浮面","浮面"],["浴帘","浴簾"],["海上台风警报","海上颱風警報"],["海上布雷","海上佈雷"],["海上游","海上游"],["海上采油","海上採油"],["海丰","海豐"],["海丰县","海豐縣"],["海于格松","海于格松"],["海参","海蔘"],["海参威","海參威"],["海参崴","海參崴"],["海台","海臺"],["海国图志","海國圖志"],["海埔姜","海埔姜"],["海宇升平","海宇昇平"],["海尔布隆","海爾布隆"],["海岳名言","海岳名言"],["海带卷","海帶卷"],["海干","海乾"],["海干河尽","海乾河盡"],["海平面","海平面"],["海底峡谷","海底峽谷"],["海底捞针","海底撈針"],["海德里","海德里"],["海曲","海曲"],["海松","海松"],["海水不可斗量","海水不可斗量"],["海水淡化厂","海水淡化廠"],["海水面","海水面"],["海洋开发","海洋開發"],["海洋温差发电","海洋溫差發電"],["海洋生态系","海洋生態系"],["海涂","海塗"],["海涂围垦","海塗圍墾"],["海淀","海淀"],["海淀区","海淀區"],["海淀图书城","海淀圖書城"],["海湾合作理事会","海灣合作理事會"],["海湾布雷","海灣佈雷"],["海漂杯","海漂杯"],["海百合","海百合"],["海立云垂","海立雲垂"],["海苔","海苔"],["海蒂克伦","海蒂克倫"],["海藻虫","海藻蟲"],["海蚀台地","海蝕臺地"],["海蚀平台","海蝕平臺"],["海表","海表"],["海西蒙古族藏族自治州","海西蒙古族藏族自治州"],["海谷","海谷"],["海里","海里","海裏"],["海里海外","海裏海外"],["海面","海面"],["海马回","海馬迴"],["海鲜面","海鮮麪"],["海默症","海默症"],["浸于","浸於"],["浸制","浸製"],["浸种","浸種"],["涂上","塗上"],["涂乙","塗乙"],["涂了","塗了"],["涂写","塗寫"],["涂到","塗到"],["涂刷","塗刷"],["涂去","塗去"],["涂善妮","涂善妮"],["涂在","塗在"],["涂地","塗地"],["涂坤","涂坤"],["涂壮勋","涂壯勳"],["涂壯勳","涂壯勳"],["涂天相","涂天相"],["涂好","塗好"],["涂姓","涂姓"],["涂姓技士","塗姓技士"],["涂尔干","涂爾干"],["涂层","塗層"],["涂居贤","涂居賢"],["涂山","塗山"],["涂布","塗布"],["涂序瑄","涂序瑄"],["涂惠元","涂惠元"],["涂惠源","涂惠源"],["涂惠源雨","涂惠源雨"],["涂成","塗成"],["涂抹","塗抹"],["涂抹诗书","塗抹詩書"],["涂掉","塗掉"],["涂改","塗改"],["涂改无效","塗改無效"],["涂敏恆","涂敏恆"],["涂敏恒","涂敏恆"],["涂文生","涂文生"],["涂料","塗料"],["涂月","涂月"],["涂有","塗有"],["涂来涂去","塗來塗去"],["涂永辉","涂永輝"],["涂油","塗油"],["涂油于","塗油於"],["涂泽","塗澤"],["涂泽民","涂澤民"],["涂浆台","塗漿檯"],["涂涂","塗塗"],["涂涂改改","塗塗改改"],["涂消","塗消"],["涂满","塗滿"],["涂漆","塗漆"],["涂潦","塗潦"],["涂潭","塗潭"],["涂澤民","涂澤民"],["涂炭","塗炭"],["涂炭生民","塗炭生民"],["涂炭生灵","塗炭生靈"],["涂着","塗着"],["涂窜","塗竄"],["涂粉","塗粉"],["涂绍煃","涂紹煃"],["涂美伦","涂美倫"],["涂羽卿","涂羽卿"],["涂胶","塗膠"],["涂脂抹粉","塗脂抹粉"],["涂色","塗色"],["涂色板","塗色板"],["涂药","塗藥"],["涂蜡","塗蠟"],["涂謹申","涂謹申"],["涂说","塗說"],["涂谨申","涂謹申"],["涂过","塗過"],["涂过去","塗過去"],["涂过来","塗過來"],["涂逢年","涂逢年"],["涂醒哲","涂醒哲"],["涂金","塗金"],["涂销","塗銷"],["涂長望","涂長望"],["涂长望","涂長望"],["涂附","塗附"],["涂饰","塗飾"],["涂饰剂","塗飾劑"],["涂鴻欽","涂鴻欽"],["涂鸦","塗鴉"],["涂鸦区","塗鴉區"],["涂鸭","塗鴨"],["涂鸿钦","涂鴻欽"],["涂黑","塗黑"],["涅面","涅面"],["消了","消了"],["消化系统","消化系統"],["消噪","消噪"],["消息面","消息面"],["消折","消折"],["消极","消極"],["消极性","消極性"],["消极论","消極論"],["消毒药","消毒藥"],["消毒药水","消毒藥水"],["消沈","消沈"],["消渴症","消渴症"],["消灭殆尽","消滅殆盡"],["消灭淨尽","消滅淨盡"],["消炎药","消炎藥"],["消肿药","消腫藥"],["消费价格指数","消費價格指數"],["消费借贷","消費借貸"],["消费合作社","消費合作社"],["消费欲","消費慾"],["消闲儿","消閒兒"],["涉历","涉歷"],["涉台","涉臺"],["涉谷","涉谷"],["涉足于","涉足於"],["涌出","涌出"],["涌出去","涌出去"],["涌出来","涌出來"],["涌升流","涌升流"],["涌向","涌向"],["涌来","涌來"],["涌现","涌現"],["涌现出","涌現出"],["涌进","涌進"],["涛生云灭","濤生雲滅"],["涡虫","渦蟲"],["涡虫纲","渦蟲綱"],["涡轮喷气发动机","渦輪噴氣發動機"],["涡轮轴发动机","渦輪軸發動機"],["涤尽","滌盡"],["涤瑕荡垢","滌瑕盪垢"],["涤瑕荡秽","滌瑕盪穢"],["涤秽荡瑕","滌穢盪瑕"],["涤荡","滌盪"],["涤面","滌面"],["润发","潤髮"],["涨了","漲了"],["涨价","漲價"],["涨价归公","漲價歸公"],["涨停板","漲停板"],["涨出","漲出"],["涨升","漲升"],["涨回","漲回"],["涨回去","漲回去"],["涨回来","漲回來"],["涨红了脸","漲紅了臉"],["涨跌幅限制","漲跌幅限制"],["涨过了头","漲過了頭"],["涩谷","澀谷"],["液体燃料火箭发动机","液體燃料火箭發動機"],["液压千斤顶","液壓千斤頂"],["液晶板","液晶板"],["液晶表","液晶錶"],["液面","液麪"],["涳蒙","涳濛"],["涸干","涸乾"],["淀乃不耕之地","澱乃不耕之地"],["淀北片","澱北片"],["淀山","澱山"],["淀山湖","澱山湖"],["淀淀","澱澱"],["淀积","澱積"],["淀积物","澱積物"],["淀粉","澱粉"],["淀粉样","澱粉樣"],["淀粉类","澱粉類"],["淀粉类作物","澱粉類作物"],["淀粉糖","澱粉糖"],["淀粉脢","澱粉脢"],["淀粉质","澱粉質"],["淀解物","澱解物"],["淀谓之滓","澱謂之滓"],["淋余土","淋餘土"],["淋冲","淋沖"],["淋巴系统","淋巴系統"],["淋淋漓漓","淋淋漓漓"],["淋漓","淋漓"],["淋漓尽致","淋漓盡致"],["淋漓痛快","淋漓痛快"],["淌板船","淌板船"],["淑范","淑範"],["淑郁","淑郁"],["淘尽","淘盡"],["淘汰制","淘汰制"],["淘闲气","淘閒氣"],["淡于","淡於"],["淡于名利","淡於名利"],["淡入淡出","淡入淡出"],["淡出","淡出"],["淡出淡入","淡出淡入"],["淡彩","淡彩"],["淡朱","淡朱"],["淡水河系","淡水河系"],["淡水生态系","淡水生態系"],["淡蒙蒙","淡濛濛"],["淨价","淨價"],["淨化系统","淨化系統"],["淨发","淨髮"],["淨尽","淨盡"],["淨水厂","淨水廠"],["淨流出","淨流出"],["淨胜球","淨勝球"],["淨面","淨面"],["淩云笔","淩雲筆"],["淫念","淫念"],["淫欲","淫慾"],["淫游","淫遊"],["淫荡","淫蕩"],["淬炼","淬鍊"],["淮阴师范学院","淮陰師範學院"],["深于","深於"],["深仇","深仇"],["深仇大恨","深仇大恨"],["深入敌后","深入敵後"],["深入显出","深入顯出"],["深入浅出","深入淺出"],["深奸巨猾","深奸巨猾"],["深居简出","深居簡出"],["深山何处钟","深山何處鐘"],["深山出俊鸟","深山出俊鳥"],["深山穷谷","深山窮谷"],["深念","深念"],["深思极虑","深思極慮"],["深恶","深惡"],["深恶痛嫉","深惡痛嫉"],["深恶痛绝","深惡痛絕"],["深成岩","深成岩"],["深文周纳","深文周納"],["深暗","深暗"],["深有同感","深有同感"],["深沈","深沈"],["深沈不露","深沈不露"],["深沟墩台","深溝墩臺"],["深浅不同","深淺不同"],["深海烟囱","深海煙囪"],["深渊里","深淵裏"],["深秋","深秋"],["深色系列","深色系列"],["深获","深獲"],["深获好评","深獲好評"],["深表","深表"],["深表同情","深表同情"],["深谷","深谷"],["淳于","淳于"],["淳于意","淳于意"],["淳于髡","淳于髡"],["淳朴","淳樸"],["混了","混了"],["混出","混出"],["混出去","混出去"],["混出来","混出來"],["混合","混合"],["混合体","混合體"],["混合使用","混合使用"],["混合列车","混合列車"],["混合动力车","混合動力車"],["混合器","混合器"],["混合型","混合型"],["混合失语症","混合失語症"],["混合层","混合層"],["混合式","混合式"],["混合性","混合性"],["混合感染","混合感染"],["混合林","混合林"],["混合模型","混合模型"],["混合毒剂","混合毒劑"],["混合比","混合比"],["混合法","混合法"],["混合泳","混合泳"],["混合物","混合物"],["混合疫苗","混合疫苗"],["混合组","混合組"],["混合经济","混合經濟"],["混合结构","混合結構"],["混合肥料","混合肥料"],["混合裁判","混合裁判"],["混合语","混合語"],["混合齿列","混合齒列"],["混同","混同"],["混同江","混同江"],["混炼","混煉"],["混虫","混蟲"],["混血种","混血種"],["添个","添個"],["添了","添了"],["添枝加叶","添枝加葉"],["添枝接叶","添枝接葉"],["清丰","清豐"],["清丰县","清豐縣"],["清了","清了"],["清修","清修"],["清党","清黨"],["清党行动","清黨行動"],["清出","清出"],["清发","清發"],["清台","清檯"],["清实录","清實錄"],["清异录","清異錄"],["清心寡欲","清心寡慾"],["清晨杯","清晨盃"],["清杆运动","清桿運動"],["清査不当党产","清查不當黨產"],["清水下杂面","清水下雜麪"],["清水烟","清水煙"],["清汤挂面","清湯掛麪"],["清浊同流","清濁同流"],["清算斗争","清算鬥爭"],["清胄","清胄"],["清芬志","清芬志"],["清贫寡欲","清貧寡欲"],["清酒红人面财帛动人心","清酒紅人面財帛動人心"],["清闲自在","清閒自在"],["清静寡欲","清靜寡欲"],["渊淳岳峙","淵淳嶽峙"],["渊源录","淵源錄"],["渊谷","淵谷"],["渊鉴类函","淵鑑類函"],["渍已干","漬已乾"],["渐升","漸升"],["渐暗","漸暗"],["渔娘","漁娘"],["渔梁","漁梁"],["渔民团体","漁民團體"],["渔获","漁獲"],["渔获量","漁獲量"],["渗出","滲出"],["渗出来","滲出來"],["渗出物","滲出物"],["渗出量","滲出量"],["渠冲","渠衝"],["渡了","渡了"],["渡假胜地","渡假勝地"],["渡头云","渡頭雲"],["渡海小轮","渡海小輪"],["渡轮","渡輪"],["渥兹尼克","渥茲尼克"],["温克","溫克"],["温卷","溫卷"],["温州师范学院","溫州師範學院"],["温布尔登","溫布爾登"],["温布尔登网球公开赛","溫布爾登網球公開賽"],["温布尔顿","溫布爾頓"],["温布敦","溫布敦"],["温布里","溫布里"],["温布顿","溫布頓"],["温布顿赛","溫布頓賽"],["温度范围","溫度範圍"],["温度表","溫度表"],["温得和克","溫得和克"],["温祥云","溫祥雲"],["港制","港製"],["港制品","港製品"],["港台","港臺"],["港台地区","港臺地區"],["港澳台","港澳臺"],["渴了","渴了"],["渴念","渴念"],["渴欲","渴欲"],["渴饮饥餐","渴飲飢餐"],["游上","游上"],["游上去","游上去"],["游上来","游上來"],["游下","游下"],["游下去","游下去"],["游下来","游下來"],["游丝","遊絲"],["游丝飞絮","遊絲飛絮"],["游中国","遊中國"],["游乃海","游乃海"],["游乐","遊樂"],["游乐区","遊樂區"],["游乐器","遊樂器"],["游乐园","遊樂園"],["游乐场","遊樂場"],["游乐林","遊樂林"],["游乡","遊鄉"],["游了","遊了"],["游云惊龙","遊雲驚龍"],["游亚洲","遊亞洲"],["游人","遊人"],["游人如织","遊人如織"],["游仙","遊仙"],["游仙区","遊仙區"],["游仙枕","遊仙枕"],["游仙窟","遊仙窟"],["游仙诗","遊仙詩"],["游仪","遊儀"],["游伴","遊伴"],["游侠","遊俠"],["游侠骑士","遊俠騎士"],["游僧攒住持","游僧攢住持"],["游兴","遊興"],["游兴正浓","遊興正濃"],["游冶","遊冶"],["游出","游出"],["游击","遊擊"],["游击区","游擊區"],["游击战","游擊戰"],["游击手","游擊手"],["游击队","游擊隊"],["游刃","遊刃"],["游刃有余","遊刃有餘"],["游刃有馀","遊刃有餘"],["游到","游到"],["游动","遊動"],["游勇","遊勇"],["游北美","遊北美"],["游历","遊歷"],["游去","游去"],["游台湾","遊臺灣"],["游吟诗人","遊吟詩人"],["游嘴光棍","遊嘴光棍"],["游回","游回"],["游回去","游回去"],["游回来","游回來"],["游园","遊園"],["游园会","遊園會"],["游园惊梦","遊園驚夢"],["游囿伦","游囿倫"],["游士","遊士"],["游头浪子","遊頭浪子"],["游奕","遊奕"],["游女","遊女"],["游子","遊子"],["游子吟","遊子吟"],["游子天涯","遊子天涯"],["游学","遊學"],["游学生","遊學生"],["游完","游完"],["游客","遊客"],["游客如织","遊客如織"],["游客止步","遊客止步"],["游客量","遊客量"],["游宦","遊宦"],["游尘","游塵"],["游尺","遊尺"],["游履","游履"],["游山","遊山"],["游山玩水","遊山玩水"],["游幕","遊幕"],["游庠","遊庠"],["游廊","遊廊"],["游开","遊開"],["游弋","遊弋"],["游徼","遊徼"],["游心寓目","遊心寓目"],["游心骋目","遊心騁目"],["游必有方","遊必有方"],["游志宏","游志宏"],["游惰","遊惰"],["游憩","遊憩"],["游憩区","遊憩區"],["游戏","遊戲"],["游戏三昧","遊戲三昧"],["游戏业","遊戲業"],["游戏人间","遊戲人間"],["游戏包","遊戲包"],["游戏区","遊戲區"],["游戏场","遊戲場"],["游戏尘寰","遊戲塵寰"],["游戏机","遊戲機"],["游戏机台","遊戲機檯"],["游戏池","遊戲池"],["游戏王","遊戲王"],["游戏町","遊戲町"],["游戏规则","遊戲規則"],["游戏设备","遊戲設備"],["游戏说","遊戲說"],["游手","遊手"],["游手人户","遊手人戶"],["游手好闲","遊手好閒"],["游手恣睢","遊手恣睢"],["游手游食","遊手遊食"],["游扬","遊揚"],["游文宏","游文宏"],["游方","遊方"],["游日","遊日"],["游旧","遊舊"],["游明金","游明金"],["游易网","遊易網"],["游星","遊星"],["游春","遊春"],["游昭钦","游昭欽"],["游来","游來"],["游来游去","游來游去"],["游标","遊標"],["游标位置","遊標位置"],["游标卡尺","遊標卡尺"],["游欧洲","遊歐洲"],["游民","遊民"],["游民收容所","遊民收容所"],["游民改造","遊民改造"],["游气","遊氣"],["游水","游水"],["游河","遊河"],["游泮","游泮"],["游泳","游泳"],["游泳圈","游泳圈"],["游泳池","游泳池"],["游泳衣","游泳衣"],["游泳裤","游泳褲"],["游泳课","游泳課"],["游泳赛","游泳賽"],["游泳镜","游泳鏡"],["游泳队","游泳隊"],["游泳馆","游泳館"],["游游磨磨儿","遊遊磨磨兒"],["游湖","遊湖"],["游湖借伞","遊湖借傘"],["游澳洲","遊澳洲"],["游牧","遊牧"],["游牧区","遊牧區"],["游牧民族","遊牧民族"],["游猎","遊獵"],["游玩","遊玩"],["游畋","遊畋"],["游皓玮","游皓瑋"],["游盈隆","游盈隆"],["游益网","遊益網"],["游目","遊目"],["游目骋怀","遊目騁懷"],["游离","遊離"],["游离份子","遊離份子"],["游离层","遊離層"],["游离电子","遊離電子"],["游离票","遊離票"],["游离辐射","遊離輻射"],["游禽类","游禽類"],["游移","遊移"],["游移不决","遊移不決"],["游移不定","遊移不定"],["游程","遊程"],["游网","遊網"],["游美洲","遊美洲"],["游耕","遊耕"],["游船","遊船"],["游艇","遊艇"],["游艇业","遊艇業"],["游艇业者","遊艇業者"],["游艺","遊藝"],["游艺会","遊藝會"],["游艺团","遊藝團"],["游艺场","遊藝場"],["游花插趣","遊花插趣"],["游芳来","游芳來"],["游荡","遊蕩"],["游荡不归","遊蕩不歸"],["游营撞尸","遊營撞屍"],["游蜂戏蝶","遊蜂戲蝶"],["游蜂浪蝶","遊蜂浪蝶"],["游行","遊行"],["游行到","遊行到"],["游行法","遊行法"],["游行示众","遊行示衆"],["游行示威","遊行示威"],["游衍","遊衍"],["游街","遊街"],["游街示众","遊街示衆"],["游观","遊觀"],["游览","遊覽"],["游览区","遊覽區"],["游览胜地","遊覽勝地"],["游览车","遊覽車"],["游言","遊言"],["游记","遊記"],["游说","遊說"],["游说团","遊說團"],["游说团体","遊說團體"],["游谈","遊談"],["游谈无根","遊談無根"],["游资","遊資"],["游资氾滥","遊資氾濫"],["游赏","遊賞"],["游走","遊走"],["游踪","遊蹤"],["游轮","遊輪"],["游辞","遊辭"],["游辞浮说","遊辭浮說"],["游过","遊過"],["游过去","游過去"],["游过来","游過來"],["游进","遊進"],["游进去","游進去"],["游进来","游進來"],["游逛","遊逛"],["游遍","遊遍"],["游错","遊錯"],["游锡","遊錫"],["游锡坤","游錫坤"],["游锡堃","游錫堃"],["游锡昆","游錫昆"],["游隼","遊隼"],["游非洲","遊非洲"],["游食","遊食"],["游食之民","遊食之民"],["游香港","遊香港"],["游骑","遊騎"],["游骑兵","遊騎兵"],["游骑兵队","遊騎兵隊"],["游骑无归","遊騎無歸"],["游魂","遊魂"],["游鱼","游魚"],["游鸿儒","游鴻儒"],["游鸿明","游鴻明"],["游龙","游龍"],["游龙戏凤","游龍戲鳳"],["游龙荣","游龍榮"],["渺无人烟","渺無人煙"],["湖北师范学院","湖北師範學院"],["湖南师范大学","湖南師範大學"],["湖州师范学院","湖州師範學院"],["湖里","湖裏"],["湖里区","湖裏區"],["湖面","湖面"],["湘帘","湘簾"],["湘累","湘累"],["湘绣","湘繡"],["湛江师范学院","湛江師範學院"],["湟潦生苹","湟潦生苹"],["湮灭证据","湮滅證據"],["湮郁","湮鬱"],["湾里","灣裏"],["湾里区","灣裏區"],["湿地松","溼地松"],["湿度表","溼度表"],["湿肉伴干柴","溼肉伴乾柴"],["溃于","潰於"],["溅了","濺了"],["源于","源於"],["源汇区","源匯區"],["源泉万斛","源泉萬斛"],["源自于","源自於"],["溜个","溜個"],["溜了","溜了"],["溜冰团","溜冰團"],["溜出","溜出"],["溜出去","溜出去"],["溜出来","溜出來"],["溜回","溜回"],["溜回去","溜回去"],["溜回来","溜回來"],["溜溜秋秋","溜溜秋秋"],["溜滑板","溜滑板"],["溜须","溜鬚"],["溜须拍马","溜鬚拍馬"],["溟蒙","溟濛"],["溢于","溢於"],["溢于言表","溢於言表"],["溢价","溢價"],["溢出","溢出"],["溢出来","溢出來"],["溢恶","溢惡"],["溥天同庆","溥天同慶"],["溪谷","溪谷"],["溯游","溯游"],["溲面","溲麪"],["溶于","溶於"],["溶合","溶合"],["溶岩","溶岩"],["溶岩流","溶岩流"],["溶液聚合","溶液聚合"],["溶溶荡荡","溶溶蕩蕩"],["溺于","溺於"],["溺志","溺志"],["溺谷","溺谷"],["滃郁","滃鬱"],["滇西纵谷","滇西縱谷"],["滋补药品","滋補藥品"],["滑了","滑了"],["滑了一跤","滑了一跤"],["滑借","滑藉"],["滑出","滑出"],["滑出跑道","滑出跑道"],["滑动面","滑動面"],["滑回","滑回"],["滑杆","滑桿"],["滑板","滑板"],["滑板运动","滑板運動"],["滑水板","滑水板"],["滑铲","滑鏟"],["滑雪术","滑雪術"],["滑雪板","滑雪板"],["滔滔不尽","滔滔不盡"],["滔荡","滔蕩"],["滚了","滾了"],["滚出","滾出"],["滚出去","滾出去"],["滚出来","滾出來"],["滚回","滾回"],["滚回去","滾回去"],["滚回来","滾回來"],["滚彩蛋","滾彩蛋"],["滚成一团","滾成一團"],["滚杠","滾槓"],["滚杯","滾杯"],["滚石合唱团","滾石合唱團"],["滞后","滯後"],["滞后现象","滯後現象"],["满了","滿了"],["满于","滿於"],["满出","滿出"],["满出来","滿出來"],["满口称赞","滿口稱讚"],["满口胡扯","滿口胡扯"],["满口胡柴","滿口胡柴"],["满口胡言","滿口胡言"],["满口胡说","滿口胡說"],["满口脏话","滿口髒話"],["满场一致","滿場一致"],["满坑满谷","滿坑滿谷"],["满城尽带黄金甲","滿城盡帶黃金甲"],["满堂彩","滿堂彩"],["满天星斗","滿天星斗"],["满头洋发","滿頭洋髮"],["满好个","滿好個"],["满山满谷","滿山滿谷"],["满布","滿布"],["满布疑云","滿佈疑雲"],["满当当","滿當當"],["满怀心腹事尽在不言中","滿懷心腹事盡在不言中"],["满拚自尽","滿拚自盡"],["满杯","滿杯"],["满洲里","滿洲里"],["满洲里市","滿洲裏市"],["满满当当","滿滿當當"],["满脸溅朱","滿臉濺朱"],["满腹才学","滿腹才學"],["满腹疑云","滿腹疑雲"],["满面","滿面"],["满面堆笑","滿面堆笑"],["满面怒容","滿面怒容"],["满面愁容","滿面愁容"],["满面春生","滿面春生"],["满面春风","滿面春風"],["满面杀气","滿面殺氣"],["满面生春","滿面生春"],["满面生花","滿面生花"],["满面笑容","滿面笑容"],["满面红胀","滿面紅脹"],["满面羞惭","滿面羞慚"],["满面羞愧","滿面羞愧"],["满面通红","滿面通紅"],["满面雪霜","滿面雪霜"],["满面飞红","滿面飛紅"],["滤出","濾出"],["滤出去","濾出去"],["滤出来","濾出來"],["滥发","濫發"],["滨松市","濱松市"],["滩涂","灘塗"],["滴了","滴了"],["滴了天","滴了天"],["滴修都速","滴修都速"],["滴出","滴出"],["滴出来","滴出來"],["滴向","滴向"],["滴干","滴乾"],["滴水漏斗","滴水漏斗"],["滴注","滴注"],["滴羞都苏","滴羞都蘇"],["滴苏","滴蘇"],["滴虫","滴蟲"],["滴里嘟噜","滴里嘟嚕"],["滴里搭拉","滴里搭拉"],["滴里耷拉","滴里耷拉"],["漂了","漂了"],["漂向","漂向"],["漂布","漂布"],["漂摆","漂擺"],["漂游","漂游"],["漂荡","漂盪"],["漂荡子弟","漂蕩子弟"],["漆了","漆了"],["漆出","漆出"],["漆器雕","漆器雕"],["漆布","漆布"],["漆雕","漆雕"],["漆黑一团","漆黑一團"],["漏了","漏了"],["漏了眼","漏了眼"],["漏借","漏借"],["漏出","漏出"],["漏出去","漏出去"],["漏出来","漏出來"],["漏尽","漏盡"],["漏尽更阑","漏盡更闌"],["漏尽通","漏盡通"],["漏斗","漏斗"],["漏斗器","漏斗器"],["漏斗状花冠","漏斗狀花冠"],["漏斗管","漏斗管"],["漏斗胸","漏斗胸"],["漏洞百出","漏洞百出"],["漏电保护接地极插座","漏電保護接地極插座"],["漏网游鱼","漏網游魚"],["漏脯充饥","漏脯充飢"],["漏针","漏針"],["漏面贼","漏面賊"],["漓水","灕水"],["漓江","灕江"],["漓湘","灕湘"],["漓漓拉拉","漓漓拉拉"],["漓然","灕然"],["演个","演個"],["演出","演出"],["演出人","演出人"],["演出地点","演出地點"],["演出来","演出來"],["演出者","演出者"],["演化出","演化出"],["演员表","演員表"],["演奏出","演奏出"],["演奏台","演奏臺"],["演奏曲","演奏曲"],["演武修文","演武修文"],["演绎出","演繹出"],["演讲台","演講臺"],["漕挽","漕輓"],["漫出","漫出"],["漫出来","漫出來"],["漫卷","漫卷"],["漫天叫价","漫天叫價"],["漫天开价","漫天開價"],["漫天索价","漫天索價"],["漫天要价就地还钱","漫天要價就地還錢"],["漫天讨价","漫天討價"],["漫布","漫布"],["漫录","漫錄"],["漫无节制","漫無節制"],["漫无限制","漫無限制"],["漫游","漫遊"],["漫游四方","漫遊四方"],["漫游费","漫遊費"],["漱口杯","漱口杯"],["漱口药水","漱口藥水"],["漳州师范学院","漳州師範學院"],["漾出","漾出"],["潇洒","瀟灑"],["潘太克斯","潘太克斯"],["潘威志","潘威誌"],["潘安白发","潘安白髮"],["潘岳","潘岳"],["潘嶽白发","潘嶽白髮"],["潘谷","潘谷"],["潘越云","潘越雲"],["潘连周","潘連周"],["潘金莲给武松敬酒","潘金蓮給武松敬酒"],["潘鬓沈腰","潘鬢沈腰"],["潜了","潛了"],["潜修","潛修"],["潜出","潛出"],["潜出去","潛出去"],["潜出来","潛出來"],["潜台词","潛臺詞"],["潜回","潛回"],["潜意识历程","潛意識歷程"],["潜意识里","潛意識裏"],["潜水夫症","潛水夫症"],["潜水表","潛水錶"],["潜水钟","潛水鐘"],["潜水钟表","潛水鐘錶"],["潜游","潛游"],["潜移暗化","潛移暗化"],["潜蛟困凤","潛蛟困鳳"],["潟卤","潟鹵"],["潭祉叶吉","潭祉叶吉"],["潭里","潭裏"],["潮力发电","潮力發電"],["潮烟","潮菸"],["澄澹精致","澄澹精致"],["澎湖天后宫","澎湖天后宮"],["澒蒙","澒濛"],["澥谷","澥谷"],["澳新军团","澳新軍團"],["澳新军团日","澳新軍團日"],["澳洲广播电台","澳洲廣播電臺"],["澳门汇业","澳門匯業"],["澹台","澹臺"],["澹台灭明","澹臺滅明"],["澹彩","澹彩"],["澹泊寡欲","澹泊寡欲"],["澹泊明志","澹泊明志"],["澹荡","澹盪"],["激于","激於"],["激于义愤","激於義憤"],["激光二极管","激光二極管"],["激出","激出"],["激发","激發"],["激发出","激發出"],["激发出来","激發出來"],["激发态","激發態"],["激发注射","激發注射"],["激发起","激發起"],["激发起来","激發起來"],["激活整合模型","激活整合模型"],["激荡","激盪"],["激荡不已","激盪不已"],["激荡出","激盪出"],["激进党","激進黨"],["濒临绝种","瀕臨絕種"],["濒于","瀕於"],["濒于绝境","瀕於絕境"],["濒于绝种","瀕於絕種"],["濒危物种","瀕危物種"],["濒危野生动植物种国际贸易公约","瀕危野生動植物種國際貿易公約"],["濠梁","濠梁"],["瀍河回族区","瀍河回族區"],["瀑布","瀑布"],["瀑布区","瀑布區"],["瀑布群","瀑布羣"],["瀛台","瀛臺"],["瀛表","瀛表"],["灌个","灌個"],["灌了","灌了"],["灌于","灌於"],["灌云","灌雲"],["灌云县","灌雲縣"],["灌出","灌出"],["灌出去","灌出去"],["灌出来","灌出來"],["灌制","灌製"],["灌向","灌向"],["灌回","灌回"],["灌回去","灌回去"],["灌录","灌錄"],["灌注","灌注"],["灌注器","灌注器"],["灌溉系统","灌溉系統"],["灌溉面积","灌溉面積"],["灌药","灌藥"],["火中取栗","火中取栗"],["火了","火了"],["火云","火雲"],["火云邪","火雲邪"],["火力发电","火力發電"],["火力发电厂","火力發電廠"],["火山岩","火山岩"],["火山爆发","火山爆發"],["火山爆发指数","火山爆發指數"],["火并","火併"],["火彩儿","火彩兒"],["火成岩","火成岩"],["火折子","火摺子"],["火斗","火斗"],["火杯","火盃"],["火柴杆","火柴桿"],["火海战术","火海戰術"],["火灭烟消","火滅煙消"],["火炬松","火炬松"],["火烟","火煙"],["火烧云","火燒雲"],["火症","火症"],["火种","火種"],["火签","火籤"],["火箭发动","火箭發動"],["火箭喷射推进系统","火箭噴射推進系統"],["火箭布雷","火箭佈雷"],["火绳杆","火繩桿"],["火耕水种","火耕水種"],["火耕流种","火耕流種"],["火药","火藥"],["火药味","火藥味"],["火药味甚浓","火藥味甚濃"],["火药库","火藥庫"],["火虫儿","火蟲兒"],["火里火去水里水去","火裏火去水裏水去"],["火里火发","火裏火發"],["火里赤","火裏赤"],["火链片","火鏈片"],["灭不个","滅不個"],["灭尸","滅屍"],["灭尽","滅盡"],["灭种","滅種"],["灭种罪","滅種罪"],["灭绝种族","滅絕種族"],["灭罪修因","滅罪修因"],["灭虫剂","滅蟲劑"],["灭虫宁","滅蟲寧"],["灯台","燈臺"],["灯台不照自己","燈臺不照自己"],["灯台不自照","燈臺不自照"],["灯彩","燈綵"],["灯杆","燈杆"],["灯杯","燈杯"],["灯火万家","燈火萬家"],["灯火管制","燈火管制"],["灰云","灰雲"],["灰发","灰髮"],["灰同协","灰同協"],["灰头土面","灰頭土面"],["灰头草面","灰頭草面"],["灰姑娘","灰姑娘"],["灰岩残丘","灰巖殘丘"],["灰暗","灰暗"],["灰灰暗暗","灰灰暗暗"],["灰灰蒙蒙","灰灰濛濛"],["灰胡","灰鬍"],["灰蒙","灰濛"],["灰蒙蒙","灰濛濛"],["灰面鵟鹰","灰面鵟鷹"],["灰飞烟灭","灰飛煙滅"],["灵丹圣药","靈丹聖藥"],["灵丹妙药","靈丹妙藥"],["灵修","靈脩"],["灵台","靈臺"],["灵台县","靈臺縣"],["灵坛","靈壇"],["灵欲","靈慾"],["灵药","靈藥"],["灵谷寺","靈谷寺"],["灵迹","靈蹟"],["灸术","灸術"],["灾后","災後"],["灾害链","災害鏈"],["灿烂多彩","燦爛多彩"],["炆面","炆麪"],["炉台","爐臺"],["炊烟","炊煙"],["炊烟袅袅","炊煙裊裊"],["炊臼之戚","炊臼之鏚"],["炎日当空","炎日當空"],["炎症","炎症"],["炎症性","炎症性"],["炒栗子","炒栗子"],["炒汇","炒匯"],["炒菜铲","炒菜鏟"],["炒面","炒麪"],["炒面块子","炒麪塊子"],["炕席","炕蓆"],["炕面砖","炕面磚"],["炖了","燉了"],["炖药","燉藥"],["炭水化合物","炭水化合物"],["炭疽杆菌","炭疽桿菌"],["炮制","炮製"],["炮台","炮臺"],["炮炼","炮煉"],["炳烛夜游","炳燭夜遊"],["炸出","炸出"],["炸毁","炸燬"],["炸药","炸藥"],["炸药箱","炸藥箱"],["炸酱面","炸醬麪"],["点个","點個"],["点了","點了"],["点出","點出"],["点出去","點出去"],["点出来","點出來"],["点击一个链接","點擊一個鏈接"],["点半钟","點半鐘"],["点发","點發"],["点名表","點名表"],["点回","點回"],["点回去","點回去"],["点回来","點回來"],["点多钟","點多鐘"],["点将录","點將錄"],["点扎","點扎"],["点播曲","點播曲"],["点染云烟","點染雲煙"],["点核","點核"],["点烟","點菸"],["点烟器","點菸器"],["点线面","點線面"],["点里","點裏"],["点钟","點鐘"],["点集合","點集合"],["点面结合","點面結合"],["点饥","點飢"],["炼丹","煉丹"],["炼丹八卦炉","煉丹八卦爐"],["炼丹术","煉丹術"],["炼之未定","煉之未定"],["炼乳","煉乳"],["炼冶","鍊冶"],["炼制","煉製"],["炼制厂","煉製廠"],["炼化","煉化"],["炼句","煉句"],["炼字","煉字"],["炼山","煉山"],["炼师","鍊師"],["炼度","鍊度"],["炼形","煉形"],["炼气","煉氣"],["炼汞","鍊汞"],["炼油","煉油"],["炼油厂","煉油廠"],["炼焦","煉焦"],["炼焦厂","煉焦廠"],["炼焦炉","煉焦爐"],["炼焦煤","煉焦煤"],["炼狱","煉獄"],["炼石","煉石"],["炼石补天","煉石補天"],["炼糖","煉糖"],["炼糖厂","煉糖廠"],["炼药","煉藥"],["炼贫","鍊貧"],["炼金","鍊金"],["炼金术","鍊金術"],["炼金术士","煉金術士"],["炼钢","鍊鋼"],["炼钢业","鍊鋼業"],["炼钢厂","鍊鋼廠"],["炼钢炉","鍊鋼爐"],["炼铁","鍊鐵"],["炼铁厂","鍊鐵廠"],["炼铁炉","鍊鐵爐"],["炼铜","鍊銅"],["炼铜厂","鍊銅廠"],["炼铝","鍊鋁"],["炽热火山云","熾熱火山雲"],["烂了嘴","爛了嘴"],["烂了舌头","爛了舌頭"],["烂板乌龟","爛板烏龜"],["烂板洋钱","爛板洋錢"],["烂游","爛遊"],["烈日当空","烈日當空"],["烈火干柴","烈火乾柴"],["烘了","烘了"],["烘云托月","烘雲托月"],["烘制","烘製"],["烘干","烘乾"],["烘干机","烘乾機"],["烘托","烘托"],["烘托出","烘托出"],["烘板","烘板"],["烘熏","烘燻"],["烛台","燭臺"],["烛杯","燭杯"],["烛穗","燭穗"],["烝尝","烝嘗"],["烟丝","菸絲"],["烟云","煙雲"],["烟云供养","煙雲供養"],["烟云过眼","煙雲過眼"],["烟供","煙供"],["烟傢伙","煙傢伙"],["烟具","煙具"],["烟农","菸農"],["烟卷","菸捲"],["烟卷儿","菸捲兒"],["烟厂","菸廠"],["烟台","煙臺"],["烟台地区","煙臺地區"],["烟台市","煙臺市"],["烟台师范学院","煙臺師範學院"],["烟叶","菸葉"],["烟合包","煙合包"],["烟味","煙味"],["烟商","煙商"],["烟嘴","菸嘴"],["烟嘴儿","菸嘴兒"],["烟囱","煙囪"],["烟圈","菸圈"],["烟土","煙土"],["烟夜蛾","煙夜蛾"],["烟头","菸頭"],["烟子","煙子"],["烟客","煙客"],["烟害","菸害"],["烟尘","煙塵"],["烟屁股","菸屁股"],["烟岚","煙嵐"],["烟岚云岫","煙嵐雲岫"],["烟岸","煙岸"],["烟幕","煙幕"],["烟幕弹","煙幕彈"],["烟户","煙戶"],["烟斗","菸斗"],["烟斗丝","菸斗絲"],["烟景","煙景"],["烟月","煙月"],["烟月场","煙月場"],["烟月牌","煙月牌"],["烟机","煙機"],["烟杆","煙桿"],["烟枪","煙槍"],["烟枪洞","煙槍洞"],["烟柱","煙柱"],["烟树","煙樹"],["烟毒","煙毒"],["烟毒犯","煙毒犯"],["烟民","菸民"],["烟气","煙氣"],["烟油","煙油"],["烟泡","煙泡"],["烟波","煙波"],["烟波万顷","煙波萬頃"],["烟波客","煙波客"],["烟波浩渺","煙波浩渺"],["烟波钓叟","煙波釣叟"],["烟波钓徒","煙波釣徒"],["烟海","煙海"],["烟消云散","煙消雲散"],["烟消冰释","煙消冰釋"],["烟消火灭","煙消火滅"],["烟消雾散","煙消霧散"],["烟渚","煙渚"],["烟火","煙火"],["烟火之警","煙火之警"],["烟火气","煙火氣"],["烟火秀","煙火秀"],["烟火节","煙火節"],["烟火邻居","煙火鄰居"],["烟火食","煙火食"],["烟灯","煙燈"],["烟灰","菸灰"],["烟灰缸","菸灰缸"],["烟煤","煙煤"],["烟煴","煙熅"],["烟熏","煙燻"],["烟熏妆","煙燻妝"],["烟熏火燎","煙熏火燎"],["烟燄障天","煙燄障天"],["烟爨","煙爨"],["烟生喉舌","煙生喉舌"],["烟瘴","煙瘴"],["烟瘾","煙癮"],["烟盒","煙盒"],["烟硝","煙硝"],["烟硝味","煙硝味"],["烟碱","菸鹼"],["烟碱酸","菸鹼酸"],["烟禁","菸禁"],["烟穗","煙穗"],["烟突","煙突"],["烟窝","煙窩"],["烟笼雾锁","煙籠霧鎖"],["烟筒","煙筒"],["烟筒山","煙筒山"],["烟管","煙管"],["烟管面","煙管麪"],["烟篷","煙篷"],["烟粉","煙粉"],["烟纸店","菸紙店"],["烟缕","煙縷"],["烟缸","菸缸"],["烟肉","煙肉"],["烟膏","煙膏"],["烟臭","煙臭"],["烟臭味","煙臭味"],["烟花","煙花"],["烟花债","煙花債"],["烟花厂","煙花廠"],["烟花场","煙花場"],["烟花女","煙花女"],["烟花寨","煙花寨"],["烟花寨主","煙花寨主"],["烟花巷","煙花巷"],["烟花市","煙花市"],["烟花柳巷","煙花柳巷"],["烟花窟","煙花窟"],["烟花簿","煙花簿"],["烟花粉柳","煙花粉柳"],["烟花粉黛","煙花粉黛"],["烟花行院","煙花行院"],["烟花门户","煙花門戶"],["烟花队","煙花隊"],["烟花阵","煙花陣"],["烟花风月","煙花風月"],["烟苗","煙苗"],["烟草","菸草"],["烟草味","菸草味"],["烟蒂","菸蒂"],["烟蓑雨笠","煙蓑雨笠"],["烟蚜","菸蚜"],["烟袋","菸袋"],["烟袋哨子","菸袋哨子"],["烟袋嘴","菸袋嘴"],["烟袋嘴儿","菸袋嘴兒"],["烟袋杆儿","菸袋桿兒"],["烟袋油子","菸袋油子"],["烟袋荷包","菸袋荷包"],["烟袋锅子","菸袋鍋子"],["烟视媚行","煙視媚行"],["烟酒","菸酒"],["烟酒不沾","煙酒不沾"],["烟酒公卖","菸酒公賣"],["烟酒公卖局","菸酒公賣局"],["烟酒税","菸酒稅"],["烟酸","煙酸"],["烟锅","煙鍋"],["烟雨","煙雨"],["烟雨楼","煙雨樓"],["烟雾","煙霧"],["烟雾剂","煙霧劑"],["烟雾弥漫","煙霧瀰漫"],["烟雾弹","煙霧彈"],["烟雾症","煙霧症"],["烟雾迷漫","煙霧迷漫"],["烟霏","煙霏"],["烟霏雾集","煙霏霧集"],["烟霏露结","煙霏露結"],["烟霞","煙霞"],["烟霞外人","煙霞外人"],["烟霞痼疾","煙霞痼疾"],["烟霞癖","煙霞癖"],["烟霭","煙靄"],["烟霾","煙霾"],["烟飞星散","煙飛星散"],["烟馆","煙館"],["烟鬟","煙鬟"],["烟鬼","煙鬼"],["烤个","烤個"],["烤了","烤了"],["烤干","烤乾"],["烤晒","烤曬"],["烤漆板","烤漆板"],["烤烟","烤煙"],["烤胡椒香肠","烤胡椒香腸"],["烤面包","烤麪包"],["烤面包机","烤麪包機"],["烦了","煩了"],["烦复","煩複"],["烦恼皆因强出头","煩惱皆因強出頭"],["烦死了","煩死了"],["烧了","燒了"],["烧出","燒出"],["烧出去","燒出去"],["烧出来","燒出來"],["烧制","燒製"],["烧尽","燒盡"],["烧干","燒乾"],["烧录","燒錄"],["烧录器","燒錄器"],["烧录机","燒錄機"],["烧杯","燒杯"],["烧杯架","燒杯架"],["烧毁","燒燬"],["烧炼","燒煉"],["烧糊了洗脸水","燒糊了洗臉水"],["烩面","燴麪"],["烫一个发","燙一個髮"],["烫一次发","燙一次髮"],["烫个","燙個"],["烫个发","燙個髮"],["烫出","燙出"],["烫发","燙髮"],["烫发师","燙髮師"],["烫头发","燙頭髮"],["烫完发","燙完髮"],["烫次发","燙次髮"],["烫蜡","燙蠟"],["烫衣板","燙衣板"],["烫面","燙麪"],["烬余","燼餘"],["热出病来","熱出病來"],["热功当量","熱功當量"],["热发光剂量计","熱發光劑量計"],["热合","熱合"],["热干面","熱乾麪"],["热当量","熱當量"],["热核","熱核"],["热电厂","熱電廠"],["热症","熱症"],["热脉冲","熱脈衝"],["热药","熱藥"],["热衷于","熱衷於"],["热量表","熱量表"],["热闹哄哄","熱鬧哄哄"],["烹制","烹製"],["烹调术","烹調術"],["烽火台","烽火臺"],["烽烟","烽煙"],["烽烟四起","烽煙四起"],["烽烟四起战火纷飞","烽煙四起戰火紛飛"],["烽烟遍地","烽煙遍地"],["焉耆回族自治县","焉耆回族自治縣"],["焊了","焊了"],["焊出","焊出"],["焊接艺术","焊接藝術"],["焕别","煥別"],["焕发","煥發"],["焕发起来","煥發起來"],["焙干","焙乾"],["焚修","焚修"],["焚化厂","焚化廠"],["焚尸","焚屍"],["焚尸扬灰","焚屍揚灰"],["焚尸案","焚屍案"],["焚尸炉","焚屍爐"],["焚毁","焚燬"],["無言不仇","無言不讎"],["焦了","焦了"],["焦化厂","焦化廠"],["焦干","焦乾"],["焦急万分","焦急萬分"],["焦获","焦穫"],["焦虑症","焦慮症"],["焦面大士","焦面大士"],["焰彩","焰彩"],["然后","然後"],["然后就","然後就"],["然身死才数月耳","然身死纔數月耳"],["煅炼","煅煉"],["煎个","煎個"],["煎了","煎了"],["煎出","煎出"],["煎药","煎藥"],["煎药法","煎藥法"],["煎蛋卷","煎蛋卷"],["煎面","煎麪"],["煞费周章","煞費周章"],["煤核","煤核"],["煤气工厂","煤氣工廠"],["煤气表","煤氣表"],["煤烟","煤煙"],["煤系","煤系"],["煤铲","煤鏟"],["照个","照個"],["照了","照了"],["照价","照價"],["照价征税","照價徵稅"],["照价收买","照價收買"],["照价收购","照價收購"],["照价赔偿","照價賠償"],["照入签","照入籤"],["照准","照準"],["照出","照出"],["照出去","照出去"],["照出来","照出來"],["照占","照佔"],["照发","照發"],["照台","照臺"],["照后镜","照後鏡"],["照录","照錄"],["照相制版","照相製版"],["照相干片","照相乾片"],["照相术","照相術"],["照签","照簽"],["照签不误","照簽不誤"],["照表","照表"],["照面","照面"],["煨干","煨乾"],["煨干就湿","煨乾就溼"],["煨干避湿","煨乾避溼"],["煮个","煮個"],["煮出","煮出"],["煮出来","煮出來"],["煮字疗饥","煮字療飢"],["煮沸后","煮沸後"],["煮熟的鸭子飞了","煮熟的鴨子飛了"],["煮粥焚须","煮粥焚鬚"],["煮面","煮麪"],["煴斗","熅斗"],["熄了","熄了"],["熊克武","熊克武"],["熊据虎跱","熊據虎跱"],["熏习","熏習"],["熏人","燻人"],["熏制","熏製"],["熏天","熏天"],["熏染","薰染"],["熏沐","薰沐"],["熏烝","熏烝"],["熏烤","燻烤"],["熏熏","熏熏"],["熏笼","熏籠"],["熏肉","燻肉"],["熏腐","熏腐"],["熏草","燻草"],["熏草纸","燻草紙"],["熏蒸","燻蒸"],["熏蒸剂","熏蒸劑"],["熏蒸室","熏蒸室"],["熏衣草","熏衣草"],["熏赫","燻赫"],["熏鑪","燻鑪"],["熏陶","薰陶"],["熏陶成性","熏陶成性"],["熏风","薰風"],["熏风徐来","熏風徐來"],["熏香","薰香"],["熏鱼儿","燻魚兒"],["熏鸡","燻雞"],["熏黑","燻黑"],["熏黑了","燻黑了"],["熔于","熔於"],["熔合","熔合"],["熔岩","熔岩"],["熔岩流","熔岩流"],["熔岩湖","熔岩湖"],["熔岩穹丘","熔岩穹丘"],["熔核","熔核"],["熔毁","熔燬"],["熔炼","熔鍊"],["熔炼炉","熔煉爐"],["熔融岩浆","熔融岩漿"],["熟了","熟了"],["熟念","熟念"],["熟药","熟藥"],["熟读王叔和不如临症多","熟讀王叔和不如臨症多"],["熟面人","熟面人"],["熟面孔","熟面孔"],["熨斗","熨斗"],["熬出","熬出"],["熬出头","熬出頭"],["熬出来","熬出來"],["熬制","熬製"],["熬姜呷醋","熬薑呷醋"],["熬炼","熬煉"],["熬药","熬藥"],["熬药汤","熬藥湯"],["燃尽","燃盡"],["燃料处理厂","燃料處理廠"],["燃料组合","燃料組合"],["燃气电厂","燃氣電廠"],["燎发","燎髮"],["燔针","燔針"],["燕云十六州","燕雲十六州"],["燕几","燕几"],["燕台","燕臺"],["燕巢于幕","燕巢於幕"],["燕昭筑台","燕昭築臺"],["燕游","燕遊"],["燕燕于飞","燕燕于飛"],["燕雀安知鸿鹄之志","燕雀安知鴻鵠之志"],["燕雀焉知鸿鹄之志","燕雀焉知鴻鵠之志"],["爆出","爆出"],["爆发","爆發"],["爆发出","爆發出"],["爆发出来","爆發出來"],["爆发力","爆發力"],["爆发性","爆發性"],["爆发星","爆發星"],["爆发音","爆發音"],["爆扣","爆扣"],["爆破术","爆破術"],["爬出","爬出"],["爬出去","爬出去"],["爬出来","爬出來"],["爬升","爬升"],["爬回","爬回"],["爬满了","爬滿了"],["爬虫","爬蟲"],["爬虫动物","爬蟲動物"],["爬虫类","爬蟲類"],["爬虫类动物","爬蟲類動物"],["爰历篇","爰歷篇"],["爱丽丝梦游记","愛麗絲夢遊記"],["爱丽丝漫游奇境记","愛麗絲漫遊奇境記"],["爱丽舍宫","愛麗捨宮"],["爱之欲其生恶之欲其死","愛之欲其生惡之欲其死"],["爱之适足以害之","愛之適足以害之"],["爱乐乐团","愛樂樂團"],["爱了","愛了"],["爱别离苦","愛別離苦"],["爱困","愛睏"],["爱在心里","愛在心裏"],["爱幸","愛幸"],["爱弥儿","愛彌兒"],["爱彼表","愛彼錶"],["爱德蒙","愛德蒙"],["爱心刮刮乐","愛心刮刮樂"],["爱心彩券","愛心彩券"],["爱念","愛念"],["爱恶分明","愛惡分明"],["爱情征服一切","愛情征服一切"],["爱情里","愛情裏"],["爱才","愛才"],["爱才好士","愛才好士"],["爱才如命","愛才如命"],["爱才若渴","愛才若渴"],["爱抽烟","愛抽菸"],["爱欲","愛慾"],["爱游玩","愛遊玩"],["爱管闲事","愛管閒事"],["爱莫大于心死","愛莫大於心死"],["爱远恶近","愛遠惡近"],["爱里","愛裏"],["爱面子","愛面子"],["爲了","爲了"],["爲幸","爲幸"],["爲恶","爲惡"],["爵仇","爵仇"],["父党","父黨"],["父台","父臺"],["父子同牝","父子同牝"],["父权制","父權制"],["父母两系血统主义","父母兩系血統主義"],["父母在不远游","父母在不遠游"],["父系","父系"],["父系亲属","父系親屬"],["父系制度","父系制度"],["爷娘","爺孃"],["爷羹娘饭","爺羹孃飯"],["爷饭娘羹","爺飯孃羹"],["爹娘","爹孃"],["爽荡","爽蕩"],["牀头柜","牀頭櫃"],["牀头金尽","牀頭金盡"],["片云遮顶","片雲遮頂"],["片价","片價"],["片善小才","片善小才"],["片头曲","片頭曲"],["片尾曲","片尾曲"],["片岩","片岩"],["片甲不回","片甲不回"],["片石千钧","片石千鈞"],["片纸只字","片紙隻字"],["片言只字","片言隻字"],["片言只语","片言隻語"],["片言折狱","片言折獄"],["片语只字","片語隻字"],["片语只辞","片語隻辭"],["片面","片面"],["片面之言","片面之言"],["片面之词","片面之詞"],["片面性","片面性"],["片面最惠国","片面最惠國"],["片麻岩","片麻岩"],["版筑","版築"],["版面","版面"],["牉合","牉合"],["牌价","牌價"],["牌子曲","牌子曲"],["牌板","牌板"],["牌面","牌面"],["牒发","牒發"],["牖里","牖里"],["牙买加胡椒","牙買加胡椒"],["牙克石","牙克石"],["牙克石市","牙克石市"],["牙医系","牙醫系"],["牙后慧","牙後慧"],["牙周","牙周"],["牙周炎","牙周炎"],["牙周病","牙周病"],["牙机巧制","牙機巧制"],["牙板","牙板"],["牙签","牙籤"],["牙签万轴","牙籤萬軸"],["牙签犀轴","牙籤犀軸"],["牙签玉轴","牙籤玉軸"],["牙签锦轴","牙籤錦軸"],["牙籤万轴","牙籤萬軸"],["牙缝里","牙縫裏"],["牙虫","牙蟲"],["牙雕","牙雕"],["牙齿咬合不正","牙齒咬合不正"],["牛仔布","牛仔布"],["牛只","牛隻"],["牛后","牛後"],["牛回磨转","牛回磨轉"],["牛头马面","牛頭馬面"],["牛李党争","牛李黨爭"],["牛柳面","牛柳麪"],["牛肉干","牛肉乾"],["牛肉拉面","牛肉拉麪"],["牛肉汤面","牛肉湯麪"],["牛肉炒面","牛肉炒麪"],["牛肉面","牛肉麪"],["牛肉面节","牛肉麪節"],["牛舍","牛舍"],["牛表牛觔","牛表牛觔"],["牛角挂书","牛角掛書"],["牛角面包","牛角麪包"],["牛骥同一皁","牛驥同一皁"],["牛骥同槽","牛驥同槽"],["牛骥同皁","牛驥同皁"],["牛骥同皂","牛驥同皂"],["牡丹虽好全仗绿叶扶","牡丹雖好全仗綠葉扶"],["牡丹虽好全仗绿叶扶持","牡丹雖好全仗綠葉扶持"],["牡丹虽好全凭绿叶扶持","牡丹雖好全憑綠葉扶持"],["牡丹虽好终须绿叶扶持","牡丹雖好終須綠葉扶持"],["牢靠妥当","牢靠妥當"],["牧神午后","牧神午後"],["物产丰富","物產豐富"],["物件导向","物件導向"],["物价","物價"],["物价指数","物價指數"],["物价督导会报","物價督導會報"],["物尽其用","物盡其用"],["物极则衰","物極則衰"],["物极必反","物極必反"],["物欲","物慾"],["物欲世界","物慾世界"],["物欲横流","物慾橫流"],["物流系统","物流系統"],["物理系","物理系"],["物种","物種"],["物种来由","物種來由"],["物种起源","物種起源"],["物美价廉","物美價廉"],["物腐虫生","物腐蟲生"],["物色人才","物色人才"],["物阜民丰","物阜民豐"],["牲干下","牲幹下"],["牵一发","牽一髮"],["牵一发而动全身","牽一髮而動全身"],["牵三挂四","牽三掛四"],["牵了","牽了"],["牵五挂四","牽五掛四"],["牵出","牽出"],["牵出去","牽出去"],["牵出来","牽出來"],["牵制","牽制"],["牵制行动","牽制行動"],["牵合","牽合"],["牵合附会","牽合附會"],["牵回","牽回"],["牵回去","牽回去"],["牵回来","牽回來"],["牵引出","牽引出"],["牵引发电机","牽引發電機"],["牵彩","牽彩"],["牵心挂肠","牽心掛腸"],["牵念","牽念"],["牵挂","牽掛"],["牵机药","牽機藥"],["牵籐带叶","牽籐帶葉"],["牵系","牽繫"],["牵肚挂肠","牽肚掛腸"],["牵肠挂肚","牽腸掛肚"],["特于","特於"],["特价","特價"],["特价品","特價品"],["特价菜","特價菜"],["特使团","特使團"],["特克斯","特克斯"],["特克斯县","特克斯縣"],["特克斯市","特克斯市"],["特克斯河","特克斯河"],["特内里费","特內里費"],["特准","特准"],["特出","特出"],["特别","特別"],["特别任务连","特別任務連"],["特别公积","特別公積"],["特别公积金","特別公積金"],["特别刑法","特別刑法"],["特别助理","特別助理"],["特别卖力","特別賣力"],["特别号","特別號"],["特别奖","特別獎"],["特别客串","特別客串"],["特别座","特別座"],["特别待遇","特別待遇"],["特别感谢","特別感謝"],["特别扣除额","特別扣除額"],["特别护士","特別護士"],["特别护理","特別護理"],["特别报导","特別報導"],["特别报道","特別報道"],["特别提款权","特別提款權"],["特别是","特別是"],["特别来宾","特別來賓"],["特别法","特別法"],["特别版","特別版"],["特别组","特別組"],["特别股","特別股"],["特别致","特別緻"],["特别节目","特別節目"],["特别行政区","特別行政區"],["特别费","特別費"],["特别费案","特別費案"],["特别长","特別長"],["特别门诊","特別門診"],["特制","特製"],["特制住","特制住"],["特制品","特製品"],["特制定","特制定"],["特制止","特制止"],["特制订","特制訂"],["特地回","特地回"],["特征","特徵"],["特征值","特徵值"],["特征向量","特徵向量"],["特征多项式","特徵多項式"],["特征联合","特徵聯合"],["特惠价","特惠價"],["特惠制度","特惠制度"],["特技团","特技團"],["特效药","特效藥"],["特有种","特有種"],["特松加","特松加"],["特林布","特林布"],["特殊性向","特殊性向"],["特殊才能","特殊才能"],["特种","特種"],["特种作战","特種作戰"],["特种兵","特種兵"],["特种工艺","特種工藝"],["特种文书","特種文書"],["特种空勤团","特種空勤團"],["特种考试","特種考試"],["特种行业","特種行業"],["特种警察","特種警察"],["特种部队","特種部隊"],["特种钢","特種鋼"],["特艺彩色","特藝彩色"],["特蒙德","特蒙德"],["特里","特里"],["特里尔","特里爾"],["犁板","犁板"],["犬只","犬隻"],["犬牙相制","犬牙相制"],["犯了","犯了"],["犯台","犯臺"],["犯奸","犯奸"],["犯恶","犯惡"],["犯罪团伙","犯罪團伙"],["犯罪集团","犯罪集團"],["犵党","犵黨"],["状态参数","狀態參數"],["状态表","狀態表"],["犹太历","猶太曆"],["犹太复国主义","猶太復國主義"],["犹太复国主义者","猶太復國主義者"],["犹太复国运动","猶太復國運動"],["犹如表","猶如錶"],["犹如钟","猶如鐘"],["犹如钟表","猶如鐘錶"],["狂占","狂佔"],["狂并潮","狂併潮"],["狂想曲","狂想曲"],["狂搜","狂搜"],["狂牛症","狂牛症"],["狂花病叶","狂花病葉"],["狂荡","狂蕩"],["狂药","狂藥"],["狃于","狃於"],["狃于成见","狃於成見"],["狄仁杰","狄仁傑"],["狄克","狄克"],["狄克森","狄克森"],["狄志杰","狄志杰"],["狄拉克","狄拉克"],["狄里斯","狄里斯"],["狎妓冶游","狎妓冶游"],["狎游","狎遊"],["狐借虎威","狐藉虎威"],["狐朋狗党","狐朋狗黨"],["狐群狗党","狐羣狗黨"],["狐裘蒙戎","狐裘蒙戎"],["狗党狐群","狗黨狐羣"],["狗占马坑","狗占馬坑"],["狗口里吐不出象牙","狗口裏吐不出象牙"],["狗嘴里","狗嘴裏"],["狗嘴里还有象牙","狗嘴裏還有象牙"],["狗娘养的","狗孃養的"],["狗才","狗才"],["狗扣","狗釦"],["狗杂种","狗雜種"],["狗皮膏药","狗皮膏藥"],["狗链","狗鏈"],["狞恶","獰惡"],["狞恶可怖","獰惡可怖"],["狠了","狠了"],["狠干","狠幹"],["狠恶","狠惡"],["独具只眼","獨具隻眼"],["独出一时","獨出一時"],["独出心裁","獨出心裁"],["独出机杼","獨出機杼"],["独占","獨佔"],["独占事业","獨佔事業"],["独占市场","獨佔市場"],["独占性","獨佔性"],["独占权","獨佔權"],["独占花魁","獨佔花魁"],["独占资本","獨佔資本"],["独占鳌头","獨佔鰲頭"],["独占鼇头","獨佔鼇頭"],["独唱曲","獨唱曲"],["独奏曲","獨奏曲"],["独尊儒术","獨尊儒術"],["独当","獨當"],["独当一面","獨當一面"],["独挑大梁","獨挑大樑"],["独擅胜场","獨擅勝場"],["独曲","獨曲"],["独根孤种","獨根孤種"],["独步当时","獨步當時"],["独立党","獨立黨"],["独立出来","獨立出來"],["独立千古","獨立千古"],["独立国家联合体","獨立國家聯合體"],["独立悬吊系统","獨立懸吊系統"],["独自个","獨自個"],["独辟蹊径","獨闢蹊徑"],["独钟","獨鍾"],["狭心症","狹心症"],["狭谷","狹谷"],["狮坛","獅壇"],["狮身人面像","獅身人面像"],["狱里","獄裏"],["狼仆","狼僕"],["狼卜食","狼卜食"],["狼吞虎咽","狼吞虎嚥"],["狼心狗幸","狼心狗幸"],["狼来了","狼來了"],["狼烟","狼煙"],["狼烟四起","狼煙四起"],["狼狈万状","狼狽萬狀"],["狼狈为奸","狼狽爲奸"],["狼虎药","狼虎藥"],["狼飧虎咽","狼飧虎嚥"],["狼餐虎咽","狼餐虎嚥"],["猎狩终极","獵狩終極"],["猎获","獵獲"],["猎获物","獵獲物"],["猛个劲","猛個勁"],["猛于","猛於"],["猛冲","猛衝"],["猛升","猛升"],["猛可里","猛可裏"],["猛回头","猛回頭"],["猛地里","猛地裏"],["猛干","猛幹"],["猛药","猛藥"],["猜三划五","猜三划五"],["猜出","猜出"],["猜出来","猜出來"],["猜得出","猜得出"],["猜测出","猜測出"],["猝发","猝發"],["猢狲入布袋","猢猻入布袋"],["猥当大任","猥當大任"],["猪八戒吃人参果","豬八戒吃人參果"],["猪只","豬隻"],["猪肉干","豬肉乾"],["猪肝面","豬肝麪"],["猪脚面","豬腳麪"],["猪脚面线","豬腳麪線"],["猪舌面","豬舌麪"],["猪舍","豬舍"],["猪链球菌","豬鏈球菌"],["猪链球菌病","豬鏈球菌病"],["猫儿见了鱼鲜饭","貓兒見了魚鮮飯"],["猫鼠同眠","貓鼠同眠"],["猫鼠游戏","貓鼠遊戲"],["献丑","獻醜"],["献了","獻了"],["献出","獻出"],["献台","獻臺"],["猴面包","猴麪包"],["猴面包树","猴麪包樹"],["猿鹤沙虫","猿鶴沙蟲"],["猿鹤虫沙","猿鶴蟲沙"],["獑胡","獑胡"],["獠面","獠面"],["玄了","玄了"],["玄云","玄雲"],["玄冬","玄冬"],["玄制","玄製"],["玄参","玄蔘"],["玄机暗藏","玄機暗藏"],["玄武岩","玄武岩"],["玄武质熔岩","玄武質熔岩"],["玄胄","玄胄"],["玄针","玄鍼"],["玄黄翻复","玄黃翻覆"],["率先垂范","率先垂範"],["率同","率同"],["率团","率團"],["率团参加","率團參加"],["率土同庆","率土同慶"],["玉制","玉製"],["玉勒雕鞍","玉勒雕鞍"],["玉卮无当","玉卮無當"],["玉历","玉曆"],["玉参差","玉參差"],["玉台","玉臺"],["玉台体","玉臺體"],["玉台新咏","玉臺新詠"],["玉叶金枝","玉葉金枝"],["玉叶金柯","玉葉金柯"],["玉叶金花","玉葉金花"],["玉尺量才","玉尺量才"],["玉山杯","玉山杯"],["玉帘","玉簾"],["玉手纤纤","玉手纖纖"],["玉斗","玉斗"],["玉杯","玉杯"],["玉枝卜寿","玉枝卜壽"],["玉石同沉","玉石同沉"],["玉石同烬","玉石同燼"],["玉石同焚","玉石同焚"],["玉米淀粉","玉米澱粉"],["玉米面","玉米麪"],["玉米须","玉米鬚"],["玉纤","玉纖"],["玉虫","玉蟲"],["玉里","玉里"],["玉里镇","玉里鎮"],["玉镜台","玉鏡臺"],["玉雕","玉雕"],["玉面","玉面"],["玉面貍","玉面貍"],["王于真","王于真"],["王云五","王雲五"],["王佐之才","王佐之才"],["王余鱼","王餘魚"],["王侯后","王侯后"],["王公贵戚","王公貴戚"],["王制","王制"],["王台","王臺"],["王后","王后"],["王太后","王太后"],["王婆卖瓜自卖自夸","王婆賣瓜自賣自誇"],["王婆子卖了磨","王婆子賣了磨"],["王子犯法与庶民同罪","王子犯法與庶民同罪"],["王子面","王子麪"],["王干发","王乾發"],["王幸男","王幸男"],["王庄","王莊"],["王彩桦","王彩樺"],["王彩碧","王彩碧"],["王志华","王志華"],["王志文","王志文"],["王志群","王志羣"],["王志贞","王志貞"],["王杰","王傑"],["王杰胜","王傑勝"],["王正杰","王正杰"],["王母娘娘","王母娘娘"],["王涂发","王塗發"],["王熙松","王熙松"],["王献极","王獻極"],["王秋凤","王秋鳳"],["王者风范","王者風範"],["王茂松","王茂松"],["王蒙","王蒙"],["王鉴","王鑑"],["玛斯克","瑪斯克"],["玛曲","瑪曲"],["玛曲县","瑪曲縣"],["玛泰克","瑪泰克"],["玢岩","玢岩"],["玩了","玩了"],["玩具厂","玩具廠"],["玩出","玩出"],["玩出去","玩出去"],["玩出来","玩出來"],["玩团","玩團"],["玩物丧志","玩物喪志"],["环保斗士","環保鬥士"],["环安系","環安系"],["环工系","環工系"],["环扣","環扣"],["环极涡旋","環極渦旋"],["环游","環遊"],["环游世界","環遊世界"],["环球定位系统","環球定位系統"],["环面","環面"],["环顾四周","環顧四周"],["现于","現於"],["现代修正主义","現代修正主義"],["现代建筑","現代建築"],["现代舞团","現代舞團"],["现代艺术","現代藝術"],["现代集团","現代集團"],["现出","現出"],["现出原形","現出原形"],["现出原身","現出原身"],["现制性","現制性"],["现场表演","現場表演"],["现场采访","現場採訪"],["现实面","現實面"],["现货价","現貨價"],["现进现出","現進現出"],["现金流量表","現金流量表"],["玳梁","玳梁"],["玳瑁梁","玳瑁梁"],["玻璃布","玻璃布"],["玻璃杯","玻璃杯"],["玻璃板","玻璃板"],["玻璃柜","玻璃櫃"],["玻璃浮雕","玻璃浮雕"],["玻璃纤维","玻璃纖維"],["玻里尼西","玻里尼西"],["玻里尼西亚人","玻里尼西亞人"],["珂里","珂里"],["珊卓布拉克","珊卓布拉克"],["珊瑚虫","珊瑚蟲"],["珍同拱璧","珍同拱璧"],["珍娜杰克森","珍娜傑克森"],["珍珠岩","珍珠岩"],["珍珠项链","珍珠項鍊"],["珍肴异馔","珍餚異饌"],["珐瑯彩","琺瑯彩"],["珠帘","珠簾"],["珠斗烂班","珠斗爛班"],["珠联璧合","珠聯璧合"],["珠胎暗结","珠胎暗結"],["珠还合浦","珠還合浦"],["班代表","班代表"],["班克劳夫","班克勞夫"],["班克拉夫特","班克拉夫特"],["班克斯","班克斯"],["班兰叶","班蘭葉"],["班别","班別"],["班师回朝","班師回朝"],["班游","班遊"],["班艾伏列克","班艾伏列克"],["班艾佛列克","班艾佛列克"],["班里","班裏"],["球台","球檯"],["球后","球后"],["球后小","球后小"],["球后艾宁","球后艾寧"],["球后辛吉丝","球后辛吉絲"],["球团","球團"],["球团矿","球團礦"],["球坛","球壇"],["球坛上","球壇上"],["球杆","球杆"],["球状星团","球狀星團"],["球面","球面"],["球面三角","球面三角"],["球面体","球面體"],["球面几何","球面幾何"],["球面几何学","球面幾何學"],["球面镜","球面鏡"],["琅邪台刻石","琅邪臺刻石"],["理一个发","理一個髮"],["理一次发","理一次髮"],["理不胜辞","理不勝辭"],["理个","理個"],["理个发","理個髮"],["理了","理了"],["理事长杯","理事長盃"],["理出","理出"],["理出头绪","理出頭緒"],["理发","理髮"],["理发匠","理髮匠"],["理发厅","理髮廳"],["理发员","理髮員"],["理发师","理髮師"],["理发师傅","理髮師傅"],["理发店","理髮店"],["理发院","理髮院"],["理合","理合"],["理固当然","理固當然"],["理头发","理頭髮"],["理完发","理完髮"],["理当","理當"],["理当如此","理當如此"],["理念","理念"],["理所当然","理所當然"],["理次发","理次髮"],["理胡子","理鬍子"],["理致","理致"],["琉璃厂","琉璃廠"],["琐才","瑣才"],["琛板","琛板"],["琨玉秋霜","琨玉秋霜"],["琴弦","琴絃"],["琴断朱弦","琴斷朱絃"],["琴斯托霍瓦","琴斯托霍瓦"],["琴杆","琴桿"],["琴钟","琴鐘"],["琵琶别抱","琵琶別抱"],["琵琶录","琵琶錄"],["琵琶虫","琵琶蟲"],["琼台玉宇","瓊臺玉宇"],["琼台玉阁","瓊臺玉閣"],["琼枝玉叶","瓊枝玉葉"],["琼瑶曲","瓊瑤曲"],["瑜伽术","瑜伽術"],["瑜珈术","瑜珈術"],["瑞丰","瑞豐"],["瑞云","瑞雲"],["瑞克","瑞克"],["瑞克希","瑞克希"],["瑞士卷","瑞士捲"],["瑞征","瑞徵"],["瑞气祥云","瑞氣祥雲"],["瑞秋","瑞秋"],["瑞秋怀兹","瑞秋懷茲"],["瑞穗","瑞穗"],["瑞穗乡","瑞穗鄉"],["瑞签","瑞簽"],["瑞贝里","瑞貝里"],["瑞郎方面","瑞郎方麪"],["瑟瑟发抖","瑟瑟發抖"],["瑟瑟秋风","瑟瑟秋風"],["瑶台","瑤臺"],["瑶台琼室","瑤臺瓊室"],["瑶台银阙","瑤臺銀闕"],["瑶台镜","瑤臺鏡"],["瑶签","瑤籤"],["璅虫","璅蟲"],["璧合","璧合"],["璧合珠联","璧合珠聯"],["璧合珠连","璧合珠連"],["璧回","璧回"],["璧炉台","璧爐臺"],["瓠叶","瓠葉"],["瓢虫","瓢蟲"],["瓦利泰克","瓦利泰克"],["瓦历斯","瓦歷斯"],["瓦合","瓦合"],["瓦合之卒","瓦合之卒"],["瓦尔基里","瓦爾基里"],["瓦尔达克","瓦爾達克"],["瓦尔达克省","瓦爾達克省"],["瓦当","瓦當"],["瓦当文","瓦當文"],["瓦松","瓦松"],["瓦特表","瓦特表"],["瓦瑞泰克","瓦瑞泰克"],["瓦舍","瓦舍"],["瓦萨里","瓦薩里"],["瓦西里","瓦西里"],["瓦西里耶维奇","瓦西裏耶維奇"],["瓦解云散","瓦解雲散"],["瓦达克","瓦達克"],["瓦里","瓦里"],["瓦里斯","瓦里斯"],["瓮安","甕安"],["瓶坠簪折","瓶墜簪折"],["瓷杯","瓷杯"],["甄别","甄別"],["甄别考试","甄別考試"],["甄后","甄后"],["甄奇录异","甄奇錄異"],["甄才品能","甄才品能"],["甄选人才","甄選人才"],["甕尽杯干","甕盡杯乾"],["甕里醯鸡","甕裏醯雞"],["甘于","甘於"],["甘居下游","甘居下游"],["甘巴里","甘巴里"],["甘当","甘當"],["甘心情愿","甘心情願"],["甘愿","甘願"],["甘托克","甘托克"],["甘谷","甘谷"],["甘谷县","甘谷縣"],["甚么","甚麼"],["甚么都干","甚麼都幹"],["甚于","甚於"],["甚至于","甚至於"],["甚获","甚獲"],["甚获好评","甚獲好評"],["甜水面","甜水麪"],["甜萝卜","甜蘿蔔"],["甜面酱","甜麪醬"],["甜面醬","甜麪醬"],["生个","生個"],["生了","生了"],["生于","生於"],["生于忧患","生於憂患"],["生于忧患死于安乐","生於憂患死於安樂"],["生产合作","生產合作"],["生产合作社","生產合作社"],["生产斗争","生產鬥爭"],["生产管制","生產管制"],["生佛万家","生佛萬家"],["生出","生出"],["生出来","生出來"],["生刍致祭","生芻致祭"],["生别死离","生別死離"],["生力面","生力麪"],["生华发","生華髮"],["生发","生髮"],["生发剂","生髮劑"],["生发水","生髮水"],["生发药","生髮藥"],["生同衾死同穴","生同衾死同穴"],["生命不息战斗不止","生命不息戰鬥不止"],["生命共同体","生命共同體"],["生命周期","生命週期"],["生命在于运动","生命在於運動"],["生命征象","生命徵象"],["生命表","生命表"],["生姜","生薑"],["生姜丝","生薑絲"],["生姜汁","生薑汁"],["生姜片","生薑片"],["生字表","生字表"],["生布","生布"],["生态旅游","生態旅遊"],["生态环境游","生態環境游"],["生态系","生態系"],["生态系统","生態系統"],["生情发意","生情發意"],["生技医药","生技醫藥"],["生旦淨末丑","生旦淨末丑"],["生栋复屋","生棟覆屋"],["生死别离","生死別離"],["生死斗","生死鬥"],["生死未卜","生死未卜"],["生死轮回","生死輪迴"],["生殖洄游","生殖洄游"],["生殖系统","生殖系統"],["生民涂炭","生民塗炭"],["生活杯","生活杯"],["生活水准","生活水準"],["生活面","生活面"],["生涯规划","生涯規劃"],["生灵涂地","生靈塗地"],["生灵涂炭","生靈塗炭"],["生物伦琴当量","生物倫琴當量"],["生物制剂","生物製劑"],["生物制品","生物製品"],["生物合成","生物合成"],["生物学系","生物學系"],["生物弹药","生物彈藥"],["生物技术","生物技術"],["生物技术与制药工业发展推动小组","生物技術與製藥工業發展推動小組"],["生物时钟","生物時鐘"],["生物系","生物系"],["生物钟","生物鐘"],["生理时钟","生理時鐘"],["生田斗","生田斗"],["生离死别","生離死別"],["生药","生藥"],["生药局","生藥局"],["生词表","生詞表"],["生迭水准","生迭水準"],["生锈","生鏽"],["生长板","生長板"],["生面","生面"],["生面团","生麪糰"],["生面孔","生面孔"],["用一当十","用一當十"],["用不了","用不了"],["用于","用於"],["用于修饰","用於修飾"],["用作配种","用作配種"],["用出","用出"],["用字不当","用字不當"],["用尽","用盡"],["用尽心思","用盡心思"],["用尽心机","用盡心機"],["用尽方法","用盡方法"],["用幸福","用幸福"],["用志不分","用志不分"],["用户数据","用戶數據"],["用户界面","用戶界面"],["用报台","用報臺"],["用搜","用搜"],["用来配种","用來配種"],["用汇","用匯"],["用舍失宜","用舍失宜"],["用舍行藏","用舍行藏"],["用药","用藥"],["用行舍藏","用行舍藏"],["用词不当","用詞不當"],["甩出","甩出"],["甩出去","甩出去"],["甩出来","甩出來"],["甩发","甩髮"],["甩手掌柜","甩手掌櫃"],["甪里","甪里"],["田园交响曲","田園交響曲"],["田园曲","田園曲"],["田字面","田字面"],["田家庵","田家庵"],["田家庵区","田家庵區"],["田庄","田莊"],["田志兴","田志興"],["田父之获","田父之獲"],["田秋堇","田秋堇"],["田种玉","田種玉"],["田舍","田舍"],["田舍奴","田舍奴"],["田舍翁","田舍翁"],["田舍郎","田舍郎"],["田螺含水过冬","田螺含水過冬"],["田谷","田穀"],["田里","田裏"],["由于","由於"],["由余","由余"],["由恪志远","由恪志遠"],["由表及里","由表及裏"],["甲壳虫","甲殼蟲"],["甲壳虫类","甲殼蟲類"],["甲板","甲板"],["甲种","甲種"],["甲种体位","甲種體位"],["甲种国库券","甲種國庫券"],["甲种国民兵役","甲種國民兵役"],["甲种维生素","甲種維生素"],["甲第连云","甲第連雲"],["甲胄","甲冑"],["甲胄鱼类","甲冑魚類"],["甲虫","甲蟲"],["甲虫类","甲蟲類"],["甲虫车","甲蟲車"],["申复","申覆"],["申扎","申扎"],["申扎县","申扎縣"],["申曲","申曲"],["申请表","申請表"],["电价","電價"],["电冰柜","電冰櫃"],["电冲","電衝"],["电力厂","電力廠"],["电卷星飞","電卷星飛"],["电卷风驰","電卷風馳"],["电厂","電廠"],["电压表","電壓表"],["电台","電臺"],["电唱针","電唱針"],["电复","電覆"],["电子云","電子雲"],["电子反制","電子反制"],["电子学系","電子學系"],["电子布告栏","電子布告欄"],["电子店面","電子店面"],["电子数据交换","電子數據交換"],["电子杂志","電子雜誌"],["电子游戏","電子遊戲"],["电子看板","電子看板"],["电子系","電子系"],["电子表","電子錶"],["电子表单","電子表單"],["电子表情","電子表情"],["电子表格","電子表格"],["电子表示","電子表示"],["电子论坛","電子論壇"],["电子邮件系统","電子郵件系統"],["电子钟","電子鐘"],["电子钟表","電子鐘錶"],["电宰厂","電宰廠"],["电度表","電度表"],["电影分级制","電影分級制"],["电影制作","電影製作"],["电影制片","電影製片"],["电影台","電影臺"],["电影回顾展","電影回顧展"],["电影美术","電影美術"],["电影艺术","電影藝術"],["电影集团","電影集團"],["电机及电子学工程师联合会","電機及電子學工程師聯合會"],["电机系","電機系"],["电杆","電杆"],["电板","電板"],["电极","電極"],["电检制","電檢制"],["电汇","電匯"],["电池厂","電池廠"],["电池板","電池板"],["电流表","電流表"],["电热杯","電熱杯"],["电熨斗","電熨斗"],["电码表","電碼表"],["电磁干扰","電磁干擾"],["电磁振荡","電磁振盪"],["电磁脉冲","電磁脈衝"],["电线杆","電線杆"],["电缆调制解调器","電纜調制解調器"],["电胡刀","電鬍刀"],["电脑与电话系统整合","電腦與電話系統整合"],["电脑互动艺术","電腦互動藝術"],["电脑台","電腦檯"],["电脑周边设备","電腦周邊設備"],["电脑图书出版业","電腦圖書出版業"],["电脑彩喷","電腦彩噴"],["电脑游戏","電腦遊戲"],["电脑看板","電腦看板"],["电脑系统","電腦系統"],["电脑系统业","電腦系統業"],["电脑绘图技术","電腦繪圖技術"],["电脑网志","電腦網誌"],["电脑艺术","電腦藝術"],["电脑闸道系统","電腦閘道系統"],["电荷耦合","電荷耦合"],["电荷耦合器件","電荷耦合器件"],["电表","電錶"],["电视兴奋症","電視興奮症"],["电视台","電視臺"],["电视柜","電視櫃"],["电视游乐器","電視遊樂器"],["电视采访","電視採訪"],["电话录音","電話錄音"],["电话答录机","電話答錄機"],["电路板","電路板"],["电量表","電量表"],["电针","電針"],["电针麻醉","電針麻醉"],["电钟","電鐘"],["电铲","電鏟"],["电须刀","電鬚刀"],["男仆","男僕"],["男佣","男傭"],["男佣人","男傭人"],["男同学","男同學"],["男同志","男同志"],["男大当婚","男大當婚"],["男女有别","男女有別"],["男尸","男屍"],["男性厌恶","男性厭惡"],["男才女貌","男才女貌"],["男生宿舍","男生宿舍"],["男用表","男用錶"],["男系","男系"],["甸后","甸後"],["画了","畫了"],["画出","畫出"],["画出来","畫出來"],["画卷","畫卷"],["画坛","畫壇"],["画布","畫布"],["画板","畫板"],["画栋雕梁","畫棟雕樑"],["画栋飞云","畫棟飛雲"],["画梁雕栋","畫樑雕棟"],["画法几何","畫法幾何"],["画着","畫着"],["画表","畫表"],["画表格","畫表格"],["画阁朱楼","畫閣朱樓"],["画面","畫面"],["画饼充饥","畫餅充飢"],["畅所欲为","暢所欲爲"],["畅所欲言","暢所欲言"],["畅游","暢遊"],["畅销曲","暢銷曲"],["界分别观","界分別觀"],["界别","界別"],["界面","界面"],["畎亩下才","畎畝下才"],["畏于","畏於"],["畏影恶迹","畏影惡跡"],["留个","留個"],["留中不发","留中不發"],["留了","留了"],["留余地","留餘地"],["留出","留出"],["留别","留別"],["留发","留髮"],["留后","留後"],["留后手","留後手"],["留后步","留後步"],["留后路","留後路"],["留头发","留頭髮"],["留念","留念"],["留种","留種"],["留种地","留種地"],["留美同学会","留美同學會"],["留胡子","留鬍子"],["留胡须","留鬍鬚"],["留脸面","留臉面"],["留芳千古","留芳千古"],["留芳后世","留芳後世"],["留言板","留言板"],["留连不舍","留連不捨"],["留针","留針"],["留面子","留面子"],["畚斗","畚斗"],["略低于","略低於"],["略同","略同"],["略大于","略大於"],["略尽情谊","略盡情誼"],["略无参商","略無參商"],["略有出入","略有出入"],["略胜","略勝"],["略胜一筹","略勝一籌"],["略语表","略語表"],["略高于","略高於"],["番泻叶","番瀉葉"],["畸形发展","畸形發展"],["疋先里","疋先裏"],["疏于","疏於"],["疏于防备","疏於防備"],["疏于防范","疏於防範"],["疏松","疏鬆"],["疏松症","疏鬆症"],["疑云","疑雲"],["疑云重重","疑雲重重"],["疑信参半","疑信參半"],["疑凶","疑兇"],["疑团","疑團"],["疑心生暗鬼","疑心生暗鬼"],["疑念","疑念"],["疑核","疑核"],["疑系","疑係"],["疑难杂症","疑難雜症"],["疗饥","療飢"],["疟原虫","瘧原蟲"],["疟虫","瘧蟲"],["疥癣虫","疥癬蟲"],["疥虫","疥蟲"],["疯了","瘋了"],["疱疹性咽狭症","皰疹性咽狹症"],["疲于","疲於"],["疲于奔命","疲於奔命"],["疲劳极限","疲勞極限"],["疲劳症","疲勞症"],["疲困","疲睏"],["疵蒙谬累","疵蒙謬累"],["疾之如仇","疾之如仇"],["疾之若仇","疾之若仇"],["疾恶","疾惡"],["疾恶好善","疾惡好善"],["疾恶如仇","疾惡如仇"],["疾恶若仇","疾惡若仇"],["疾病控制中心","疾病控制中心"],["疾病突发","疾病突發"],["疾风扫秋叶","疾風掃秋葉"],["病了","病了"],["病从口入祸从口出","病從口入禍從口出"],["病余","病餘"],["病出","病出"],["病历","病歷"],["病历卡","病歷卡"],["病历室","病歷室"],["病历表","病歷表"],["病原虫","病原蟲"],["病发","病發"],["病后","病後"],["病后初愈","病後初愈"],["病后初癒","病後初癒"],["病容满面","病容滿面"],["病征","病徵"],["病愈","病癒"],["病毒血症","病毒血症"],["病毒防范","病毒防範"],["病症","病症"],["病舍","病舍"],["病虫","病蟲"],["病虫危害","病蟲危害"],["病虫害","病蟲害"],["症侯群","症侯羣"],["症候","症候"],["症候群","症候羣"],["症状","症狀"],["症状性","症狀性"],["症结","癥結"],["症结点","癥結點"],["痊愈","痊癒"],["痒了","癢了"],["痒疹","癢疹"],["痒痒","癢癢"],["痔核","痔核"],["痕迹","痕跡"],["痖弦","瘂弦"],["痘疹娘娘","痘疹娘娘"],["痛不欲生","痛不欲生"],["痛了","痛了"],["痛失英才","痛失英才"],["痛快淋漓","痛快淋漓"],["痛恶","痛惡"],["痛毁极诋","痛毀極詆"],["痛苦万分","痛苦萬分"],["痛赞","痛贊"],["痢疾杆菌","痢疾桿菌"],["痨虫","癆蟲"],["痫症","癇症"],["痰症","痰症"],["痲痹不了","痲痹不了"],["痲痺不了","痲痺不了"],["痴呆症","癡呆症"],["痴念","癡念"],["痴虫","癡蟲"],["瘅恶彰善","癉惡彰善"],["瘙痒症","瘙癢症"],["瘦了","瘦了"],["瘦小枯干","瘦小枯乾"],["瘫子掉在井里","癱子掉在井裏"],["癌症","癌症"],["癌症病患","癌症病患"],["癌症肿瘤","癌症腫瘤"],["癒合","癒合"],["癫痫症","癲癇症"],["癸丑","癸丑"],["登个","登個"],["登了","登了"],["登云梯","登雲梯"],["登出","登出"],["登出去","登出去"],["登出来","登出來"],["登台","登臺"],["登台拜将","登臺拜將"],["登台演唱","登臺演唱"],["登台表演","登臺表演"],["登坛","登壇"],["登坛拜将","登壇拜將"],["登峰造极","登峯造極"],["登庸人才","登庸人才"],["登录","登錄"],["登机手续柜台","登機手續櫃檯"],["登极","登極"],["登科录","登科錄"],["登记表","登記表"],["登革出血热","登革出血熱"],["登龙术","登龍術"],["發表","發表"],["白了了","白了了"],["白云","白雲"],["白云乡","白雲鄉"],["白云亲舍","白雲親舍"],["白云区","白雲區"],["白云孤飞","白雲孤飛"],["白云山","白雲山"],["白云岩","白雲岩"],["白云机场","白雲機場"],["白云母","白雲母"],["白云片片","白雲片片"],["白云石","白雲石"],["白云矿区","白雲礦區"],["白云苍狗","白雲蒼狗"],["白云观","白雲觀"],["白僵蚕","白殭蠶"],["白兔捣药","白兔搗藥"],["白净面皮","白淨面皮"],["白刀子进去红刀子出来","白刀子進去紅刀子出來"],["白化症","白化症"],["白千层","白千層"],["白卷","白卷"],["白发","白髮"],["白发人","白髮人"],["白发其事","白發其事"],["白发如新","白髮如新"],["白发朱颜","白髮朱顏"],["白发相守","白髮相守"],["白发红颜","白髮紅顏"],["白发苍苍","白髮蒼蒼"],["白发苍颜","白髮蒼顏"],["白发郎潜","白髮郎潛"],["白发银须","白髮銀鬚"],["白发青衫","白髮青衫"],["白发齐眉","白髮齊眉"],["白变种","白變種"],["白古苏花","白古蘇花"],["白合金","白合金"],["白喉杆菌","白喉桿菌"],["白团","白團"],["白团扇","白團扇"],["白垩系","白堊系"],["白娘子","白娘子"],["白布","白布"],["白干","白乾","白幹"],["白干儿","白乾兒"],["白当","白當"],["白得发亮","白得發亮"],["白搽白折","白搽白折"],["白斑症","白斑症"],["白日升天","白日昇天"],["白日飞升","白日飛昇"],["白术","白朮"],["白朴","白樸"],["白杆兵","白桿兵"],["白松","白松"],["白板","白板"],["白板单吊","白板單吊"],["白板天子","白板天子"],["白板笔","白板筆"],["白果松","白果松"],["白洋淀","白洋澱"],["白淨面皮","白淨面皮"],["白烟","白煙"],["白皮松","白皮松"],["白种","白種"],["白种人","白種人"],["白粉面","白粉麪"],["白胡","白鬍"],["白胡椒","白胡椒"],["白色人种","白色人種"],["白色系","白色系"],["白苏","白蘇"],["白苹","白蘋"],["白苹洲","白蘋洲"],["白药","白藥"],["白菜价","白菜價"],["白萝卜","白蘿蔔"],["白蒙蒙","白濛濛"],["白蜡","白蠟"],["白蜡明经","白蠟明經"],["白蜡杆子","白蠟杆子"],["白蜡树","白蠟樹"],["白蜡虫","白蠟蟲"],["白蜡蜡","白蠟蠟"],["白血球过多症","白血球過多症"],["白里安","白里安"],["白里透红","白裏透紅"],["白雪公主症候群","白雪公主症候羣"],["白雪曲","白雪曲"],["白霉","白黴"],["白面","白麪"],["白面书生","白面書生"],["白面书郎","白面書郎"],["白面僧面猴","白面僧面猴"],["白面儿","白麪兒"],["白面无须","白面無鬚"],["白面鼯鼠","白面鼯鼠"],["白须","白鬚"],["白首北面","白首北面"],["白首同归","白首同歸"],["白马归周","白馬歸周"],["白驹空谷","白駒空谷"],["白骨松","白骨松"],["白鹤梁","白鶴梁"],["白鹤秀才","白鶴秀才"],["百万","百萬"],["百万之众","百萬之衆"],["百万买宅千万买邻","百萬買宅千萬買鄰"],["百万位","百萬位"],["百万分之一","百萬分之一"],["百万吨","百萬噸"],["百万吨级核武器","百萬噸級核武器"],["百万富翁","百萬富翁"],["百万年","百萬年"],["百万赫兹","百萬赫茲"],["百万雄兵","百萬雄兵"],["百万雄师","百萬雄師"],["百不当一","百不當一"],["百个","百個"],["百中百发","百中百發"],["百了","百了"],["百了千当","百了千當"],["百事和合","百事和合"],["百余","百餘"],["百余只","百餘隻"],["百余里","百餘里"],["百几个","百幾個"],["百出","百出"],["百分之一千","百分之一千"],["百分制","百分制"],["百分表","百分表"],["百划","百劃"],["百卉千葩","百卉千葩"],["百发","百發"],["百发百中","百發百中"],["百只","百隻"],["百只足够","百只足夠"],["百叶","百葉"],["百叶卷","百葉捲"],["百叶窗","百葉窗"],["百叶窗帘","百葉窗簾"],["百叶箱","百葉箱"],["百合","百合"],["百合子","百合子"],["百合科","百合科"],["百合花","百合花"],["百合花饰","百合花飾"],["百团大战","百團大戰"],["百多只","百多隻"],["百天后","百天後"],["百姿千态","百姿千態"],["百媚千娇","百媚千嬌"],["百子千孙","百子千孫"],["百孔千创","百孔千創"],["百孔千疮","百孔千瘡"],["百尺竿头更尽一步","百尺竿頭更盡一步"],["百岁之后","百歲之後"],["百岁千秋","百歲千秋"],["百巧千穷","百巧千窮"],["百年之后","百年之後"],["百年后","百年後"],["百年好合","百年好合"],["百度表","百度表"],["百当","百當"],["百念","百念"],["百战百胜","百戰百勝"],["百扎","百紮"],["百折不回","百折不回"],["百折不挠","百折不撓"],["百折不挫","百折不挫"],["百折裙","百摺裙"],["百拙千丑","百拙千醜"],["百汇","百匯"],["百炼","百鍊"],["百炼成钢","百鍊成鋼"],["百科里","百科裏"],["百紫千红","百紫千紅"],["百纵千随","百縱千隨"],["百老汇","百老匯"],["百胜餐饮","百勝餐飲"],["百胜餐饮集团","百勝餐飲集團"],["百脑汇","百腦匯"],["百舍重茧","百舍重繭"],["百舍重趼","百舍重趼"],["百花历","百花曆"],["百花历史","百花歷史"],["百花娘子","百花娘子"],["百药之长","百藥之長"],["百虑一致","百慮一致"],["百计千心","百計千心"],["百计千方","百計千方"],["百计千谋","百計千謀"],["百谋千计","百謀千計"],["百谷","百穀"],["百谷王","百谷王"],["百足不僵","百足不僵"],["百足之虫","百足之蟲"],["百足之虫死而不僵","百足之蟲死而不僵"],["百足之虫至死不僵","百足之蟲至死不僵"],["百足虫","百足蟲"],["百辟","百辟"],["百里","百里"],["百里之才","百里之才"],["百里侯","百里侯"],["百里傒","百里傒"],["百里挑一","百裏挑一"],["百里香","百里香"],["百锻千练","百鍛千練"],["百面雷","百面雷"],["皂化","皂化"],["皂白","皁白"],["皂荚","皂莢"],["皂荚树","皂莢樹"],["皂角","皁角"],["的一确二","的一確二"],["的历","的歷"],["的当","的當"],["的扣","的扣"],["的杯","的杯"],["的核","的核"],["的泛","的泛"],["的的确确","的的確確"],["的确","的確"],["的确会","的確會"],["的确如此","的確如此"],["的确是","的確是"],["的确良","的確良"],["的钟","的鐘"],["的黎波里","的黎波里"],["皆准","皆準"],["皆可作淀","皆可作澱"],["皇亲国戚","皇親國戚"],["皇冠出版","皇冠出版"],["皇冠出版集团","皇冠出版集團"],["皇历","皇曆"],["皇后","皇后"],["皇后区","皇后區"],["皇后号","皇后號"],["皇后镇","皇后鎮"],["皇天后土","皇天后土"],["皇太后","皇太后"],["皇太极","皇太極"],["皇太极清太宗","皇太極清太宗"],["皇家加勒比海游轮公司","皇家加勒比海遊輪公司"],["皇家马德里","皇家馬德里"],["皇庄","皇莊"],["皇恩浩荡","皇恩浩蕩"],["皇极","皇極"],["皇极历","皇極曆"],["皇极历史","皇極歷史"],["皇极数","皇極數"],["皇胄","皇胄"],["皇辟","皇辟"],["皓发","皓髮"],["皓月千里","皓月千里"],["皓月当空","皓月當空"],["皓齿朱唇","皓齒硃脣"],["皓齿朱脣","皓齒朱脣"],["皖系军阀","皖系軍閥"],["皖系战败","皖系戰敗"],["皙面","皙面"],["皮下出血","皮下出血"],["皮下注射","皮下注射"],["皮克斯","皮克斯"],["皮克林","皮克林"],["皮克罗比","皮克羅比"],["皮划艇","皮划艇"],["皮划艇激流回旋","皮劃艇激流回旋"],["皮划艇静水","皮劃艇靜水"],["皮制","皮製"],["皮制品","皮製品"],["皮制服","皮制服"],["皮困秋","皮困秋"],["皮夹克","皮夾克"],["皮尔斯布洛斯南","皮爾斯布洛斯南"],["皮层下失语症","皮層下失語症"],["皮托管","皮托管"],["皮松","皮鬆"],["皮松肉紧","皮鬆肉緊"],["皮松骨痒","皮鬆骨癢"],["皮板儿","皮板兒"],["皮特拉克","皮特拉克"],["皮里抽肉","皮裏抽肉"],["皮里春秋","皮裏春秋"],["皮里晋书","皮裏晉書"],["皮里膜外","皮裏膜外"],["皮里走肉","皮裏走肉"],["皮里阳秋","皮裏陽秋"],["皮雕","皮雕"],["皮面","皮面"],["皱别","皺彆"],["皱叶欧芹","皺葉歐芹"],["皱折","皺摺"],["盆吊","盆吊"],["盆里","盆裏"],["盈余","盈餘"],["盈千累万","盈千累萬"],["盈千累百","盈千累百"],["盈泛","盈泛"],["盈盈秋水","盈盈秋水"],["盈车嘉穗","盈車嘉穗"],["盈馀加征","盈餘加徵"],["益于","益於"],["益发","益發"],["益州名画录","益州名畫錄"],["益虫","益蟲"],["益觉困难","益覺困難"],["益鸟益虫","益鳥益蟲"],["盎格鲁撒克逊","盎格魯撒克遜"],["盎格鲁萨克逊","盎格魯薩克遜"],["盎格鲁萨克逊人","盎格魯薩克遜人"],["盎盂相系","盎盂相繫"],["盐余","鹽餘"],["盐卤","鹽滷"],["盐城师范学院","鹽城師範學院"],["盐打怎么咸","鹽打怎麼鹹"],["盐打怎么咸醋打怎么酸","鹽打怎麼鹹醋打怎麼酸"],["盐水选种","鹽水選種"],["盐水针","鹽水針"],["盐酸克仑特罗","鹽酸克侖特羅"],["监修","監修"],["监制","監製"],["监听系统","監聽系統"],["监察御史","監察御史"],["监管不周","監管不周"],["监管体制","監管體制"],["监管范围","監管範圍"],["监系","監繫"],["盒子里","盒子裏"],["盒式录音带","盒式錄音帶"],["盒式录音磁带","盒式錄音磁帶"],["盒里","盒裏"],["盖世之才","蓋世之才"],["盖了","蓋了"],["盖了又盖","蓋了又蓋"],["盖于","蓋於"],["盖杯","蓋杯"],["盖板","蓋板"],["盖维克","蓋維克"],["盗录","盜錄"],["盗御马","盜御馬"],["盗无实据","盜無實據"],["盗版党","盜版黨"],["盗采","盜採"],["盗钟","盜鐘"],["盗钟掩耳","盜鐘掩耳"],["盘回","盤迴"],["盘扣","盤扣"],["盘据","盤據"],["盘旋曲折","盤旋曲折"],["盘曲","盤曲"],["盘术","盤術"],["盘松","盤松"],["盘游","盤遊"],["盘获","盤獲"],["盘谷","盤谷"],["盘里","盤裏"],["盘面","盤面"],["盛了","盛了"],["盛价","盛价"],["盛冬","盛冬"],["盛德遗范","盛德遺範"],["盛极一时","盛極一時"],["盛极必衰","盛極必衰"],["盛极而衰","盛極而衰"],["盛行于","盛行於"],["盛赞","盛讚"],["盟旗制度","盟旗制度"],["目前目后","目前目後"],["目力表","目力表"],["目录","目錄"],["目录卡","目錄卡"],["目录学","目錄學"],["目无余子","目無餘子"],["目标价","目標價"],["目牛游刃","目牛游刃"],["目眦尽裂","目眥盡裂"],["目瞪口僵","目瞪口僵"],["目瞪舌僵","目瞪舌僵"],["目短于自见","目短於自見"],["目视云霄","目視雲霄"],["目骇耳回","目駭耳回"],["盲干","盲幹"],["直上青云","直上青雲"],["直了","直了"],["直于","直於"],["直冲","直衝"],["直升","直升"],["直升机","直升機"],["直升飞机","直升飛機"],["直发","直髮"],["直发女","直髮女"],["直发毛","直發毛"],["直头布袋","直頭布袋"],["直布罗陀","直布羅陀"],["直布罗陀海峡","直布羅陀海峽"],["直截了当","直截了當"],["直捷了当","直捷了當"],["直接了当","直接了當"],["直接制版","直接制版"],["直接参与","直接參與"],["直接征税","直接徵稅"],["直接数据","直接數據"],["直接证据","直接證據"],["直摆","直襬"],["直杆","直杆"],["直流发电机","直流發電機"],["直系","直系"],["直系亲","直系親"],["直系亲属","直系親屬"],["直系军阀","直係軍閥"],["直系祖先","直系祖先"],["直系血亲","直系血親"],["直致","直致"],["直落布兰雅","直落布蘭雅"],["直言尽意","直言盡意"],["直言极谏","直言極諫"],["直进直出","直進直出"],["直链","直鏈"],["直销式传销制度","直銷式傳銷制度"],["直须","直須"],["相为表里","相爲表裏"],["相于","相於"],["相交满天下知心能几人","相交滿天下知心能幾人"],["相克","相剋"],["相克制","相剋制"],["相克服","相克服"],["相关系数","相關係數"],["相冲","相沖"],["相别","相別"],["相别多年","相別多年"],["相去万里","相去萬里"],["相去无几","相去無幾"],["相台","相臺"],["相叶雅纪","相葉雅紀"],["相合","相合"],["相同","相同"],["相同点","相同點"],["相向","相向"],["相奸","相姦"],["相对于","相對於"],["相对极","相對極"],["相差无几","相差無幾"],["相干","相干"],["相平面","相平面"],["相并","相併"],["相当","相當"],["相当于","相當於"],["相当于或大于","相當於或大於"],["相当程度","相當程度"],["相念","相念"],["相托","相托"],["相扣","相扣"],["相提并论","相提並論"],["相斗","相鬥"],["相术","相術"],["相生相克","相生相剋"],["相符合","相符合"],["相等于","相等於"],["相结合","相結合"],["相融合","相融合"],["相距千里","相距千里"],["相适应","相適應"],["相里","相里"],["相门出相","相門出相"],["相面","相面"],["相须为命","相須爲命"],["相须而行","相須而行"],["盼了","盼了"],["盼既示复","盼既示覆"],["盾板","盾板"],["省个","省個"],["省了","省了"],["省党部","省黨部"],["省出","省出"],["省出来","省出來"],["省欲去奢","省慾去奢"],["省民同胞","省民同胞"],["省道台","省道臺"],["眉分八彩","眉分八彩"],["眉南面北","眉南面北"],["眉垂目合","眉垂目合"],["眉毛胡子一把抓","眉毛鬍子一把抓"],["眉里","眉裏"],["眉面","眉面"],["看上了","看上了"],["看下表","看下錶"],["看下钟","看下鐘"],["看不出","看不出"],["看不出来","看不出來"],["看个究竟","看個究竟"],["看中了","看中了"],["看了","看了"],["看了又看","看了又看"],["看傻了眼","看傻了眼"],["看准","看準"],["看出","看出"],["看出了神","看出了神"],["看出去","看出去"],["看出来","看出來"],["看台","看臺"],["看台股","看臺股"],["看向","看向"],["看回","看回"],["看尽","看盡"],["看得出","看得出"],["看得出来","看得出來"],["看朱成碧","看朱成碧"],["看板","看板"],["看淡后市","看淡後市"],["看终了","看終了"],["看花了","看花了"],["看表","看錶"],["看表面","看表面"],["看走了眼","看走了眼"],["看钟","看鐘"],["看风向","看風向"],["看麦娘","看麥娘"],["真个","真個"],["真主党","真主黨"],["真保志","真保志"],["真值表","真值表"],["真凭实据","真憑實據"],["真凶","真兇"],["真凶实犯","真兇實犯"],["真受不了","真受不了"],["真后生动物","真後生動物"],["真实面","真實面"],["真彩色","真彩色"],["真成了","真成了"],["真才实学","真才實學"],["真服了","真服了"],["真核","真核"],["真理必胜","真理必勝"],["真确","真確"],["真草千字文","真草千字文"],["真身舍利","真身舍利"],["真金不怕火炼","真金不怕火煉"],["真面目","真面目"],["眠云","眠雲"],["眷念","眷念"],["眷注","眷注"],["眷舍","眷舍"],["眺台","眺臺"],["眺望台","眺望臺"],["眼前花发","眼前花發"],["眼动技术","眼動技術"],["眼动记录","眼動記錄"],["眼同","眼同"],["眼周","眼周"],["眼圈红了","眼圈紅了"],["眼如秋水","眼如秋水"],["眼帘","眼簾"],["眼干","眼乾"],["眼干症","眼乾症"],["眼手并用","眼手並用"],["眼扎毛","眼扎毛"],["眼泛","眼泛"],["眼泪往肚子里流","眼淚往肚子裏流"],["眼泪洗面","眼淚洗面"],["眼球干燥症","眼球乾燥症"],["眼看四面","眼看四面"],["眼眶里","眼眶裏"],["眼睛里","眼睛裏"],["眼花了乱","眼花瞭亂"],["眼药","眼藥"],["眼药水","眼藥水"],["眼药膏","眼藥膏"],["眼虫","眼蟲"],["眼观四面","眼觀四面"],["眼迷心荡","眼迷心蕩"],["眼酸","眼痠"],["眼里","眼裏"],["眼里不揉沙子","眼裏不揉沙子"],["眼里揉不下沙子","眼裏揉不下沙子"],["眼镜布","眼鏡布"],["着儿","着兒"],["着手于","着手於"],["着眼于","着眼於"],["着色软体","着色軟體"],["着迷于","着迷於"],["着重于","着重於"],["着重指出","着重指出"],["睁一只眼","睜一隻眼"],["睟面盎背","睟面盎背"],["睡个","睡個"],["睡个夠","睡個夠"],["睡个痛快","睡個痛快"],["睡个觉","睡個覺"],["睡了","睡了"],["睡了又睡","睡了又睡"],["睡游病","睡遊病"],["睡病虫","睡病蟲"],["睡眠曲","睡眠曲"],["睡眠欲","睡眠慾"],["睡眠虫","睡眠蟲"],["睡眼蒙眬","睡眼矇矓"],["睡莲叶","睡蓮葉"],["睥睨物表","睥睨物表"],["睽合","睽合"],["瞄不准","瞄不準"],["瞄了","瞄了"],["瞄准","瞄準"],["瞄准到","瞄準到"],["瞄出","瞄出"],["瞅下表","瞅下錶"],["瞅下钟","瞅下鐘"],["瞅不准","瞅不準"],["瞇了","瞇了"],["瞌睡虫","瞌睡蟲"],["瞎了","瞎了"],["瞎了眼","瞎了眼"],["瞎了眼睛","瞎了眼睛"],["瞎扎呼","瞎扎呼"],["瞑子里","瞑子裏"],["瞒了","瞞了"],["瞒哄","瞞哄"],["瞒天讨价就地还钱","瞞天討價就地還錢"],["瞠乎其后","瞠乎其後"],["瞠乎后矣","瞠乎後矣"],["瞧不准","瞧不準"],["瞧不出","瞧不出"],["瞧了","瞧了"],["瞧出","瞧出"],["瞩托","矚託"],["瞪了","瞪了"],["瞬发中子","瞬發中子"],["瞬发辐射","瞬發輻射"],["瞬得彩色电影","瞬得彩色電影"],["瞬息万变","瞬息萬變"],["瞬息千变","瞬息千變"],["瞭望台","瞭望臺"],["瞳蒙","瞳矇"],["瞻前忽后","瞻前忽後"],["瞻前顾后","瞻前顧後"],["瞻念","瞻念"],["瞿秋白","瞿秋白"],["矛头指向","矛頭指向"],["矛盾百出","矛盾百出"],["矛盾相向","矛盾相向"],["矜功负胜","矜功負勝"],["矜夸","矜誇"],["矜庄","矜莊"],["矜才使气","矜才使氣"],["矜能负才","矜能負才"],["矞云","矞雲"],["矢不虚发","矢不虛發"],["矢尽兵穷","矢盡兵窮"],["矢志","矢志"],["矢志不移","矢志不移"],["矢无虚发","矢無虛發"],["知了","知了"],["知人知面","知人知面"],["知人知面不知心","知人知面不知心"],["知几其神","知幾其神"],["知制诰","知制誥"],["知名当世","知名當世"],["知尽能索","知盡能索"],["知往鉴今","知往鑑今"],["知情同意","知情同意"],["知感不尽","知感不盡"],["知无不言言无不尽","知無不言言無不盡"],["知行合一","知行合一"],["知识范围","知識範圍"],["知道了","知道了"],["矫制","矯制"],["矫情干誉","矯情干譽"],["矫正术","矯正術"],["矫若游龙","矯若遊龍"],["矬个儿","矬個兒"],["矬子里头选将军","矬子裏頭選將軍"],["短不了","短不了"],["短了","短了"],["短于","短於"],["短价","短價"],["短几","短几"],["短发","短髮"],["短发性","短發性"],["短叹","短嘆"],["短叹长吁","短嘆長吁"],["短后","短後"],["短小精干","短小精幹"],["短幸","短幸"],["短折","短折"],["短曲","短曲"],["短板","短板"],["短纤维","短纖維"],["短针","短針"],["短须","短鬚"],["矮个","矮個"],["矮个儿","矮個兒"],["矮个子","矮個子"],["矮了","矮了"],["矮了一截","矮了一截"],["矮了半截","矮了半截"],["矮冬瓜","矮冬瓜"],["矮几","矮几"],["矮子里拔将军","矮子裏拔將軍"],["矮杆品种","矮桿品種"],["石內卜","石內卜"],["石几","石几"],["石化厂","石化廠"],["石台","石臺"],["石台县","石臺縣"],["石坛","石壇"],["石头布","石頭布"],["石家庄","石家莊"],["石屋制果","石屋製果"],["石工术","石工術"],["石志伟","石志偉"],["石拐","石柺"],["石敢当","石敢當"],["石松","石松"],["石松粉","石松粉"],["石板","石板"],["石板屋","石板屋"],["石板瓦","石板瓦"],["石板路","石板路"],["石板道","石板道"],["石枯松老","石枯松老"],["石柜","石櫃"],["石梁","石樑"],["石棉布","石棉布"],["石棉板","石棉板"],["石棉症","石棉症"],["石油蜡","石油蠟"],["石油输出","石油輸出"],["石油输出国家组织","石油輸出國家組織"],["石油输出国组织","石油輸出國組織"],["石灰岩","石灰岩"],["石灰岩洞","石灰岩洞"],["石炭系","石炭系"],["石版术","石版術"],["石百合","石百合"],["石绵板","石綿板"],["石胡荽","石胡荽"],["石膏墙板","石膏牆板"],["石英卤素灯","石英鹵素燈"],["石英岩","石英岩"],["石英表","石英錶"],["石英钟","石英鐘"],["石英钟表","石英鐘錶"],["石莼","石蓴"],["石蜡","石蠟"],["石蜡像","石蠟像"],["石针","石針"],["石钟乳","石鐘乳"],["石雕","石雕"],["石雕像","石雕像"],["石雕家","石雕家"],["石黑彩","石黑彩"],["矽岩","矽岩"],["矽肺症","矽肺症"],["矽谷","矽谷"],["矽质岩","矽質岩"],["矿物纤维","礦物纖維"],["码表","碼錶","碼表"],["砂岩","砂岩"],["砂布","砂布"],["砂锅面","砂鍋麪"],["砌合","砌合"],["砌合法","砌合法"],["砌块建筑","砌塊建築"],["砍了","砍了"],["砍出","砍出"],["砍出去","砍出去"],["砍出来","砍出來"],["砍向","砍向"],["研修","研修"],["研修员","研修員"],["研修班","研修班"],["研几探赜","研幾探賾"],["研几析理","研幾析理"],["研判出","研判出"],["研制","研製"],["研制出","研製出"],["研制过程","研製過程"],["研发","研發"],["研发出","研發出"],["研发出来","研發出來"],["研发替代役","研發替代役"],["研发部","研發部"],["研发部门","研發部門"],["研拟出","研擬出"],["研究出","研究出"],["研究出来","研究出來"],["砖厂","磚廠"],["砖雕","磚雕"],["砖面","磚面"],["砚台","硯臺"],["砥志砺行","砥志礪行"],["砥据","砥據"],["砧板","砧板"],["砭灸术","砭灸術"],["砭针","砭鍼"],["砰当","砰噹"],["砲台","砲臺"],["破了脸","破了臉"],["破产财团","破產財團"],["破价","破價"],["破发","破發"],["破发点","破發點"],["破坏欲","破壞慾"],["破布","破布"],["破布子","破布子"],["破折号","破折號"],["破格录用","破格錄用"],["破盘价","破盤價"],["破纪录","破紀錄"],["破绽百出","破綻百出"],["破茧而出","破繭而出"],["破获","破獲"],["破蒸笼只会撒气","破蒸籠只會撒氣"],["破表","破錶"],["破记录","破記錄"],["破釜沈舟","破釜沈舟"],["破镜重合","破鏡重合"],["破面","破面"],["破风筝抖起来了","破風箏抖起來了"],["砸了","砸了"],["砻谷机","礱穀機"],["砾岩","礫岩"],["硅谷","硅谷"],["硅质岩","硅質岩"],["硗确","磽确"],["硝烟","硝煙"],["硝烟弹雨","硝煙彈雨"],["硫磺谷","硫磺谷"],["硫酸烟碱","硫酸菸鹼"],["硬了","硬了"],["硬了起来","硬了起來"],["硬件平台","硬件平臺"],["硬冲","硬衝"],["硬化症","硬化症"],["硬咽","硬嚥"],["硬干","硬幹"],["硬彩","硬彩"],["硬核","硬核"],["硬纸板","硬紙板"],["硬肥皂","硬肥皂"],["硬质合金","硬質合金"],["硬里子","硬裏子"],["硬面","硬麪"],["硬页岩","硬頁岩"],["确乎","確乎"],["确保","確保"],["确保安全","確保安全"],["确信","確信"],["确信无疑","確信無疑"],["确凿","確鑿"],["确凿不移","確鑿不移"],["确切","確切"],["确切不变","確切不變"],["确切性","確切性"],["确定","確定"],["确定会","確定會"],["确定判决","確定判決"],["确定性","確定性"],["确定故意","確定故意"],["确定效应","確定效應"],["确定是","確定是"],["确定有","確定有"],["确定能","確定能"],["确实","確實"],["确实会","確實會"],["确实可靠","確實可靠"],["确实在","確實在"],["确实性","確實性"],["确实是","確實是"],["确实有","確實有"],["确实能","確實能"],["确山县","確山縣"],["确当","確當"],["确是","確是"],["确有","確有"],["确有其事","確有其事"],["确有其人","確有其人"],["确有此事","確有此事"],["确瘠","确瘠"],["确知","確知"],["确确实实","確確實實"],["确立","確立"],["确系","確係"],["确认","確認"],["确认为","確認爲"],["确认是","確認是"],["确论","確論"],["确证","確證"],["确非","確非"],["碌曲","碌曲"],["碌曲县","碌曲縣"],["碌碌庸才","碌碌庸才"],["碍于","礙於"],["碍于情面","礙於情面"],["碍难照准","礙難照准"],["碍面子","礙面子"],["碎修儿","碎修兒"],["碎发","碎髮"],["碎尸万段","碎屍萬段"],["碎屑岩","碎屑岩"],["碎布","碎布"],["碎布条","碎布條"],["碑坛","碑壇"],["碑志","碑誌"],["碑面","碑面"],["碗柜","碗櫃"],["碗白干","碗白乾"],["碗面","碗麪"],["碛卤","磧鹵"],["碧云","碧雲"],["碧云寺","碧雲寺"],["碧娜芝．布托","碧娜芝．布托"],["碧波万顷","碧波萬頃"],["碧波荡漾","碧波盪漾"],["碧瓦朱甍","碧瓦朱甍"],["碧眼紫须","碧眼紫鬚"],["碧眼胡","碧眼胡"],["碧眼金发","碧眼金髮"],["碧鸡漫志","碧雞漫志"],["碰了","碰了"],["碰杯","碰杯"],["碰碰胡","碰碰胡"],["碰钟","碰鐘"],["碰面","碰面"],["碱性岩","鹼性岩"],["碱纤维素","鹼纖維素"],["碳氢化合","碳氫化合"],["碳氢化合物","碳氫化合物"],["碳水化合","碳水化合"],["碳水化合物","碳水化合物"],["碳的化合物","碳的化合物"],["碳纤","碳纖"],["碳纤维","碳纖維"],["碳酸岩","碳酸岩"],["碳链纤维","碳鏈纖維"],["碾米厂","碾米廠"],["磁制","磁製"],["磁北极","磁北極"],["磁单极子","磁單極子"],["磁南极","磁南極"],["磁扣","磁扣"],["磁极","磁極"],["磁核","磁核"],["磁碟作业系统","磁碟作業系統"],["磁针","磁針"],["磊落轶荡","磊落軼蕩"],["磕个响头","磕個響頭"],["磕个头","磕個頭"],["磕头虫","磕頭蟲"],["磨了","磨了"],["磨了半截舌头","磨了半截舌頭"],["磨出","磨出"],["磨制","磨製"],["磨制石器","磨製石器"],["磨厉以须","磨厲以須"],["磨变岩","磨變岩"],["磨合","磨合"],["磨合期","磨合期"],["磨合罗","磨合羅"],["磨折","磨折"],["磨杵成针","磨杵成針"],["磨炼","磨鍊"],["磨皮术","磨皮術"],["磨石子面","磨石子面"],["磨石粗砂岩","磨石粗砂岩"],["磨砺以须","磨礪以須"],["磨粉厂","磨粉廠"],["磨耗症","磨耗症"],["磨脊梁","磨脊樑"],["磨针溪","磨針溪"],["磨铁成针","磨鐵成針"],["磬折","磬折"],["磬钟","磬鐘"],["磷酸盐岩","磷酸鹽岩"],["礁岩","礁岩"],["示复","示覆"],["示威游行","示威遊行"],["示范","示範"],["示范企业","示範企業"],["示范作用","示範作用"],["示范动作","示範動作"],["示范区","示範區"],["示范单位","示範單位"],["示范厂","示範廠"],["示范园","示範園"],["示范园区","示範園區"],["示范场","示範場"],["示范基地","示範基地"],["示范学校","示範學校"],["示范岗","示範崗"],["示范工程","示範工程"],["示范带","示範帶"],["示范店","示範店"],["示范性","示範性"],["示范户","示範戶"],["示范效应","示範效應"],["示范教学","示範教學"],["示范文本","示範文本"],["示范村","示範村"],["示范校","示範校"],["示范法","示範法"],["示范点","示範點"],["示范片","示範片"],["示范班","示範班"],["示范田","示範田"],["示范社区","示範社區"],["示范街","示範街"],["示范表演","示範表演"],["示范课","示範課"],["示范赛","示範賽"],["示范项目","示範項目"],["礼义生于富足","禮義生於富足"],["礼乐射御","禮樂射御"],["礼仪规范","禮儀規範"],["礼制","禮制"],["礼台","禮臺"],["礼所当然","禮所當然"],["礼数周到","禮數周到"],["礼斗","禮斗"],["礼赞","禮讚"],["礼轻人意重千里送鹅毛","禮輕人意重千里送鵝毛"],["社交恐惧症","社交恐懼症"],["社交才能","社交才能"],["社会主义制度","社會主義制度"],["社会价值","社會價值"],["社会体系","社會體系"],["社会党","社會黨"],["社会制度","社會制度"],["社会发展","社會發展"],["社会团体","社會團體"],["社会学系","社會學系"],["社会控制","社會控制"],["社会整合","社會整合"],["社会民主党","社會民主黨"],["社会民主党人","社會民主黨人"],["社会福利彩券","社會福利彩券"],["社会系","社會系"],["社会规范","社會規範"],["社会调适","社會調適"],["社党","社黨"],["社区发展","社區發展"],["社区电台","社區電臺"],["社团","社團"],["社团活动","社團活動"],["社团课","社團課"],["社工系","社工系"],["社教系","社教系"],["社民党","社民黨"],["社里","社裏"],["祁奚荐仇","祁奚薦仇"],["祇洹精舍","祇洹精舍"],["祈仙台","祈仙臺"],["祈愿","祈願"],["祈祷团","祈禱團"],["祖冲之","祖沖之"],["祖国光复会","祖國光復會"],["祛痰药","祛痰藥"],["祛蠹除奸","祛蠹除奸"],["祝厘","祝釐"],["祝发","祝髮"],["祝年丰","祝年豐"],["祝愿","祝願"],["祝英台","祝英臺"],["祝赞","祝讚"],["神不守舍","神不守舍"],["神人鉴知","神人鑑知"],["神出鬼入","神出鬼入"],["神出鬼没","神出鬼沒"],["神分志夺","神分志奪"],["神台","神臺"],["神圣同盟","神聖同盟"],["神圣周","神聖週"],["神坛","神壇"],["神头鬼面","神頭鬼面"],["神彩奕奕","神彩奕奕"],["神志","神志"],["神志昏迷","神志昏迷"],["神态悠闲","神態悠閒"],["神摇魂荡","神搖魂盪"],["神曲","神曲"],["神曲茶","神麴茶"],["神术","神術"],["神术妙法","神術妙法"],["神术妙策","神術妙策"],["神术妙计","神術妙計"],["神机妙术","神機妙術"],["神杯","神杯"],["神游","神遊"],["神游太虚","神遊太虛"],["神经干","神經幹"],["神经战术","神經戰術"],["神经症","神經症"],["神经系","神經系"],["神经系统","神經系統"],["神经纤维","神經纖維"],["神经纤维瘤","神經纖維瘤"],["神胄","神胄"],["神荼郁垒","神荼鬱壘"],["神迹","神蹟"],["神采","神采"],["神采奕奕","神采奕奕"],["神采奕然","神采奕然"],["神采焕发","神采煥發"],["神采英拔","神采英拔"],["神采飘逸","神采飄逸"],["神采飞扬","神采飛揚"],["神采骏发","神采駿發"],["神雕","神鵰"],["神雕侠侣","神鵰俠侶"],["神雕像","神雕像"],["神魂摇荡","神魂搖盪"],["神魂荡漾","神魂盪漾"],["神魂荡飏","神魂盪颺"],["神魂飘荡","神魂飄蕩"],["神魂飞荡","神魂飛蕩"],["神魂驰荡","神魂馳蕩"],["祥丰街","祥豐街"],["祥云","祥雲"],["祥云县","祥雲縣"],["祥云瑞彩","祥雲瑞彩"],["祥云瑞气","祥雲瑞氣"],["祥风庆云","祥風慶雲"],["票价","票價"],["票庄","票莊"],["票房价值","票房價值"],["票房毒药","票房毒藥"],["票房纪录","票房紀錄"],["票房记录","票房記錄"],["票据","票據"],["票据交换","票據交換"],["票据交易所","票據交易所"],["票据存款","票據存款"],["票据法","票據法"],["票据行为","票據行爲"],["票汇","票匯"],["票选出","票選出"],["票面","票面"],["票面价值","票面價值"],["票面值","票面值"],["祭东施娘","祭東施娘"],["祭了","祭了"],["祭五脏庙","祭五臟廟"],["祭出","祭出"],["祭台","祭臺"],["祭司权术","祭司權術"],["祭吊","祭弔"],["祭吊文","祭弔文"],["祭坛","祭壇"],["祭尸","祭尸"],["祭遵布被","祭遵布被"],["祷念","禱唸"],["祸于","禍於"],["祸从口出","禍從口出"],["祸出不测","禍出不測"],["祸发萧墙","禍發蕭牆"],["祸发齿牙","禍發齒牙"],["祸因恶积","禍因惡積"],["祸生于忽","禍生於忽"],["祸盈恶稔","禍盈惡稔"],["祸福吉凶","禍福吉凶"],["祸福同门","禍福同門"],["祸种","禍種"],["祸种头","禍種頭"],["祸稔恶盈","禍稔惡盈"],["禀复","稟覆"],["禁制","禁制"],["禁制令","禁制令"],["禁制品","禁製品"],["禁奸除猾","禁奸除猾"],["禁当","禁當"],["禁忌站台","禁忌站臺"],["禁核","禁核"],["禁欲","禁慾"],["禁欲主义","禁慾主義"],["禁止吸烟","禁止吸菸"],["禁止外出","禁止外出"],["禁毁","禁燬"],["禁毁书","禁燬書"],["禁烟","禁菸"],["禁烟令","禁菸令"],["禁烟节","禁菸節"],["禁药","禁藥"],["禁药案","禁藥案"],["禄丰","祿豐"],["禄丰县","祿豐縣"],["福克","福克"],["福克兰群岛","福克蘭羣島"],["福克斯","福克斯"],["福克纳","福克納"],["福兰克","福蘭克"],["福尽灾生","福盡災生"],["福布斯","福布斯"],["福建师范","福建師範"],["福建师范大学","福建師範大學"],["福惠双修","福惠雙修"],["福无重受日祸有并来时","福無重受日禍有並來時"],["福瑞克","福瑞克"],["福生于微","福生于微"],["福维克","福維克"],["福舍","福舍"],["福荫","福廕"],["禹余粮","禹餘糧"],["禹王台","禹王臺"],["禹王台区","禹王臺區"],["禺谷","禺谷"],["离不了","離不了"],["离了","離了"],["离于","離於"],["离别","離別"],["离别多年","離別多年"],["离别已久","離別已久"],["离合","離合"],["离合体诗","離合體詩"],["离合器","離合器"],["离合悲欢","離合悲歡"],["离合板","離合板"],["离合诗","離合詩"],["离奇曲折","離奇曲折"],["离娘饭","離娘飯"],["离婚同意书","離婚同意書"],["离家出走","離家出走"],["离岸价","離岸價"],["离弦","離弦"],["离弦走板儿","離弦走板兒"],["离情别绪","離情別緒"],["离题万里","離題萬里"],["离鸾别凤","離鸞別鳳"],["禽困复车","禽困覆車"],["禽滑厘","禽滑釐"],["禽舍","禽舍"],["禾虫","禾蟲"],["禾谷","禾穀"],["禾谷类作物","禾穀類作物"],["秀出","秀出"],["秀出班行","秀出班行"],["秀发","秀髮"],["秀发垂肩","秀髮垂肩"],["秀才","秀才"],["秀才不出门能知天下事","秀才不出門能知天下事"],["秀才人情","秀才人情"],["秀才作医如菜作虀","秀才作醫如菜作虀"],["秀才造反","秀才造反"],["私下里","私下裏"],["私了","私了"],["私仇","私仇"],["私党","私黨"],["私心藏奸","私心藏奸"],["私念","私念"],["私斗","私鬥"],["私曲","私曲"],["私有制","私有制"],["私有财产制","私有財產制"],["私欲","私慾"],["私自同意","私自同意"],["秃发","禿髮"],["秃发症","禿髮症"],["秃妃之发","禿妃之髮"],["秃秃里","禿禿裏"],["秉台衡","秉臺衡"],["秉烛夜游","秉燭夜遊"],["秉鉴","秉鑑"],["秋不干","秋不乾"],["秋事","秋事"],["秋令","秋令"],["秋假里","秋假裏"],["秋冬","秋冬"],["秋决","秋決"],["秋凉","秋涼"],["秋凉时节","秋涼時節"],["秋刀鱼","秋刀魚"],["秋分","秋分"],["秋分点","秋分點"],["秋初","秋初"],["秋千","鞦韆"],["秋发","秋髮"],["秋叶","秋葉"],["秋叶原","秋葉原"],["秋后","秋後"],["秋后算帐","秋後算帳"],["秋后算账","秋後算賬"],["秋场","秋場"],["秋士","秋士"],["秋声","秋聲"],["秋声赋","秋聲賦"],["秋夜","秋夜"],["秋天","秋天"],["秋天里","秋天裏"],["秋娘","秋娘"],["秋季","秋季"],["秋季学期","秋季學期"],["秋季旅行","秋季旅行"],["秋季档","秋季檔"],["秋季班","秋季班"],["秋季赛","秋季賽"],["秋官","秋官"],["秋审","秋審"],["秋山","秋山"],["秋川雅史","秋川雅史"],["秋庄稼","秋莊稼"],["秋征","秋征"],["秋心","秋心"],["秋思","秋思"],["秋意","秋意"],["秋意已浓","秋意已濃"],["秋成","秋成"],["秋扇","秋扇"],["秋扇见捐","秋扇見捐"],["秋播","秋播"],["秋收","秋收"],["秋收冬藏","秋收冬藏"],["秋收季节","秋收季節"],["秋收起义","秋收起義"],["秋方","秋方"],["秋日","秋日"],["秋日里","秋日裏"],["秋旱","秋旱"],["秋景","秋景"],["秋月","秋月"],["秋月寒江","秋月寒江"],["秋月春风","秋月春風"],["秋期","秋期"],["秋枫","秋楓"],["秋榜","秋榜"],["秋毫","秋毫"],["秋毫不犯","秋毫不犯"],["秋毫之末","秋毫之末"],["秋毫无犯","秋毫無犯"],["秋气","秋氣"],["秋水","秋水"],["秋水仙素","秋水仙素"],["秋水伊人","秋水伊人"],["秋汛","秋汛"],["秋河","秋河"],["秋波","秋波"],["秋波送情","秋波送情"],["秋海棠","秋海棠"],["秋海棠花","秋海棠花"],["秋游","秋遊"],["秋灌","秋灌"],["秋熟","秋熟"],["秋燥","秋燥"],["秋牡丹","秋牡丹"],["秋瑾","秋瑾"],["秋田","秋田"],["秋田县","秋田縣"],["秋眉","秋眉"],["秋石","秋石"],["秋社","秋社"],["秋禊","秋禊"],["秋篠宫","秋篠宮"],["秋粮","秋糧"],["秋老虎","秋老虎"],["秋耕","秋耕"],["秋胡","秋胡"],["秋胡变文","秋胡變文"],["秋胡戏妻","秋胡戲妻"],["秋色","秋色"],["秋色宜人","秋色宜人"],["秋节","秋節"],["秋茶","秋茶"],["秋草","秋草"],["秋草人情","秋草人情"],["秋荼","秋荼"],["秋荼密网","秋荼密網"],["秋莲","秋蓮"],["秋菊","秋菊"],["秋菊傲霜","秋菊傲霜"],["秋菜","秋菜"],["秋葵","秋葵"],["秋葵荚","秋葵莢"],["秋虫","秋蟲"],["秋蝉","秋蟬"],["秋衣","秋衣"],["秋装","秋裝"],["秋裤","秋褲"],["秋试","秋試"],["秋闱","秋闈"],["秋阳","秋陽"],["秋阴入井干","秋陰入井幹"],["秋雨","秋雨"],["秋霖","秋霖"],["秋霜","秋霜"],["秋颜","秋顏"],["秋风","秋風"],["秋风团扇","秋風團扇"],["秋风扫落叶","秋風掃落葉"],["秋风落叶","秋風落葉"],["秋风辞","秋風辭"],["秋风过耳","秋風過耳"],["秋风送爽","秋風送爽"],["秋风飒飒","秋風颯颯"],["秋香","秋香"],["秋高气爽","秋高氣爽"],["秋高气肃","秋高氣肅"],["秋高马肥","秋高馬肥"],["秋麻","秋麻"],["种上","種上"],["种上蒺藜就要扎脚","種上蒺藜就要扎腳"],["种下","種下"],["种下祸根","種下禍根"],["种人","種人"],["种仁","種仁"],["种公畜","種公畜"],["种出","種出"],["种出来","種出來"],["种切","種切"],["种别","種別"],["种到","種到"],["种名","種名"],["种因","種因"],["种地","種地"],["种姓","種姓"],["种姓制","種姓制"],["种姓制度","種姓制度"],["种子","種子"],["种子园","種子園"],["种子地","種子地"],["种子岛","種子島"],["种子植物","種子植物"],["种子球员","種子球員"],["种子田","種子田"],["种子网路","種子網路"],["种子选手","種子選手"],["种子队","種子隊"],["种差","種差"],["种师中","种師中"],["种师道","种師道"],["种庄稼","種莊稼"],["种得","種得"],["种德","種德"],["种性","種性"],["种户","種戶"],["种放","种放"],["种族","種族"],["种族中心主义","種族中心主義"],["种族主义","種族主義"],["种族主义者","種族主義者"],["种族偏见","種族偏見"],["种族平等","種族平等"],["种族歧视","種族歧視"],["种族清洗","種族清洗"],["种族清除","種族清除"],["种族灭绝","種族滅絕"],["种族迫害","種族迫害"],["种族问题","種族問題"],["种族隔离","種族隔離"],["种树","種樹"],["种植","種植"],["种植业","種植業"],["种植义齿","種植義齒"],["种植区","種植區"],["种植园","種植園"],["种植户","種植戶"],["种概念","種概念"],["种源中心","種源中心"],["种源论","種源論"],["种火又长拄门又短","種火又長拄門又短"],["种牛","種牛"],["种牛痘","種牛痘"],["种猪","種豬"],["种玉","種玉"],["种瓜得瓜","種瓜得瓜"],["种瓜得瓜种豆得豆","種瓜得瓜種豆得豆"],["种生","種生"],["种田","種田"],["种田人家","種田人家"],["种畜","種畜"],["种痘","種痘"],["种的","種的"],["种皮","種皮"],["种祸","種禍"],["种种","種種"],["种稻","種稻"],["种类","種類"],["种籽","種籽"],["种系","種系"],["种群","種羣"],["种肥","種肥"],["种花","種花"],["种花草","種花草"],["种菜","種菜"],["种蛋","種蛋"],["种谷","種穀"],["种豆","種豆"],["种豆得豆","種豆得豆"],["种起","種起"],["种过","種過"],["种过去","種過去"],["种过来","種過來"],["种近乎幻想","種近乎幻想"],["种间杂交","種間雜交"],["种马","種馬"],["种麦得麦","種麥得麥"],["种麻","種麻"],["科举制","科舉制"],["科举制度","科舉制度"],["科克","科克"],["科克林","科克林"],["科别","科別"],["科学万能","科學萬能"],["科学中药","科學中藥"],["科学技术","科學技術"],["科学技术是第一生产力","科學技術是第一生產力"],["科学技术现代化","科學技術現代化"],["科学种田","科學種田"],["科学规范","科學規範"],["科学面","科學麪"],["科尔沁左翼后","科爾沁左翼後"],["科尔沁左翼后旗","科爾沁左翼後旗"],["科尼賽克","科尼賽克"],["科布多","科布多"],["科布多河","科布多河"],["科布多盆地","科布多盆地"],["科托努","科托努"],["科技示范户","科技示範戶"],["科斗","科斗"],["科斗书","科斗書"],["科斗文","科斗文"],["科特布斯","科特布斯"],["科班出身","科班出身"],["科目表","科目表"],["科系","科系"],["科纳克里","科納克里"],["科罗拉多大峡谷","科羅拉多大峽谷"],["科范","科範"],["科迪勒拉山系","科迪勒拉山系"],["科际整合","科際整合"],["秒表","秒錶"],["秒针","秒針"],["秒钟","秒鐘"],["秕谷","秕穀"],["秘制","祕製"],["秘录","祕錄"],["租价","租價"],["租借","租借"],["租借人","租借人"],["租借地","租借地"],["租借法案","租借法案"],["租借给","租借給"],["租出","租出"],["租出去","租出去"],["秤平斗满","秤平斗滿"],["秤斤注两","秤斤注兩"],["秤杆","秤桿"],["秤砣虽小压千斤","秤砣雖小壓千斤"],["秦吉了","秦吉了"],["秦少游","秦少游"],["秧针","秧針"],["积于忽微","積於忽微"],["积云","積雲"],["积分制","積分制"],["积层云","積層雲"],["积恶","積惡"],["积恶余殃","積惡餘殃"],["积恶馀殃","積惡餘殃"],["积极","積極"],["积极份子","積極份子"],["积极参与","積極參與"],["积极参加","積極參加"],["积极反应","積極反應"],["积极因素","積極因素"],["积极型","積極型"],["积极性","積極性"],["积极论","積極論"],["积淀","積澱"],["积谷","積穀"],["积谷防饥","積穀防饑"],["积郁","積鬱"],["积里渐里","積裏漸裏"],["积金至斗","積金至斗"],["积雨云","積雨雲"],["称出","稱出"],["称制","稱制"],["称叹","稱歎"],["称心满志","稱心滿志"],["称念","稱念"],["称愿","稱願"],["称王封后","稱王封后"],["称谓录","稱謂錄"],["称赞","稱讚"],["称赞不已","稱讚不已"],["移出","移出"],["移出去","移出去"],["移出来","移出來"],["移向","移向"],["移回","移回"],["移山志","移山志"],["移情别恋","移情別戀"],["移星换斗","移星換斗"],["移植手术","移植手術"],["移祸于","移禍於"],["秾纤","穠纖"],["秾纤合度","穠纖合度"],["稀松","稀鬆"],["稀松平常","稀鬆平常"],["稀松骨质","稀鬆骨質"],["稀释后","稀釋後"],["稀里","稀里"],["稀里哗啦","稀里嘩啦"],["稀里打哄","稀里打哄"],["稀里糊涂","稀裏糊塗"],["程序修宪","程序修憲"],["程序控制","程序控制"],["程式控制","程式控制"],["程式规划","程式規劃"],["程朱","程朱"],["程砚秋","程硯秋"],["稍出","稍出"],["稍占上风","稍占上風"],["稍后","稍後"],["稍干的","稍乾的"],["稍感不适","稍感不適"],["稍有不准","稍有不準"],["稍胜一筹","稍勝一籌"],["稍高于","稍高於"],["税制","稅制"],["税后","稅後"],["税捐稽征","稅捐稽徵"],["税捐稽征处","稅捐稽徵處"],["税种","稅種"],["税负制","稅負制"],["稔恶不悛","稔惡不悛"],["稠云","稠雲"],["稳占","穩佔"],["稳吃三注","穩吃三注"],["稳坐钓鱼台","穩坐釣魚臺"],["稳定物价","穩定物價"],["稳当","穩當"],["稳当性","穩當性"],["稳扎","穩紮"],["稳扎稳打","穩紮穩打"],["稳操胜券","穩操勝券"],["稳操胜算","穩操勝算"],["稳稳当当","穩穩當當"],["稳获","穩獲"],["稻种","稻種"],["稻穗","稻穗"],["稻谷","稻穀"],["稽征","稽徵"],["稽征处","稽徵處"],["稽征所","稽徵所"],["稽核","稽覈"],["穆克吉","穆克吉"],["穆巴拉克","穆巴拉克"],["穆斯坦西里","穆斯坦西里"],["穆罕默德历","穆罕默德曆"],["穆罕默德历史","穆罕默德歷史"],["穗儿","穗兒"],["穗子","穗子"],["穗帏飘井干","繐幃飄井幹"],["穗帐","繐帳"],["穗帷","繐帷"],["穗状","穗狀"],["穗状花序","穗狀花序"],["穗肥","穗肥"],["穗花杉","穗花杉"],["穗裳","繐裳"],["穗轴","穗軸"],["穗选","穗選"],["穷于","窮於"],["穷于应付","窮於應付"],["穷兵极武","窮兵極武"],["穷兵黩武","窮兵黷武"],["穷冬","窮冬"],["穷凶恶极","窮兇惡極"],["穷凶极恶","窮兇極惡"],["穷凶极虐","窮兇極虐"],["穷发","窮髮"],["穷困","窮困"],["穷困人家","窮困人家"],["穷天极地","窮天極地"],["穷奢极侈","窮奢極侈"],["穷奢极多","窮奢極多"],["穷奢极欲","窮奢極欲"],["穷妙极巧","窮妙極巧"],["穷富极贵","窮富極貴"],["穷尽","窮盡"],["穷山恶水","窮山惡水"],["穷工极巧","窮工極巧"],["穷幽极微","窮幽極微"],["穷当益坚","窮當益堅"],["穷当益坚老当益壮","窮當益堅老當益壯"],["穷形尽相","窮形盡相"],["穷形极状","窮形極狀"],["穷本极源","窮本極源"],["穷极","窮極"],["穷极其妙","窮極其妙"],["穷极则变","窮極則變"],["穷极无聊","窮極無聊"],["穷极要妙","窮極要妙"],["穷根寻叶","窮根尋葉"],["穷灵尽妙","窮靈盡妙"],["穷理尽性","窮理盡性"],["穷纤入微","窮纖入微"],["穷而后工","窮而後工"],["穷贵极富","窮貴極富"],["穷追不舍","窮追不捨"],["穷里","窮里"],["穹谷","穹谷"],["空个","空個"],["空中交通管制","空中交通管制"],["空中交通管制员","空中交通管制員"],["空中布雷","空中佈雷"],["空中格斗","空中格鬥"],["空中管制站","空中管制站"],["空了","空了"],["空优迷彩","空優迷彩"],["空余","空餘"],["空军航空技术学院","空軍航空技術學院"],["空出","空出"],["空出来","空出來"],["空前绝后","空前絕後"],["空前绝后后","空前絕后後"],["空叹","空嘆"],["空当","空當"],["空当儿","空當兒"],["空当子","空當子"],["空心汤团","空心湯糰"],["空心萝卜","空心蘿蔔"],["空手而回","空手而回"],["空投布雷","空投佈雷"],["空杯","空杯"],["空柜子","空櫃子"],["空梁落燕泥","空梁落燕泥"],["空气喷气发动机","空氣噴氣發動機"],["空气缓冲间","空氣緩衝間"],["空泛","空泛"],["空疏无据","空疏無據"],["空空荡荡","空空蕩蕩"],["空荡","空蕩"],["空荡荡","空蕩蕩"],["空蒙","空濛"],["空调症","空調症"],["空谷","空谷"],["空谷幽兰","空谷幽蘭"],["空谷足音","空谷足音"],["空钟","空鐘"],["空间曲线","空間曲線"],["空间艺术","空間藝術"],["空集合","空集合"],["穿不出","穿不出"],["穿云裂石","穿雲裂石"],["穿出","穿出"],["穿出去","穿出去"],["穿出来","穿出來"],["穿回","穿回"],["穿跟斗","穿跟斗"],["穿针","穿針"],["穿针引线","穿針引線"],["穿针走线","穿針走線"],["穿鞋的不斗赤脚的","穿鞋的不鬥赤腳的"],["穿麻挂孝","穿麻掛孝"],["突出","突出"],["突出去","突出去"],["突出来","突出來"],["突出重围","突出重圍"],["突升","突升"],["突发","突發"],["突发事件","突發事件"],["突发奇想","突發奇想"],["突发性","突發性"],["突发状况","突發狀況"],["突围而出","突圍而出"],["突显出","突顯出"],["突袭战术","突襲戰術"],["突触后","突觸後"],["窃占","竊占"],["窃占罪","竊占罪"],["窃幸乘宠","竊幸乘寵"],["窃据","竊據"],["窃钟掩耳","竊鐘掩耳"],["窅娘","窅娘"],["窒欲","窒慾"],["窗台","窗臺"],["窗台上","窗臺上"],["窗帘","窗簾"],["窗帘布","窗簾布"],["窗明几亮","窗明几亮"],["窗明几净","窗明几淨"],["窘困","窘困"],["窘态百出","窘態百出"],["窜出","竄出"],["窜升","竄升"],["窜游","竄遊"],["窜进窜出","竄進竄出"],["窝里","窩裏"],["窝里反","窩裏反"],["窝里发炮","窩裏發炮"],["窝里炮","窩裏炮"],["窝里窝囊","窩里窩囊"],["窝里翻","窩裏翻"],["窝阔台","窩闊臺"],["窝阔台汗","窩闊臺汗"],["窝阔台汗国","窩闊臺汗國"],["窟里拔蛇","窟裏拔蛇"],["窥御激夫","窺御激夫"],["窦太后","竇太后"],["窨子里秋月","窨子裏秋月"],["立了","立了"],["立于","立於"],["立于不败","立於不敗"],["立于不败之地","立於不敗之地"],["立体几何","立體幾何"],["立体身历声","立體身歷聲"],["立克次体","立克次體"],["立冬","立冬"],["立升","立升"],["立宪民主党","立憲民主黨"],["立当","立當"],["立志","立志"],["立扎","立扎"],["立扫千言","立掃千言"],["立方公里","立方公里"],["立方厘米","立方厘米"],["立杆","立杆"],["立杆见影","立杆見影"],["立柜","立櫃"],["立氏立克次体","立氏立克次體"],["立秋","立秋"],["立联合医院","立聯合醫院"],["立范","立範"],["立面","立面"],["立面图","立面圖"],["竖人毛发","豎人毛髮"],["竖柱上梁","豎柱上梁"],["竖起脊梁","豎起脊梁"],["站个","站個"],["站了","站了"],["站出","站出"],["站出去","站出去"],["站出来","站出來"],["站台","站臺"],["站台票","站臺票"],["站干岸儿","站乾岸兒"],["站柜台","站櫃檯"],["竞争和聚合","競爭和聚合"],["竞价","競價"],["竞合现象","競合現象"],["竞向","競向"],["竞斗","競鬥"],["竟于","竟於"],["竟须","竟須"],["章台","章臺"],["章台杨柳","章臺楊柳"],["章台柳","章臺柳"],["章回","章回"],["章回体","章回體"],["章回小说","章回小說"],["章表","章表"],["童仆","童僕"],["童军团","童軍團"],["童蒙","童蒙"],["童蒙训","童蒙訓"],["童颜鹤发","童顏鶴髮"],["竭尽","竭盡"],["竭尽全力","竭盡全力"],["竭尽力量","竭盡力量"],["竭尽心思","竭盡心思"],["竭尽所能","竭盡所能"],["竭尽棉薄","竭盡棉薄"],["竭智尽力","竭智盡力"],["竭智尽忠","竭智盡忠"],["竭智尽虑","竭智盡慮"],["竭诚尽节","竭誠盡節"],["端了","端了"],["端出","端出"],["端出去","端出去"],["端出来","端出來"],["端庄","端莊"],["端杯","端杯"],["端系统","端系統"],["端面","端面"],["竹几","竹几"],["竹制","竹製"],["竹叶","竹葉"],["竹叶青","竹葉青"],["竹叶青蛇","竹葉青蛇"],["竹叶鲢","竹葉鰱"],["竹布","竹布"],["竹帘","竹簾"],["竹席","竹蓆"],["竹扣","竹扣"],["竹杠","竹槓"],["竹板","竹板"],["竹板书","竹板書"],["竹板歌","竹板歌"],["竹林之游","竹林之遊"],["竹笋干","竹筍乾"],["竹签","竹籤"],["竹篱茅舍","竹籬茅舍"],["竹节虫","竹節蟲"],["竹苞松茂","竹苞松茂"],["竹野內丰","竹野內豐"],["笃志","篤志"],["笃志好学","篤志好學"],["笃志爱古","篤志愛古"],["笆斗","笆斗"],["笋干","筍乾"],["笋里不知茆里","筍裏不知茆裏"],["笏板","笏板"],["笑个","笑個"],["笑个痛快","笑個痛快"],["笑了","笑了"],["笑了起来","笑了起來"],["笑代表拒绝","笑代表拒絕"],["笑出","笑出"],["笑出来","笑出來"],["笑出眼泪","笑出眼淚"],["笑口弥勒","笑口彌勒"],["笑容满面","笑容滿面"],["笑成一团","笑成一團"],["笑耍头回","笑耍頭回"],["笑话百出","笑話百出"],["笑里藏刀","笑裏藏刀"],["笑面","笑面"],["笑面夜叉","笑面夜叉"],["笑面虎","笑面虎"],["笔划","筆劃"],["笔划检字表","筆劃檢字表"],["笔力万钧","筆力萬鈞"],["笔卷","筆捲"],["笔参造化","筆參造化"],["笔录","筆錄"],["笔扫千军","筆掃千軍"],["笔据","筆據"],["笔杆","筆桿"],["笔杆子","筆桿子"],["笔秃墨干","筆禿墨乾"],["笔管面","筆管麪"],["笔胜于刀文比武强","筆勝於刀文比武強"],["笔致","筆致"],["笔迹鉴定","筆跡鑑定"],["笙磬同音","笙磬同音"],["笛卡儿坐标制","笛卡兒座標制"],["笛布斯","笛布斯"],["符号表","符號表"],["符合","符合"],["符合标准","符合標準"],["符合美国利益","符合美國利益"],["符拉迪沃斯托克","符拉迪沃斯託克"],["符拉迪沃斯讬克","符拉迪沃斯託克"],["符采","符采"],["笨蛋挂","笨蛋掛"],["第一个","第一個"],["第一个层次","第一個層次"],["第一信号系统","第一信號系統"],["第一准备金","第一準備金"],["第一出","第一齣"],["第一千","第一千"],["第一千万","第一千萬"],["第一卷","第一卷"],["第一回","第一回"],["第一志愿","第一志願"],["第一性征","第一性徵"],["第七个","第七個"],["第七出","第七齣"],["第七回","第七回"],["第三个","第三個"],["第三出","第三齣"],["第三回","第三回"],["第九个","第九個"],["第九出","第九齣"],["第九回","第九回"],["第九艺术","第九藝術"],["第二个","第二個"],["第二出","第二齣"],["第二回","第二回"],["第二性征","第二性徵"],["第五个","第五個"],["第五个现代化","第五個現代化"],["第五出","第五齣"],["第五回","第五回"],["第八个","第八個"],["第八出","第八齣"],["第八回","第八回"],["第八艺术","第八藝術"],["第六个","第六個"],["第六出","第六齣"],["第六回","第六回"],["第几","第幾"],["第几个","第幾個"],["第几冊","第幾冊"],["第几名","第幾名"],["第几回","第幾回"],["第几次","第幾次"],["第几章","第幾章"],["第几节","第幾節"],["第几课","第幾課"],["第十个","第十個"],["第十出","第十齣"],["第十回","第十回"],["第四个","第四個"],["第四出","第四齣"],["第四出局","第四出局"],["第四台","第四臺"],["第四回","第四回"],["笺注","箋註"],["等个","等個"],["等了","等了"],["等于","等於"],["等于在","等於在"],["等于是","等於是"],["等于有","等於有"],["等于零","等於零"],["等价","等價"],["等价交换","等價交換"],["等价关系","等價關係"],["等价物","等價物"],["等值价格","等值價格"],["等势面","等勢面"],["等同","等同"],["等同于","等同於"],["等周不等式","等周不等式"],["等效百万吨当量","等效百萬噸當量"],["等级制度","等級制度"],["等轴晶系","等軸晶系"],["等速圆周运动","等速圓周運動"],["等闲之辈","等閒之輩"],["等闲人物","等閒人物"],["等闲视之","等閒視之"],["等高种植","等高種植"],["筋斗","筋斗"],["筋斗云","筋斗雲"],["筋疲力尽","筋疲力盡"],["筋面粉","筋麪粉"],["筑前","筑前"],["筑北","筑北"],["筑后","筑後"],["筑土墙","築土牆"],["筑坛","築壇"],["筑坛拜将","築壇拜將"],["筑城","築城"],["筑堤","築堤"],["筑墙","築牆"],["筑室","築室"],["筑室反耕","築室反耕"],["筑室道谋","築室道謀"],["筑屋","築屋"],["筑州","筑州"],["筑巢","築巢"],["筑底","築底"],["筑底巷","築底巷"],["筑後","筑後"],["筑成","築成"],["筑有","築有"],["筑栏","築欄"],["筑波","筑波"],["筑磕","築磕"],["筑筑磕磕","築築磕磕"],["筑紫","筑紫"],["筑肥","筑肥"],["筑西","筑西"],["筑起","築起"],["筑路","築路"],["筑路工程","築路工程"],["筑邦","筑邦"],["筑阳","筑陽"],["筑陽","筑陽"],["答不出","答不出"],["答出","答出"],["答出来","答出來"],["答剌苏","答剌蘇"],["答卷","答卷"],["答复","答覆"],["答录机","答錄機"],["答案卷","答案卷"],["策划","策劃"],["策划人","策劃人"],["策划者","策劃者"],["筛子喂驴","篩子餵驢"],["筛板","篩板"],["筛检出","篩檢出"],["筛选出","篩選出"],["筲斗","筲斗"],["筵几","筵几"],["筹划","籌劃"],["筹码面","籌碼面"],["签上","簽上"],["签上去","簽上去"],["签上来","簽上來"],["签下","簽下"],["签下去","簽下去"],["签下来","簽下來"],["签书会","簽書會"],["签了","簽了"],["签些","簽些"],["签入","簽入"],["签写","簽寫"],["签出","簽出"],["签到","簽到"],["签到处","簽到處"],["签到簿","簽到簿"],["签单","簽單"],["签印","簽印"],["签发","簽發"],["签发地点","簽發地點"],["签发日期","簽發日期"],["签名","簽名"],["签名会","簽名會"],["签名信","簽名信"],["签名球","簽名球"],["签名簿","簽名簿"],["签名运动","簽名運動"],["签呈","簽呈"],["签唱","簽唱"],["签唱会","簽唱會"],["签在","簽在"],["签好","簽好"],["签妥","簽妥"],["签子","籤子"],["签字","簽字"],["签字笔","簽字筆"],["签字者","簽字者"],["签字费","簽字費"],["签完","簽完"],["签定","簽定"],["签帐","簽帳"],["签帐卡","簽帳卡"],["签幐","籤幐"],["签得","簽得"],["签报","簽報"],["签押","簽押"],["签押房","簽押房"],["签收","簽收"],["签有","簽有"],["签条","籤條"],["签注","簽註"],["签派室","簽派室"],["签爲","簽爲"],["签着","簽着"],["签章","簽章"],["签筒","籤筒"],["签约","簽約"],["签约人","簽約人"],["签约国","簽約國"],["签约奖金","簽約獎金"],["签约金","簽約金"],["签结","簽結"],["签署","簽署"],["签署人","簽署人"],["签署国","簽署國"],["签証","簽証"],["签订","簽訂"],["签证","簽證"],["签证费","簽證費"],["签诗","籤詩"],["签语饼","籤語餅"],["签赌","簽賭"],["签赌案","簽賭案"],["签赌站","簽賭站"],["签过","簽過"],["签退","簽退"],["简余晏","簡余晏"],["简别","簡別"],["简单明了","簡單明瞭"],["简历","簡歷"],["简历表","簡歷表"],["简字表","簡字表"],["简字谱录","簡字譜錄"],["简尸","簡屍"],["简并","簡併"],["简截了当","簡截了當"],["简报导览系统","簡報導覽系統"],["简易包扎法","簡易包紮法"],["简易师范","簡易師範"],["简朝仑","簡朝崙"],["简朴","簡樸"],["简板","簡板"],["简氏防务周刊","簡氏防務週刊"],["箕山之志","箕山之志"],["箕斗","箕斗"],["算不了","算不了"],["算不出","算不出"],["算了","算了"],["算了又算","算了又算"],["算准","算準"],["算出","算出"],["算出去","算出去"],["算出来","算出來"],["算历","算曆"],["算发","算髮"],["算得了","算得了"],["算术","算術"],["算术和","算術和"],["算术家","算術家"],["算术平均","算術平均"],["算术平均数","算術平均數"],["算术式","算術式"],["算术级数","算術級數"],["算术课","算術課"],["箝制","箝制"],["管不了","管不了"],["管个","管個"],["管乐团","管樂團"],["管了","管了"],["管人吊脚儿事","管人弔腳兒事"],["管制","管制"],["管制中心","管制中心"],["管制区","管制區"],["管制区域","管制區域"],["管制员","管制員"],["管制品","管制品"],["管制塔台","管制塔臺"],["管制局","管制局"],["管制法","管制法"],["管制点","管制點"],["管制空域","管制空域"],["管制站","管制站"],["管制路线","管制路線"],["管圆线虫","管圓線蟲"],["管城回族区","管城回族區"],["管家娘子","管家娘子"],["管干","管幹"],["管弦","管絃"],["管弦乐团","管弦樂團"],["管理人才","管理人才"],["管理体制","管理體制"],["管理系","管理系"],["管理规范","管理規範"],["管理资讯系统","管理資訊系統"],["管辖范围","管轄範圍"],["管道升","管道昇"],["管闲事","管閒事"],["箭不虚发","箭不虛發"],["箭在弦上不得不发","箭在弦上不得不發"],["箭无虚发","箭無虛發"],["箭杆","箭桿"],["箭虫","箭蟲"],["箱帘","箱簾"],["箱扣","箱釦"],["箱梁","箱梁"],["箱里","箱裏"],["篆烟","篆煙"],["篇卷","篇卷"],["篡党","篡黨"],["篮下三秒钟","籃下三秒鐘"],["篮坛","籃壇"],["篮板","籃板"],["篮板王","籃板王"],["篮板球","籃板球"],["篮虹杯","籃虹盃"],["篷盖布","篷蓋佈"],["簇合","簇合"],["簌簌发抖","簌簌發抖"],["簪笔磬折","簪筆磬折"],["簪缨世胄","簪纓世胄"],["簳面杖","簳麪杖"],["簸荡","簸盪"],["簿历","簿歷"],["簿录","簿錄"],["簿据","簿據"],["籧篨戚施","籧篨戚施"],["米价","米價"],["米克","米克"],["米克杰格","米克傑格"],["米克森","米克森"],["米克诺斯","米克諾斯"],["米利托","米利托"],["米制","米制"],["米卤蛋","米滷蛋"],["米厘米突","米釐米突"],["米德尔伯里","米德爾伯裏"],["米格式战斗机","米格式戰鬥機"],["米纳谷","米納谷"],["米罗的维纳斯雕像","米羅的維納斯雕像"],["米苏里","米蘇里"],["米苏里州","米蘇里州"],["米虫","米蟲"],["米蛀虫","米蛀蟲"],["米谷","米穀"],["米里","米里"],["米雅托维奇","米雅托維奇"],["米雕","米雕"],["米面","米麪"],["类似于","類似於"],["类别","類別"],["类别的团体","類別的團體"],["类同","類同"],["类同法","類同法"],["类球面","類球面"],["粉丝团","粉絲團"],["粉丝谷","粉絲谷"],["粉团儿","粉團兒"],["粉团儿似的","粉團兒似的"],["粉彩","粉彩"],["粉拳绣腿","粉拳繡腿"],["粉板","粉板"],["粉砂岩","粉砂岩"],["粉签子","粉籤子"],["粉红色系","粉紅色系"],["粉面","粉面"],["粉面朱脣","粉面硃脣"],["粉面油头","粉面油頭"],["粉饰门面","粉飾門面"],["粒变岩","粒變岩"],["粗制","粗製"],["粗制品","粗製品"],["粗制滥造","粗製濫造"],["粗卤","粗鹵"],["粗布","粗布"],["粗布条","粗布條"],["粗恶","粗惡"],["粗枝大叶","粗枝大葉"],["粗毛布","粗毛布"],["粗管面","粗管麪"],["粗纤维","粗纖維"],["粗衣恶食","粗衣惡食"],["粗面","粗麪"],["粗面岩","粗面岩"],["粘合剂","粘合劑"],["粘板岩","粘板岩"],["粜出","糶出"],["粤曲","粵曲"],["粤胡","粵胡"],["粥厂","粥廠"],["粪坑里的石头","糞坑裏的石頭"],["粪秽蔑面","糞穢衊面"],["粪缸里掷骰子","糞缸裏擲骰子"],["粮尽援绝","糧盡援絕"],["粮食平准基金","糧食平準基金"],["粲夸克","粲夸克"],["粽粑叶","粽粑葉"],["精于","精於"],["精于此道","精於此道"],["精兵制","精兵制"],["精准","精準"],["精准度","精準度"],["精制","精製"],["精制品","精製品"],["精制服","精制服"],["精奇里江","精奇里江"],["精干","精幹"],["精干高效","精幹高效"],["精当","精當"],["精彩","精彩"],["精彩度","精彩度"],["精彩生动","精彩生動"],["精彩逼人","精彩逼人"],["精彩镜头","精彩鏡頭"],["精心制作","精心製作"],["精心制造","精心製造"],["精心杰作","精心傑作"],["精悟玄鉴","精悟玄鑑"],["精明干练","精明幹練"],["精明强干","精明強幹"],["精明能干","精明能幹"],["精松","精鬆"],["精核","精核"],["精炼","精煉"],["精炼厂","精煉廠"],["精炼炉","精煉爐"],["精疲力尽","精疲力盡"],["精确","精確"],["精确到","精確到"],["精确度","精確度"],["精确性","精確性"],["精神分裂症","精神分裂症"],["精神官能症","精神官能症"],["精神性厌食症","精神性厭食症"],["精神焕发","精神煥發"],["精神药物","精神藥物"],["精致","精緻"],["精致化","精緻化"],["精致度","精緻度"],["精舍","精舍"],["精虫","精蟲"],["精虫冲脑","精蟲衝腦"],["精诚团结","精誠團結"],["精辟","精闢"],["精通于","精通於"],["精采","精采"],["精采度","精采度"],["精采绝伦","精采絕倫"],["精金百炼","精金百煉"],["精雕","精雕"],["精雕细刻","精雕細刻"],["精雕细琢","精雕細琢"],["精雕细镂","精雕細鏤"],["糅合","糅合"],["糊口","餬口"],["糊涂","糊塗"],["糊涂一时","糊塗一時"],["糊涂帐","糊塗帳"],["糊涂油蒙心","糊塗油蒙心"],["糊涂虫","糊塗蟲"],["糊涂蛋","糊塗蛋"],["糊涂账","糊塗賬"],["糊糊涂涂","糊糊塗塗"],["糊里糊涂","糊里糊塗"],["糕干","糕乾"],["糖厂","糖廠"],["糖堆里养的","糖堆裏養的"],["糖炒栗子","糖炒栗子"],["糖萝卜","糖蘿蔔"],["糖醋里脊","糖醋里脊"],["糙叶树","糙葉樹"],["糙面内质网","糙面內質網"],["糟了","糟了"],["糟糕了","糟糕了"],["糟透了","糟透了"],["糟齿类爬虫","糟齒類爬蟲"],["糠穗","糠穗"],["糯米团","糯米糰"],["系一片","係一片"],["系一番","係一番"],["系一种","係一種"],["系一线","繫一線"],["系上","繫上"],["系世","繫世"],["系丝带","繫絲帶"],["系个","繫個"],["系为","係爲"],["系主任","系主任"],["系了","繫了"],["系争","係爭"],["系争物","係爭物"],["系于","繫於"],["系于一发","繫於一髮"],["系住","繫住"],["系出名门","系出名門"],["系刊","系刊"],["系列","系列"],["系列化","系列化"],["系列战","系列戰"],["系列放大器","系列放大器"],["系列片","系列片"],["系列电视剧","系列電視劇"],["系列赛","系列賽"],["系列里","系列裏"],["系到","繫到"],["系务","系務"],["系发带","繫髮帶"],["系命","繫命"],["系囚","繫囚"],["系头巾","繫頭巾"],["系好","繫好"],["系孙","系孫"],["系学会","系學會"],["系带","繫帶"],["系心","繫心"],["系念","繫念"],["系怀","繫懷"],["系恋","繫戀"],["系所","系所"],["系扣","係扣"],["系指","係指"],["系捻儿","繫捻兒"],["系数","係數"],["系族","系族"],["系有","繫有"],["系条","繫條"],["系泊","繫泊"],["系爪","繫爪"],["系爲","係爲"],["系牢","繫牢"],["系狱","繫獄"],["系璧","系璧"],["系留","繫留"],["系着","繫着"],["系系","繫系"],["系紧","繫緊"],["系累","繫累"],["系结","繫結"],["系统","系統"],["系统分析","系統分析"],["系统分类","系統分類"],["系统化","系統化"],["系统发育","系統發育"],["系统商","系統商"],["系统图","系統圖"],["系统工程","系統工程"],["系统性","系統性"],["系统抽样法","系統抽樣法"],["系统流程图","系統流程圖"],["系统理论","系統理論"],["系统级","系統級"],["系统论","系統論"],["系统设计","系統設計"],["系统软体","系統軟體"],["系统部","系統部"],["系绳","繫繩"],["系缆","繫纜"],["系缚","繫縛"],["系而不食","繫而不食"],["系胄","系胄"],["系腰","繫腰"],["系臂","係臂"],["系臂之宠","繫臂之寵"],["系船桩","繫船樁"],["系花","系花"],["系获","係獲"],["系裤子","繫褲子"],["系裹","繫裹"],["系词","系詞"],["系谱","系譜"],["系趾","繫趾"],["系踵","係踵"],["系蹄","係蹄"],["系辞","繫辭"],["系里","系裏"],["系铃人","繫鈴人"],["系铃解铃","繫鈴解鈴"],["系鞋带","繫鞋帶"],["系颈","繫頸"],["系颈阙庭","係頸闕庭"],["系风捕影","繫風捕影"],["系风捕景","繫風捕景"],["系馆","系館"],["系马","繫馬"],["素借","素藉"],["素发","素髮"],["素志","素志"],["素愿","素願"],["素未谋面","素未謀面"],["素朴","素樸"],["素面","素面","素麪"],["素面朝天","素面朝天"],["素食面","素食麪"],["素餐尸位","素餐尸位"],["索价","索價"],["索价过高","索價過高"],["索克","索克"],["索克斯队","索克斯隊"],["索合","索合"],["索夫克","索夫克"],["索夫克郡","索夫克郡"],["索尔兹伯里平原","索爾茲伯里平原"],["索尔兹伯里石环","索爾茲伯里石環"],["索尽枯肠","索盡枯腸"],["索托","索托"],["索杰纳","索傑納"],["索福克勒斯","索福克勒斯"],["索福克里斯","索福克裏斯"],["索里亚","索里亞"],["索里士","索里士"],["索面","索麪"],["索馬里","索馬里"],["索马里","索馬里"],["索马里亚","索馬里亞"],["紧了","緊了"],["紧关里","緊關裏"],["紧密配合","緊密配合"],["紧急制动","緊急制動"],["紧急集合","緊急集合"],["紧扣","緊扣"],["紧挨","緊挨"],["紧溜子里","緊溜子裏"],["紧系","緊繫"],["紧绷","緊繃"],["紧绷着","緊繃着"],["紧绷绷","緊繃繃"],["紧致","緊緻"],["紧追不舍","緊追不捨"],["紧随其后","緊隨其後"],["紫云","紫雲"],["紫云乡","紫雲鄉"],["紫云苗族布依族自治县","紫云苗族布依族自治縣"],["紫云英","紫雲英"],["紫台","紫臺"],["紫姜","紫薑"],["紫微斗数","紫微斗數"],["紫穗槐","紫穗槐"],["紫苏","紫蘇"],["紫苏属","紫蘇屬"],["紫苏梅","紫蘇梅"],["紫药水","紫藥水"],["紫金山天文台","紫金山天文臺"],["累了","累了"],["累囚","累囚"],["累块积苏","累塊積蘇"],["累堆","累堆"],["累瓦结绳","累瓦結繩"],["累积性伤害症候群","累積性傷害症候羣"],["累积折耗","累積折耗"],["累绁","累紲"],["累臣","累臣"],["絣扒吊拷","絣扒吊拷"],["綑了","綑了"],["綑吊","綑吊"],["綑扎","綑紮"],["緝凶","緝兇"],["縻系","縻繫"],["繁台","繁臺"],["繁复","繁複"],["繁征博引","繁徵博引"],["繁殖系数","繁殖係數"],["繁钟","繁鐘"],["繃价","繃價"],["繃针","繃針"],["纂修","纂修"],["纂胄","纂胄"],["纠合","糾合"],["纡余","紆餘"],["纡回","紆迴"],["纡曲","紆曲"],["纡朱怀金","紆朱懷金"],["纡郁","紆鬱"],["红丝暗系","紅絲暗繫"],["红中白板","紅中白板"],["红了","紅了"],["红云","紅雲"],["红光满面","紅光滿面"],["红冬冬","紅鼕鼕"],["红发","紅髮"],["红发女郎","紅髮女郎"],["红叶","紅葉"],["红叶之题","紅葉之題"],["红叶少棒队","紅葉少棒隊"],["红叶村","紅葉村"],["红叶杯","紅葉盃"],["红叶树","紅葉樹"],["红叶题诗","紅葉題詩"],["红头发","紅頭髮"],["红姑娘","紅姑娘"],["红娘","紅娘"],["红孩症","紅孩症"],["红尘万丈","紅塵萬丈"],["红岩","紅巖"],["红得发紫","紅得發紫"],["红日当午","紅日當午"],["红曲","紅曲"],["红杏出墙","紅杏出牆"],["红杠","紅槓"],["红松","紅松"],["红极一时","紅極一時"],["红牙板","紅牙板"],["红眼症","紅眼症"],["红种人","紅種人"],["红紫乱朱","紅紫亂朱"],["红绳系足","紅繩繫足"],["红胡子","紅鬍子"],["红色娘子军","紅色娘子軍"],["红色系","紅色系"],["红花绿叶","紅花綠葉"],["红药","紅藥"],["红药水","紅藥水"],["红萝卜","紅蘿蔔"],["红萝卜炒辣椒","紅蘿蔔炒辣椒"],["红虫","紅蟲"],["红运当头","紅運當頭"],["红醋栗","紅醋栗"],["红钟","紅鐘"],["红铃虫","紅鈴蟲"],["红霉素","紅黴素"],["红面番鸭","紅面番鴨"],["红须绿眼","紅鬚綠眼"],["纤不盈握","纖不盈握"],["纤丽","纖麗"],["纤云","纖雲"],["纤人","纖人"],["纤介","纖介"],["纤体","纖體"],["纤儿","纖兒"],["纤夫","縴夫"],["纤妍","纖妍"],["纤密","纖密"],["纤小","纖小"],["纤尘不染","纖塵不染"],["纤屑","纖屑"],["纤巧","纖巧"],["纤度","纖度"],["纤弱","纖弱"],["纤微","纖微"],["纤悉","纖悉"],["纤悉无遗","纖悉無遺"],["纤户","縴戶"],["纤手","纖手","縴手"],["纤指","纖指"],["纤柔","纖柔"],["纤毛","纖毛"],["纤毛动力蛋白","纖毛動力蛋白"],["纤毛虫","纖毛蟲"],["纤毛运动","纖毛運動"],["纤毫","纖毫"],["纤玉","纖玉"],["纤画","纖畫"],["纤瘦","纖瘦"],["纤离","纖離"],["纤秾中度","纖穠中度"],["纤纤","纖纖"],["纤纤弱质","纖纖弱質"],["纤纤玉手","纖纖玉手"],["纤细","纖細"],["纤细画","纖細畫"],["纤维","纖維"],["纤维丛","纖維叢"],["纤维光学","纖維光學"],["纤维化","纖維化"],["纤维囊泡症","纖維囊泡症"],["纤维工业","纖維工業"],["纤维板","纖維板"],["纤维植物","纖維植物"],["纤维状","纖維狀"],["纤维素","纖維素"],["纤维细胞","纖維細胞"],["纤维肌痛","纖維肌痛"],["纤维胶","纖維膠"],["纤维蛋原","纖維蛋原"],["纤维蛋白","纖維蛋白"],["纤维蛋白原","纖維蛋白原"],["纤维质","纖維質"],["纤维镜","纖維鏡"],["纤维长度","纖維長度"],["纤美","纖美"],["纤腰","纖腰"],["纤芥不遗","纖芥不遺"],["纤芯直径","纖芯直徑"],["纤长","纖長"],["纤阿","纖阿"],["约克","約克"],["约克夏","約克夏"],["约克夏猪","約克夏豬"],["约克曼","約克曼"],["约克维奇","約克維奇"],["约克郡","約克郡"],["约出","約出"],["约占","約佔"],["约同","約同"],["约当现金","約當現金"],["约据","約據"],["约柜","約櫃"],["约核","約核"],["约等于","約等於"],["约维克","約維克"],["约翰参书","約翰參書"],["约翰松","約翰松"],["级任制","級任制"],["级别","級別"],["纪元后","紀元後"],["纪历","紀曆"],["纪录","紀錄"],["纪录下来","紀錄下來"],["纪录创造者","紀錄創造者"],["纪录器","紀錄器"],["纪录点","紀錄點"],["纪录片","紀錄片"],["纪录片儿","紀錄片兒"],["纪录片奖","紀錄片獎"],["纪录表","紀錄表"],["纪念","紀念"],["纪念周","紀念週"],["纪里谷","紀里谷"],["纯属巧合","純屬巧合"],["纯情蜡妹","純情蠟妹"],["纯朴","純樸"],["纯种","純種"],["纯种牛","純種牛"],["纯种马","純種馬"],["纱厂","紗廠"],["纱布","紗布"],["纱布口罩","紗布口罩"],["纱布绷带","紗布繃帶"],["纲鉴","綱鑑"],["纳修斯","納修斯"],["纳克希班迪","納克希班迪"],["纳合","納合"],["纳吉布","納吉布"],["纳奇录异","納奇錄異"],["纳征","納徵"],["纳德阿里","納德阿里"],["纳扎尔巴耶夫","納扎爾巴耶夫"],["纳斯达克","納斯達克"],["纳杰夫","納傑夫"],["纳波里塔诺","納波里塔諾"],["纳米技术","納米技術"],["纳粹党","納粹黨"],["纳莉台风","納莉颱風"],["纳采","納采"],["纵出","縱出"],["纵切面","縱切面"],["纵剖面","縱剖面"],["纵向","縱向"],["纵情恣欲","縱情恣欲"],["纵情遂欲","縱情遂欲"],["纵断面","縱斷面"],["纵曲枉直","縱曲枉直"],["纵梁","縱梁"],["纵横交布","縱橫交佈"],["纵欲","縱慾"],["纵欲主义","縱慾主義"],["纵欲无度","縱慾無度"],["纵谷","縱谷"],["纵谷区","縱谷區"],["纷如烟","紛如煙"],["纸制","紙製"],["纸卷子","紙卷子"],["纸叶子","紙葉子"],["纸团","紙團"],["纸尿布","紙尿布"],["纸扎","紙紮"],["纸扎店","紙紮店"],["纸杯","紙杯"],["纸板","紙板"],["纸板盒","紙板盒"],["纸板部","紙板部"],["纸浆厂","紙漿廠"],["纸烟","紙菸"],["纸雕","紙雕"],["纸面","紙面"],["纹光针","紋光針"],["纹板","紋板"],["纹面","紋面"],["纺纤","紡纖"],["纺纱厂","紡紗廠"],["纺织厂","紡織廠"],["纺织娘","紡織娘"],["纺锤虫","紡錘蟲"],["纽几内亚","紐幾內亞"],["纽华克","紐華克"],["纽扣","鈕釦"],["纽瓦克","紐瓦克"],["纽芬兰与拉布拉多","紐芬蘭與拉布拉多"],["纽蒙特","紐蒙特"],["纾困","紓困"],["线上","線上"],["线团","線團"],["线性系统","線性系統"],["线性规划","線性規劃"],["线虫","線蟲"],["练习曲","練習曲"],["练了","練了"],["练出","練出"],["练出来","練出來"],["练团室","練團室"],["练声曲","練聲曲"],["练武术","練武術"],["组党","組黨"],["组别","組別"],["组合","組合"],["组合为","組合爲"],["组合式","組合式"],["组合成","組合成"],["组合数学","組合數學"],["组合服装","組合服裝"],["组合法","組合法"],["组合而成","組合而成"],["组合菜","組合菜"],["组合论","組合論"],["组合语言","組合語言"],["组合音响","組合音響"],["组团","組團"],["组曲","組曲"],["组立式建筑","組立式建築"],["组里","組裏"],["细不容发","細不容髮"],["细别","細別"],["细叶山茶","細葉山茶"],["细叶脉","細葉脈"],["细叶金午时花","細葉金午時花"],["细咽","細嚥"],["细如发","細如髮"],["细娘","細娘"],["细布","細布"],["细曲","細曲"],["细术","細術"],["细炼","細鍊"],["细胞周期","細胞週期"],["细胞融合","細胞融合"],["细致","細緻"],["细致入微","細緻入微"],["细蒙蒙","細濛濛"],["细表","細表"],["细袅袅","細嫋嫋"],["细针密缕","細針密縷"],["细雨蒙蒙","細雨濛濛"],["细雨蒙蒙忆当年","細雨濛濛憶當年"],["织出","織出"],["织布","織布"],["织布厂","織布廠"],["织布娘","織布娘"],["织布机","織布機"],["织席","織蓆"],["织当访婢","織當訪婢"],["织锦回文","織錦回文"],["终了","終了"],["终于","終於"],["终制","終制"],["终南别业","終南別業"],["终归于","終歸於"],["终曲","終曲"],["终极","終極"],["终极杀阵","終極殺陣"],["终极目标","終極目標"],["终止症","終止症"],["终焉之志","終焉之志"],["终端台","終端檯"],["终而复始","終而復始"],["终身有托","終身有托"],["终须","終須"],["绉布","縐布"],["经世之才","經世之才"],["经世致用","經世致用"],["经丝彩色显花","經絲彩色顯花"],["经典动力系统","經典動力系統"],["经制","經制"],["经卷","經卷"],["经厂本","經廠本"],["经历","經歷"],["经历过","經歷過"],["经历风雨","經歷風雨"],["经发","經發"],["经合会","經合會"],["经合组织","經合組織"],["经国之才","經國之才"],["经坛","經壇"],["经折","經摺"],["经折装","經摺裝"],["经曲","經曲"],["经有云","經有云"],["经术","經術"],["经板儿","經板兒"],["经济之才","經濟之才"],["经济体制","經濟體制"],["经济体系","經濟體系"],["经济制度","經濟制度"],["经济制裁","經濟制裁"],["经济协力开发机构","經濟協力開發機構"],["经济发展","經濟發展"],["经济合作与发展组织","經濟合作與發展組織"],["经济合作开发组织","經濟合作開發組織"],["经济周期","經濟週期"],["经济困境","經濟困境"],["经济技术","經濟技術"],["经济槓杆","經濟槓桿"],["经济系","經濟系"],["经济范畴","經濟範疇"],["经济落后","經濟落後"],["经济计划","經濟計劃"],["经济部标准检验局","經濟部標準檢驗局"],["经济面","經濟面"],["经营决策资讯系统","經營決策資訊系統"],["经营范围","經營範圍"],["经贸关系","經貿關係"],["经验丰富","經驗豐富"],["绑回","綁回"],["绑回去","綁回去"],["绑回来","綁回來"],["绑扎","綁紮"],["绒布","絨布"],["结了","結了"],["结仇","結仇"],["结伙","結夥"],["结伙抢劫","結夥搶劫"],["结伴同游","結伴同遊"],["结伴同行","結伴同行"],["结余","結餘"],["结党","結黨"],["结党聚群","結黨聚羣"],["结党营私","結黨營私"],["结党连群","結黨連羣"],["结出","結出"],["结制","結制"],["结发","結髮"],["结发事师","結髮事師"],["结发人","結髮人"],["结发夫妻","結髮夫妻"],["结合","結合"],["结合为","結合爲"],["结合体","結合體"],["结合剂","結合劑"],["结合实际","結合實際"],["结合律","結合律"],["结合成","結合成"],["结合模型","結合模型"],["结合水","結合水"],["结合点","結合點"],["结合线","結合線"],["结合能","結合能"],["结合起来","結合起來"],["结合过程","結合過程"],["结合韵","結合韻"],["结合韵母","結合韻母"],["结彩","結綵"],["结扎","結紮"],["结扎手术","結紮手術"],["结扎术","結紮術"],["结托","結托"],["结扣","結釦"],["结晶岩","結晶岩"],["结核","結核"],["结核杆菌","結核桿菌"],["结梁子","結樑子"],["结汇","結匯"],["结汇证","結匯證"],["结草虫","結草蟲"],["结采","結采"],["绕回","繞回"],["绕梁","繞樑"],["绕梁三日","繞樑三日"],["绕梁之音","繞樑之音"],["绕梁韵永","繞樑韻永"],["绘事后素","繪事後素"],["绘出","繪出"],["绘制","繪製"],["绘制图","繪製圖"],["绘图板","繪圖板"],["绘彩陶","繪彩陶"],["绘画板","繪畫板"],["绘里","繪里"],["给个棒锤当针认","給個棒錘當針認"],["给于","給於"],["给价","給價"],["给出","給出"],["给我干脆","給我乾脆"],["给药","給藥"],["绚丽多彩","絢麗多彩"],["绚烂归于平淡","絢爛歸於平淡"],["络合","絡合"],["络合物","絡合物"],["络绎于途","絡繹於途"],["络腮胡","絡腮鬍"],["络腮胡子","絡腮鬍子"],["绝不相同","絕不相同"],["绝世出尘","絕世出塵"],["绝于","絕於"],["绝后","絕後"],["绝后光前","絕後光前"],["绝后患","絕後患"],["绝后计","絕後計"],["绝对参照","絕對參照"],["绝岩","絕巖"],["绝才","絕才"],["绝望已极","絕望已極"],["绝症","絕症"],["绝种","絕種"],["绝缘台","絕緣檯"],["绞刑台","絞刑臺"],["绞包针","絞包針"],["绞尽","絞盡"],["绞尽脑汁","絞盡腦汁"],["绞干","絞乾"],["绞面","絞面"],["统一党","統一黨"],["统一发票","統一發票"],["统一规划","統一規劃"],["统一规范","統一規範"],["统一计划","統一計劃"],["统制","統制"],["统合","統合"],["统合体","統合體"],["统合力","統合力"],["统合性","統合性"],["统御","統御"],["统筹规划","統籌規劃"],["统计出","統計出"],["统计制图","統計製圖"],["统计图表","統計圖表"],["统计数据","統計數據"],["统计表","統計表"],["绢布版","絹布版"],["绣像","繡像"],["绣出","繡出"],["绣口","繡口"],["绣帘","繡簾"],["绣得","繡得"],["绣户","繡戶"],["绣房","繡房"],["绣毯","繡毯"],["绣球","繡球"],["绣的","繡的"],["绣花","繡花"],["绣花针","繡花針"],["绣花针儿","繡花針兒"],["绣虎雕龙","繡虎雕龍"],["绣衣","繡衣"],["绣衣御史","繡衣御史"],["绣衣朱履","繡衣朱履"],["绣起","繡起"],["绣针","繡針"],["绣阁","繡閣"],["绣面","繡面"],["绣鞋","繡鞋"],["绦虫","絛蟲"],["绦虫纲","絛蟲綱"],["继天立极","繼天立極"],["继志","繼志"],["继志述事","繼志述事"],["继续干","繼續幹"],["绪余","緒餘"],["绪胄","緒胄"],["续借","續借"],["续借手续","續借手續"],["续发性","續發性"],["续发感染","續發感染"],["续后","續後"],["续后汉书","續後漢書"],["续弦","續絃"],["续杯","續杯"],["续签","續簽"],["续西游记","續西遊記"],["续通志","續通志"],["绮云","綺雲"],["绮想曲","綺想曲"],["绰板","綽板"],["绰板婆","綽板婆"],["绰绰有余","綽綽有餘"],["绳扣","繩釦"],["维修","維修"],["维修区","維修區"],["维修费","維修費"],["维克","維克"],["维克佛瑞柏加","維克佛瑞柏加"],["维克利","維克利"],["维克托","維克托"],["维几尼亚","維幾尼亞"],["维几尼亚州","維幾尼亞州"],["维基数据","維基數據"],["维基物种","維基物種"],["维多利亚瀑布","維多利亞瀑布"],["维多里欧","維多里歐"],["维尔布鲁根","維爾布魯根"],["维斗","維斗"],["维斯杯","維斯杯"],["维杰辛","維傑辛"],["维科扬斯克","維科揚斯克"],["维系","維繫"],["维系人心","維繫人心"],["维苏威","維蘇威"],["维苏威火山","維蘇威火山"],["绵中刺笑里刀","綿中刺笑裏刀"],["绵历","綿歷"],["绵延不尽","綿延不盡"],["绵里藏针","綿裏藏針"],["绵里针","綿裏針"],["绷住","繃住"],["绷场面","繃場面"],["绷子","繃子"],["绷巴吊拷","繃巴吊拷"],["绷带","繃帶"],["绷开","繃開"],["绷扒吊拷","繃扒吊拷"],["绷爬吊拷","繃爬吊拷"],["绷紧","繃緊"],["绷脸","繃臉"],["绸布","綢布"],["绸缎庄","綢緞莊"],["综合","綜合"],["综合业务数字网","綜合業務數字網"],["综合体","綜合體"],["综合医院","綜合醫院"],["综合叙述","綜合敘述"],["综合型","綜合型"],["综合存款","綜合存款"],["综合布线","綜合佈線"],["综合平衡","綜合平衡"],["综合征","綜合徵"],["综合性","綜合性"],["综合所得","綜合所得"],["综合所得税","綜合所得稅"],["综合扩大机","綜合擴大機"],["综合报导","綜合報導"],["综合报道","綜合報道"],["综合服务数位网络","綜合服務數位網絡"],["综合杂志","綜合雜誌"],["综合法","綜合法"],["综合症","綜合症"],["综合类","綜合類"],["综合艺术","綜合藝術"],["综合语","綜合語"],["综合课","綜合課"],["综合银行","綜合銀行"],["综合防治","綜合防治"],["综合险","綜合險"],["综核","綜覈"],["综艺团","綜藝團"],["绽出","綻出"],["绽放出","綻放出"],["绾发","綰髮"],["绿云","綠雲"],["绿党","綠黨"],["绿发","綠髮"],["绿叶","綠葉"],["绿叶成荫","綠葉成蔭"],["绿叶成阴","綠葉成陰"],["绿暗红稀","綠暗紅稀"],["绿松石","綠松石"],["绿游网","綠遊網"],["绿烟红雾","綠煙紅霧"],["绿蜡","綠蠟"],["绿衣黄里","綠衣黃裏"],["绿鬓朱颜","綠鬢朱顏"],["缀出","綴出"],["缀合","綴合"],["缆索吊椅","纜索吊椅"],["缉凶","緝兇"],["缉获","緝獲"],["缎面","緞面"],["缓了","緩了"],["缓冲","緩衝"],["缓冲体","緩衝體"],["缓冲作用","緩衝作用"],["缓冲剂","緩衝劑"],["缓冲区","緩衝區"],["缓冲器","緩衝器"],["缓冲国","緩衝國"],["缓冲地","緩衝地"],["缓冲地区","緩衝地區"],["缓冲地带","緩衝地帶"],["缓冲式","緩衝式"],["缓冲期","緩衝期"],["缓冲液","緩衝液"],["缓冲溶液","緩衝溶液"],["缓发中子","緩發中子"],["缓征","緩徵"],["缔造出","締造出"],["缕当","縷當"],["编个","編個"],["编了","編了"],["编余","編余"],["编余人员","編餘人員"],["编修","編修"],["编写出","編寫出"],["编出","編出"],["编出来","編出來"],["编列出","編列出"],["编制","編制","編製"],["编制成","編製成"],["编制法","編制法"],["编发","編髮"],["编录","編錄"],["编曲","編曲"],["编构出","編構出"],["编注","編注"],["编目表格","編目表格"],["编目记录","編目記錄"],["编目记录输入","編目記錄輸入"],["编码系统","編碼系統"],["编码表","編碼表"],["编算出","編算出"],["编织出","編織出"],["编选出","編選出"],["编造出","編造出"],["编采","編採"],["编钟","編鐘"],["缘分已尽","緣分已盡"],["缙云","縉雲"],["缙云县","縉雲縣"],["缜致","縝緻"],["缝个","縫個"],["缝了","縫了"],["缝制","縫製"],["缝制成","縫製成"],["缝合","縫合"],["缝合处","縫合處"],["缝合带","縫合帶"],["缝合线","縫合線"],["缝衣针","縫衣針"],["缝里","縫裏"],["缝针","縫針"],["缝针补线","縫針補線"],["缝针迹","縫針跡"],["缠回","纏回"],["缠斗","纏鬥"],["缣缃黄卷","縑緗黃卷"],["缥致","縹致"],["缦胡","縵胡"],["缩合","縮合"],["缩回","縮回"],["缩回去","縮回去"],["缩回来","縮回來"],["缩影微卷","縮影微捲"],["缩成一团","縮成一團"],["缩栗","縮慄"],["缪种流传","繆種流傳"],["缮修","繕修"],["缱绻难舍","繾綣難捨"],["缴不出来","繳不出來"],["缴出","繳出"],["缴出去","繳出去"],["缴出来","繳出來"],["缴卷","繳卷"],["缴回","繳回"],["缴白卷","繳白卷"],["缴获","繳獲"],["缺乏症","缺乏症"],["缺氧症","缺氧症"],["缺课纪录","缺課紀錄"],["缾沉簪折","缾沉簪折"],["罂粟种子","罌粟種子"],["罄尽","罄盡"],["网上杂志","網上雜誌"],["网坛","網壇"],["网坛史","網壇史"],["网布","網布"],["网开一面","網開一面"],["网开三面","網開三面"],["网御","網禦"],["网志","網誌"],["网志上","網誌上"],["网扣","網扣"],["网游","網遊"],["网状系统","網狀系統"],["网管系统","網管系統"],["网络技术","網絡技術"],["网络操作系统","網絡操作系統"],["网络游戏","網絡遊戲"],["网络管理系统","網絡管理系統"],["网络规划人员","網絡規劃人員"],["网罗人才","網羅人才"],["网里","網裏"],["网际电台","網際電臺"],["罔极","罔極"],["罗克耶","羅克耶"],["罗兴梁","羅興樑"],["罗圣杰","羅聖傑"],["罗宗胜","羅宗勝"],["罗密欧与朱丽叶","羅密歐與朱麗葉"],["罗密欧与茱丽叶","羅密歐與茱麗葉"],["罗布","羅布"],["罗布林卡","羅布林卡"],["罗布森","羅布森"],["罗布泊","羅布泊"],["罗布麻","羅布麻"],["罗式几何","羅式幾何"],["罗彦杰","羅彥傑"],["罗德里奎兹","羅德里奎茲"],["罗德里格兹","羅德里格茲"],["罗德里格斯","羅德里格斯"],["罗德里盖兹","羅德里蓋茲"],["罗志恩","羅志恩"],["罗志明","羅志明"],["罗志祥","羅志祥"],["罗志良","羅志良"],["罗拉巴克","羅拉巴克"],["罗斯托克","羅斯托克"],["罗斯托夫","羅斯托夫"],["罗时丰","羅時豐"],["罗曼蒂克","羅曼蒂克"],["罗杰","羅傑"],["罗杰斯","羅傑斯"],["罗杰斯杯","羅傑斯杯"],["罗柜","羅櫃"],["罗氏几何","羅氏幾何"],["罗汉松","羅漢松"],["罗盘针","羅盤針"],["罗素克洛","羅素克洛"],["罗胡斯","羅胡斯"],["罗致","羅致"],["罗致人材","羅致人材"],["罗致政","羅致政"],["罗蒙诺索","羅蒙諾索"],["罗西里尼","羅西里尼"],["罗迪克","羅迪克"],["罗马建筑","羅馬建築"],["罗马里奥","羅馬裏奧"],["罚不当罪","罰不當罪"],["罚个","罰個"],["罚了","罰了"],["罚出","罰出"],["罚出去","罰出去"],["罚出来","罰出來"],["罢了","罷了"],["罢于","罷於"],["罢于奔命","罷於奔命"],["罢黜百家独尊儒术","罷黜百家獨尊儒術"],["罩杯","罩杯"],["罪大恶极","罪大惡極"],["罪当万死","罪當萬死"],["罪恶","罪惡"],["罪恶如山","罪惡如山"],["罪恶感","罪惡感"],["罪恶深重","罪惡深重"],["罪恶滔天","罪惡滔天"],["罪恶累累","罪惡累累"],["罪恶行径","罪惡行徑"],["罪恶贯盈","罪惡貫盈"],["罪证确凿","罪證確鑿"],["罪该万死","罪該萬死"],["置之死地而后生","置之死地而後生"],["置之脑后","置之腦後"],["置于","置於"],["置信系数","置信係數"],["置换术","置換術"],["置物柜","置物櫃"],["置言成范","置言成範"],["羁系","羈繫"],["羊卜","羊卜"],["羊布婚","羊布婚"],["羊拐","羊拐"],["羊毛出在羊身上","羊毛出在羊身上"],["羊瘙痒症","羊瘙癢症"],["羊群里跑出骆驼来","羊羣裏跑出駱駝來"],["羊肉落在狗嘴里","羊肉落在狗嘴裏"],["羊膜穿刺术","羊膜穿刺術"],["羊舍","羊舍"],["羊角面包","羊角麪包"],["羊须疮","羊鬚瘡"],["羌胡","羌胡"],["美不胜收","美不勝收"],["美丑","美醜"],["美于","美於"],["美仑","美崙"],["美仑美奂","美侖美奐"],["美利坚合众国","美利堅合衆國"],["美制","美製"],["美占","美佔"],["美发","美髮"],["美发业","美髮業"],["美发师","美髮師"],["美发店","美髮店"],["美台","美臺"],["美后","美后"],["美国制","美國製"],["美国参议院","美國參議院"],["美国国际开发总署","美國國際開發總署"],["美国国际集团","美國國際集團"],["美国在台协会","美國在臺協會"],["美国存托凭证","美國存託憑證"],["美国总统报复权","美國總統報復權"],["美国标准交换码","美國標準交換碼"],["美国谷","美國谷"],["美国资讯交换标准码","美國資訊交換標準碼"],["美女如云","美女如雲"],["美娇娘","美嬌娘"],["美容手术","美容手術"],["美容术","美容術"],["美恶","美惡"],["美才","美才"],["美日关系","美日關係"],["美术","美術"],["美术史","美術史"],["美术品","美術品"],["美术商","美術商"],["美术大师","美術大師"],["美术字","美術字"],["美术家","美術家"],["美术灯","美術燈"],["美术班","美術班"],["美术电影","美術電影"],["美术界","美術界"],["美术系","美術系"],["美术节","美術節"],["美术设计","美術設計"],["美术课","美術課"],["美术馆","美術館"],["美林集团","美林集團"],["美沙冬","美沙冬"],["美泽鉴人","美澤鑑人"],["美洲杯","美洲盃"],["美白针","美白針"],["美穗","美穗"],["美系","美系"],["美耐板","美耐板"],["美苏","美蘇"],["美苏关系","美蘇關係"],["美里","美里"],["美里达","美里達"],["羑里","羑里"],["羚羊挂角","羚羊掛角"],["羞于","羞於"],["羞于启齿","羞於啓齒"],["羞以牛后","羞以牛後"],["羞恶","羞惡"],["羞恶之心","羞惡之心"],["羞愧难当","羞愧難當"],["羞面见人","羞面見人"],["羡余","羨餘"],["羡叹","羨歎"],["群丑","羣醜"],["群众关系","羣衆關係"],["群众团体","羣衆團體"],["群后","羣后"],["群系","羣系"],["群而不党","羣而不黨"],["群谋咸同","羣謀咸同"],["群轻折轴","羣輕折軸"],["群辟","羣辟"],["群雕","羣雕"],["羹里来饭里去","羹裏來飯裏去"],["羽毛丰满","羽毛豐滿"],["羽毛未丰","羽毛未豐"],["羽状复叶","羽狀複葉"],["羽翼丰满","羽翼豐滿"],["羽翼已丰","羽翼已豐"],["羽虫","羽蟲"],["翁同和","翁同和"],["翁同龢","翁同龢"],["翁山苏姬","翁山蘇姬"],["翁干晃","翁乾晃"],["翁郁容","翁郁容"],["翊赞","翊贊"],["翕辟","翕闢"],["翘了","翹了"],["翘出","翹出"],["翘出去","翹出去"],["翘出来","翹出來"],["翘曲","翹曲"],["翘翘板","翹翹板"],["翠云裘","翠雲裘"],["翡翠谷","翡翠谷"],["翦彩","翦綵"],["翰墨志","翰墨志"],["翱游","翱遊"],["翱游四海","翱遊四海"],["翻个","翻個"],["翻了","翻了"],["翻云复雨","翻雲覆雨"],["翻云覆雨","翻雲覆雨"],["翻修","翻修"],["翻出","翻出"],["翻出去","翻出去"],["翻出来","翻出來"],["翻卷","翻卷"],["翻台","翻檯"],["翻复","翻覆"],["翻复无常","翻覆無常"],["翻天复地","翻天覆地"],["翻录","翻錄"],["翻手为云","翻手爲雲"],["翻手为云覆手变雨","翻手爲雲覆手變雨"],["翻手作云复手雨","翻手作雲覆手雨"],["翻把恩人当仇人","翻把恩人當仇人"],["翻新后","翻新後"],["翻来吊去","翻來吊去"],["翻来复去","翻來覆去"],["翻松","翻鬆"],["翻空出奇","翻空出奇"],["翻筋斗","翻筋斗"],["翻箱倒柜","翻箱倒櫃"],["翻觔斗","翻觔斗"],["翻译出","翻譯出"],["翻跟斗","翻跟斗"],["翻过筋斗","翻過筋斗"],["翻面","翻面"],["翻面皮","翻面皮"],["翾风回雪","翾風迴雪"],["老不修","老不修"],["老个","老個"],["老了","老了"],["老于","老於"],["老于世故","老於世故"],["老人失智症","老人失智症"],["老人癡呆症","老人癡呆症"],["老仆","老僕"],["老克","老克"],["老八板儿","老八板兒"],["老几","老幾"],["老医少卜","老醫少卜"],["老千","老千"],["老古板","老古板"],["老台","老臺"],["老合儿","老合兒"],["老同学","老同學"],["老向","老向"],["老和尚撞钟","老和尚撞鐘"],["老咬虫","老咬蟲"],["老大娘","老大娘"],["老太婆的裹脚布","老太婆的裹腳布"],["老奴才","老奴才"],["老奸","老奸"],["老奸巨猾","老奸巨猾"],["老姑娘","老姑娘"],["老姜","老薑"],["老娘","老孃"],["老娘儿","老孃兒"],["老婆娘","老婆娘"],["老婆当军","老婆當軍"],["老实的终须在","老實的終須在"],["老少一同","老少一同"],["老少咸宜","老少咸宜"],["老干","老幹"],["老干妈","老乾媽"],["老干部","老幹部"],["老年性痴呆症","老年性癡呆症"],["老年痴呆症","老年癡呆症"],["老年癡呆症","老年癡呆症"],["老幼咸宜","老幼咸宜"],["老庄","老莊"],["老当","老當"],["老当益壮","老當益壯"],["老态龙钟","老態龍鍾"],["老斗","老斗"],["老板","老闆"],["老板人","老闆人"],["老板娘","老闆娘"],["老板家","老闆家"],["老残游记","老殘遊記"],["老气横秋","老氣橫秋"],["老烟枪","老煙槍"],["老烟鬼","老煙鬼"],["老熊当道","老熊當道"],["老爷钟","老爺鐘"],["老猫鼻子上挂咸鱼","老貓鼻子上掛鹹魚"],["老王卖瓜自卖自夸","老王賣瓜自賣自誇"],["老皇历","老皇曆"],["老米饭捏杀不成团","老米飯捏殺不成團"],["老糊涂","老糊塗"],["老罴当道","老羆當道"],["老而弥坚","老而彌堅"],["老胡","老胡"],["老腌儿","老醃兒"],["老腌瓜","老醃瓜"],["老臊胡","老臊胡"],["老舍","老舍"],["老蒙","老懞"],["老虎挂念佛珠","老虎掛念佛珠"],["老虎生了翅膀一般","老虎生了翅膀一般"],["老蚌出明珠","老蚌出明珠"],["老表","老表"],["老起面皮","老起面皮"],["老郎庵","老郎庵"],["老雕","老鵰"],["老面子","老面子"],["老面孔","老面孔"],["老面皮","老面皮"],["老骥伏枥志在千里","老驥伏櫪志在千里"],["老鸹窝里出凤凰","老鴰窩裏出鳳凰"],["考个","考個"],["考了","考了"],["考信录","考信錄"],["考克斯","考克斯"],["考出","考出"],["考出来","考出來"],["考前考后","考前考後"],["考卷","考卷"],["考卷纸","考卷紙"],["考后","考後"],["考察团","考察團"],["考征","考徵"],["考据","考據"],["考据学","考據學"],["考核","考覈"],["考种","考種"],["考虑不周","考慮不周"],["考虑周到","考慮周到"],["考试卷","考試卷"],["考试卷子","考試卷子"],["考试范围","考試範圍"],["者回","者回"],["而于","而於"],["而云","而云"],["而今而后","而今而後"],["而克制","而剋制"],["而后","而後"],["而回","而回"],["而胜于蓝","而勝於藍"],["耍奸","耍奸"],["耍得团团转","耍得團團轉"],["耍斗","耍鬥"],["耍笔杆","耍筆桿"],["耍老千","耍老千"],["耐克","耐克"],["耐冬","耐冬"],["耐多药","耐多藥"],["耐多药结核病","耐多藥結核病"],["耐热合金","耐熱合金"],["耐药性","耐藥性"],["耕九余三","耕九餘三"],["耕作制度","耕作制度"],["耕佣","耕傭"],["耕出","耕出"],["耕前耡后","耕前耡後"],["耕地面积","耕地面積"],["耕当问奴","耕當問奴"],["耕当问奴织当访婢","耕當問奴織當訪婢"],["耕御路","耕御路"],["耕种","耕種"],["耕获","耕穫"],["耗尽","耗盡"],["耘荡","耘盪"],["耦合","耦合"],["耳余","耳餘"],["耳刮子","耳刮子"],["耳卜","耳卜"],["耳后","耳後"],["耳提面命","耳提面命"],["耳提面训","耳提面訓"],["耳朵里冒出脚来","耳朵裏冒出腳來"],["耳朵里响","耳朵裏響"],["耳檐儿当不的胡帽","耳檐兒當不的胡帽"],["耳沈","耳沈"],["耳目之欲","耳目之欲"],["耳红面赤","耳紅面赤"],["耳针","耳針"],["耶娘","耶孃"],["耶烈万","耶烈萬"],["耶稣升天节","耶穌升天節"],["耶稣基督后期圣徒教会","耶穌基督後期聖徒教會"],["耸了","聳了"],["耸了耸","聳了聳"],["耸了耸肩","聳了聳肩"],["耸入云霄","聳入雲霄"],["耸出","聳出"],["耻居王后","恥居王後"],["耽于","耽於"],["耿于","耿於"],["耿耿于心","耿耿於心"],["耿耿于怀","耿耿於懷"],["聊个","聊個"],["聊个天","聊個天"],["聊个痛快","聊個痛快"],["聊复备数","聊復備數"],["聊复尔尔","聊復爾爾"],["聊复尔耳","聊復爾耳"],["聊斋志异","聊齋志異"],["聊胜一筹","聊勝一籌"],["聊胜于无","聊勝於無"],["聊表","聊表"],["聊表寸心","聊表寸心"],["聊表心意","聊表心意"],["聋哑症","聾啞症"],["聋虫","聾蟲"],["职业代表制","職業代表制"],["职业倦怠症","職業倦怠症"],["职业团体","職業團體"],["职业水准","職業水準"],["职别","職別"],["职员录","職員錄"],["职员表","職員表"],["职志","職志"],["职权范围","職權範圍"],["职系","職系"],["职能范围","職能範圍"],["职责范围","職責範圍"],["聒噪","聒噪"],["联于","聯於"],["联体别墅","聯體別墅"],["联准会","聯準會"],["联发科","聯發科"],["联合","聯合"],["联合企业","聯合企業"],["联合会","聯合會"],["联合体","聯合體"],["联合作战","聯合作戰"],["联合促销","聯合促銷"],["联合党","聯合黨"],["联合內阁","聯合內閣"],["联合公报","聯合公報"],["联合军演","聯合軍演"],["联合利华","聯合利華"],["联合制","聯合制"],["联合包裹服务公司","聯合包裹服務公司"],["联合参谋","聯合參謀"],["联合发表","聯合發表"],["联合号","聯合號"],["联合国","聯合國"],["联合国日","聯合國日"],["联合国案","聯合國案"],["联合声明","聯合聲明"],["联合大学","聯合大學"],["联合战线","聯合戰線"],["联合报","聯合報"],["联合报系","聯合報系"],["联合政府","聯合政府"],["联合文学","聯合文學"],["联合晚报","聯合晚報"],["联合机","聯合機"],["联合演习","聯合演習"],["联合王国","聯合王國"],["联合目录","聯合目錄"],["联合社","聯合社"],["联合组织","聯合組織"],["联合自强","聯合自強"],["联合舰队","聯合艦隊"],["联合行","聯合行"],["联合行动","聯合行動"],["联合通讯社","聯合通訊社"],["联合部队","聯合部隊"],["联想集团","聯想集團"],["联机游戏","聯機遊戲"],["联盟党","聯盟黨"],["联盟杯","聯盟杯"],["联系","聯繫"],["联系实际","聯繫實際"],["联系方式","聯繫方式"],["联系汇率","聯繫匯率"],["联系群众","聯繫羣衆"],["联赛杯","聯賽盃"],["联邦制","聯邦制"],["聘任制","聘任制"],["聘姑娘","聘姑娘"],["聘雇","聘僱"],["聚了","聚了"],["聚合","聚合"],["聚合体","聚合體"],["聚合作用","聚合作用"],["聚合反应","聚合反應"],["聚合果","聚合果"],["聚合物","聚合物"],["聚合脢","聚合脢"],["聚合资讯订阅","聚合資訊訂閱"],["聚合起来","聚合起來"],["聚合酶","聚合酶"],["聚药雄蕊","聚葯雄蕊"],["聚酯纤维","聚酯纖維"],["聪了","聰了"],["聪明一世糊涂一时","聰明一世糊塗一時"],["聪明才智","聰明才智"],["肃北蒙古族自治县","肅北蒙古族自治縣"],["肆奸植党","肆奸植黨"],["肆志","肆志"],["肇因于","肇因於"],["肉丝面","肉絲麪"],["肉吊窗","肉吊窗"],["肉干","肉乾"],["肉松","肉鬆"],["肉松罐头","肉鬆罐頭"],["肉欲","肉慾"],["肉欲主义","肉慾主義"],["肉毒杆菌","肉毒桿菌"],["肉毒杆菌毒素","肉毒桿菌毒素"],["肉毒梭状芽孢杆菌","肉毒梭狀芽孢桿菌"],["肉汤面","肉湯麪"],["肉穗花序","肉穗花序"],["肉羹面","肉羹麪"],["肉袒面缚","肉袒面縛"],["肉里钱","肉裏錢"],["肉重千斤","肉重千斤"],["肌原纤维","肌原纖維"],["肌理丰盈","肌理豐盈"],["肌纤维","肌纖維"],["肌纤蛋白","肌纖蛋白"],["肌肉发达","肌肉發達"],["肌肉松弛剂","肌肉鬆弛劑"],["肌肉注射","肌肉注射"],["肌肉萎缩症","肌肉萎縮症"],["肌腺症","肌腺症"],["肐膊只折在袖子里","肐膊只折在袖子裏"],["肐膊折了往袖子里藏","肐膊折了往袖子裏藏"],["肘后方","肘後方"],["肘手链足","肘手鍊足"],["肚儿里有勾当","肚兒裏有勾當"],["肚子里点灯","肚子裏點燈"],["肚皮里","肚皮裏"],["肚肠阁落里边","肚腸閣落裏邊"],["肚里","肚裏"],["肚里一轮","肚裏一輪"],["肚里寻思","肚裏尋思"],["肚里明白","肚裏明白"],["肚里的蛔虫","肚裏的蛔蟲"],["肚里说不出来的苦","肚裏說不出來的苦"],["肚里踌躇","肚裏躊躇"],["肚里雷鸣","肚裏雷鳴"],["肚饥","肚飢"],["肝吸虫","肝吸蟲"],["肝脏","肝臟"],["肝脑涂地","肝腦塗地"],["肝郁","肝鬱"],["肠系膜","腸繫膜"],["肠胃药","腸胃藥"],["肠脏","腸臟"],["股东特别大会","股東特別大會"],["股价","股價"],["股价指数","股價指數"],["股份制","股份制"],["股栗","股慄"],["股栗肤粟","股栗膚粟"],["股票价值","股票價值"],["股票价格","股票價格"],["股票投资获利率","股票投資獲利率"],["肢体冲突","肢體衝突"],["肤发","膚髮"],["肥了","肥了"],["肥冬瘦年","肥冬瘦年"],["肥料厂","肥料廠"],["肥水不过别人田","肥水不過別人田"],["肥皂","肥皂"],["肥皂劇","肥皂剧"],["肥皂泡","肥皂泡"],["肥皂粉","肥皂粉"],["肥皂絲","肥皂丝"],["肥皂莢","肥皂荚"],["肥筑方言","肥筑方言"],["肥胖症","肥胖症"],["肥虫蚁","肥蟲蟻"],["肩并肩","肩並肩"],["肩须拍","肩須拍"],["肮肮脏脏","骯骯髒髒"],["肮脏","骯髒"],["肮脏鬼","骯髒鬼"],["肯出","肯出"],["肯出去","肯出去"],["肯出来","肯出來"],["肯回","肯回"],["肯回去","肯回去"],["肯回来","肯回來"],["肯定并例句","肯定並例句"],["肯干","肯幹"],["肯干啊","肯幹啊"],["肯德瑞克","肯德瑞克"],["育乐台","育樂臺"],["育才","育才"],["育种","育種"],["肴馔","餚饌"],["肺出血","肺出血"],["肺叶","肺葉"],["肺吸虫","肺吸蟲"],["肺尘矽症","肺塵矽症"],["肺炎克雷伯氏菌","肺炎克雷伯氏菌"],["肺脏","肺臟"],["肽链","肽鏈"],["肾脏","腎臟"],["肾脏炎","腎臟炎"],["肾脏病","腎臟病"],["肾脏癌","腎臟癌"],["肾脏科","腎臟科"],["肿大症","腫大症"],["肿瘤切除术","腫瘤切除術"],["胁制","脅制"],["胃出血","胃出血"],["胃脏","胃臟"],["胃药","胃藥"],["胃药片","胃藥片"],["胃里","胃裏"],["胄嗣","胄嗣"],["胄子","胄子"],["胄序","胄序"],["胄族","胄族"],["胄甲","冑甲"],["胄监","胄監"],["胄科","冑科"],["胄绪","胄緒"],["胄胤","胄胤"],["胄裔","胄裔"],["胄裔繁衍","胄裔繁衍"],["胄阀","胄閥"],["胆大于天","膽大於天"],["胆大如斗","膽大如斗"],["胆石症","膽石症"],["背人","揹人"],["背他","揹他"],["背你","揹你"],["背來","揹來"],["背债","揹債"],["背出","背出"],["背出去","揹出去"],["背出来","背出來","揹出來"],["背前背后","背前背後"],["背包","揹包"],["背包袱","揹包袱"],["背后","背後"],["背向","背向","揹向"],["背回","揹回"],["背回家去","揹回家去"],["背地里","背地裏"],["背城借一","背城借一"],["背她","揹她"],["背小孩","揹小孩"],["背山面水","背山面水"],["背带","揹帶"],["背我","揹我"],["背暗投明","背暗投明"],["背板","背板"],["背梁骨","背梁骨"],["背榜","揹榜"],["背物","揹物"],["背着","揹着"],["背筐","揹筐"],["背篓","揹簍"],["背胶布","背膠布"],["背负","揹負"],["背走","揹走"],["背酸","背痠"],["背面","背面"],["背风面","背風面"],["背饥荒","揹饑荒"],["胎发","胎髮"],["胎里坏","胎裏壞"],["胎里富","胎裏富"],["胎里毒","胎裏毒"],["胎里素","胎裏素"],["胎面","胎面"],["胖姑娘坐小轿儿","胖姑娘坐小轎兒"],["胚叶","胚葉"],["胚胎发生","胚胎發生"],["胚胎干","胚胎幹"],["胜不骄","勝不驕"],["胜不骄败不馁","勝不驕敗不餒"],["胜之不武","勝之不武"],["胜乐金刚","勝樂金剛"],["胜了","勝了"],["胜事","勝事"],["胜于","勝於"],["胜仗","勝仗"],["胜任","勝任"],["胜任愉快","勝任愉快"],["胜任能力","勝任能力"],["胜会","勝會"],["胜似","勝似"],["胜出","勝出"],["胜利","勝利"],["胜利在望","勝利在望"],["胜利归来","勝利歸來"],["胜利投手","勝利投手"],["胜利果实","勝利果實"],["胜利组","勝利組"],["胜利者","勝利者"],["胜利队","勝利隊"],["胜券","勝券"],["胜券在握","勝券在握"],["胜博殿","勝博殿"],["胜在","勝在"],["胜地","勝地"],["胜境","勝境"],["胜局","勝局"],["胜常","勝常"],["胜得","勝得"],["胜投数","勝投數"],["胜投王","勝投王"],["胜景","勝景"],["胜朝","勝朝"],["胜概","勝概"],["胜残去杀","勝殘去殺"],["胜流","勝流"],["胜游","勝遊"],["胜率","勝率"],["胜的","勝的"],["胜算","勝算"],["胜肽","胜肽"],["胜落袋","勝落袋"],["胜衣","勝衣"],["胜诉","勝訴"],["胜负","勝負"],["胜负乃兵家常事","勝負乃兵家常事"],["胜败","勝敗"],["胜败乃兵家常事","勝敗乃兵家常事"],["胜跡","勝跡"],["胜过","勝過"],["胜过一个诸葛亮","勝過一個諸葛亮"],["胜迹","勝蹟"],["胜部","勝部"],["胜部冠军","勝部冠軍"],["胜键","胜鍵"],["胞子虫","胞子蟲"],["胞芽杯","胞芽杯"],["胡三","胡三"],["胡三省","胡三省"],["胡为慎","胡爲慎"],["胡乐","胡樂"],["胡乱","胡亂"],["胡二巴越","胡二巴越"],["胡云","胡云"],["胡亥","胡亥"],["胡人","胡人"],["胡伶","胡伶"],["胡佛","胡佛"],["胡作非为","胡作非爲"],["胡佩兰","胡佩蘭"],["胡佳","胡佳"],["胡侃","胡侃"],["胡做乔为","胡做喬爲"],["胡儿","胡兒"],["胡元辉","胡元輝"],["胡克","胡克"],["胡克定律","胡克定律"],["胡克斯特拉","胡克斯特拉"],["胡兰成","胡蘭成"],["胡力","胡力"],["胡匪","鬍匪"],["胡卢","胡盧"],["胡卢提","胡盧提"],["胡厮哄","胡廝哄"],["胡厮混","胡廝混"],["胡厮缠","胡廝纏"],["胡吃海喝","胡吃海喝"],["胡吃闷睡","胡吃悶睡"],["胡同","衚衕"],["胡吣","胡唚"],["胡吹","胡吹"],["胡吹乱捧","胡吹亂捧"],["胡吹乱滂","胡吹亂滂"],["胡吹乱诌","胡吹亂謅"],["胡吹大气","胡吹大氣"],["胡哨","胡哨"],["胡喷","胡噴"],["胡嘈","胡嘈"],["胡噜","胡嚕"],["胡国强","胡國強"],["胡图族","胡圖族"],["胡天","胡天"],["胡天胡地","胡天胡地"],["胡天胡帝","胡天胡帝"],["胡夫","胡夫"],["胡如虹","胡如虹"],["胡姑姑","胡姑姑"],["胡姓","胡姓"],["胡姬花","胡姬花"],["胡婷婷","胡婷婷"],["胡子","鬍子"],["胡子工程","鬍子工程"],["胡子拉碴","鬍子拉碴"],["胡子昂","胡子昂"],["胡子渣","鬍子渣"],["胡子阿姨","鬍子阿姨"],["胡孟轩","胡孟軒"],["胡学东","胡學東"],["胡宁","胡寧"],["胡安国","胡安國"],["胡宝元","胡寶元"],["胡富雄","胡富雄"],["胡幼伟","胡幼偉"],["胡幼凤","胡幼鳳"],["胡幼幼","胡幼幼"],["胡床","胡牀"],["胡建雄","胡建雄"],["胡弄局","胡弄局"],["胡彦斌","胡彥斌"],["胡德夫","胡德夫"],["胡心夫","胡心夫"],["胡志强","胡志強"],["胡志明","胡志明"],["胡志明市","胡志明市"],["胡志隆","胡志隆"],["胡忠信","胡忠信"],["胡思","胡思"],["胡思乱想","胡思亂想"],["胡思乱量","胡思亂量"],["胡惟庸","胡惟庸"],["胡想","胡想"],["胡慧中","胡慧中"],["胡才勇","胡才勇"],["胡扑掩","胡撲掩"],["胡扑搭","胡撲搭"],["胡打海摔","胡打海摔"],["胡托莫","胡托莫"],["胡扯","胡扯"],["胡扯八溜","胡扯八溜"],["胡扯淡","胡扯淡"],["胡技烜","胡技烜"],["胡抡混闹","胡掄混鬧"],["胡拉混扯","胡拉混扯"],["胡拨四","胡撥四"],["胡掳","胡擄"],["胡掳忙乱","胡擄忙亂"],["胡搅","胡攪"],["胡搅蛮缠","胡攪蠻纏"],["胡搞","胡搞"],["胡支对","胡支對"],["胡支扯叶","胡支扯葉"],["胡敲","胡敲"],["胡旋舞","胡旋舞"],["胡晓菁","胡曉菁"],["胡服","胡服"],["胡朴安","胡樸安"],["胡来","胡來"],["胡杨","胡楊"],["胡杰","胡杰"],["胡林翼","胡林翼"],["胡枝子","胡枝子"],["胡柏","胡柏"],["胡某","胡某"],["胡柴","胡柴"],["胡根班德","胡根班德"],["胡桃","胡桃"],["胡桃木","胡桃木"],["胡桃科","胡桃科"],["胡桃钳","胡桃鉗"],["胡桃钳组曲","胡桃鉗組曲"],["胡桐","胡桐"],["胡梢","鬍梢"],["胡梦卜","胡夢卜"],["胡梯","胡梯"],["胡椒","胡椒"],["胡椒子","胡椒子"],["胡椒属","胡椒屬"],["胡椒盐","胡椒鹽"],["胡椒粉","胡椒粉"],["胡椒粒","胡椒粒"],["胡椒薄荷","胡椒薄荷"],["胡椒面","胡椒麪"],["胡椒饼","胡椒餅"],["胡歌","胡歌"],["胡歌野调","胡歌野調"],["胡母敬","胡母敬"],["胡汉民","胡漢民"],["胡浩德","胡浩德"],["胡海","胡海"],["胡海峰","胡海峯"],["胡涂","胡塗"],["胡涂虫","胡塗蟲"],["胡淑贞","胡淑貞"],["胡混","胡混"],["胡清晖","胡清暉"],["胡渣","鬍渣"],["胡温新政","胡溫新政"],["胡渰","胡渰"],["胡燕妮","胡燕妮"],["胡爲","胡爲"],["胡牌","胡牌"],["胡猜","胡猜"],["胡琴","胡琴"],["胡琴儿","胡琴兒"],["胡瑗","胡瑗"],["胡瓜","胡瓜"],["胡瓜鱼","胡瓜魚"],["胡碴子","鬍碴子"],["胡祖庆","胡祖慶"],["胡秦","胡秦"],["胡突","胡突"],["胡立宗","胡立宗"],["胡笙","胡笙"],["胡笳","胡笳"],["胡笳十八拍","胡笳十八拍"],["胡粉","胡粉"],["胡素秋","胡素秋"],["胡紫微","胡紫微"],["胡紫薇","胡紫薇"],["胡编乱造","胡編亂造"],["胡缠","胡纏"],["胡羼","胡羼"],["胡耀邦","胡耀邦"],["胡耈","胡耈"],["胡胜川","胡勝川"],["胡胜正","胡勝正"],["胡胡卢卢","胡胡盧盧"],["胡自强","胡自強"],["胡臭","胡臭"],["胡芦巴","胡蘆巴"],["胡荽","胡荽"],["胡萝卜","胡蘿蔔"],["胡萝卜就烧酒","胡蘿蔔就燒酒"],["胡萝卜汁","胡蘿蔔汁"],["胡萝卜素","胡蘿蔔素"],["胡蓝之狱","胡藍之獄"],["胡蔓草","胡蔓草"],["胡蔓藤","胡蔓藤"],["胡虏","胡虜"],["胡蜂","胡蜂"],["胡蝶梦","胡蝶夢"],["胡行","胡行"],["胡行乱作","胡行亂作"],["胡言","胡言"],["胡言乱语","胡言亂語"],["胡言汉语","胡言漢語"],["胡讲","胡講"],["胡诌","胡謅"],["胡诌乱傍","胡謅亂傍"],["胡诌乱扯","胡謅亂扯"],["胡诌乱说","胡謅亂說"],["胡诌乱道","胡謅亂道"],["胡诌八扯","胡謅八扯"],["胡话","胡話"],["胡语","胡語"],["胡说","胡說"],["胡说乱语","胡說亂語"],["胡说乱道","胡說亂道"],["胡说八道","胡說八道"],["胡说散道","胡說散道"],["胡说白道","胡說白道"],["胡豆","胡豆"],["胡赖","胡賴"],["胡越","胡越"],["胡越一家","胡越一家"],["胡适","胡適"],["胡适之","胡適之"],["胡适纪念馆","胡適紀念館"],["胡遮刺","胡遮刺"],["胡鄂公","胡鄂公"],["胡里胡涂","胡里胡塗"],["胡金龙","胡金龍"],["胡铨","胡銓"],["胡铺搭","胡鋪搭"],["胡锦涛","胡錦濤"],["胡长豪","胡長豪"],["胡闹","胡鬧"],["胡雕刺","胡雕刺"],["胡雪岩","胡雪巖"],["胡须","鬍鬚"],["胡须渣","鬍鬚渣"],["胡颓子","胡頹子"],["胡风","胡風"],["胡饼","胡餅"],["胡马","胡馬"],["胡马依北风","胡馬依北風"],["胡骑","胡騎"],["胡髭","鬍髭"],["胡髯","鬍髯"],["胡麻","胡麻"],["胡麻油","胡麻油"],["胡麻籽","胡麻籽"],["胤胄","胤胄"],["胰淀粉酶","胰澱粉酶"],["胰脏","胰臟"],["胰脏炎","胰臟炎"],["胰脏癌","胰臟癌"],["胶卷","膠捲"],["胶原纤维","膠原纖維"],["胶合","膠合"],["胶合板","膠合板"],["胶布","膠布"],["胶布膏","膠布膏"],["胶彩画","膠彩畫"],["胶莱谷地","膠萊谷地"],["胸廓切开术","胸廓切開術"],["胸怀坦荡","胸懷坦蕩"],["胸怀大志","胸懷大志"],["胸无大志","胸無大志"],["胸杯","胸杯"],["胸罗万象","胸羅萬象"],["胸部手术","胸部手術"],["胸针","胸針"],["胼胚种","胼胚種"],["能借","能借"],["能克制","能剋制"],["能力范围","能力範圍"],["能干","能幹"],["能干巴巴","能乾巴巴"],["能干扰","能干擾"],["能干杯","能乾杯"],["能干涉","能干涉"],["能干着急","能乾着急"],["能干耗","能乾耗"],["能干脆","能乾脆"],["能干预","能干預"],["能征善战","能征善戰"],["能征惯战","能征慣戰"],["能愿动词","能願動詞"],["能自制","能自制"],["能舍","能捨"],["能说不能干","能說不能幹"],["脂漏性角化症","脂漏性角化症"],["脆快了当","脆快了當"],["脆谷乐","脆穀樂"],["脉不制肉","脈不制肉"],["脉冲","脈衝"],["脉冲光","脈衝光"],["脉冲式","脈衝式"],["脉冲数","脈衝數"],["脉冲星","脈衝星"],["脉冲电磁场","脈衝電磁場"],["脉冲雷达","脈衝雷達"],["脉岩","脈岩"],["脊梁","脊樑"],["脊梁背","脊樑背"],["脊梁骨","脊樑骨"],["脊百合","脊百合"],["脏东西","髒東西"],["脏乱","髒亂"],["脏乱点","髒亂點"],["脏了","髒了"],["脏兮兮","髒兮兮"],["脏发","髒髮"],["脏器","臟器"],["脏土","髒土"],["脏字","髒字"],["脏字儿","髒字兒"],["脏弹","髒彈"],["脏得","髒得"],["脏心","髒心"],["脏死","髒死"],["脏水","髒水"],["脏污","髒污"],["脏病","髒病"],["脏的","髒的"],["脏脏","髒髒"],["脏腑","臟腑"],["脏词","髒詞"],["脏话","髒話"],["脏钱","髒錢"],["脑出血","腦出血"],["脑前额叶","腦前額葉"],["脑力激荡","腦力激盪"],["脑力激荡术","腦力激盪術"],["脑力激荡法","腦力激盪法"],["脑后","腦後"],["脑回","腦回"],["脑子里","腦子裏"],["脑干","腦幹"],["脑成像技术","腦成像技術"],["脑海里","腦海裏"],["脑震荡","腦震盪"],["脓团","膿團"],["脚价","腳價"],["脚划船","腳划船"],["脚后跟","腳後跟"],["脚夫","腳伕"],["脚底板","腳底板"],["脚底板儿","腳底板兒"],["脚扣","腳釦"],["脚板","腳板"],["脚注","腳註"],["脚炼","腳鍊"],["脚踏板","腳踏板"],["脚酸","腳痠"],["脚面","腳面"],["脣似抹朱","脣似抹硃"],["脣如涂朱","脣如塗朱"],["脣彩盘","脣彩盤"],["脣若抹朱","脣若抹硃"],["脣若涂朱","脣若塗硃"],["脣若涂脂","脣若塗脂"],["脱不了","脫不了"],["脱不了身","脫不了身"],["脱了","脫了"],["脱党","脫黨"],["脱出","脫出"],["脱出重围","脫出重圍"],["脱发","脫髮"],["脱发剂","脫髮劑"],["脱口而出","脫口而出"],["脱困","脫困"],["脱尽","脫盡"],["脱帽致敬","脫帽致敬"],["脱离不了","脫離不了"],["脱离关系","脫離關係"],["脱蜡","脫蠟"],["脱衣舞娘","脫衣舞娘"],["脱谷机","脫穀機"],["脱身而出","脫身而出"],["脱轨而出","脫軌而出"],["脱颎而出","脫熲而出"],["脱颖而出","脫穎而出"],["脸上挂了招牌","臉上掛了招牌"],["脸都绿了","臉都綠了"],["脸面","臉面"],["脸面之情","臉面之情"],["脸面无光","臉面無光"],["脺脏","脺臟"],["脾脏","脾臟"],["腊之以为饵","腊之以爲餌"],["腊味","臘味"],["腊尽","臘盡"],["腊尽冬残","臘盡冬殘"],["腊斯克","臘斯克"],["腊笔","臘筆"],["腌䐶","腌䐶"],["腌制","醃製"],["腌成","醃成"],["腌汁","醃汁"],["腌泡","醃泡"],["腌渍","醃漬"],["腌渍物","醃漬物"],["腌猪肉","醃豬肉"],["腌肉","醃肉"],["腌腊","醃臘"],["腌臜","腌臢"],["腌菜","醃菜"],["腌起来","醃起來"],["腌过","醃過"],["腌酱瓜","醃醬瓜"],["腌里巴臜","腌裏巴臢"],["腌鱼","醃魚"],["腌鱼肉","醃魚肉"],["腌黄瓜","醃黃瓜"],["腐余","腐餘"],["腐女军团","腐女軍團"],["腐干","腐乾"],["腐恶","腐惡"],["腐肠之药","腐腸之藥"],["腑脏","腑臟"],["腕表","腕錶"],["腕道症候群","腕道症候羣"],["腕隧道症","腕隧道症"],["腕隧道症候群","腕隧道症候羣"],["腥黑穗病","腥黑穗病"],["腮托","腮托"],["腮斗","腮斗"],["腰一卷","腰一捲"],["腰布","腰布"],["腰扣","腰釦"],["腰杆","腰桿"],["腰杆子","腰桿子"],["腰板","腰板"],["腰板儿","腰板兒"],["腰板脖硬","腰板脖硬"],["腰柜","腰櫃"],["腰椎间盘突出","腰椎間盤突出"],["腰椎间盘突出症","腰椎間盤突出症"],["腰系","腰繫"],["腰缠万贯","腰纏萬貫"],["腰酸","腰痠"],["腰里","腰裏"],["腰里硬","腰裏硬"],["腰间系","腰間繫"],["腹板","腹板"],["腹泻药","腹瀉藥"],["腹语术","腹語術"],["腹里","腹裏"],["腹面","腹面"],["腻了","膩了"],["腻云","膩雲"],["腼面","靦面"],["腼颜事仇","靦顏事仇"],["腼颜借命","靦顏借命"],["腾云","騰雲"],["腾云跨风","騰雲跨風"],["腾云驾雾","騰雲駕霧"],["腾冲","騰衝"],["腾冲县","騰衝縣"],["腾出","騰出"],["腾出来","騰出來"],["腾升","騰昇"],["腾捷飞升","騰捷飛升"],["腾格里","騰格里"],["腾格里山","騰格里山"],["腾格里沙漠","騰格裏沙漠"],["腾格里湖","騰格里湖"],["腿后腱","腿後腱"],["腿酸","腿痠"],["膊风板","膊風板"],["膏药","膏藥"],["膏药旗","膏藥旗"],["膨土岩","膨土岩"],["膨松","膨鬆"],["膨松剂","膨鬆劑"],["膨胀系数","膨脹係數"],["膻中","膻中"],["膻中穴","膻中穴"],["臀位取胎术","臀位取胎術"],["臂一卷","臂一捲"],["臣仆","臣僕"],["臣服于","臣服於"],["臣服于心","臣服於心"],["臥云","臥雲"],["臥游","臥遊"],["臥狼当道","臥狼當道"],["臥薪尝胆","臥薪嘗膽"],["臧获","臧獲"],["臧谷亡羊","臧穀亡羊"],["自个","自個"],["自个儿","自個兒"],["自主旅游","自主旅遊"],["自主游","自主遊"],["自主系统","自主系統"],["自了","自了"],["自于","自於"],["自交系","自交系"],["自修","自修"],["自修室","自修室"],["自修法","自修法"],["自修课","自修課"],["自出","自出"],["自出一家","自出一家"],["自出机杼","自出機杼"],["自制","自制","自製"],["自制一下","自制一下"],["自制下来","自制下來"],["自制之力","自制之力"],["自制之能","自制之能"],["自制力","自制力"],["自制炸弹","自製炸彈"],["自制的能","自制的能"],["自制能力","自制能力"],["自动化技术","自動化技術"],["自动恢复","自動恢復"],["自动挂挡","自動掛擋"],["自动控制","自動控制"],["自动柜员机","自動櫃員機"],["自动离合","自動離合"],["自动自发","自動自發"],["自动表","自動錶"],["自动资料处理系统","自動資料處理系統"],["自助旅游","自助旅遊"],["自助游","自助遊"],["自卖自夸","自賣自誇"],["自发","自發"],["自发对称破缺","自發對稱破缺"],["自发性","自發性"],["自发电位","自發電位"],["自发运动","自發運動"],["自叹","自嘆"],["自同寒蝉","自同寒蟬"],["自后","自後"],["自夸","自誇"],["自学成才","自學成才"],["自尽","自盡"],["自度曲","自度曲"],["自当","自當"],["自愿","自願"],["自愿书","自願書"],["自愿就学方案","自願就學方案"],["自愿性","自願性"],["自愿者","自願者"],["自我表现","自我表現"],["自我评价","自我評價"],["自来水厂","自來水廠"],["自核","自核"],["自此以后","自此以後"],["自此而后","自此而後"],["自民党","自民黨"],["自治制","自治制"],["自注","自注"],["自点曲","自點曲"],["自然卷","自然捲"],["自然历","自然歷"],["自然接种","自然接種"],["自由亚洲电台","自由亞洲電臺"],["自由党","自由黨"],["自由意志","自由意志"],["自由意志主义","自由意志主義"],["自由斗士","自由鬥士"],["自由民主党","自由民主黨"],["自由组合","自由組合"],["自由组合规律","自由組合規律"],["自由面","自由面"],["自种","自種"],["自觉自愿","自覺自願"],["自诒伊戚","自詒伊戚"],["自贻伊戚","自貽伊戚"],["自赞","自贊"],["自适","自適"],["自适应","自適應"],["自选曲","自選曲"],["自采","自採"],["自闭症","自閉症"],["自须","自須"],["自食恶果","自食惡果"],["自驾汽车出租","自駕汽車出租"],["自鸣钟","自鳴鐘"],["臭不可当","臭不可當"],["臭局","臭侷"],["臭气冲天","臭氣沖天"],["臭气熏天","臭氣熏天"],["臭熏熏","臭燻燻"],["臭虫","臭蟲"],["至于","至於"],["至当","至當"],["至愚极陋","至愚極陋"],["至极","至極"],["至矣尽矣","至矣盡矣"],["致上","致上"],["致书","致書"],["致乱","致亂"],["致于","致於"],["致仕","致仕"],["致以","致以"],["致使","致使"],["致使动词","致使動詞"],["致冷","致冷"],["致冷劑","致冷劑"],["致函","致函"],["致力","致力"],["致力于","致力於"],["致命","致命"],["致命伤","致命傷"],["致命处","致命處"],["致命性","致命性"],["致哀","致哀"],["致奠","致奠"],["致密","緻密"],["致富","致富"],["致富之道","致富之道"],["致师","致師"],["致志","致志"],["致思","致思"],["致意","致意"],["致政","致政"],["致敬","致敬"],["致歉","致歉"],["致死","致死"],["致死剂量","致死劑量"],["致死性","致死性"],["致死性毒剂","致死性毒劑"],["致死案","致死案"],["致死率","致死率"],["致死量","致死量"],["致残","致殘"],["致理","致理"],["致理商专","致理商專"],["致理商业专科学校","致理商業專科學校"],["致理技术学院","致理技術學院"],["致用","致用"],["致电","致電"],["致畸","致畸"],["致疑","致疑"],["致病","致病"],["致病性","致病性"],["致病菌","致病菌"],["致癌","致癌"],["致癌物","致癌物"],["致癌物质","致癌物質"],["致知","致知"],["致祭","致祭"],["致胜","致勝"],["致胜率","致勝率"],["致胜球","致勝球"],["致获","致獲"],["致词","致詞"],["致详","致詳"],["致语","致語"],["致谢","致謝"],["致贺","致賀"],["致赠","致贈"],["致身","致身"],["致辞","致辭"],["致远","致遠"],["致远任重","致遠任重"],["致送","致送"],["臻于","臻於"],["臻于完善","臻於完善"],["臻于郅治","臻於郅治"],["舂谷","舂穀"],["舄卤","舄鹵"],["舆台","輿臺"],["舆地志","輿地志"],["舆尸","輿尸"],["舆志","輿志"],["舌一卷","舌一捲"],["舌叶","舌葉"],["舌叶音","舌葉音"],["舌后","舌後"],["舌尖后音","舌尖後音"],["舌干唇焦","舌乾脣焦"],["舌干脣焦","舌乾脣焦"],["舌面","舌面"],["舌面元音","舌面元音"],["舌面前音","舌面前音"],["舌面后音","舌面後音"],["舌面如镜","舌面如鏡"],["舌面音","舌面音"],["舍下","舍下"],["舍下他","捨下他"],["舍下你","捨下你"],["舍下她","捨下她"],["舍下我","捨下我"],["舍不得","捨不得"],["舍亲","舍親"],["舍人","舍人"],["舍出","捨出"],["舍利","舍利"],["舍利佛","舍利佛"],["舍利塔","舍利塔"],["舍利子","舍利子"],["舍利子塔","舍利子塔"],["舍利弗","舍利弗"],["舍去","捨去"],["舍命","捨命"],["舍命救人","捨命救人"],["舍堕","捨墮"],["舍妹","舍妹"],["舍姪","舍姪"],["舍安就危","捨安就危"],["舍实","捨實"],["舍实求虚","捨實求虛"],["舍己","捨己"],["舍己为人","捨己爲人"],["舍己为公","捨己爲公"],["舍己为国","捨己爲國"],["舍己从人","捨己從人"],["舍己就人","捨己就人"],["舍己成人","捨己成人"],["舍己救人","捨己救人"],["舍己芸人","捨己芸人"],["舍弃","捨棄"],["舍弗勒","舍弗勒"],["舍弟","舍弟"],["舍得","捨得"],["舍德主义","舍德主義"],["舍我其谁","捨我其誰"],["舍我复谁","捨我復誰"],["舍旧迎新","捨舊迎新"],["舍本","捨本"],["舍本事末","捨本事末"],["舍本逐末","捨本逐末"],["舍本问末","捨本問末"],["舍正从邪","捨正從邪"],["舍死忘生","捨死忘生"],["舍生","捨生"],["舍生取义","捨生取義"],["舍生存义","舍生存義"],["舍生忘死","捨生忘死"],["舍监","舍監"],["舍短从长","捨短從長"],["舍短取长","捨短取長"],["舍短录长","捨短錄長"],["舍短用长","捨短用長"],["舍身","捨身"],["舍身为国","捨身爲國"],["舍身图报","捨身圖報"],["舍身报国","捨身報國"],["舍身救人","捨身救人"],["舍身求法","捨身求法"],["舍车保帅","捨車保帥"],["舍近务远","捨近務遠"],["舍近即远","捨近即遠"],["舍近求远","捨近求遠"],["舍近谋远","捨近謀遠"],["舍间","舍間"],["舒卷","舒捲"],["舒卷自如","舒捲自如"],["舒发","舒發"],["舒适","舒適"],["舒适度","舒適度"],["舒适性","舒適性"],["舒适感","舒適感"],["舒适音","舒適音"],["舒马克","舒馬克"],["舔干淨","舔乾淨"],["舞出","舞出"],["舞台","舞臺"],["舞台剧","舞臺劇"],["舞台区","舞臺區"],["舞台戏","舞臺戲"],["舞台效果","舞臺效果"],["舞台秀","舞臺秀"],["舞台艺术","舞臺藝術"],["舞台音乐","舞臺音樂"],["舞后","舞后"],["舞团","舞團"],["舞娘","舞娘"],["舞曲","舞曲"],["舞榭歌台","舞榭歌臺"],["舞水端里","舞水端里"],["舞蹈团","舞蹈團"],["舞蹈症","舞蹈症"],["舞蹈系","舞蹈系"],["舟曲","舟曲"],["舟曲县","舟曲縣"],["舢板","舢板"],["舢板运动","舢板運動"],["航发中心","航發中心"],["航发会","航發會"],["航向","航向"],["航太系","航太系"],["航海历","航海曆"],["航海历史","航海歷史"],["航海年表","航海年表"],["航海日志","航海日誌"],["航班表","航班表"],["航空术","航空術"],["航空母舰战斗群","航空母艦戰鬥羣"],["舰只","艦隻"],["舳舻千里","舳艫千里"],["船不漏针漏针没外人","船不漏針漏針沒外人"],["船厂","船廠"],["船只","船隻"],["船台","船臺"],["船员表","船員表"],["船夫","船伕"],["船娘","船孃"],["船期表","船期表"],["船板","船板"],["船载的金银填不满烟花债","船載的金銀填不滿煙花債"],["船边交货价","船邊交貨價"],["船钟","船鐘"],["艇甲板","艇甲板"],["艎板","艎板"],["艨冲","艨衝"],["良价","良价"],["良心发现","良心發現"],["良游","良遊"],["良田万顷不如薄艺随身","良田萬頃不如薄藝隨身"],["良种","良種"],["良种繁育","良種繁育"],["良药","良藥"],["良药苦口","良藥苦口"],["良药苦口忠言逆耳","良藥苦口忠言逆耳"],["艰困","艱困"],["艰巨","艱鉅"],["艰苦备尝","艱苦備嚐"],["艰苦奋斗","艱苦奮鬥"],["艰难困苦","艱難困苦"],["艰难曲折","艱難曲折"],["色当","色當"],["色彩","色彩"],["色彩三要素","色彩三要素"],["色彩学","色彩學"],["色彩缤纷","色彩繽紛"],["色彩艳丽","色彩豔麗"],["色彩鲜明","色彩鮮明"],["色彩鲜艳","色彩鮮豔"],["色情杂志","色情雜誌"],["色欲","色慾"],["色盲症","色盲症"],["色系","色系"],["艳后","豔后"],["艸木丰丰","艸木丰丰"],["艺压当行","藝壓當行"],["艺坛","藝壇"],["艺文志","藝文志"],["艺术","藝術"],["艺术体操","藝術體操"],["艺术化","藝術化"],["艺术区","藝術區"],["艺术厅","藝術廳"],["艺术史","藝術史"],["艺术品","藝術品"],["艺术团","藝術團"],["艺术奖","藝術獎"],["艺术字","藝術字"],["艺术季","藝術季"],["艺术学院","藝術學院"],["艺术家","藝術家"],["艺术展","藝術展"],["艺术性","藝術性"],["艺术指导","藝術指導"],["艺术村","藝術村"],["艺术歌曲","藝術歌曲"],["艺术片","藝術片"],["艺术界","藝術界"],["艺术类","藝術類"],["艺术系","藝術系"],["艺术美","藝術美"],["艺术者","藝術者"],["艺术节","藝術節"],["艺术街","藝術街"],["艺术院","藝術院"],["艺术馆","藝術館"],["艺穗节","藝穗節"],["艾万斯","艾萬斯"],["艾伦图克","艾倫圖克"],["艾克尔","艾克爾"],["艾克斯","艾克斯"],["艾克曼","艾克曼"],["艾克森","艾克森"],["艾克森美孚","艾克森美孚"],["艾克雷史东","艾克雷史東"],["艾力克","艾力克"],["艾力克斯","艾力克斯"],["艾回","艾迴"],["艾布兰","艾布蘭"],["艾布拉莫维奇","艾布拉莫維奇"],["艾希克罗","艾希克羅"],["艾弥尔","艾彌爾"],["艾德蒙斯","艾德蒙斯"],["艾德蒙顿","艾德蒙頓"],["艾斯托利尔","艾斯托利爾"],["艾瑞克","艾瑞克"],["艾瑞克森","艾瑞克森"],["艾瑞斯托","艾瑞斯托"],["艾瑞里","艾瑞里"],["艾米里","艾米里"],["艾维斯普里斯莱","艾維斯普里斯萊"],["艾赛克斯","艾賽克斯"],["艾达克","艾達克"],["艾里亚森","艾里亞森"],["艾里斯","艾里斯"],["艾里森","艾里森"],["艾里赛宫","艾里賽宮"],["节余","節餘"],["节制","節制"],["节制资本","節制資本"],["节奏布鲁斯","節奏布魯斯"],["节录","節錄"],["节录自","節錄自"],["节欲","節慾"],["节流踏板","節流踏板"],["节目表","節目表"],["节节上升","節節上升"],["节节胜利","節節勝利"],["芍药","芍藥"],["芍药花","芍藥花"],["芒果干","芒果乾"],["芒种","芒種"],["芙蓉出水","芙蓉出水"],["芟秋","芟秋"],["芥子气恶病质","芥子氣惡病質"],["芥子纳须弥","芥子納須彌"],["芦帘","蘆簾"],["芦席","蘆蓆"],["芦洲蟹舍","蘆洲蟹舍"],["芦花荡","蘆花蕩"],["芦荡","蘆蕩"],["芧栗","芧栗"],["芫荽叶","芫荽葉"],["芬郁","芬鬱"],["芭丝克华","芭絲克華"],["芭托莉","芭托莉"],["芭蕉布","芭蕉布"],["芭蕾舞团","芭蕾舞團"],["芯慧同用","芯慧同用"],["芯片厂","芯片廠"],["花个","花個"],["花了","花了"],["花价","花價"],["花儿针","花兒針"],["花六出","花六出"],["花卷","花捲"],["花厂","花廠"],["花发老","花髮老"],["花台","花臺"],["花叶","花葉"],["花叶病","花葉病"],["花哄","花鬨"],["花团","花團"],["花团锦簇","花團錦簇"],["花园里","花園裏"],["花坛","花壇"],["花坛乡","花壇鄉"],["花娘","花娘"],["花尽","花盡"],["花岗岩","花崗岩"],["花岗岩质层","花崗岩質層"],["花布","花布"],["花布包","花布包"],["花庵词选","花菴詞選"],["花彩","花彩"],["花心萝卜","花心蘿蔔"],["花托","花托"],["花招百出","花招百出"],["花拳绣腿","花拳繡腿"],["花旗参","花旗參"],["花无百日开人无千日好","花無百日開人無千日好"],["花明柳暗","花明柳暗"],["花栗鼠","花栗鼠"],["花样游泳","花樣游泳"],["花样百出","花樣百出"],["花椒面","花椒麪"],["花烟馆","花煙館"],["花盆里","花盆裏"],["花种","花種"],["花粉症","花粉症"],["花红叶绿","花紅葉綠"],["花胜","花勝"],["花胡同","花衚衕"],["花胡瓜","花胡瓜"],["花荡","花蕩"],["花药","花葯"],["花药瓣","花葯瓣"],["花莲师范学院","花蓮師範學院"],["花藜胡哨","花藜胡哨"],["花虫","花蟲"],["花车游行","花車遊行"],["花采","花采"],["花里胡哨","花裏胡哨"],["花钟","花鐘"],["花雕","花雕"],["花雕酒","花雕酒"],["花面","花面"],["花面狸","花面狸"],["花马吊嘴","花馬弔嘴"],["花魁娘子","花魁娘子"],["芳名录","芳名錄"],["芸苔","蕓薹"],["芸薹","蕓薹"],["芸辉","蕓輝"],["苇席","葦蓆"],["苇苕系巢","葦苕繫巢"],["苍发","蒼髮"],["苍术","蒼朮"],["苍松","蒼松"],["苍松翠柏","蒼松翠柏"],["苍生涂炭","蒼生塗炭"],["苍翠欲滴","蒼翠欲滴"],["苍蝇掐了头","蒼蠅掐了頭"],["苍郁","蒼鬱"],["苍黄翻复","蒼黃翻覆"],["苎麻","苧麻"],["苏东启案","蘇東啓案"],["苏东坡","蘇東坡"],["苏丹","蘇丹"],["苏丹人","蘇丹人"],["苏丹共和国","蘇丹共和國"],["苏丹达佛","蘇丹達佛"],["苏丹达佛区","蘇丹達佛區"],["苏丽文","蘇麗文"],["苏乐明","蘇樂明"],["苏乐桃","蘇樂桃"],["苏仙区","甦仙區"],["苏伊士","蘇伊士"],["苏伊士河","蘇伊士河"],["苏伊士运河","蘇伊士運河"],["苏俄","蘇俄"],["苏俄在中国","蘇俄在中國"],["苏俊仁","蘇俊仁"],["苏俊宾","蘇俊賓"],["苏克雷","蘇克雷"],["苏公隄","蘇公隄"],["苏共","蘇共"],["苏凡纳布","蘇凡納布"],["苏利南","蘇利南"],["苏利南共和国","蘇利南共和國"],["苏利文","蘇利文"],["苏北","蘇北"],["苏区","蘇區"],["苏占区","蘇佔區"],["苏合香","蘇合香"],["苏启荣","蘇啓榮"],["苏哈托","蘇哈托"],["苏哲毅","蘇哲毅"],["苏嘉全","蘇嘉全"],["苏圣斌","蘇聖斌"],["苏堤","蘇堤"],["苏头","蘇頭"],["苏妮儿","蘇妮兒"],["苏妮妮","蘇妮妮"],["苏妮萨","蘇妮薩"],["苏姆盖特","蘇姆蓋特"],["苏子油","蘇子油"],["苏宁","蘇寧"],["苏宁电器","蘇寧電器"],["苏家屯","甦家屯"],["苏家屯区","甦家屯區"],["苏家明","蘇家明"],["苏富比","蘇富比"],["苏富比公司","蘇富比公司"],["苏小妹","蘇小妹"],["苏尔","蘇爾"],["苏尔坦","蘇爾坦"],["苏尔奈","蘇爾奈"],["苏尼特右旗","蘇尼特右旗"],["苏尼特左旗","蘇尼特左旗"],["苏峻","蘇峻"],["苏州","蘇州"],["苏州人","蘇州人"],["苏州地区","蘇州地區"],["苏州城","蘇州城"],["苏州大学","蘇州大學"],["苏州市","蘇州市"],["苏州弹词","蘇州彈詞"],["苏州片","蘇州片"],["苏州码","蘇州碼"],["苏州码子","蘇州碼子"],["苏州评弹","蘇州評彈"],["苏州话","蘇州話"],["苏巴猜","蘇巴猜"],["苏帕瑞","蘇帕瑞"],["苏建","蘇建"],["苏建和","蘇建和"],["苏建忠","蘇建忠"],["苏建荣","蘇建榮"],["苏式","蘇式"],["苏彝士","蘇彝士"],["苏彝士运河","蘇彝士運河"],["苏德曼","蘇德曼"],["苏必利尔湖","蘇必利爾湖"],["苏必略湖","蘇必略湖"],["苏志明","蘇志明"],["苏志燮","蘇志燮"],["苏息","蘇息"],["苏恺二七战机","蘇愷二七戰機"],["苏打","蘇打"],["苏打水","蘇打水"],["苏打粉","蘇打粉"],["苏打绿","蘇打綠"],["苏打饼干","蘇打餅乾"],["苏扬托","蘇揚托"],["苏报案","蘇報案"],["苏拉","蘇拉"],["苏拉威","蘇拉威"],["苏拉威西","蘇拉威西"],["苏拉威西岛","蘇拉威西島"],["苏拉朋","蘇拉朋"],["苏拉特","蘇拉特"],["苏拉育","蘇拉育"],["苏拾平","蘇拾平"],["苏振平","蘇振平"],["苏文生","蘇文生"],["苏方","蘇方"],["苏昆","蘇崑"],["苏易简","蘇易簡"],["苏曼殊","蘇曼殊"],["苏有朋","蘇有朋"],["苏木","蘇木"],["苏杭","蘇杭"],["苏杯","蘇盃"],["苏枋木","蘇枋木"],["苏格兰","蘇格蘭"],["苏格兰人","蘇格蘭人"],["苏格兰场","蘇格蘭場"],["苏格兰女王玛丽","蘇格蘭女王瑪麗"],["苏格兰帽","蘇格蘭帽"],["苏格兰折耳猫","蘇格蘭摺耳貓"],["苏格兰王","蘇格蘭王"],["苏格兰裙","蘇格蘭裙"],["苏格兰队","蘇格蘭隊"],["苏格拉底","蘇格拉底"],["苏梅岛","蘇梅島"],["苏步青","蘇步青"],["苏武","蘇武"],["苏武牧羊","蘇武牧羊"],["苏比克湾","蘇比克灣"],["苏氨酸","蘇氨酸"],["苏永康","蘇永康"],["苏永耀","蘇永耀"],["苏永钦","蘇永欽"],["苏治芬","蘇治芬"],["苏泽光","蘇澤光"],["苏洵","蘇洵"],["苏海韩潮","蘇海韓潮"],["苏澳","蘇澳"],["苏澳港","蘇澳港"],["苏澳镇","蘇澳鎮"],["苏炎坤","蘇炎坤"],["苏炳宪","蘇炳憲"],["苏焕智","蘇煥智"],["苏玲瑶","蘇玲瑤"],["苏珊","蘇珊"],["苏珊娜","蘇珊娜"],["苏珊莎兰登","蘇珊莎蘭登"],["苏瓦","蘇瓦"],["苏白","蘇白"],["苏盈贵","蘇盈貴"],["苏禄岛","蘇祿島"],["苏福男","蘇福男"],["苏秦","蘇秦"],["苏秦刺股","蘇秦刺股"],["苏立吉","蘇立吉"],["苏糖","蘇糖"],["苏绣","蘇繡"],["苏维埃","蘇維埃"],["苏维埃俄国","蘇維埃俄國"],["苏维埃社会主义共和国联盟","蘇維埃社會主義共和國聯盟"],["苏维埃社会主义共和国联邦","蘇維埃社會主義共和國聯邦"],["苏维成","蘇維成"],["苏罗河","蘇羅河"],["苏美人","蘇美人"],["苏美尔","蘇美爾"],["苏翊杰","蘇翊傑"],["苏联","蘇聯"],["苏联之友社","蘇聯之友社"],["苏联人","蘇聯人"],["苏联共产党","蘇聯共產黨"],["苏联最高苏维埃","蘇聯最高蘇維埃"],["苏胺酸","蘇胺酸"],["苏舜钦","蘇舜欽"],["苏芮","蘇芮"],["苏花公路","蘇花公路"],["苏花高","蘇花高"],["苏苏","蘇蘇"],["苏莱曼","蘇萊曼"],["苏菜","蘇菜"],["苏菲","蘇菲"],["苏菲亚","蘇菲亞"],["苏菲亚罗兰","蘇菲亞羅蘭"],["苏菲玛索","蘇菲瑪索"],["苏菲雅","蘇菲雅"],["苏蕙","蘇蕙"],["苏西洛","蘇西洛"],["苏谢配","蘇謝配"],["苏贞昌","蘇貞昌"],["苏超凡","蘇超凡"],["苏轩弘","蘇軒弘"],["苏轼","蘇軾"],["苏辙","蘇轍"],["苏达拉","蘇達拉"],["苏达索诺","蘇達索諾"],["苏迪曼杯","蘇迪曼杯"],["苏迪约梭","蘇迪約梭"],["苏醒","甦醒"],["苏醒剂","甦醒劑"],["苏醒过来","甦醒過來"],["苏里","蘇里"],["苏里南","蘇里南"],["苏里南河","蘇裏南河"],["苏里安提沙洛索","蘇里安提沙洛索"],["苏金达","蘇金達"],["苏铁","蘇鐵"],["苏镇霖","蘇鎮霖"],["苏门答腊","蘇門答臘"],["苏门答腊岛","蘇門答臘島"],["苏门答腊省","蘇門答臘省"],["苏门达腊","蘇門達臘"],["苏门达腊岛","蘇門達臘島"],["苏门长啸","蘇門長嘯"],["苏隄","蘇隄"],["苏雷曼","蘇雷曼"],["苏非","蘇非"],["苏非主义","蘇非主義"],["苏非教派","蘇非教派"],["苏黎世","蘇黎世"],["苏黎世联邦理工学院","蘇黎世聯邦理工學院"],["苏黎士","蘇黎士"],["苑里","苑裏"],["苑里镇","苑裏鎮"],["苗栗","苗栗"],["苗栗人","苗栗人"],["苗栗县","苗栗縣"],["苗栗市","苗栗市"],["苗种","苗種"],["苗胄","苗胄"],["苛政猛于虎","苛政猛於虎"],["苜蓿长栏干","苜蓿長欄干"],["苞叶","苞葉"],["苞虫","苞蟲"],["苟合","苟合"],["苟合取容","苟合取容"],["苟同","苟同"],["苟容曲从","苟容曲從"],["若个","若個"],["若于","若於"],["若出一辙","若出一轍"],["若合符节","若合符節"],["若向","若向"],["若干","若干"],["若干个","若干個"],["若干人","若干人"],["若干年","若干年"],["若虫","若蟲"],["苦了","苦了"],["苦于","苦於"],["苦修","苦修"],["苦卤","苦鹵"],["苦参","苦蔘"],["苦大仇深","苦大仇深"],["苦尽甘来","苦盡甘來"],["苦干","苦幹"],["苦干实干","苦幹實幹"],["苦思恶想","苦思惡想"],["苦斗","苦鬥"],["苦杯","苦杯"],["苦海无边回头是岸","苦海無邊回頭是岸"],["苦瓜干","苦瓜乾"],["苦药","苦藥"],["苦读出身","苦讀出身"],["苦酒满杯","苦酒滿杯"],["苦里","苦裏"],["苧悴","薴悴"],["苧烯","薴烯"],["苫布","苫布"],["苯并噻吩","苯並噻吩"],["苯酮尿症","苯酮尿症"],["英克丝特","英克絲特"],["英制","英制"],["英占","英佔"],["英发","英發"],["英国广播电台","英國廣播電臺"],["英姿焕发","英姿煥發"],["英布","英布"],["英才","英才"],["英才俊伟","英才俊偉"],["英文系","英文系"],["英日同盟","英日同盟"],["英杰","英傑"],["英气风发","英氣風發"],["英烈千秋","英烈千秋"],["英联合王国","英聯合王國"],["英胄","英胄"],["英语系","英語系"],["英里","英里"],["英雄交响曲","英雄交響曲"],["英雄只怕病来磨","英雄只怕病來磨"],["英雄所见略同","英雄所見略同"],["英雄模范","英雄模範"],["英雄豪杰","英雄豪傑"],["苴布","苴布"],["苹叶","蘋葉"],["苹婆","蘋婆"],["苹果","蘋果"],["苹果公司","蘋果公司"],["苹果园","蘋果園"],["苹果子姜尼","蘋果子姜尼"],["苹果干","蘋果乾"],["苹果手机","蘋果手機"],["苹果树","蘋果樹"],["苹果核","蘋果核"],["苹果汁","蘋果汁"],["苹果派","蘋果派"],["苹果电脑","蘋果電腦"],["苹果皮","蘋果皮"],["苹果绿","蘋果綠"],["苹果肉","蘋果肉"],["苹果脸","蘋果臉"],["苹果螺","蘋果螺"],["苹果蠹蛾","蘋果蠹蛾"],["苹果迷","蘋果迷"],["苹果酒","蘋果酒"],["苹果酱","蘋果醬"],["苹果酸","蘋果酸"],["苹果馅饼","蘋果餡餅"],["苹萦","苹縈"],["苹风","蘋風"],["茂发","茂發"],["茂才","茂才"],["茂才异等","茂才異等"],["茂松","茂松"],["茂都淀","茂都澱"],["范仲淹","范仲淹"],["范伦铁诺","范倫鐵諾"],["范佩西","范佩西"],["范例","範例"],["范光群","范光羣"],["范公偁","范公偁"],["范公堤","范公堤"],["范冰冰","范冰冰"],["范可钦","范可欽"],["范哈能","范哈能"],["范嘉骅","范嘉驊"],["范围","範圍"],["范围之内","範圍之內"],["范围之外","範圍之外"],["范围之广","範圍之廣"],["范围内","範圍內"],["范围属性","範圍屬性"],["范围很大","範圍很大"],["范围是","範圍是"],["范围查询","範圍查詢"],["范围调整","範圍調整"],["范国铨","范國銓"],["范增","范增"],["范士丹","范士丹"],["范姜","范姜"],["范字","範字"],["范家谦","范家謙"],["范宽","范寬"],["范小姐","范小姐"],["范尼斯特鲁伊","范尼斯特魯伊"],["范履霜","范履霜"],["范式","範式"],["范张鸡黍","范張雞黍"],["范德林特","范德林特"],["范德格拉夫","范德格拉夫"],["范德瓦耳斯","范德瓦耳斯"],["范德瓦耳斯力","范德瓦耳斯力"],["范德维德","范德維德"],["范德萨","范德薩"],["范志毅","范志毅"],["范性形变","範性形變"],["范戈德","范戈德"],["范成大","范成大"],["范文","範文"],["范文同","范文同"],["范文正公","范文正公"],["范文澜","范文瀾"],["范文照","范文照"],["范文程","范文程"],["范文网","範文網"],["范文芳","范文芳"],["范文藤","范文藤"],["范文虎","范文虎"],["范文选读","範文選讀"],["范斯坦","范斯坦"],["范晓萱","范曉萱"],["范晔","范曄"],["范本","範本"],["范植伟","范植偉"],["范植谷","范植谷"],["范欣妤","范欣妤"],["范正祥","范正祥"],["范洪森","范洪森"],["范湘暄","范湘暄"],["范特尔","范特爾"],["范特西","范特西"],["范玮琪","范瑋琪"],["范琪斐","范琪斐"],["范甘迪","范甘迪"],["范畴","範疇"],["范畴内","範疇內"],["范畴论","範疇論"],["范登堡","范登堡"],["范皓阗","范皓闐"],["范筱梵","范筱梵"],["范纲武","范綱武"],["范织钦","范織欽"],["范绮馨","范綺馨"],["范范之辈","范範之輩"],["范蠡","范蠡"],["范进","范進"],["范逸臣","范逸臣"],["范金","範金"],["范阳","范陽"],["范陈柏","范陳柏"],["范雎","范雎"],["范靖瑶","范靖瑤"],["茄二十八星瓢虫","茄二十八星瓢蟲"],["茄克","茄克"],["茄克衫","茄克衫"],["茄冬","茄冬"],["茅以升","茅以升"],["茅厕里的石头","茅廁裏的石頭"],["茅台","茅臺"],["茅台酒","茅臺酒"],["茅舍","茅舍"],["茅针","茅針"],["茈胡","茈胡"],["茉莉克","茉莉克"],["茎干","莖幹"],["茑萝施乔松","蔦蘿施喬松"],["茧栗","繭栗"],["茧纤维","繭纖維"],["茨万吉拉伊","茨萬吉拉伊"],["茫茫荡荡","茫茫蕩蕩"],["茱丽叶","茱麗葉"],["茵借","茵藉"],["茶余","茶餘"],["茶几","茶几"],["茶卤","茶滷"],["茶叶","茶葉"],["茶叶末","茶葉末"],["茶叶末儿","茶葉末兒"],["茶叶碱","茶葉鹼"],["茶叶罐","茶葉罐"],["茶叶蛋","茶葉蛋"],["茶已干","茶已乾"],["茶庄","茶莊"],["茶托","茶托"],["茶杯","茶杯"],["茶毛虫","茶毛蟲"],["茶里王","茶裏王"],["茶面","茶麪"],["茶面子","茶麪子"],["茶馀酒后","茶餘酒後"],["茶馀饭后","茶餘飯後"],["茹志鹃","茹誌鵑"],["荅布","荅布"],["荆尸","荊尸"],["荆布","荊布"],["荆钗布袄","荊釵布襖"],["荆钗布裙","荊釵布裙"],["荆钗裙布","荊釵裙布"],["草丛里","草叢裏"],["草原千里","草原千里"],["草台班子","草臺班子"],["草叶","草葉"],["草叶集","草葉集"],["草团瓢","草團瓢"],["草头药","草頭藥"],["草字汇","草字彙"],["草履虫","草履蟲"],["草席","草蓆"],["草庵","草菴"],["草枝摆","草枝擺"],["草签","草簽"],["草舍","草舍"],["草草了事","草草了事"],["草荐","草荐"],["草药","草藥"],["草药方","草藥方"],["草虫","草蟲"],["荐居","荐居"],["荐臻","荐臻"],["荐饥","荐饑"],["荑手纤纤","荑手纖纖"],["荒了","荒了"],["荒年谷","荒年穀"],["荒无人烟","荒無人煙"],["荒烟漫草","荒煙漫草"],["荒烟蔓草","荒煙蔓草"],["荒腔走板","荒腔走板"],["荞面","蕎麪"],["荞麦面","蕎麥麪"],["荡产","蕩產"],["荡产倾家","蕩產傾家"],["荡出","盪出"],["荡到","盪到"],["荡口","盪口"],["荡垢涤汙","盪垢滌污"],["荡复","蕩覆"],["荡女","蕩女"],["荡妇","蕩婦"],["荡子","蕩子"],["荡寇","蕩寇"],["荡寒","盪寒"],["荡尽","蕩盡"],["荡平","蕩平"],["荡开","盪開"],["荡心","蕩心"],["荡志","蕩志"],["荡悠悠","盪悠悠"],["荡散","蕩散"],["荡来荡去","盪來盪去"],["荡析","蕩析"],["荡析离居","蕩析離居"],["荡检逾闲","蕩檢逾閑"],["荡气回肠","蕩氣迴腸"],["荡气回阳","蕩氣迴陽"],["荡涤","盪滌"],["荡漾","盪漾"],["荡漾出","盪漾出"],["荡潏","蕩潏"],["荡然","蕩然"],["荡然无存","蕩然無存"],["荡瑕涤秽","蕩瑕滌穢"],["荡田","蕩田"],["荡秋千","盪鞦韆"],["荡舟","盪舟"],["荡船","盪船"],["荡荡","蕩蕩"],["荡荡悠悠","盪盪悠悠"],["荡酒","盪酒"],["荡风","盪風"],["荣升","榮升"],["荣幸","榮幸"],["荣幸之至","榮幸之至"],["荣归故里","榮歸故里"],["荣登后座","榮登后座"],["荣获","榮獲"],["荣获冠军","榮獲冠軍"],["荤油蒙了心","葷油蒙了心"],["荦确","犖确"],["荧郁","熒鬱"],["荫生","廕生"],["荫监","廕監"],["荫蔽","廕庇"],["荫袭","廕襲"],["药专","藥專"],["药业","藥業"],["药丸","藥丸"],["药事法","藥事法"],["药价","藥價"],["药价差","藥價差"],["药典","藥典"],["药兽","藥獸"],["药农","藥農"],["药到命除","藥到命除"],["药到回春","藥到回春"],["药到病除","藥到病除"],["药剂","藥劑"],["药剂士","藥劑士"],["药剂学","藥劑學"],["药剂师","藥劑師"],["药剂量","藥劑量"],["药力","藥力"],["药包","藥包"],["药医","藥醫"],["药医不死病佛度有缘人","藥醫不死病佛度有緣人"],["药医学系","藥醫學系"],["药单","藥單"],["药厂","藥廠"],["药叉","藥叉"],["药发傀儡","藥發傀儡"],["药吊子","藥吊子"],["药名","藥名"],["药味","藥味"],["药品","藥品"],["药品店","藥品店"],["药商","藥商"],["药壶","藥壺"],["药头","藥頭"],["药妆","藥妝"],["药妆品","藥妝品"],["药妆店","藥妝店"],["药婆","藥婆"],["药学","藥學"],["药学专科学校","藥學專科學校"],["药学系","藥學系"],["药害","藥害"],["药局","藥局"],["药师","藥師"],["药师佛","藥師佛"],["药师如来","藥師如來"],["药师经","藥師經"],["药师节","藥師節"],["药店","藥店"],["药引","藥引"],["药引子","藥引子"],["药性","藥性"],["药性气","藥性氣"],["药房","藥房"],["药捻子","藥捻子"],["药政处","藥政處"],["药效","藥效"],["药效持久","藥效持久"],["药方","藥方"],["药方儿","藥方兒"],["药明康德","藥明康德"],["药末","藥末"],["药杀","藥殺"],["药材","藥材"],["药械","藥械"],["药检","藥檢"],["药检局","藥檢局"],["药棉","藥棉"],["药死","藥死"],["药水","藥水"],["药水儿","藥水兒"],["药水味","藥水味"],["药汁","藥汁"],["药油","藥油"],["药法","藥法"],["药浴","藥浴"],["药液","藥液"],["药渣","藥渣"],["药片","藥片"],["药物","藥物"],["药物中毒","藥物中毒"],["药物学","藥物學"],["药物学家","藥物學家"],["药物成瘾","藥物成癮"],["药物治疗","藥物治療"],["药王","藥王"],["药王菩萨","藥王菩薩"],["药理","藥理"],["药理学","藥理學"],["药瓶","藥瓶"],["药瓶子","藥瓶子"],["药用","藥用"],["药用价值","藥用價值"],["药用植物","藥用植物"],["药疗","藥療"],["药疹","藥疹"],["药瘾","藥癮"],["药皂","藥皂"],["药监局","藥監局"],["药盒","藥盒"],["药石","藥石"],["药石之言","藥石之言"],["药石罔效","藥石罔效"],["药科","藥科"],["药笼中物","藥籠中物"],["药筒","藥筒"],["药签","藥籤"],["药箭","藥箭"],["药箱","藥箱"],["药籤","藥籤"],["药粉","藥粉"],["药糖","藥糖"],["药线","藥線"],["药罐","藥罐"],["药罐子","藥罐子"],["药而愈","藥而癒"],["药膏","藥膏"],["药膛","藥膛"],["药膳","藥膳"],["药舖","藥舖"],["药茶","藥茶"],["药草","藥草"],["药草茶","藥草茶"],["药行","藥行"],["药衡","藥衡"],["药衣子","藥衣子"],["药补","藥補"],["药袋","藥袋"],["药裹关心","藥裹關心"],["药言","藥言"],["药贩","藥販"],["药贴","藥貼"],["药费","藥費"],["药酒","藥酒"],["药量","藥量"],["药针","藥針"],["药铺","藥鋪"],["药锭","藥錠"],["药面儿","藥麪兒"],["药食同源","藥食同源"],["药饵","藥餌"],["药饼","藥餅"],["药骰","藥骰"],["荷叶","荷葉"],["荷叶先师","荷葉先師"],["荷叶肉","荷葉肉"],["荷尔蒙","荷爾蒙"],["荷花出水","荷花出水"],["荷花淀","荷花澱"],["荷里活","荷里活"],["荷雷克","荷雷克"],["莎玛海耶克","莎瑪海耶克"],["莒光周","莒光週"],["莜面","莜麪"],["莫三比克","莫三比克"],["莫三比克人民共和国","莫三比克人民共和國"],["莫乃耳合金","莫乃耳合金"],["莫余毒也","莫余毒也"],["莫信直中直须防人不仁","莫信直中直須防人不仁"],["莫克姆湾","莫克姆灣"],["莫吉托","莫吉托"],["莫布里","莫布里"],["莫干山","莫干山"],["莫当","莫當"],["莫扎特","莫扎特"],["莫扎里拉","莫扎里拉"],["莫折大提","莫折大提"],["莫报万一","莫報萬一"],["莫曼斯克","莫曼斯克"],["莫杰斯特","莫傑斯特"],["莫桑比克","莫桑比克"],["莫管闲事","莫管閒事"],["莫索里尼","莫索里尼"],["莫荷不连续面","莫荷不連續面"],["莫莉克","莫莉克"],["莫蹪于山而蹪于垤","莫蹪於山而蹪於垤"],["莫辨楮叶","莫辨楮葉"],["莫过于","莫過於"],["莫里","莫里"],["莫里叶","莫里葉"],["莫里哀","莫里哀"],["莫里尼奥","莫里尼奧"],["莫里希","莫里希"],["莫里斯","莫里斯"],["莫里森","莫里森"],["莫里纳","莫里納"],["莫霍洛维奇不连续面","莫霍洛維奇不連續面"],["莫霍面","莫霍面"],["莫须","莫須"],["莫须有","莫須有"],["莱布尼兹","萊布尼茲"],["莱彩","萊彩"],["莱彩北堂","萊綵北堂"],["莱德杯","萊德杯"],["莱索托","萊索托"],["莱里达","萊里達"],["莲台","蓮臺"],["莲叶","蓮葉"],["莲开并蒂","蓮開並蒂"],["莲须","蓮鬚"],["获准","獲准"],["获刑","獲刑"],["获判","獲判"],["获判无罪","獲判無罪"],["获利","獲利"],["获利倍蓰","獲利倍蓰"],["获利率","獲利率"],["获利王","獲利王"],["获到","獲到"],["获匪其丑","獲匪其醜"],["获取","獲取"],["获咎","獲咎"],["获嘉","獲嘉"],["获嘉县","獲嘉縣"],["获奖","獲獎"],["获奖人","獲獎人"],["获奖率","獲獎率"],["获奖者","獲獎者"],["获得","獲得"],["获得四","獲得四"],["获得四坏","獲得四壞"],["获得性","獲得性"],["获得者","獲得者"],["获得胜利","獲得勝利"],["获悉","獲悉"],["获戾","獲戾"],["获报","獲報"],["获捷","獲捷"],["获救","獲救"],["获暴利者","獲暴利者"],["获有","獲有"],["获益","獲益"],["获益不浅","獲益不淺"],["获益匪浅","獲益匪淺"],["获益者","獲益者"],["获益良多","獲益良多"],["获知","獲知"],["获罪","獲罪"],["获胜","獲勝"],["获胜者","獲勝者"],["获致","獲致"],["获赠","獲贈"],["获赦","獲赦"],["获选","獲選"],["获选为","獲選爲"],["获邀","獲邀"],["获释","獲釋"],["获颁","獲頒"],["获鹿","獲鹿"],["获鹿县","獲鹿縣"],["获鹿镇","獲鹿鎮"],["莺谷","鶯谷"],["莽卤","莽鹵"],["莽荡","莽蕩"],["菁英杯","菁英盃"],["菅野美穗","菅野美穗"],["菊坛","菊壇"],["菊秋","菊秋"],["菌丝体","菌絲體"],["菌托","菌托"],["菌核","菌核"],["菌种","菌種"],["菌胶团","菌膠團"],["菌血症","菌血症"],["菜干","菜乾"],["菜板","菜板"],["菜瓜布","菜瓜布"],["菜种","菜種"],["菜系","菜系"],["菜肴","菜餚"],["菜苔","菜薹"],["菜虫","菜蟲"],["菜青虫","菜青蟲"],["菠棱菜","菠棱菜"],["菠萝干","菠蘿乾"],["菩提流志","菩提流志"],["菲佣","菲傭"],["菲利克斯","菲利克斯"],["菲利克斯．米达麦亚","菲利克斯．米達麥亞"],["菲力克斯","菲力克斯"],["菲尼克斯","菲尼克斯"],["菲德烈克","菲德烈克"],["菲才寡学","菲才寡學"],["菲舍尔","菲捨爾"],["菲茨杰拉德","菲茨傑拉德"],["菲衣恶食","菲衣惡食"],["萌发","萌發"],["萎缩症","萎縮症"],["萎雕","萎雕"],["萝卜","蘿蔔"],["萝卜头","蘿蔔頭"],["萝卜干","蘿蔔乾"],["萝卜精","蘿蔔精"],["萝卜精头上青","蘿蔔精頭上青"],["萝卜糕","蘿蔔糕"],["萝卜腿","蘿蔔腿"],["萤光板","螢光板"],["萤火虫","螢火蟲"],["萤火虫儿","螢火蟲兒"],["营养价值","營養價值"],["营养系","營養系"],["营干","營幹"],["营建厂","營建廠"],["营舍","營舍"],["营造出","營造出"],["营造出来","營造出來"],["营造厂","營造廠"],["营造厂商","營造廠商"],["萦回","縈迴"],["萦系","縈繫"],["萧万长","蕭萬長"],["萧参","蕭蔘"],["萧太后","蕭太后"],["萧娘","蕭娘"],["萧扎某","蕭扎某"],["萧玮志","蕭瑋志"],["萧行范篆","蕭行范篆"],["萨克","薩克"],["萨克号","薩克號"],["萨克司风","薩克司風"],["萨克斯","薩克斯"],["萨克斯管","薩克斯管"],["萨克斯风","薩克斯風"],["萨克森","薩克森"],["萨克森州","薩克森州"],["萨克森邦","薩克森邦"],["萨克洛夫","薩克洛夫"],["萨克洛夫奖","薩克洛夫獎"],["萨克管","薩克管"],["萨克逊","薩克遜"],["萨克逊人","薩克遜人"],["萨尔布吕肯","薩爾布呂肯"],["萨巴托","薩巴托"],["萨布里","薩布里"],["萨布里多","薩布里多"],["萨格勒布","薩格勒布"],["萨瓦里","薩瓦里"],["萨迪克","薩迪克"],["萨里","薩里"],["萨里郡","薩里郡"],["落个直过儿","落個直過兒"],["落了","落了"],["落了灶","落了竈"],["落于","落於"],["落于下风","落於下風"],["落价","落價"],["落卷","落卷"],["落发","落髮"],["落发为僧","落髮爲僧"],["落台","落臺"],["落叶","落葉"],["落叶乔木","落葉喬木"],["落叶剂","落葉劑"],["落叶层","落葉層"],["落叶归根","落葉歸根"],["落叶归根家","落葉歸根家"],["落叶松","落葉松"],["落叶林","落葉林"],["落叶果树","落葉果樹"],["落叶树","落葉樹"],["落叶植物","落葉植物"],["落叶知秋","落葉知秋"],["落后","落後"],["落后国家","落後國家"],["落在后面","落在後面"],["落地签证","落地簽證"],["落托","落托"],["落月屋梁","落月屋梁"],["落腮胡","落腮鬍"],["落落寡合","落落寡合"],["落落难合","落落難合"],["葑菲之采","葑菲之采"],["著录","著錄"],["著志","著志"],["著称于世","著稱於世"],["葛兰素史克","葛蘭素史克"],["葛布","葛布"],["葛托维纳","葛托維納"],["葛拉斯里","葛拉斯里"],["葛斯范桑","葛斯范桑"],["葛罗托斯基","葛羅托斯基"],["葛里芬","葛里芬"],["葡占","葡佔"],["葡萄叶银莲花","葡萄葉銀蓮花"],["葡萄干","葡萄乾"],["葡萄干儿","葡萄乾兒"],["董氏封发","董氏封髮"],["董里府","董里府"],["葫芦谷","葫蘆谷"],["葫芦里卖甚么药","葫蘆裏賣甚麼藥"],["葫芦里卖的甚么药","葫蘆裏賣的甚麼藥"],["葱姜蒜","蔥薑蒜"],["葱胡子","蔥鬍子"],["葱葱郁郁","蔥蔥郁郁"],["葱郁","蔥鬱"],["蒂森克虏伯","蒂森克虜伯"],["蒋国梁","蔣國樑"],["蒋干","蔣幹"],["蒋百里","蔣百里"],["蒋舍三径","蔣舍三徑"],["蒌叶","蔞葉"],["蒐录","蒐錄"],["蒙一饭之恩尚杀身以报","蒙一飯之恩尚殺身以報"],["蒙上","蒙上"],["蒙主宠召","蒙主寵召"],["蒙事","矇事"],["蒙人","蒙人"],["蒙代尔","蒙代爾"],["蒙住","矇住"],["蒙兀儿","蒙兀兒"],["蒙兀儿帝国","蒙兀兒帝國"],["蒙养","蒙養"],["蒙冤","蒙冤"],["蒙冲","蒙衝"],["蒙受","蒙受"],["蒙叟","蒙叟"],["蒙古","蒙古"],["蒙古人","蒙古人"],["蒙古人民共和国","蒙古人民共和國"],["蒙古人种","蒙古人種"],["蒙古儿","蒙古兒"],["蒙古利亚","蒙古利亞"],["蒙古包","蒙古包"],["蒙古国","蒙古國"],["蒙古地方","蒙古地方"],["蒙古大夫","蒙古大夫"],["蒙古帝国","蒙古帝國"],["蒙古文","蒙古文"],["蒙古斑","蒙古斑"],["蒙古族","蒙古族"],["蒙古症","蒙古症"],["蒙古话","蒙古話"],["蒙古语","蒙古語"],["蒙古高原","蒙古高原"],["蒙台梭利","蒙臺梭利"],["蒙吏","蒙吏"],["蒙哄","蒙哄"],["蒙哥","蒙哥"],["蒙哥马利","蒙哥馬利"],["蒙嘉慧","蒙嘉慧"],["蒙在","蒙在"],["蒙在鼓里","矇在鼓裏"],["蒙地卡罗","蒙地卡羅"],["蒙坑","蒙坑"],["蒙垢","蒙垢"],["蒙城","蒙城"],["蒙城县","蒙城縣"],["蒙塔丝","蒙塔絲"],["蒙塔尼斯","蒙塔尼斯"],["蒙塔斯","蒙塔斯"],["蒙塔达","蒙塔達"],["蒙大拿","蒙大拿"],["蒙大拿州","蒙大拿州"],["蒙太奇","蒙太奇"],["蒙太奇电影","蒙太奇電影"],["蒙头","矇頭"],["蒙头大睡","矇頭大睡"],["蒙头衲被","矇頭衲被"],["蒙头转","矇頭轉"],["蒙头转向","矇頭轉向"],["蒙娜丽莎","蒙娜麗莎"],["蒙学","蒙學"],["蒙尘","蒙塵"],["蒙山","蒙山"],["蒙山县","蒙山縣"],["蒙巴萨","蒙巴薩"],["蒙巴顿","蒙巴頓"],["蒙师","蒙師"],["蒙帕纳斯","蒙帕納斯"],["蒙席","蒙席"],["蒙庄","蒙莊"],["蒙彼利埃","蒙彼利埃"],["蒙得维的亚","蒙得維的亞"],["蒙恩","蒙恩"],["蒙恬","蒙恬"],["蒙恬造笔","蒙恬造筆"],["蒙懂","懞懂"],["蒙戎","蒙戎"],["蒙托罗拉","蒙托羅拉"],["蒙拾","蒙拾"],["蒙故业","蒙故業"],["蒙文","蒙文"],["蒙族","蒙族"],["蒙昧","矇昧"],["蒙昧不清","濛昧不清"],["蒙昧无知","矇昧無知"],["蒙松雨","濛鬆雨"],["蒙求","蒙求"],["蒙汗药","蒙汗藥"],["蒙汜","濛汜"],["蒙混","矇混"],["蒙混过关","矇混過關"],["蒙爱","蒙愛"],["蒙牛","蒙牛"],["蒙特","蒙特"],["蒙特內哥罗","蒙特內哥羅"],["蒙特利","蒙特利"],["蒙特利尔","蒙特利爾"],["蒙特卡洛","蒙特卡洛"],["蒙特卡洛法","蒙特卡洛法"],["蒙特卡罗","蒙特卡羅"],["蒙特卡罗方法","蒙特卡羅方法"],["蒙特塞拉特","蒙特塞拉特"],["蒙特娄","蒙特婁"],["蒙特维多","蒙特維多"],["蒙特贝娄","蒙特貝婁"],["蒙特雷","蒙特雷"],["蒙特鲁","蒙特魯"],["蒙狄维欧","蒙狄維歐"],["蒙田","蒙田"],["蒙皮","蒙皮"],["蒙盖","蒙蓋"],["蒙直","懞直"],["蒙眬","矇矓"],["蒙眼","矇眼"],["蒙瞍","矇瞍"],["蒙稚","蒙稚"],["蒙童","蒙童"],["蒙笼","蒙籠"],["蒙笼暗碧","蒙籠暗碧"],["蒙络","蒙絡"],["蒙罗维亚","蒙羅維亞"],["蒙羞","蒙羞"],["蒙聩","矇聵"],["蒙胞","蒙胞"],["蒙脸","蒙臉"],["蒙自","蒙自"],["蒙自县","蒙自縣"],["蒙茏","蒙蘢"],["蒙药","蒙藥"],["蒙菲尔斯","蒙菲爾斯"],["蒙蒙","濛濛","矇矇"],["蒙蒙亮","矇矇亮"],["蒙蒙懂懂","懞懞懂懂"],["蒙蒙眬眬","矇矇矓矓"],["蒙蒙细雨","濛濛細雨"],["蒙蒙谷","濛濛谷"],["蒙蒙黑","矇矇黑"],["蒙蔽","矇蔽"],["蒙藏","蒙藏"],["蒙藏同胞","蒙藏同胞"],["蒙藏委员","蒙藏委員"],["蒙藏委员会","蒙藏委員會"],["蒙语","蒙語"],["蒙谷","蒙谷"],["蒙贝列","蒙貝列"],["蒙起","蒙起"],["蒙起来","蒙起來"],["蒙阴","蒙陰"],["蒙阴县","蒙陰縣"],["蒙难","蒙難"],["蒙难记","蒙難記"],["蒙雾","濛霧"],["蒙雾露","濛霧露"],["蒙面","蒙面"],["蒙面人","蒙面人"],["蒙面侠","蒙面俠"],["蒙面客","蒙面客"],["蒙馆","蒙館"],["蒙骗","矇騙"],["蒙鸿","濛鴻"],["蒜发","蒜髮"],["蒜苔","蒜薹"],["蒲团","蒲團"],["蒲扇价增","蒲扇價增"],["蒲松龄","蒲松齡"],["蒸了","蒸了"],["蒸便当","蒸便當"],["蒸发","蒸發"],["蒸发器","蒸發器"],["蒸发掉","蒸發掉"],["蒸发散","蒸發散"],["蒸发热","蒸發熱"],["蒸发皿","蒸發皿"],["蒸发空调","蒸發空調"],["蒸发计","蒸發計"],["蒸发量","蒸發量"],["蒸干","蒸乾"],["蒸汽熨斗","蒸汽熨斗"],["蒸沤历澜","蒸漚歷瀾"],["蒸藜出妻","蒸藜出妻"],["蒸面","蒸麪"],["蒸骨验尸","蒸骨驗屍"],["蒿里","蒿里"],["蓄势待发","蓄勢待發"],["蓄发","蓄髮"],["蓄志","蓄志"],["蓄胡","蓄鬍"],["蓄长发","蓄長髮"],["蓄须","蓄鬚"],["蓄须明志","蓄鬚明志"],["蓊郁","蓊鬱"],["蓝发","藍髮"],["蓝布","藍布"],["蓝托斯","藍托斯"],["蓝板","藍板"],["蓝淀","藍澱"],["蓝田出玉","藍田出玉"],["蓝田种玉","藍田種玉"],["蓝胡子","藍鬍子"],["蓝色系","藍色系"],["蓝采和","藍采和"],["蓟训历家","薊訓歷家"],["蓦然回首","驀然回首"],["蓬勃发展","蓬勃發展"],["蓬发","蓬髮"],["蓬头垢面","蓬頭垢面"],["蓬松","蓬鬆"],["蓬蓬松松","蓬蓬鬆鬆"],["蓬门荆布","蓬門荊布"],["蓬首垢面","蓬首垢面"],["蔑如","蔑如"],["蔑弃","蔑棄"],["蔑称","蔑稱"],["蔑蒙","蔑蒙"],["蔑视","蔑視"],["蔗板","蔗板"],["蔡丰州","蔡豐州"],["蔡仰秋","蔡仰秋"],["蔡克嵩","蔡克嵩"],["蔡同荣","蔡同榮"],["蔡志忠","蔡志忠"],["蔡志杰","蔡志傑"],["蔡文丰","蔡文豐"],["蔡松坡","蔡松坡"],["蔡清游","蔡清遊"],["蔡秋炎","蔡秋炎"],["蔡细历","蔡細歷"],["蔷薇十字团","薔薇十字團"],["蔼彩","藹彩"],["蔽形术","蔽形術"],["蔽面","蔽面"],["蕃薯叶","蕃薯葉"],["蕈状云","蕈狀雲"],["蕉叶","蕉葉"],["蕉布","蕉布"],["蕲向","蘄向"],["蕴借","蘊藉"],["蕴借含蓄","蘊藉含蓄"],["蕴奇待价","蘊奇待價"],["薄云","薄雲"],["薄干","薄幹"],["薄幸","薄倖"],["薄幸人","薄倖人"],["薄恶","薄惡"],["薄曲","薄曲"],["薄松松","薄鬆鬆"],["薄板","薄板"],["薄海同仇","薄海同仇"],["薄荷叶","薄荷葉"],["薄面","薄面"],["薄面含嗔","薄面含嗔"],["薙发","薙髮"],["薙发令","薙髮令"],["薛松干","薛松乾"],["薝卜","薝蔔"],["薪尽火传","薪盡火傳"],["薪资表","薪資表"],["薰修","薰脩"],["薰莸不同器","薰蕕不同器"],["薰莸同器","薰蕕同器"],["藉资挹注","藉資挹注"],["藏于","藏於"],["藏匿于","藏匿於"],["藏南纵谷","藏南縱谷"],["藏历","藏曆"],["藏奸","藏奸"],["藏尸","藏屍"],["藏幸","藏幸"],["藏蒙歌儿","藏矇歌兒"],["藏量丰富","藏量豐富"],["藏针缝","藏針縫"],["藕复","藕覆"],["藜藿不采","藜藿不採"],["藤制","藤製"],["藩台","藩臺"],["蘑菇云","蘑菇雲"],["虎克","虎克"],["虎克党","虎克黨"],["虎克定律","虎克定律"],["虎兕出柙","虎兕出柙"],["虎山艺术馆","虎山藝術館"],["虎据","虎據"],["虎斗","虎鬥"],["虎斗龙争","虎鬥龍爭"],["虎甲虫","虎甲蟲"],["虎皮松","虎皮松"],["虎荡羊群","虎蕩羊羣"],["虎须","虎鬚"],["虏获","虜獲"],["虑周行果","慮周行果"],["虑无不周","慮無不周"],["虚云大师","虛雲大師"],["虚冲","虛沖"],["虚发","虛發"],["虚夸","虛誇"],["虚心使人进步骄傲使人落后","虛心使人進步驕傲使人落後"],["虚怀若谷","虛懷若谷"],["虚拟通道标志符","虛擬通道標誌符"],["虚有其表","虛有其表"],["虚症","虛症"],["虚荡","虛蕩"],["虞歌决别","虞歌決別"],["虫书","蟲書"],["虫体","蟲體"],["虫儿","蟲兒"],["虫出","蟲出"],["虫卵","蟲卵"],["虫吃牙","蟲吃牙"],["虫声","蟲聲"],["虫媒病毒","蟲媒病毒"],["虫媒花","蟲媒花"],["虫子","蟲子"],["虫子牙","蟲子牙"],["虫孔","蟲孔"],["虫字旁儿","蟲字旁兒"],["虫害","蟲害"],["虫情","蟲情"],["虫沙微类","蟲沙微類"],["虫沙猿鹤","蟲沙猿鶴"],["虫漆","蟲漆"],["虫灾","蟲災"],["虫牙","蟲牙"],["虫瘿","蟲癭"],["虫白蜡","蟲白蠟"],["虫眼","蟲眼"],["虫篆","蟲篆"],["虫篆之技","蟲篆之技"],["虫类","蟲類"],["虫胶","蟲膠"],["虫臂鼠肝","蟲臂鼠肝"],["虫虫","蟲蟲"],["虫虫蚁蚁","蟲蟲蟻蟻"],["虫蚀","蟲蝕"],["虫蚁","蟲蟻"],["虫蛭","蟲蛭"],["虫豸","蟲豸"],["虫部","虫部"],["虫霜水旱","蟲霜水旱"],["虫鱼","蟲魚"],["虫鸟叫声","蟲鳥叫聲"],["虫鸣","蟲鳴"],["虫鸣水沸","蟲鳴水沸"],["虬须","虯鬚"],["虮蝨相吊","蟣蝨相弔"],["虹彩","虹彩"],["虹彩流辉","虹彩流輝"],["虹彩炎","虹彩炎"],["虹彩膜","虹彩膜"],["虽复能复","雖覆能復"],["虾干","蝦乾"],["虾蟆跳在戥盘子里","蝦蟆跳在戥盤子裏"],["虾须","蝦鬚"],["蚀船虫","蝕船蟲"],["蚁合","蟻合"],["蚁后","蟻后"],["蚁斗蜗争","蟻鬥蝸爭"],["蚁术","蟻術"],["蚊动牛斗","蚊動牛鬥"],["蚊子遭扇打只为嘴伤人","蚊子遭扇打只爲嘴傷人"],["蚊睫之虫","蚊睫之蟲"],["蚊虫","蚊蟲"],["蚊虫叮咬","蚊蟲叮咬"],["蚕种","蠶種"],["蚕豆症","蠶豆症"],["蚜虫","蚜蟲"],["蚵仔面线","蚵仔麪線"],["蛀虫","蛀蟲"],["蛆虫","蛆蟲"],["蛇发女妖","蛇髮女妖"],["蛇口蜂针","蛇口蜂針"],["蛇皮松","蛇皮松"],["蛇纹岩","蛇紋岩"],["蛇绿岩","蛇綠岩"],["蛇绿混杂岩","蛇綠混雜岩"],["蛇绿混杂岩带","蛇綠混雜岩帶"],["蛋卷","蛋卷"],["蛋彩画","蛋彩畫"],["蛋杯","蛋杯"],["蛏干","蟶乾"],["蛓毛虫","蛓毛蟲"],["蛔虫","蛔蟲"],["蛔虫病","蛔蟲病"],["蛔虫症","蛔蟲症"],["蛔虫药","蛔蟲藥"],["蛙鼓虫吟","蛙鼓蟲吟"],["蛟龙得云雨","蛟龍得雲雨"],["蛮干","蠻幹"],["蛮干到底","蠻幹到底"],["蛮干淨","蠻乾淨"],["蛮干爽","蠻乾爽"],["蛮针瞎灸","蠻針瞎灸"],["蛰虫","蟄蟲"],["蛲虫","蟯蟲"],["蛲虫病","蟯蟲病"],["蜀党","蜀黨"],["蜂准","蜂準"],["蜂出","蜂出"],["蜂午并起","蜂午並起"],["蜂后","蜂后"],["蜂巢式行动电话系统","蜂巢式行動電話系統"],["蜂涌而出","蜂涌而出"],["蜂蒙","蜂蒙"],["蜂蜡","蜂蠟"],["蜗杆","蝸桿"],["蜗舍","蝸舍"],["蜜蜡","蜜蠟"],["蜜里调油","蜜裏調油"],["蜡丸","蠟丸"],["蜡书","蠟書"],["蜡人","蠟人"],["蜡人馆","蠟人館"],["蜡像","蠟像"],["蜡像馆","蠟像館"],["蜡光纸","蠟光紙"],["蜡原型","蠟原型"],["蜡台","蠟臺"],["蜡嘴","蠟嘴"],["蜡坨儿","蠟坨兒"],["蜡坨子","蠟坨子"],["蜡头儿","蠟頭兒"],["蜡封","蠟封"],["蜡屐","蠟屐"],["蜡布","蠟布"],["蜡弹","蠟彈"],["蜡扦","蠟扦"],["蜡月","蜡月"],["蜡本","蠟本"],["蜡板","蠟板"],["蜡果","蠟果"],["蜡枪头","蠟槍頭"],["蜡染","蠟染"],["蜡査","蠟查"],["蜡梅","蠟梅"],["蜡油","蠟油"],["蜡泪","蠟淚"],["蜡渣","蠟渣"],["蜡灯","蠟燈"],["蜡炬","蠟炬"],["蜡烛","蠟燭"],["蜡烛不点不亮","蠟燭不點不亮"],["蜡烛台","蠟燭臺"],["蜡烛油","蠟燭油"],["蜡烛相","蠟燭相"],["蜡烛线","蠟燭線"],["蜡版","蠟版"],["蜡珀","蠟珀"],["蜡画","蠟畫"],["蜡疗","蠟療"],["蜡皮","蠟皮"],["蜡祭","蜡祭"],["蜡笔","蠟筆"],["蜡笔小新","蠟筆小新"],["蜡笔画","蠟筆畫"],["蜡笺","蠟箋"],["蜡纸","蠟紙"],["蜡膏","蠟膏"],["蜡膜","蠟膜"],["蜡芯儿","蠟芯兒"],["蜡花","蠟花"],["蜡茶","蠟茶"],["蜡虫","蠟蟲"],["蜡蜂","蠟蜂"],["蜡诏","蠟詔"],["蜡质","蠟質"],["蜡铺","蠟鋪"],["蜡黄","蠟黃"],["蜡黄色","蠟黃色"],["蜰虫","蜰蟲"],["蜷曲","蜷曲"],["蝎谮","蠍譖"],["蝗虫","蝗蟲"],["蝗虫过境","蝗蟲過境"],["蝨多了不咬债多了不愁","蝨多了不咬債多了不愁"],["蝴蝶谷","蝴蝶谷"],["蝼蚁得志","螻蟻得志"],["融合","融合"],["融合为","融合爲"],["融合为一","融合爲一"],["融合式","融合式"],["融合式翼梢小翼","融合式翼梢小翼"],["融合线","融合線"],["融汇","融匯"],["螟虫","螟蟲"],["螫针","螫針"],["螳臂当车","螳臂當車"],["螳螂捕蝉黄雀在后","螳螂捕蟬黃雀在後"],["螹胡","螹胡"],["螺旋千斤顶","螺旋千斤頂"],["螺旋曲面","螺旋曲面"],["螺旋杆菌","螺旋桿菌"],["螺旋面","螺旋麪"],["螺杆","螺桿"],["螽斯之征","螽斯之徵"],["螾庐曲谈","螾廬曲談"],["蟠尾丝虫","蟠尾絲蟲"],["蟠尾丝虫症","蟠尾絲蟲症"],["蟠据","蟠據"],["蟠曲","蟠曲"],["蟠桃胜会","蟠桃勝會"],["蟠采","蟠采"],["蟠龙松","蟠龍松"],["蟪蛄不知春秋","蟪蛄不知春秋"],["蟭蟟虫","蟭蟟蟲"],["蟹黄鲍鱼面","蟹黃鮑魚麪"],["蟻后","蟻后"],["蟾宫折桂","蟾宮折桂"],["蟾彩","蟾彩"],["蠁干","蠁幹"],["蠓虫","蠓蟲"],["蠕虫","蠕蟲"],["蠕虫形","蠕蟲形"],["蠢虫","蠢蟲"],["蠢蠢欲动","蠢蠢欲動"],["蠹书虫","蠹書蟲"],["蠹众木折","蠹衆木折"],["蠹众而木折隙大而墙坏","蠹衆而木折隙大而牆壞"],["蠹啄剖梁柱","蠹啄剖梁柱"],["蠹虫","蠹蟲"],["血亲复仇","血親復仇"],["血仇","血仇"],["血余","血餘"],["血克帮帮","血克幫幫"],["血制品","血製品"],["血参","血蔘"],["血吸虫","血吸蟲"],["血吸虫病","血吸蟲病"],["血小板","血小板"],["血已干","血已乾"],["血才干","血纔乾"],["血栓症","血栓症"],["血汗工厂","血汗工廠"],["血洗台湾","血洗臺灣"],["血流如注","血流如注"],["血浓于水","血濃於水"],["血海尸山","血海屍山"],["血海深仇","血海深仇"],["血液恐怖症","血液恐怖症"],["血症","血癥"],["血线虫","血線蟲"],["血缘关系","血緣關係"],["血肉淋漓","血肉淋漓"],["血胄","血胄"],["血胡同","血衚衕"],["血脂升高症","血脂升高症"],["血色素沉积症","血色素沉積症"],["衅发萧墙","釁發蕭牆"],["衅恶","釁惡"],["衅钟","釁鐘"],["衅面","釁面"],["行万里路","行萬里路"],["行万里路胜读万卷书","行萬裏路勝讀萬捲書"],["行万里路读万卷书","行萬里路讀萬卷書"],["行不苟合","行不苟合"],["行业别","行業別"],["行业规范","行業規範"],["行个方便","行個方便"],["行为世范","行爲世範"],["行为准则","行爲準則"],["行为艺术","行爲藝術"],["行为艺术者","行爲藝術者"],["行为规范","行爲規範"],["行了","行了"],["行事历","行事曆"],["行事历史","行事歷史"],["行于","行於"],["行云","行雲"],["行云流水","行雲流水"],["行伍出身","行伍出身"],["行佣","行佣"],["行修寺","行修寺"],["行兵布阵","行兵佈陣"],["行凶","行兇"],["行凶前","行兇前"],["行凶后","行兇後"],["行凶後","行兇後"],["行凶杀人","行兇殺人"],["行凶者","行兇者"],["行动党","行動黨"],["行动计划","行動計劃"],["行千里路读万卷书","行千裏路讀萬卷書"],["行卷","行卷"],["行台","行臺"],["行合趋同","行合趨同"],["行同","行同"],["行同狗彘","行同狗彘"],["行同狗豨","行同狗豨"],["行善不欲人知","行善不欲人知"],["行复","行復"],["行奸卖俏","行奸賣俏"],["行尸","行屍"],["行尸视肉","行屍視肉"],["行尸走肉","行屍走肉"],["行尸走骨","行屍走骨"],["行幸","行幸"],["行当","行當"],["行志","行志"],["行情价","行情價"],["行情表","行情表"],["行成于思","行成於思"],["行政区划","行政區劃"],["行政区划图","行政區劃圖"],["行政当局","行政當局"],["行政系","行政系"],["行政诉愿","行政訴願"],["行有余力","行有餘力"],["行李卷","行李捲"],["行板","行板"],["行游","行遊"],["行百里","行百里"],["行百里者半于九十","行百里者半於九十"],["行短才乔","行短才喬"],["行短才高","行短才高"],["行程表","行程表"],["行药","行藥"],["行行出状元","行行出狀元"],["行针","行鍼"],["行针布线","行鍼佈線"],["行针走线","行鍼走線"],["行雨朝云","行雨朝雲"],["衍声复词","衍聲複詞"],["衍极","衍極"],["衍生出","衍生出"],["衍生出来","衍生出來"],["衔哀致诚","銜哀致誠"],["衔恨蒙枉","銜恨蒙枉"],["衔缺相当","銜缺相當"],["街坊邻舍","街坊鄰舍"],["街坊邻里","街坊鄰里"],["街里街坊","街里街坊"],["街面儿","街面兒"],["衡量制","衡量制"],["衣不兼采","衣不兼采"],["衣不完采","衣不完采"],["衣不布体","衣不布體"],["衣不重采","衣不重采"],["衣丰食足","衣豐食足"],["衣丰食饱","衣豐食飽"],["衣冠云集","衣冠雲集"],["衣扣","衣釦"],["衣摆","衣襬"],["衣斗木","衣斗木"],["衣柜","衣櫃"],["衣物已干","衣物已乾"],["衣物柜","衣物櫃"],["衣物渐干","衣物漸乾"],["衣绣昼行","衣繡晝行"],["衣衫已干","衣衫已乾"],["衣锦夜游","衣錦夜游"],["衣锦昼游","衣錦晝游"],["补于","補於"],["补修","補修"],["补发","補發"],["补回","補回"],["补回来","補回來"],["补扣","補釦"],["补挂朝珠","補掛朝珠"],["补气固表","補氣固表"],["补注","補註"],["补票价","補票價"],["补种","補種"],["补药","補藥"],["补血药","補血藥"],["补血针","補血針"],["补针","補針"],["表亲","表親"],["表仪","表儀"],["表件","表件"],["表侄","表侄"],["表停","錶停"],["表兄","表兄"],["表兄弟","表兄弟"],["表冊","表冊"],["表册","表冊"],["表冠","錶冠"],["表决","表決"],["表决权","表決權"],["表出","表出"],["表出来","表出來"],["表列","表列"],["表列出","表列出"],["表功","表功"],["表单","表單"],["表厂","錶廠"],["表叔","表叔"],["表同情","表同情"],["表哥","表哥"],["表唱","表唱"],["表土","表土"],["表土层","表土層"],["表壮不如里壮","表壯不如裏壯"],["表壳","錶殼"],["表壳儿","錶殼兒"],["表头","表頭"],["表奏","表奏"],["表妹","表妹"],["表姊","表姊"],["表姊妹","表姊妹"],["表姊家","表姊家"],["表姐","表姐"],["表姐妹","表姐妹"],["表姑","表姑"],["表姨","表姨"],["表姨父","表姨父"],["表姪","表姪"],["表婶","表嬸"],["表嫂","表嫂"],["表子","表子"],["表字","表字"],["表尺","表尺"],["表层","表層"],["表层水","表層水"],["表带","錶帶"],["表店","錶店"],["表弟","表弟"],["表形文字","表形文字"],["表彰","表彰"],["表彰出来","表彰出來"],["表征","表徵"],["表德","表德"],["表快","錶快"],["表态","表態"],["表态句","表態句"],["表情","表情"],["表意","表意"],["表意文字","表意文字"],["表意符阶段","表意符階段"],["表慢","錶慢"],["表扬","表揚"],["表扬大会","表揚大會"],["表报","表報"],["表揭","表揭"],["表文","表文"],["表明","表明"],["表明心迹","表明心跡"],["表显","表顯"],["表本","表本"],["表板","錶板"],["表格","表格"],["表格化公文","表格化公文"],["表款","錶款"],["表沃夫","表沃夫"],["表海","表海"],["表演","表演"],["表演会","表演會"],["表演区","表演區"],["表演厅","表演廳"],["表演性","表演性"],["表演欲","表演慾"],["表演秀","表演秀"],["表演给","表演給"],["表演艺术","表演藝術"],["表演赛","表演賽"],["表演过火","表演過火"],["表照","表照"],["表率","表率"],["表王","錶王"],["表现","表現"],["表现为","表現爲"],["表现为费","表現爲費"],["表现主义","表現主義"],["表现出","表現出"],["表现出来","表現出來"],["表现力","表現力"],["表现型","表現型"],["表现对象","表現對象"],["表现形","表現形"],["表现自己","表現自己"],["表甥","表甥"],["表白","表白"],["表的历史","錶的歷史"],["表的嘀嗒","錶的嘀嗒"],["表皮","表皮"],["表皮剥脱素","表皮剝脫素"],["表皮层","表皮層"],["表盘","錶盤"],["表相","表相"],["表示","表示"],["表示出","表示出"],["表示出来","表示出來"],["表示层","表示層"],["表示敬意","表示敬意"],["表礼","表禮"],["表章","表章"],["表笔","表筆"],["表笺","表箋"],["表背","表背"],["表舅","表舅"],["表舅母","表舅母"],["表荐","表薦"],["表蒙子","錶蒙子"],["表行","錶行"],["表表","表表"],["表襮","表襮"],["表观","表觀"],["表记","表記"],["表记物件","表記物件"],["表证","表證"],["表识","表識"],["表词","表詞"],["表语","表語"],["表象","表象"],["表转","錶轉"],["表达","表達"],["表达出","表達出"],["表达出来","表達出來"],["表达力","表達力"],["表达失语症","表達失語症"],["表达式","表達式"],["表达能力","表達能力"],["表述","表述"],["表速","錶速"],["表里","表裏"],["表里一致","表裏一致"],["表里不一","表裏不一"],["表里受敌","表裏受敵"],["表里如一","表裏如一"],["表里山河","表裏山河"],["表里相合","表裏相合"],["表里相应","表裏相應"],["表里相济","表裏相濟"],["表针","錶針"],["表链","錶鏈"],["表错","表錯"],["表错情","表錯情"],["表门","表門"],["表露","表露"],["表露出","表露出"],["表露无遗","表露無遺"],["表面","表面"],["表面上","表面上"],["表面信息","表面信息"],["表面光洁","表面光潔"],["表面化","表面化"],["表面外膜","表面外膜"],["表面工夫","表面工夫"],["表面张力","表面張力"],["表面性","表面性"],["表面活化剂","表面活化劑"],["表面活性剂","表面活性劑"],["表面流","表面流"],["表面的","表面的"],["表面积","表面積"],["表面质量","表面質量"],["表音","表音"],["表音文字","表音文字"],["表题","表題"],["表饰","表飾"],["衬出","襯出"],["衬布","襯布"],["衬托","襯托"],["衬托出","襯托出"],["衬托底","襯托底"],["衬托物","襯托物"],["衬里","襯裏"],["衰变曲线","衰變曲線"],["衰变链","衰變鏈"],["衲被蒙头","衲被蒙頭"],["衷于","衷於"],["衷曲","衷曲"],["衿曲","衿曲"],["袁于令","袁于令"],["袁友范","袁友范"],["袁承志","袁承志"],["袁术","袁術"],["袅娜","嫋娜"],["袅娜纤巧","嫋娜纖巧"],["袅娜风流","嫋娜風流"],["袅窕","裊窕"],["袅绕","裊繞"],["袅袅","嫋嫋"],["袅袅上升","裊裊上升"],["袅袅娉娉","嫋嫋娉娉"],["袅袅娜娜","嫋嫋娜娜"],["袅袅婷婷","嫋嫋婷婷"],["袅袅炊烟","裊裊炊煙"],["袋表","袋錶"],["袋里","袋裏"],["袒露出","袒露出"],["袖一卷","袖一捲"],["袖扣","袖釦"],["袖里","袖裏"],["袖里乾坤","袖裏乾坤"],["袖里来袖里去","袖裏來袖裏去"],["被人背","被人揹"],["被动吸烟","被動吸菸"],["被动挨打","被動挨打"],["被发","被髮"],["被发佯狂","被髮佯狂"],["被发入山","被髮入山"],["被发左衽","被髮左衽"],["被发文身","被髮文身"],["被发现","被發現"],["被发缨冠","被髮纓冠"],["被发觉","被發覺"],["被发阳狂","被髮陽狂"],["被复","被複"],["被头散发","被頭散髮"],["被害妄想症","被害妄想症"],["被干","被幹"],["被扣","被扣"],["被拐","被拐"],["被服厂","被服廠"],["被泽蒙庥","被澤蒙庥"],["被灾蒙祸","被災蒙禍"],["被窝里","被窩裏"],["被窝里放屁","被窩裏放屁"],["被里","被裏"],["被面","被面"],["袭击战术","襲擊戰術"],["袭卷","襲捲"],["裁划","裁劃"],["裁制","裁製"],["裁并","裁併"],["裁样板","裁樣板"],["裁衣合帐","裁衣合帳"],["裂了","裂了"],["裂体吸虫","裂體吸蟲"],["裂变同位素","裂變同位素"],["裂致","裂致"],["裂解厂","裂解廠"],["裂谷","裂谷"],["裂谷热","裂谷熱"],["裂谷热病毒","裂谷熱病毒"],["装修","裝修"],["装修门面","裝修門面"],["装出","裝出"],["装出去","裝出去"],["装出来","裝出來"],["装回","裝回"],["装岩机","裝岩機"],["装折","裝摺"],["装点门面","裝點門面"],["装糊涂","裝糊塗"],["装订厂","裝訂廠"],["装配厂","裝配廠"],["装配工厂","裝配工廠"],["装门面","裝門面"],["裒克","裒剋"],["裔胄","裔胄"],["裕丰","裕豐"],["裘弊金尽","裘弊金盡"],["裘馨氏肌肉萎缩症","裘馨氏肌肉萎縮症"],["裙布荆钗","裙布荊釵"],["裙带关系","裙帶關係"],["裙摆","裙襬"],["裤扣","褲釦"],["裴回","裴回"],["裴松之","裴松之"],["裴航遇云英","裴航遇雲英"],["裴里诺","裴里諾"],["裸体女尸","裸體女屍"],["裸叶","裸葉"],["裸尸","裸屍"],["裸岩","裸岩"],["裸露出","裸露出"],["裹了","裹了"],["裹尸","裹屍"],["裹尸布","裹屍布"],["裹尸马革","裹屍馬革"],["裹布","裹布"],["裹扎","裹紮"],["裹脚布","裹腳布"],["褐布","褐布"],["褒善贬恶","褒善貶惡"],["褒录","褒錄"],["褒贤遏恶","褒賢遏惡"],["褒赞","褒讚"],["褒采一介","褒采一介"],["褚人获","褚人獲"],["褪前擦后","褪前擦後"],["褶子了","褶子了"],["褶曲","褶曲"],["褶曲山脉","褶曲山脈"],["褶皱山系","褶皺山系"],["褶皱山系火地岛","褶皺山系火地島"],["襄赞","襄贊"],["襟曲","襟曲"],["西丰","西豐"],["西丰县","西豐縣"],["西冲","西衝"],["西出","西出"],["西利古里","西利古里"],["西北向","西北向"],["西北师范大学","西北師範大學"],["西北面","西北面"],["西华师范大学","西華師範大學"],["西南向","西南向"],["西南师范大学","西南師範大學"],["西南面","西南面"],["西占","西佔"],["西厂","西廠"],["西历","西曆"],["西历纪元","西曆紀元"],["西原借款","西原借款"],["西发里亚条约","西發里亞條約"],["西台","西臺"],["西台人","西臺人"],["西台古堡","西臺古堡"],["西台帝国","西臺帝國"],["西后","西后"],["西向","西向"],["西周","西周"],["西周时","西周時"],["西周时代","西周時代"],["西周时期","西周時期"],["西周钟","西周鐘"],["西哈努克","西哈努克"],["西太后","西太后"],["西尼克学派","西尼克學派"],["西岳","西嶽"],["西征","西征"],["西文系","西文系"],["西方极乐","西方極樂"],["西方极乐世界","西方極樂世界"],["西晒","西曬"],["西曲","西曲"],["西来庵","西來庵"],["西松","西松"],["西松建设","西松建設"],["西极","西極"],["西格蒙德","西格蒙德"],["西欧集团","西歐集團"],["西洋参","西洋參"],["西游","西遊"],["西游补","西遊補"],["西游记","西遊記"],["西点面包","西點麪包"],["西王母娘娘","西王母娘娘"],["西米谷","西米谷"],["西药","西藥"],["西药房","西藥房"],["西蒙","西蒙"],["西蒙斯","西蒙斯"],["西蒙逊","西蒙遜"],["西藏百万农奴解放纪念日","西藏百萬農奴解放紀念日"],["西西里","西西里"],["西西里岛","西西里島"],["西谷椰子","西谷椰子"],["西谷米","西谷米"],["西谷米冻","西谷米凍"],["西里","西里"],["西里尔","西里爾"],["西里尔字母","西裏爾字母"],["西里西亚","西里西亞"],["西门子电机厂","西門子電機廠"],["西除东荡","西除東蕩"],["西面","西面"],["要么","要麼"],["要了","要了"],["要价","要價"],["要价还价","要價還價"],["要克制","要剋制"],["要冲","要衝"],["要千取万","要千取萬"],["要占","要佔"],["要占卜","要占卜"],["要回","要回"],["要干了","要乾了"],["要念","要念"],["要怎么收获先怎么栽","要怎麼收穫先怎麼栽"],["要扣","要扣"],["要拐","要拐"],["要自制","要自制"],["要面子","要面子"],["覃天同","覃天同"],["覆巢之下无完卵","覆巢之下無完卵"],["覆水难收","覆水難收"],["覆没","覆沒"],["覆盖","覆蓋"],["覆盖范围","覆蓋範圍"],["覆盖面","覆蓋面"],["覆辙","覆轍"],["覆雨翻云","覆雨翻雲"],["視如寇仇","視如寇讎"],["见不到面","見不到面"],["见世面","見世面"],["见个","見個"],["见个情","見個情"],["见之不取思之千里","見之不取思之千里"],["见了","見了"],["见了和尚骂贼秃","見了和尚罵賊禿"],["见了新人忘旧人","見了新人忘舊人"],["见了面","見了面"],["见于","見於"],["见几","見幾"],["见几而作","見幾而作"],["见到面","見到面"],["见危致命","見危致命"],["见复","見覆"],["见尧于墙","見堯於牆"],["见得多了","見得多了"],["见棱见角","見棱見角"],["见物不取失之千里","見物不取失之千里"],["见笑于人","見笑於人"],["见素抱朴","見素抱樸"],["见缝插针","見縫插針"],["见见面","見見面"],["见过世面","見過世面"],["见鉴","見鑒"],["见钟不打","見鐘不打"],["见钟不打更去炼铜","見鐘不打更去煉銅"],["见面","見面"],["见面三分情","見面三分情"],["见面会","見面會"],["见面礼","見面禮"],["见马克思","見馬克思"],["观众台","觀衆臺"],["观光台","觀光臺"],["观光周","觀光週"],["观光团","觀光團"],["观光游憩性资源","觀光遊憩性資源"],["观光签证","觀光簽證"],["观光胜地","觀光勝地"],["观台","觀臺"],["观叶植物","觀葉植物"],["观后感","觀後感"],["观审制度","觀審制度"],["观察出来","觀察出來"],["观察团","觀察團"],["观念","觀念"],["观护制度","觀護制度"],["观星台","觀星臺"],["观景台","觀景臺"],["观望台","觀望臺"],["观测台","觀測臺"],["观礼台","觀禮臺"],["观者云集","觀者雲集"],["观者如云","觀者如雲"],["观象台","觀象臺"],["观采","觀採"],["观音庵","觀音庵"],["规划","規劃"],["规划为","規劃爲"],["规划人员","規劃人員"],["规划出","規劃出"],["规划好","規劃好"],["规划局","規劃局"],["规划成","規劃成"],["规划案","規劃案"],["规划范围","規劃範圍"],["规制","規制"],["规复","規復"],["规定价格","規定價格"],["规定出来","規定出來"],["规定地价","規定地價"],["规定范围","規定範圍"],["规画出","規畫出"],["规矩准绳","規矩準繩"],["规章制度","規章制度"],["规范","規範"],["规范企业","規範企業"],["规范作用","規範作用"],["规范动作","規範動作"],["规范化","規範化"],["规范化管理","規範化管理"],["规范司","規範司"],["规范名","規範名"],["规范字","規範字"],["规范学","規範學"],["规范市场","規範市場"],["规范性","規範性"],["规范性文件","規範性文件"],["规范意见","規範意見"],["规范执法","規範執法"],["规范技术","規範技術"],["规范文件","規範文件"],["规范理论","規範理論"],["规范的","規範的"],["规范管理","規範管理"],["规范行为","規範行爲"],["规范语言","規範語言"],["视于","視於"],["视力表","視力表"],["视同","視同"],["视同儿戏","視同兒戲"],["视同具文","視同具文"],["视同手足","視同手足"],["视同秦越","視同秦越"],["视同陌路","視同陌路"],["视如寇仇","視如寇仇"],["视如己出","視如己出"],["视杯","視杯"],["视空间系统","視空間系統"],["视窗基准","視窗基準"],["视觉系","視覺系"],["视觉艺术","視覺藝術"],["视觉适应","視覺適應"],["视讯会议系统","視訊會議系統"],["视讯系统","視訊系統"],["视野范围","視野範圍"],["览胜","覽勝"],["觉出","覺出"],["觉发","覺發"],["觉察出","覺察出"],["觊幸","覬倖"],["觊觎之志","覬覦之志"],["觌面","覿面"],["觑个意顺","覷個意順"],["觑当","覷當"],["角化症","角化症"],["角斗","角鬥"],["角斗场","角鬥場"],["角斗士","角鬥士"],["角曲尺","角曲尺"],["角砾岩","角礫岩"],["角膜移植术","角膜移植術"],["角色冲突","角色衝突"],["角色扮演游戏","角色扮演遊戲"],["角落发","角落發"],["角落里","角落裏"],["角谷猜想","角谷猜想"],["角里","角里"],["角页岩","角頁岩"],["觔斗","觔斗"],["觔斗云","觔斗雲"],["解了","解了"],["解决不了","解決不了"],["解决困难","解決困難"],["解出","解出"],["解出来","解出來"],["解到县里","解到縣裏"],["解制","解制"],["解剑拜仇","解劍拜仇"],["解发","解發"],["解发佯狂","解髮佯狂"],["解困","解困"],["解当","解當"],["解当铺","解當鋪"],["解扣","解釦"],["解放出来","解放出來"],["解放后","解放後"],["解救出来","解救出來"],["解析几何","解析幾何"],["解析几何学","解析幾何學"],["解毒药","解毒藥"],["解理方向","解理方向"],["解理面","解理面"],["解痛药","解痛藥"],["解药","解藥"],["解酸药","解酸藥"],["解铃仍须系铃人","解鈴仍須繫鈴人"],["解铃系铃","解鈴繫鈴"],["解铃还是系铃人","解鈴還是繫鈴人"],["解铃还须系铃人","解鈴還須繫鈴人"],["解雇","解僱"],["触事面墙","觸事面牆"],["触发","觸發"],["触发器","觸發器"],["触发式","觸發式"],["触发引信","觸發引信"],["触发清单","觸發清單"],["触技曲","觸技曲"],["触控板","觸控板"],["触斗蛮争","觸鬥蠻爭"],["触板","觸板"],["触须","觸鬚"],["觱发","觱發"],["言不尽意","言不盡意"],["言且表过","言且表過"],["言之不尽","言之不盡"],["言之有据","言之有據"],["言云","言云"],["言出如山","言出如山"],["言出必行","言出必行"],["言出患入","言出患入"],["言出法随","言出法隨"],["言大而夸","言大而夸"],["言尽于此","言盡於此"],["言归于好","言歸於好"],["言必有据","言必有據"],["言文一致","言文一致"],["言无不尽","言無不盡"],["言无二价","言無二價"],["言行一致","言行一致"],["言行合一","言行合一"],["言行录","言行錄"],["言语失常症","言語失常症"],["言辩而确","言辯而确"],["言隐于荣华","言隱於榮華"],["証据","証據"],["詩云","詩云"],["詹千慧","詹千慧"],["詹姆士布朗","詹姆士布朗"],["詹姆斯布朗","詹姆斯布朗"],["詹宏志","詹宏志"],["詹志宏","詹志宏"],["詹志维","詹誌維"],["詹氏年鉴","詹氏年鑑"],["詹江布尔","詹江布爾"],["誊写板","謄寫板"],["誊出","謄出"],["誊出来","謄出來"],["誊录","謄錄"],["誊录所","謄錄所"],["誓同生死","誓同生死"],["誓愿","誓願"],["誓无二志","誓無二志"],["謷丑","謷醜"],["謻台","謻臺"],["譆譆出出","譆譆出出"],["警世钟","警世鐘"],["警察制度","警察制度"],["警察广播电台","警察廣播電臺"],["警报系统","警報系統"],["警报钟","警報鐘"],["警民冲突","警民衝突"],["警示钟","警示鐘"],["警辟","警闢"],["警钟","警鐘"],["譬似闲","譬似閒"],["譬如闲","譬如閒"],["计价","計價"],["计价器","計價器"],["计出万全","計出萬全"],["计分板","計分板"],["计划","計劃"],["计划书","計劃書"],["计划图","計劃圖"],["计划好","計劃好"],["计划性","計劃性"],["计划案","計劃案"],["计划生育","計劃生育"],["计划目标","計劃目標"],["计划经济","計劃經濟"],["计划署","計劃署"],["计划者","計劃者"],["计将安出","計將安出"],["计尽力穷","計盡力窮"],["计无所出","計無所出"],["计时表","計時錶"],["计白当黑","計白當黑"],["计程车共乘制","計程車共乘制"],["计穷力尽","計窮力盡"],["计穷力极","計窮力極"],["计穷虑极","計窮慮極"],["计算出","計算出"],["计算出来","計算出來"],["计算机制图","計算機製圖"],["计算机集成制造","計算機集成製造"],["计量制","計量制"],["订个","訂個"],["订了","訂了"],["订于","訂於"],["订价","訂價"],["订出","訂出"],["订出来","訂出來"],["订制","訂製"],["订制服","訂製服"],["订杂志","訂雜誌"],["认不出","認不出"],["认不出来","認不出來"],["认个","認個"],["认了","認了"],["认准","認準"],["认出","認出"],["认出来","認出來"],["认制修","認製修"],["认同","認同"],["认同卡","認同卡"],["认同度","認同度"],["认同感","認同感"],["认尸","認屍"],["认得出","認得出"],["认知神经心里学","認知神經心裏學"],["讦发","訐發"],["讨个","討個"],["讨个分晓","討個分曉"],["讨个吉利","討個吉利"],["讨了","討了"],["讨价","討價"],["讨价还价","討價還價"],["讨出","討出"],["讨出来","討出來"],["讨回","討回"],["讨彩","討彩"],["讨恶剪暴","討惡剪暴"],["讨没脸面","討沒臉面"],["讨针线","討針線"],["讨面皮","討面皮"],["让价","讓價"],["让位于","讓位於"],["让出","讓出"],["让出去","讓出去"],["让出来","讓出來"],["让胡路","讓胡路"],["让胡路区","讓胡路區"],["讫了","訖了"],["讬了","託了"],["训兽术","訓獸術"],["训练出","訓練出"],["训练出来","訓練出來"],["训胄","訓胄"],["训蒙","訓蒙"],["议事录","議事錄"],["议事纪录","議事紀錄"],["议价","議價"],["议价空间","議價空間"],["议会制","議會制"],["议会斗争","議會鬥爭"],["议和团","議和團"],["议坛","議壇"],["讯息处理系统","訊息處理系統"],["讯框传送论坛","訊框傳送論壇"],["记不了","記不了"],["记了","記了"],["记事板","記事板"],["记仇","記仇"],["记分板","記分板"],["记录","記錄"],["记录下","記錄下"],["记录下来","記錄下來"],["记录为","記錄爲"],["记录仪","記錄儀"],["记录到","記錄到"],["记录员","記錄員"],["记录器","記錄器"],["记录本","記錄本"],["记录板","記錄板"],["记录片","記錄片"],["记录簿","記錄簿"],["记念","記念"],["记挂","記掛"],["记者团","記者團"],["讲个","講個"],["讲了","講了"],["讲价","講價"],["讲信修睦","講信修睦"],["讲出","講出"],["讲出去","講出去"],["讲出来","講出來"],["讲台","講臺"],["讲坛","講壇"],["讲情面","講情面"],["讲闲话","講閒話"],["讲面子","講面子"],["讳恶不悛","諱惡不悛"],["许下愿心","許下願心"],["许久以后","許久以後"],["许人丰","許人丰"],["许凯克","許凱克"],["许历农","許歷農"],["许圣杰","許聖杰"],["许建发","許建發"],["许志华","許志華"],["许志彰","許志彰"],["许志煌","許志煌"],["许志雄","許志雄"],["许志鸿","許志鴻"],["许愿","許願"],["许愿树","許願樹"],["许愿池","許願池"],["许愿牌","許願牌"],["许愿起经","許愿起經"],["许振发","許振發"],["许智杰","許智傑"],["许杰","許傑"],["许杰辉","許傑輝"],["许胜发","許勝發"],["许胜雄","許勝雄"],["许至胜","許至勝"],["许致强","許致強"],["许豪升","許豪升"],["许铭杰","許銘傑"],["论价","論價"],["论千论万","論千論萬"],["论坛","論壇"],["论坛区","論壇區"],["论坛报","論壇報"],["论据","論據"],["论据不足","論據不足"],["论赞","論贊"],["设了","設了"],["设于","設於"],["设党","設黨"],["设厂","設廠"],["设台","設臺"],["设坛","設壇"],["设坛祭拜","設壇祭拜"],["设朝升殿","設朝升殿"],["设柜","設櫃"],["设言托意","設言托意"],["设计出","設計出"],["设计出来","設計出來"],["设计系","設計系"],["设计规范","設計規範"],["设限于","設限於"],["设鼓悬钟","設鼓懸鐘"],["访华团","訪華團"],["访台","訪臺"],["访台之旅","訪臺之旅"],["访察团","訪察團"],["访日团","訪日團"],["访问团","訪問團"],["访韩团","訪韓團"],["诀别","訣別"],["诀别书","訣別書"],["证于","證於"],["证出","證出"],["证出来","證出來"],["证卷","證卷"],["证卷交易所","證卷交易所"],["证据","證據"],["证据力","證據力"],["证据裁判主义","證據裁判主義"],["证明了","證明了"],["证明出来","證明出來"],["评个","評個"],["评个分数","評個分數"],["评了","評了"],["评价","評價"],["评价分类","評價分類"],["评估板","評估板"],["评出","評出"],["评出来","評出來"],["评分标准","評分標準"],["评判出","評判出"],["评卷","評卷"],["评审团","評審團"],["评审团特别奖","評審團特別獎"],["评核","評覈"],["评注","評註"],["评选出","評選出"],["评鉴","評鑑"],["评鉴为","評鑑爲"],["评鉴报告","評鑑報告"],["识别","識別"],["识别信号","識別信號"],["识别力","識別力"],["识别区","識別區"],["识别号","識別號"],["识别字","識別字"],["识别码","識別碼"],["识别証","識別証"],["识别证","識別證"],["识多才广","識多才廣"],["识微见几","識微見幾"],["识才","識才"],["识才尊贤","識才尊賢"],["识时务者为俊杰","識時務者爲俊傑"],["识面","識面"],["识面台官","識面臺官"],["诈哄","詐哄"],["诈奸不及","詐奸不及"],["诈尸","詐屍"],["诈术","詐術"],["诈胡","詐胡"],["诉愿","訴願"],["诉愿权","訴願權"],["诉愿状","訴願狀"],["诉说出来","訴說出來"],["诉诸于","訴諸於"],["诊断出","診斷出"],["诊断出来","診斷出來"],["诋毁","詆譭"],["词余","詞餘"],["词干","詞幹"],["词干启动","詞幹啓動"],["词无枝叶","詞無枝葉"],["词曲","詞曲"],["词汇","詞彙"],["词汇分解","詞彙分解"],["词汇判断","詞彙判斷"],["词汇判断任务","詞彙判斷任務"],["词汇判断作业","詞彙判斷作業"],["词汇判断法","詞彙判斷法"],["词汇学","詞彙學"],["词汇通路","詞彙通路"],["词穷理尽","詞窮理盡"],["词表","詞表"],["词语汇","詞語彙"],["词采","詞采"],["诏板","詔板"],["译制","譯製"],["译注","譯註"],["诓哄","誆哄"],["诔赞","誄讚"],["试出","試出"],["试出来","試出來"],["试制","試製"],["试卷","試卷"],["试周","試周"],["试炼","試煉"],["试种","試種"],["试算表","試算表"],["试胄","試胄"],["试药","試藥"],["试表","試表"],["试验台","試驗檯"],["诗云","詩云"],["诗云子曰","詩云子曰"],["诗以言志","詩以言志"],["诗余","詩餘"],["诗卷","詩卷"],["诗坛","詩壇"],["诗才","詩才"],["诗言志歌永言","詩言志歌永言"],["诗词曲语辞汇释","詩詞曲語辭匯釋"],["诗赞","詩讚"],["诗钟","詩鐘"],["诘曲","詰曲"],["诙谐曲","詼諧曲"],["诚征","誠徵"],["诚朴","誠樸"],["诛凶殄逆","誅兇殄逆"],["诛凶讨逆","誅兇討逆"],["诛尽杀绝","誅盡殺絕"],["诛戮殆尽","誅戮殆盡"],["话别","話別"],["话剧表演","話劇表演"],["话又说回来","話又說回來"],["话念","話念"],["话说回来","話說回來"],["话里套话","話裏套話"],["话里有话","話裏有話"],["话里藏阄","話裏藏鬮"],["诠注","詮註"],["诠释出","詮釋出"],["诡计百出","詭計百出"],["诡辩术","詭辯術"],["询于","詢於"],["询于刍荛","詢於芻蕘"],["询价","詢價"],["该于","該於"],["该党","該黨"],["该厂","該廠"],["该向","該向"],["该回","該回"],["该当","該當"],["该当何罪","該當何罪"],["该扣","該扣"],["该钟","該鐘"],["该面","該面"],["详尽","詳盡"],["详尽无遗","詳盡無遺"],["详征博引","詳徵博引"],["详注","詳註"],["详确","詳確"],["诬蔑","誣衊"],["诬蔑性","誣衊性"],["语云","語云"],["语出","語出"],["语录","語錄"],["语意区分量表","語意區分量表"],["语意差别量表","語意差別量表"],["语有云","語有云"],["语汇","語彙"],["语法术语","語法術語"],["语系","語系"],["语言规范","語言規範"],["语音合成","語音合成"],["语音失语症","語音失語症"],["语音数据机","語音數據機"],["语音识别","語音識別"],["语音输入系统","語音輸入系統"],["误尽天下苍生","誤盡天下蒼生"],["误差范围","誤差範圍"],["诱出","誘出"],["诱发","誘發"],["诱发型","誘發型"],["诱发式","誘發式"],["诱奸","誘姦"],["诱拐","誘拐"],["诱掖后进","誘掖後進"],["诱敌战术","誘敵戰術"],["诱杀战术","誘殺戰術"],["诱虫灯","誘蟲燈"],["诱降战术","誘降戰術"],["说不了","說不了"],["说不准","說不準"],["说不出","說不出"],["说不出口","說不出口"],["说不出来","說不出來"],["说不出话来","說不出話來"],["说不尽","說不盡"],["说了","說了"],["说了又说","說了又說"],["说了算","說了算"],["说出","說出"],["说出去","說出去"],["说出口","說出口"],["说出来","說出來"],["说出话来","說出話來"],["说千说万","說千說萬"],["说单生万岁","說單生萬歲"],["说参请","說參請"],["说合","說合"],["说合了盖儿了","說合了蓋兒了"],["说嘴郎中无好药","說嘴郎中無好藥"],["说回来","說回來"],["说好了","說好了"],["说定了","說定了"],["说家克计","說家克計"],["说尽","說盡"],["说岳","說岳"],["说岳全传","說岳全傳"],["说干便干","說幹便幹"],["说教术","說教術"],["说文解字注","說文解字注"],["说明了","說明了"],["说白了","說白了"],["说穿了","說穿了"],["说话不当话","說話不當話"],["说闲话","說閒話"],["说雨谈云","說雨談雲"],["诵念","誦唸"],["诵经台","誦經臺"],["请个","請個"],["请了","請了"],["请出","請出"],["请出去","請出去"],["请出来","請出來"],["请别见怪","請別見怪"],["请勿吸烟","請勿吸菸"],["请参阅","請參閱"],["请向","請向"],["请君入瓮","請君入甕"],["请回","請回"],["请回到","請回到"],["请回去","請回去"],["请回来","請回來"],["请您回复","請您回復"],["请愿","請願"],["请愿书","請願書"],["请愿团","請願團"],["请愿权","請願權"],["请愿案","請願案"],["请托","請託"],["请说出","請說出"],["诸余","諸餘"],["诸葛亮借东风","諸葛亮借東風"],["诺瓦克","諾瓦克"],["诺福克","諾福克"],["诺福克岛","諾福克島"],["诺美克斯","諾美克斯"],["诺里","諾里"],["读万卷书","讀萬卷書"],["读万卷书行万里路","讀萬卷書行萬里路"],["读不舍手","讀不捨手"],["读书三余","讀書三余"],["读书种子","讀書種子"],["读了","讀了"],["读出","讀出"],["读出来","讀出來"],["读后","讀後"],["读后心得","讀後心得"],["读后感","讀後感"],["读心术","讀心術"],["读脣术","讀脣術"],["课余","課餘"],["课前课后","課前課後"],["课卷","課卷"],["课后","課後"],["课后复习","課後複習"],["课后练习","課後練習"],["课后辅导","課後輔導"],["课征","課徵"],["课田制","課田制"],["课程标准","課程標準"],["课程表","課程表"],["课表","課表"],["课表上","課表上"],["诿过于人","諉過於人"],["谁个","誰個"],["谁家灶內无烟","誰家竈內無煙"],["谁干","誰幹"],["谁干净","誰乾淨"],["谁干的","誰幹的"],["谁笑到最后谁笑得最好","誰笑到最後誰笑得最好"],["谁笑在最后谁笑得最好","誰笑在最後誰笑得最好"],["调个","調個"],["调了","調了"],["调价","調價"],["调准","調準"],["调出","調出"],["调出去","調出去"],["调出来","調出來"],["调制","調製"],["调制出","調製出"],["调制法","調製法"],["调制波","調製波"],["调制解调器","調制解調器"],["调升","調升"],["调卷","調卷"],["调发","調發"],["调合","調合"],["调合漆","調合漆"],["调哄","調哄"],["调回","調回"],["调回去","調回去"],["调回来","調回來"],["调幅台","調幅臺"],["调干","調幹"],["调弦","調絃"],["调当","調當"],["调整范围","調整範圍"],["调查团","調查團"],["调查范围","調查範圍"],["调查表","調查表"],["调査出","調查出"],["调査团","調查團"],["调査表","調查表"],["调画出","調畫出"],["调色板","調色板"],["调药刀","調藥刀"],["调表","調錶"],["调适","調適"],["调配出","調配出"],["调钟表","調鐘錶"],["调频台","調頻臺"],["调频电台","調頻電臺"],["谈不出","談不出"],["谈了","談了"],["谈出","談出"],["谈判代表","談判代表"],["谈判制度","談判制度"],["谈吐有致","談吐有致"],["谈征","談徵"],["谈得出","談得出"],["谈论出","談論出"],["谈辞如云","談辭如雲"],["谋出路","謀出路"],["谋划","謀劃"],["谋取面试","謀取面試"],["谋定后动","謀定後動"],["谋定而后","謀定而後"],["谋干","謀幹"],["谋而后动","謀而後動"],["谋面","謀面"],["谎价","謊價"],["谎敲才","謊敲才"],["谐价","諧價"],["谐当","諧當"],["谙历","諳歷"],["谜团","謎團"],["谜面","謎面"],["谢了","謝了"],["谢克","謝克"],["谢克尔","謝克爾"],["谢别","謝別"],["谢叶配","謝葉配"],["谢安折屐","謝安折屐"],["谢尔托夫","謝爾托夫"],["谢志伟","謝志偉"],["谢福松","謝福松"],["谢秋华","謝秋華"],["谢系","謝系"],["谢绝参观","謝絕參觀"],["谢苏","謝蘇"],["谢苏叶","謝蘇葉"],["谢苏配","謝蘇配"],["谢表","謝表"],["谢里","謝里"],["谢里夫","謝里夫"],["谣言止于","謠言止於"],["谣言止于智者","謠言止於智者"],["谦克","謙克"],["谦冲","謙沖"],["谦冲自牧","謙沖自牧"],["谨于心","謹於心"],["谨致","謹致"],["谨致谢意","謹致謝意"],["谬以千里","謬以千里"],["谬种","謬種"],["谬种流传","謬種流傳"],["谬误百出","謬誤百出"],["谬赞","謬讚"],["谬采虚声","謬採虛聲"],["谭嗣同","譚嗣同"],["谯周","譙周"],["谯周独笑","譙周獨笑"],["谱出","譜出"],["谱出来","譜出來"],["谱录","譜錄"],["谱曲","譜曲"],["谱系","譜系"],["谱系分类法","譜系分類法"],["谱表","譜表"],["谷中谷","谷中谷"],["谷人","穀人"],["谷仓","穀倉"],["谷保家商","穀保家商"],["谷关","谷關"],["谷口","谷口"],["谷口耕岩","谷口耕岩"],["谷圭","穀圭"],["谷地","谷地"],["谷场","穀場"],["谷垣","谷垣"],["谷垣祯","谷垣禎"],["谷垣祯一","谷垣禎一"],["谷城","谷城"],["谷城县","谷城縣"],["谷壁","谷壁"],["谷壳","穀殼"],["谷子","穀子"],["谷峰","谷峯"],["谷川","谷川"],["谷底","谷底"],["谷日","穀日"],["谷旦","穀旦"],["谷月涵","谷月涵"],["谷树皮","谷樹皮"],["谷梁","穀梁"],["谷梁传","穀梁傳"],["谷歌","谷歌"],["谷氨酰胺","谷氨醯胺"],["谷氨酸","穀氨酸"],["谷永","谷永"],["谷湾","谷灣"],["谷物","穀物"],["谷皮","穀皮"],["谷神","穀神"],["谷神星","穀神星"],["谷穗","穀穗"],["谷米","穀米"],["谷类","穀類"],["谷类作物","穀類作物"],["谷粉","穀粉"],["谷粒","穀粒"],["谷糠","穀糠"],["谷舱","穀艙"],["谷苗","穀苗"],["谷草","穀草"],["谷蠡","谷蠡"],["谷象","谷象"],["谷贱伤农","穀賤傷農"],["谷贵饿农","穀貴餓農"],["谷贵饿农谷贱伤农","穀貴餓農穀賤傷農"],["谷道","穀道"],["谷都","谷都"],["谷雨","穀雨"],["谷风","穀風","谷風"],["谷食","穀食"],["谷饮","谷飲"],["谿谷","谿谷"],["豁上干","豁上幹"],["豁出","豁出"],["豁出去","豁出去"],["豁出命干","豁出命幹"],["豁出来","豁出來"],["豁命干","豁命幹"],["豁死干","豁死幹"],["豁荡","豁蕩"],["豁起来干","豁起來幹"],["豆制品","豆製品"],["豆姑娘","豆姑娘"],["豆娘","豆娘"],["豆娘子","豆娘子"],["豆干","豆乾"],["豆干展","豆乾展"],["豆干肉丝","豆干肉絲"],["豆签","豆簽"],["豆腐干","豆腐乾"],["豆面","豆麪"],["豉虫","豉蟲"],["象征","象徵"],["象征主义","象徵主義"],["象征性","象徵性"],["象征着","象徵着"],["象板","象板"],["象牙针尖","象牙針尖"],["象牙雕","象牙雕"],["象箸玉杯","象箸玉杯"],["象鼻虫","象鼻蟲"],["豪华游","豪華遊"],["豪厘千里","豪釐千里"],["豪情万丈","豪情萬丈"],["豪情壮志","豪情壯志"],["豪情逸致","豪情逸致"],["豪杰","豪傑"],["豪气万丈","豪氣萬丈"],["豪气万千","豪氣萬千"],["豪气干云","豪氣干雲"],["豪门贵胄","豪門貴胄"],["豫游","豫遊"],["豺狼当涂","豺狼當塗"],["豺狼当路","豺狼當路"],["豺狼当道","豺狼當道"],["貂复额","貂覆額"],["貌合心离","貌合心離"],["貌合情离","貌合情離"],["貌合神离","貌合神離"],["貌合行离","貌合行離"],["貌同实异","貌同實異"],["買凶","買兇"],["賈后","賈后"],["賢后","賢后"],["賨布","賨布"],["賸余","賸餘"],["賸馀价值","賸餘價值"],["贝他系数","貝他係數"],["贝伽特症候群","貝伽特症候羣"],["贝克","貝克"],["贝克休斯","貝克休斯"],["贝克勒","貝克勒"],["贝克勒耳","貝克勒耳"],["贝克尔","貝克爾"],["贝克曼","貝克曼"],["贝克汉","貝克漢"],["贝克汉姆","貝克漢姆"],["贝克特","貝克特"],["贝卡谷地","貝卡谷地"],["贝叶","貝葉"],["贝叶书","貝葉書"],["贝叶树","貝葉樹"],["贝叶棕","貝葉棕"],["贝叶经","貝葉經"],["贝奇马克","貝奇馬克"],["贝娅特丽克丝","貝婭特麗克絲"],["贝娜齐尔布托","貝娜齊爾布托"],["贝尔托內","貝爾托內"],["贝尔杰","貝爾傑"],["贝当","貝當"],["贝理克","貝理克"],["贝胄","貝冑"],["贝西克","貝西克"],["贝那芬托","貝那芬托"],["贝里","貝里"],["贝里拉","貝里拉"],["贝里斯","貝里斯"],["贝雕","貝雕"],["贞丰","貞豐"],["贞丰县","貞豐縣"],["贞卜文字","貞卜文字"],["负乘致寇","負乘致寇"],["负债累累","負債累累"],["负债表","負債表"],["负后像","負後像"],["负向","負向"],["负回馈","負回饋"],["负图之托","負圖之托"],["负心违愿","負心違願"],["负手板","負手板"],["负才","負才"],["负才任气","負才任氣"],["负才使气","負才使氣"],["负极","負極"],["负气斗狠","負氣鬥狠"],["负笈千里","負笈千里"],["负荷不了","負荷不了"],["负重致远","負重致遠"],["负面","負面"],["负面性","負面性"],["负鼎之愿","負鼎之願"],["贡烟","貢菸"],["贡献出","貢獻出"],["财产价值","財產價值"],["财产关系","財產關係"],["财产目录","財產目錄"],["财划法","財劃法"],["财务报表","財務報表"],["财团","財團"],["财团法人","財團法人"],["财布施","財佈施"],["财政支出","財政支出"],["财殚力尽","財殫力盡"],["财竭力尽","財竭力盡"],["财金系","財金系"],["责任准备","責任準備"],["责任制","責任制"],["责任范围","責任範圍"],["贤后","賢后"],["贤奸倒置","賢奸倒置"],["贤才","賢才"],["贤胄","賢胄"],["败于","敗於"],["败于垂成","敗於垂成"],["败兵折将","敗兵折將"],["败军折将","敗軍折將"],["败叶","敗葉"],["败坏门面","敗壞門面"],["败子回头","敗子回頭"],["败子回头金不换","敗子回頭金不換"],["败血性休克","敗血性休克"],["败血症","敗血症"],["败血脓毒症","敗血膿毒症"],["败部复活","敗部復活"],["账面","賬面"],["货价","貨價"],["货卜","貨卜"],["货布","貨布"],["货柜","貨櫃"],["货柜场","貨櫃場"],["货柜屋","貨櫃屋"],["货柜船","貨櫃船"],["货柜车","貨櫃車"],["货柜轮","貨櫃輪"],["货物柜","貨物櫃"],["货真价实","貨真價實"],["质当","質當"],["质朴","質樸"],["质量规范","質量規範"],["贪婪是万恶之源","貪婪是萬惡之源"],["贪念","貪念"],["贪杯","貪杯"],["贪杯惜醉人","貪杯惜醉人"],["贪欲","貪慾"],["贪欲无艺","貪慾無藝"],["贪生恶死","貪生惡死"],["贪生舍义","貪生舍義"],["贪睡虫","貪睡蟲"],["贫嘴恶舌","貧嘴惡舌"],["贫困","貧困"],["贫困人家","貧困人家"],["贫困化","貧困化"],["贫困地区","貧困地區"],["贫困率","貧困率"],["贫寒出身","貧寒出身"],["贫血症","貧血症"],["贬价","貶價"],["购买欲","購買慾"],["购回","購回"],["购并","購併"],["购并案","購併案"],["购彩","購彩"],["购物台","購物臺"],["购物欲","購物慾"],["购销差价","購銷差價"],["贯云石","貫雲石"],["贯注","貫注"],["贱价","賤價"],["贱价出售","賤價出售"],["贱才","賤才"],["贱敛贵出","賤斂貴出"],["贱敛贵发","賤斂貴發"],["贴个","貼個"],["贴出","貼出"],["贴出去","貼出去"],["贴出来","貼出來"],["贴后","貼後"],["贴布","貼布"],["贵了","貴了"],["贵价","貴价"],["贵州师范大学","貴州師範大學"],["贵干","貴幹"],["贵幸","貴幸"],["贵征","貴徵"],["贵戚","貴戚"],["贵极人臣","貴極人臣"],["贵游子弟","貴遊子弟"],["贵胄","貴胄"],["贵贱之别","貴賤之別"],["贷个","貸個"],["贷了","貸了"],["贷借","貸借"],["贷出","貸出"],["贸易伙伴","貿易伙伴"],["费了","費了"],["费利克斯","費利克斯"],["费占","費佔"],["费卢杰","費盧傑"],["费后","費後"],["费周章","費周章"],["费尔干纳","費爾干納"],["费尔干纳槃地","費爾干納槃地"],["费尔干纳盆地","費爾幹納盆地"],["费尔法克斯","費爾法克斯"],["费尽","費盡"],["费尽心思","費盡心思"],["费尽心机","費盡心機"],["费尽精神","費盡精神"],["费尽脣舌","費盡脣舌"],["费杰罗","費傑羅"],["费洛蒙","費洛蒙"],["费玛最后定理","費瑪最後定理"],["费舍尔","費舍爾"],["费茨派垂克","費茨派垂克"],["费达克","費達克"],["费里克斯","費里克斯"],["费里克斯布朗","費里克斯布朗"],["费里尼","費里尼"],["费里斯特","費里斯特"],["贺后骂殿","賀后罵殿"],["贺尔蒙","賀爾蒙"],["贺尔蒙针","賀爾蒙針"],["贺表","賀表"],["贻笑万世","貽笑萬世"],["贻笑千古","貽笑千古"],["贻笑千秋","貽笑千秋"],["贻羞万年","貽羞萬年"],["贻范","貽範"],["贻范古今","貽範古今"],["贼党","賊黨"],["贼没种只怕哄","賊沒種只怕哄"],["贾克逊","賈克遜"],["贾可布斯","賈可布斯"],["贾后","賈后"],["贾斯克","賈斯克"],["贾氏症","賈氏症"],["贾第虫","賈第蟲"],["贾第虫属","賈第蟲屬"],["贾第虫病","賈第蟲病"],["贾胡","賈胡"],["贾里尔","賈里爾"],["贾鸿秋","賈鴻秋"],["贿赂并行","賄賂並行"],["资产价值","資產價值"],["资产组合","資產組合"],["资产负债表","資產負債表"],["资历","資歷"],["资料介面","資料介面"],["资料库管理系统","資料庫管理系統"],["资料录","資料錄"],["资料表","資料表"],["资料链结层","資料鏈結層"],["资方代表","資方代表"],["资治通鉴","資治通鑑"],["资源回收","資源回收"],["资管系","資管系"],["资讯学系","資訊學系"],["资讯系","資訊系"],["资金占用","資金佔用"],["资金面","資金面"],["赈饥","賑饑"],["赉发","賚發"],["赊借","賒借"],["赋别","賦別"],["赋格曲","賦格曲"],["赋诗言志","賦詩言志"],["赋闲","賦閒"],["赌了","賭了"],["赌台","賭檯"],["赌咒发愿","賭咒發願"],["赌当","賭當"],["赌斗","賭鬥"],["赌注","賭注"],["赌胜","賭勝"],["赌身发誓","賭身發誓"],["赌钱厂","賭錢廠"],["赍发","齎發"],["赍志没地","齎志沒地"],["赍志而殁","齎志而歿"],["赎回","贖回"],["赎回权","贖回權"],["赎当","贖當"],["赎药","贖藥"],["赏不当功","賞不當功"],["赏了","賞了"],["赏同罚异","賞同罰異"],["赏善罚恶","賞善罰惡"],["赏罚不当","賞罰不當"],["赏赞","賞讚"],["赏鉴","賞鑑"],["赏面子","賞面子"],["赐了","賜了"],["赐复","賜復"],["赐恤","賜卹"],["赒急扶困","賙急扶困"],["赔个不是","賠個不是"],["赔了","賠了"],["赔了夫人","賠了夫人"],["赔了夫人又折兵","賠了夫人又折兵"],["赔出","賠出"],["赔尽","賠盡"],["赖于","賴於"],["赖幸媛","賴幸媛"],["赖索托","賴索托"],["赖索托王国","賴索托王國"],["赖蒙特","賴蒙特"],["赚不了","賺不了"],["赚个","賺個"],["赚个饱","賺個飽"],["赚了","賺了"],["赚哄","賺哄"],["赚回来","賺回來"],["赛制","賽制"],["赛后","賽後"],["赛德克","賽德克"],["赛愿","賽願"],["赛程表","賽程表"],["赛里木湖","賽里木湖"],["赛门铁克","賽門鐵克"],["赞一句","讚一句"],["赞一声","讚一聲"],["赞一赞","讚一讚"],["赞不绝口","讚不絕口"],["赞两句","讚兩句"],["赞个不","讚個不"],["赞乐","讚樂"],["赞了","讚了"],["赞伯拉诺","贊伯拉諾"],["赞佩","讚佩"],["赞佩不已","讚佩不已"],["赞助","贊助"],["赞助人","贊助人"],["赞助商","贊助商"],["赞助者","贊助者"],["赞口不","讚口不"],["赞叹","讚歎"],["赞叹不已","讚歎不已"],["赞叹声","讚歎聲"],["赞同","贊同"],["赞呗","讚唄"],["赞善","贊善"],["赞布拉诺","贊布拉諾"],["赞成","贊成"],["赞成票","贊成票"],["赞成者","贊成者"],["赞我","讚我"],["赞扬","讚揚"],["赞拜","贊拜"],["赞普","贊普"],["赞歌","讚歌"],["赞歎","讚歎"],["赞比亚","贊比亞"],["赞理","贊理"],["赞的","讚的"],["赞皇","贊皇"],["赞皇县","贊皇縣"],["赞礼","贊禮"],["赞美","讚美"],["赞美有加","讚美有加"],["赞美歌","讚美歌"],["赞美诗","讚美詩"],["赞羡","讚羨"],["赞翼","贊翼"],["赞自己","讚自己"],["赞誉","讚譽"],["赞誉为","讚譽爲"],["赞许","讚許"],["赞词","讚詞"],["赞语","讚語"],["赞赏","讚賞"],["赞赏不已","讚賞不已"],["赞辞","讚辭"],["赞道","讚道"],["赞颂","讚頌"],["赠别","贈別"],["赡表子","贍表子"],["赢不了","贏不了"],["赢了","贏了"],["赢余","贏餘"],["赢出","贏出"],["赢回","贏回"],["赢回去","贏回去"],["赢回来","贏回來"],["赢奸卖俏","贏奸賣俏"],["赢定了","贏定了"],["赢面","贏面"],["赣南师范学院","贛南師範學院"],["赤地千里","赤地千里"],["赤术","赤朮"],["赤松","赤松"],["赤松子","赤松子"],["赤留出律","赤留出律"],["赤绳系足","赤繩繫足"],["赤道几內亚","赤道幾內亞"],["赤道几內亚共和国","赤道幾內亞共和國"],["赤道几内亚","赤道幾內亞"],["赤道面","赤道面"],["赤霉素","赤黴素"],["赫克比","赫克比"],["赫克迈泰尔","赫克邁泰爾"],["赫弗里希","赫弗里希"],["赫拉克利特","赫拉克利特"],["赫里斯","赫里斯"],["赫里斯登科","赫里斯登科"],["赫麦汉士台","赫麥漢士臺"],["赭面","赭面"],["走上台","走上臺"],["走下台","走下臺"],["走不了","走不了"],["走了","走了"],["走了和尚走不了庙","走了和尚走不了廟"],["走了大褶儿","走了大褶兒"],["走了风声","走了風聲"],["走了马脚","走了馬腳"],["走亲戚","走親戚"],["走出","走出"],["走出去","走出去"],["走出来","走出來"],["走千门踏万户","走千門踏萬戶"],["走后","走後"],["走后门","走後門"],["走向","走向"],["走向前去","走向前去"],["走向前来","走向前來"],["走向断层","走向斷層"],["走向滑动断层","走向滑動斷層"],["走回","走回"],["走回去","走回去"],["走回头","走回頭"],["走回头路","走回頭路"],["走回来","走回來"],["走回路","走迴路"],["走娘家","走孃家"],["走廊里","走廊裏"],["走来回","走來回"],["走板","走板"],["走板眼","走板眼"],["走肉行尸","走肉行屍"],["走马章台","走馬章臺"],["走骨行尸","走骨行屍"],["赴台","赴臺"],["赴曲","赴曲"],["赵丰邦","趙豐邦"],["赵云","趙雲"],["赵五娘","趙五娘"],["赵坤郁","趙坤郁"],["赵庄","趙莊"],["赵志坚","趙志堅"],["赵无极","趙無極"],["赵治勋","趙治勳"],["赵玄坛","趙玄壇"],["赶下台","趕下臺"],["赶不出","趕不出"],["赶不出来","趕不出來"],["赶了","趕了"],["赶修","趕修"],["赶出","趕出"],["赶出去","趕出去"],["赶出来","趕出來"],["赶制","趕製"],["赶前不赶后","趕前不趕後"],["赶向","趕向"],["赶回","趕回"],["赶回到","趕回到"],["赶回去","趕回去"],["赶回来","趕回來"],["赶尸","趕屍"],["赶尽杀绝","趕盡殺絕"],["赶录","趕錄"],["赶得出","趕得出"],["赶面棍","趕麪棍"],["起不了","起不了"],["起了","起了"],["起价","起價"],["起出","起出"],["起发性","起發性"],["起吊","起吊"],["起哄","起鬨"],["起因于","起因於"],["起复","起復"],["起居注","起居注"],["起扑杆","起撲桿"],["起承转合","起承轉合"],["起根发脚","起根發腳"],["起模范","起模範"],["起死回生","起死回生"],["起源于","起源於"],["起航出海","起航出海"],["起获","起獲"],["起跳价","起跳價"],["起跳板","起跳板"],["趁哄","趁哄"],["趁哄打劫","趁哄打劫"],["趁愿","趁願"],["超世之才","超世之才"],["超低价","超低價"],["超党派","超黨派"],["超准","超準"],["超凡出世","超凡出世"],["超出","超出"],["超出范围","超出範圍"],["超前瞄准","超前瞄準"],["超前绝后","超前絕後"],["超升","超升"],["超友谊关系","超友誼關係"],["超基性岩","超基性岩"],["超大曲道赛","超大曲道賽"],["超完美告别","超完美告別"],["超尘出俗","超塵出俗"],["超平面","超平面"],["超手游廊","超手遊廊"],["超新星剩余","超新星剩餘"],["超杯","超杯"],["超然台","超然臺"],["超级台风","超級颱風"],["超级杯","超級盃"],["超级链接","超級鏈接"],["超群出众","超羣出衆"],["超范围","超範圍"],["超计划利润","超計劃利潤"],["超赞","超讚"],["超链接","超鏈接"],["超额录取","超額錄取"],["越冬","越冬"],["越冬作物","越冬作物"],["越出","越出"],["越出界线","越出界線"],["越发","越發"],["越活越回去","越活越回去"],["越王尝蓼","越王嘗蓼"],["趋于","趨於"],["趋于平稳","趨於平穩"],["趋于稳定","趨於穩定"],["趋前退后","趨前退後"],["趋吉避凶","趨吉避凶"],["趋同","趨同"],["趋向","趨向"],["趋舍","趨舍"],["趋舍异路","趨舍異路"],["趋舍指凑","趨舍指湊"],["趋近于","趨近於"],["趫才","趫才"],["趱干","趲幹"],["足不出户","足不出戶"],["足不出门","足不出門"],["足了十人","足了十人"],["足于","足於"],["足协杯","足協盃"],["足坛","足壇"],["足总杯","足總盃"],["足食丰衣","足食豐衣"],["趸售物价","躉售物價"],["趸当","躉當"],["趸批卖出","躉批賣出"],["趿拉板儿","趿拉板兒"],["跃出","躍出"],["跃升","躍升"],["跃升为","躍升爲"],["跃跃欲试","躍躍欲試"],["跋前疐后","跋前疐後"],["跋前踬后","跋前躓後"],["跋涉千里","跋涉千里"],["跋胡疐尾","跋胡疐尾"],["跌了","跌了"],["跌了弹的斑鸠","跌了彈的斑鳩"],["跌价","跌價"],["跌停板","跌停板"],["跌出","跌出"],["跌回","跌回"],["跌打药","跌打藥"],["跌至谷底","跌至谷底"],["跌荡","跌蕩"],["跌荡不羁","跌蕩不羈"],["跌荡放言","跌蕩放言"],["跎纤","跎縴"],["跑不了","跑不了"],["跑了和尚跑不了寺","跑了和尚跑不了寺"],["跑了和尚跑不了庙","跑了和尚跑不了廟"],["跑出","跑出"],["跑出去","跑出去"],["跑出来","跑出來"],["跑台子","跑檯子"],["跑合","跑合"],["跑回","跑回"],["跑回去","跑回去"],["跑回来","跑回來"],["跑得了和尚跑不了庙","跑得了和尚跑不了廟"],["跑表","跑表"],["跗注","跗注"],["跗面","跗面"],["跛行症","跛行症"],["跛鳖千里","跛鱉千里"],["跟了","跟了"],["跟他一斗","跟他一鬥"],["跟出","跟出"],["跟出去","跟出去"],["跟出来","跟出來"],["跟前跟后","跟前跟後"],["跟头虫","跟頭蟲"],["跟屁虫","跟屁蟲"],["跟斗","跟斗"],["跨了","跨了"],["跨党","跨黨"],["跨出","跨出"],["跨出去","跨出去"],["跨出来","跨出來"],["跨向","跨向"],["跨媒体合作","跨媒體合作"],["跨平台","跨平臺"],["跨步向前","跨步向前"],["跨通道启动技术","跨通道啓動技術"],["跨鹤西游","跨鶴西遊"],["跪了","跪了"],["跬步千里","跬步千里"],["路克","路克"],["路克索","路克索"],["路志","路誌"],["路怒症","路怒症"],["路码表","路碼表"],["路签","路籤"],["路线斗争","路線鬥爭"],["路透集团","路透集團"],["路里","路里"],["路面","路面"],["路面等级","路面等級"],["跳了","跳了"],["跳井自尽","跳井自盡"],["跳价","跳價"],["跳伞台","跳傘臺"],["跳出","跳出"],["跳出去","跳出去"],["跳出来","跳出來"],["跳出火坑","跳出火坑"],["跳出釜底进火坑","跳出釜底進火坑"],["跳升","跳升"],["跳只舞","跳隻舞"],["跳台","跳臺"],["跳台滑雪","跳臺滑雪"],["跳回","跳回"],["跳回去","跳回去"],["跳回来","跳回來"],["跳墙出去","跳牆出去"],["跳板","跳板"],["跳梁","跳梁"],["跳梁小丑","跳樑小醜"],["跳梁猖獗之小丑","跳樑猖獗之小醜"],["跳楼自尽","跳樓自盡"],["跳水台","跳水臺"],["跳河自尽","跳河自盡"],["跳海自尽","跳海自盡"],["跳脱出","跳脫出"],["跳脱出来","跳脫出來"],["跳荡","跳蕩"],["跳表","跳錶"],["跳针","跳針"],["践极","踐極"],["跷了","蹺了"],["跷出","蹺出"],["跷跷板","蹺蹺板"],["跻升","躋升"],["跻身于","躋身於"],["踅回","踅回"],["踅门了户","踅門瞭戶"],["踊跃发言","踊躍發言"],["踌躇满志","躊躇滿志"],["踏了","踏了"],["踏出","踏出"],["踏出去","踏出去"],["踏出来","踏出來"],["踏小板凳儿糊险道神","踏小板凳兒糊險道神"],["踏板","踏板"],["踏板车","踏板車"],["踏脚板","踏腳板"],["踏足板","踏足板"],["踔厉风发","踔厲風發"],["踢不出","踢不出"],["踢了","踢了"],["踢出","踢出"],["踢出去","踢出去"],["踢出来","踢出來"],["踢到铁板","踢到鐵板"],["踢向","踢向"],["踢回","踢回"],["踢回去","踢回去"],["踢回来","踢回來"],["踩坏了","踩壞了"],["踪迹","蹤跡"],["踬仆","躓仆"],["蹀里蹀斜","蹀里蹀斜"],["蹇修","蹇修"],["蹈厉之志","蹈厲之志"],["蹈厉奋发","蹈厲奮發"],["蹦出","蹦出"],["蹦出来","蹦出來"],["蹪于","蹪於"],["蹭棱子","蹭棱子"],["蹲了","蹲了"],["蹲板","蹲板"],["躁狂抑郁症","躁狂抑鬱症"],["躁狂症","躁狂症"],["躁郁","躁鬱"],["躁郁症","躁鬱症"],["躄出","躄出"],["躏借","躪藉"],["躐胡","躐胡"],["身于","身於"],["身价","身價"],["身价百倍","身價百倍"],["身价非凡","身價非凡"],["身份识别卡","身份識別卡"],["身体发肤","身體髮膚"],["身做身当","身做身當"],["身历其境","身歷其境"],["身历声","身歷聲"],["身后","身後"],["身后之事","身後之事"],["身后事","身後事"],["身后萧条","身後蕭條"],["身当其境","身當其境"],["身当矢石","身當矢石"],["身才","身才"],["身敎重于言敎","身教重於言教"],["身教胜于言教","身教勝於言教"],["身有同感","身有同感"],["身板","身板"],["身板儿","身板兒"],["身正为范","身正爲範"],["身系囹圄","身繫囹圄"],["躬先表率","躬先表率"],["躬擐甲胄","躬擐甲冑"],["躯干","軀幹"],["躯干骨","軀幹骨"],["躲一棒槌挨一榔头","躲一棒槌挨一榔頭"],["躲不了","躲不了"],["躲了雷公遇了霹雳","躲了雷公遇了霹靂"],["躲回","躲回"],["躲得不知去向","躲得不知去向"],["躲清闲","躲清閒"],["躲过了风暴又遇了雨","躲過了風暴又遇了雨"],["躺个","躺個"],["躺出","躺出"],["躺出去","躺出去"],["躺出来","躺出來"],["躺回","躺回"],["軟肥皂","软肥皂"],["车仔面","車仔麪"],["车到没恶路","車到沒惡路"],["车厂","車廠"],["车厂子","車廠子"],["车叶草","車葉草"],["车同轨书同文","車同軌書同文"],["车后箱","車後箱"],["车坛","車壇"],["车夫","車伕"],["车库里","車庫裏"],["车攻马同","車攻馬同"],["车斗","車斗"],["车无退表","車無退表"],["车百合","車百合"],["车种","車種"],["车站里","車站裏"],["车系","車系"],["车载斗量","車載斗量"],["车里","車裏"],["车里雅宾斯克","車里雅賓斯克"],["车马夫","車馬伕"],["轧制","軋製"],["轧钢厂","軋鋼廠"],["轨制","軌制"],["轨范","軌範"],["轨道面","軌道面"],["轩辟","軒闢"],["转个","轉個"],["转个弯","轉個彎"],["转了","轉了"],["转借","轉借"],["转关系","轉關係"],["转出","轉出"],["转出去","轉出去"],["转出来","轉出來"],["转动曲柄","轉動曲柄"],["转发","轉發"],["转台","轉檯"],["转向","轉向"],["转向信号","轉向信號"],["转向器","轉向器"],["转向往","轉向往"],["转向架","轉向架"],["转向灯","轉向燈"],["转向离合","轉向離合"],["转回","轉回"],["转回去","轉回去"],["转回来","轉回來"],["转圜余地","轉圜餘地"],["转干","轉幹"],["转录","轉錄"],["转念","轉念"],["转意回心","轉意回心"],["转战千里","轉戰千里"],["转托","轉託"],["转折","轉折"],["转折亲","轉折親"],["转折点","轉折點"],["转换方向","轉換方向"],["转播台","轉播臺"],["转斗千里","轉鬥千里"],["转日回天","轉日回天"],["转汇","轉匯"],["转注","轉註"],["转注字","轉註字"],["转游","轉游"],["转系","轉系"],["转胜为败","轉勝爲敗"],["转败为胜","轉敗爲勝"],["转车台","轉車臺"],["转速表","轉速錶"],["转面无情","轉面無情"],["轮休制","輪休制"],["轮作制度","輪作制度"],["轮值表","輪值表"],["轮发","輪發"],["轮台","輪臺"],["轮台县","輪臺縣"],["轮台古城","輪臺古城"],["轮唱曲","輪唱曲"],["轮回","輪迴"],["轮奸","輪姦"],["轮旋曲","輪旋曲"],["轮流制","輪流制"],["轮流干","輪流幹"],["轮班制","輪班制"],["轮生叶","輪生葉"],["轮种","輪種"],["轮种法","輪種法"],["轮系","輪系"],["轮虫","輪蟲"],["软不叮当","軟不叮噹"],["软件平台","軟件平臺"],["软件开发","軟件開發"],["软件开发人员","軟件開發人員"],["软件技术","軟件技術"],["软件系统","軟件系統"],["软体出版协会","軟體出版協會"],["软困","軟困"],["软软松松","軟軟鬆鬆"],["软面筋","軟麪筋"],["轰了","轟了"],["轰出","轟出"],["轰出去","轟出去"],["轰出来","轟出來"],["轴承合金","軸承合金"],["轴根系","軸根系"],["轴系","軸系"],["轴舻千里","軸艫千里"],["轴面","軸面"],["轶荡","軼蕩"],["轸念","軫念"],["轻于","輕於"],["轻于鸿毛","輕於鴻毛"],["轻叹","輕嘆"],["轻度台风","輕度颱風"],["轻扣","輕釦"],["轻松","輕鬆"],["轻松地","輕鬆地"],["轻松愉快","輕鬆愉快"],["轻松自在","輕鬆自在"],["轻松自如","輕鬆自如"],["轻核","輕核"],["轻油裂解工厂","輕油裂解工廠"],["轻烟","輕煙"],["轻蔑","輕蔑"],["轻蔑性","輕蔑性"],["轻袅袅","輕嫋嫋"],["轻轻松松","輕輕鬆鬆"],["载于","載於"],["载出","載出"],["载出去","載出去"],["载出来","載出來"],["载浮载沈","載浮載沈"],["载满了","載滿了"],["载舟复舟","載舟覆舟"],["轿夫","轎伕"],["辁才","輇才"],["较于","較於"],["较胜一筹","較勝一籌"],["辅导团","輔導團"],["辅系","輔系"],["辅赞","輔贊"],["辈出","輩出"],["辈子干","輩子幹"],["辉格党","輝格黨"],["辉格党人","輝格黨人"],["辉绿岩","輝綠岩"],["辉长岩","輝長岩"],["辍耕录","輟耕錄"],["辐射警告标志","輻射警告標志"],["辑录","輯錄"],["辑录出来","輯錄出來"],["输了","輸了"],["输入系统","輸入系統"],["输入许可制","輸入許可制"],["输出","輸出"],["输出业","輸出業"],["输出入","輸出入"],["输出到","輸出到"],["输出功率","輸出功率"],["输出区","輸出區"],["输出去","輸出去"],["输出变压","輸出變壓"],["输出品","輸出品"],["输出国","輸出國"],["输出来","輸出來"],["输出管","輸出管"],["输出表","輸出表"],["输出量","輸出量"],["输出阻抗","輸出阻抗"],["输征","輸征"],["辖制","轄制"],["辗米厂","輾米廠"],["辛丑","辛丑"],["辛丑和约","辛丑和約"],["辛丑条约","辛丑條約"],["辛克","辛克"],["辛辣面","辛辣麪"],["辛里希","辛里希"],["辜濂松","辜濂松"],["辞不获命","辭不獲命"],["辞丰意雄","辭豐意雄"],["辞修","辭修"],["辞别","辭別"],["辞汇","辭彙"],["辞致","辭致"],["辞采","辭采"],["辟世","辟世"],["辟为","闢爲"],["辟举","辟舉"],["辟书","辟書"],["辟人之士","辟人之士"],["辟佛","闢佛"],["辟作","闢作"],["辟出","闢出"],["辟划","闢劃"],["辟匿","辟匿"],["辟历施鞭","辟歷施鞭"],["辟召","辟召"],["辟君三舍","辟君三舍"],["辟命","辟命"],["辟咡","辟咡"],["辟土","闢土"],["辟地","闢地"],["辟地开天","闢地開天"],["辟室","闢室"],["辟廱","辟廱"],["辟建","闢建"],["辟引","辟引"],["辟恶","辟惡"],["辟恶除患","辟惡除患"],["辟支佛","辟支佛"],["辟易","辟易"],["辟淫","辟淫"],["辟然","辟然"],["辟爲","闢爲"],["辟田","闢田"],["辟筑","闢築"],["辟纑","辟纑"],["辟色","辟色"],["辟芷","辟芷"],["辟言","辟言"],["辟设","闢設"],["辟谣","闢謠"],["辟谷","辟穀"],["辟谷绝粒","辟穀絕粒"],["辟辟","闢辟"],["辟违","辟違"],["辟逻","辟邏"],["辟邪","辟邪"],["辟邪以律","闢邪以律"],["辟雍","辟雍"],["辟雍砚","辟雍硯"],["辣哈布","辣哈布"],["辣椒面","辣椒麪"],["辣胡椒","辣胡椒"],["辨出","辨出"],["辨别","辨別"],["辨别出来","辨別出來"],["辨别力","辨別力"],["辨别是非","辨別是非"],["辨向","辨向"],["辨复","辨復"],["辨奸论","辨姦論"],["辨志","辨志"],["辨折","辨折"],["辨认出","辨認出"],["辨认出来","辨認出來"],["辨识出","辨識出"],["辩别","辯別"],["辩才","辯才"],["辩才天","辯才天"],["辩才无碍","辯才無礙"],["辩斗","辯鬥"],["辩论术","辯論術"],["辫发","辮髮"],["辫穗头","辮穗頭"],["辱游","辱游"],["边修","邊修"],["边境冲突","邊境衝突"],["边幅不修","邊幅不修"],["边核","邊核"],["辽三彩","遼三彩"],["辽太后","遼太后"],["辽宁师范大学","遼寧師範大學"],["辽沈","遼瀋"],["达克","達克"],["达克龙","達克龍"],["达尔罕茂明安联合旗","達爾罕茂明安聯合旗"],["达布洛沃斯基","達布洛沃斯基"],["达欣杯","達欣盃"],["达沃斯论坛","達沃斯論壇"],["达瓦党","達瓦黨"],["达致","達致"],["迁了","遷了"],["迁于","遷於"],["迁出","遷出"],["迁出去","遷出去"],["迁出来","遷出來"],["迁升","遷升"],["迁厂","遷廠"],["迁台","遷臺"],["迁回","遷回"],["迁回去","遷回去"],["迁回来","遷回來"],["迁就于","遷就於"],["迁怒于","遷怒於"],["迁怒于人","遷怒於人"],["迁思回虑","遷思迴慮"],["迂回","迂迴"],["迂回奔袭","迂回奔襲"],["迂回战术","迂迴戰術"],["迂回曲折","迂迴曲折"],["迂徊战术","迂徊戰術"],["迂曲","迂曲"],["迂迂曲曲","迂迂曲曲"],["迅即出发","迅即出發"],["迅速发展","迅速發展"],["过不了","過不了"],["过世面","過世面"],["过了","過了"],["过了这个村儿没这个店儿","過了這個村兒沒這個店兒"],["过了这村没这店","過了這村沒這店"],["过了青春无少年","過了青春無少年"],["过于","過於"],["过云雨","過雲雨"],["过人才略","過人才略"],["过傢伙","過傢伙"],["过冬","過冬"],["过冲","過沖"],["过几","過幾"],["过出","過出"],["过动症","過動症"],["过历","過歷"],["过去了","過去了"],["过后","過後"],["过境签证","過境簽證"],["过失致死","過失致死"],["过干瘾","過乾癮"],["过庭录","過庭錄"],["过当","過當"],["过当防卫","過當防衛"],["过录","過錄"],["过得了","過得了"],["过敏性休克","過敏性休克"],["过敏症","過敏症"],["过杆","過杆"],["过松","過鬆"],["过桥抽板","過橋抽板"],["过梁","過樑"],["过水面","過水麪"],["过河抽板","過河抽板"],["过滤出来","過濾出來"],["过滤嘴香烟","過濾嘴香菸"],["过眼云烟","過眼雲煙"],["过眼烟云","過眼煙雲"],["过耳秋风","過耳秋風"],["过蒙","過蒙"],["迈了","邁了"],["迈克","邁克"],["迈克尔","邁克爾"],["迈克尔克莱顿","邁克爾克萊頓"],["迈克尔杰克逊","邁克爾傑克遜"],["迈出","邁出"],["迈向","邁向"],["迈科里","邁科里"],["迎出","迎出"],["迎合","迎合"],["迎合人心","迎合人心"],["迎向","迎向"],["迎向前去","迎向前去"],["迎回","迎回"],["迎奸卖俏","迎奸賣俏"],["迎宾曲","迎賓曲"],["迎斗灯","迎斗燈"],["迎春曲","迎春曲"],["迎面","迎面"],["迎面而来","迎面而來"],["运出","運出"],["运出去","運出去"],["运出来","運出來"],["运出运费","運出運費"],["运动党","運動黨"],["运回","運回"],["运回去","運回去"],["运回来","運回來"],["运用之妙在于一心","運用之妙在於一心"],["运用于","運用於"],["运筹决胜","運籌決勝"],["运筹千里","運籌千里"],["运输系统","運輸系統"],["运输设备修护费","運輸設備修護費"],["近乎同步","近乎同步"],["近乎同步数位阶层","近乎同步數位階層"],["近了","近了"],["近于","近於"],["近似于","近似於"],["近几年","近幾年"],["近几年来","近幾年來"],["近思录","近思錄"],["近日無仇","近日無讎"],["近日里","近日裏"],["近朱者赤","近朱者赤"],["近朱者赤近墨者黑","近朱者赤近墨者黑"],["近朱近墨","近朱近墨"],["近水楼台","近水樓臺"],["近视眼生了瞎子","近視眼生了瞎子"],["返台","返臺"],["返吟复吟","返吟復吟"],["返回","返回"],["返复","返復"],["返朴","返樸"],["返照回光","返照回光"],["返还占有","返還占有"],["返里","返里"],["返魂乏术","返魂乏術"],["还不出","還不出"],["还乡团","還鄉團"],["还了","還了"],["还了得","還了得"],["还于","還於"],["还价","還價"],["还修","還修"],["还冲","還衝"],["还出","還出"],["还出去","還出去"],["还出来","還出來"],["还占","還佔"],["还原熔炼","還原熔煉"],["还发","還發"],["还向","還向"],["还回","還回"],["还愿","還願"],["还愿意","還願意"],["还政于民","還政於民"],["还淳反朴","還淳反樸"],["还淳返朴","還淳返樸"],["还珠合浦","還珠合浦"],["还辟","還辟"],["还采","還採"],["这一个","這一個"],["这个","這個"],["这个当儿","這個當兒"],["这个挡口","這個擋口"],["这个月","這個月"],["这个那个","這個那個"],["这么","這麼"],["这么个","這麼個"],["这么干","這麼幹"],["这么着","這麼着"],["这些个","這些個"],["这伙人","這夥人"],["这几个","這幾個"],["这几个人","這幾個人"],["这几个月","這幾個月"],["这几天","這幾天"],["这几次","這幾次"],["这出剧","這齣劇"],["这出好戏","這齣好戲"],["这出电影","這齣電影"],["这只","這隻"],["这只不","這只不"],["这只是","這只是"],["这回","這回"],["这回事","這回事"],["这当儿","這當兒"],["这方面","這方面"],["这杯","這杯"],["这注","這注"],["这种","這種"],["这种事","這種事"],["这种人","這種人"],["这种方式","這種方式"],["这般干法","這般幹法"],["这还了得","這還了得"],["这里","這裏"],["这里会","這裏會"],["这里在","這裏在"],["这里是","這裏是"],["这里有","這裏有"],["这里能","這裏能"],["这钟","這鐘"],["进一步规范","進一步規範"],["进不了","進不了"],["进了","進了"],["进了天堂","進了天堂"],["进价","進價"],["进修","進修"],["进修班","進修班"],["进出","進出"],["进出口","進出口"],["进出口商","進出口商"],["进出境","進出境"],["进占","進佔"],["进厂","進廠"],["进发","進發"],["进口加签权","進口加簽權"],["进士出身","進士出身"],["进幸","進幸"],["进度表","進度表"],["进得了","進得了"],["进德修业","進德修業"],["进步伙伴展","進步夥伴展"],["进步党","進步黨"],["进行曲","進行曲"],["进货价","進貨價"],["进货让价","進貨讓價"],["进货退出","進貨退出"],["进货退回","進貨退回"],["进进出出","進進出出"],["进退失据","進退失據"],["进退无据","進退無據"],["进退维谷","進退維谷"],["进香团","進香團"],["远东技术学院","遠東技術學院"],["远于","遠於"],["远亲近戚","遠親近戚"],["远别","遠別"],["远县才至","遠縣纔至"],["远处夸称近方卖弄","遠處誇稱近方賣弄"],["远引曲喻","遠引曲喻"],["远征","遠征"],["远征军","遠征軍"],["远志","遠志"],["远恶","遠惡"],["远房亲戚","遠房親戚"],["远打周折","遠打週折"],["远期外汇","遠期外匯"],["远水救不了近火","遠水救不了近火"],["远游","遠遊"],["远程登录","遠程登錄"],["远端监控系统","遠端監控系統"],["远端签入","遠端簽入"],["远胄","遠胄"],["远胜","遠勝"],["远距图书服务系统","遠距圖書服務系統"],["远远落后","遠遠落後"],["远隔千里","遠隔千里"],["违禁药品","違禁藥品"],["违章建筑","違章建築"],["违纪参选","違紀參選"],["连三并四","連三併四"],["连个","連個"],["连了","連了"],["连于","連於"],["连云","連雲"],["连云区","連雲區"],["连云叠嶂","連雲疊嶂"],["连云港","連雲港"],["连云港市","連雲港市"],["连出","連出"],["连升","連升"],["连占","連佔"],["连卷","連卷"],["连发","連發"],["连台","連臺"],["连台好戏","連臺好戲"],["连台本戏","連臺本戲"],["连合","連合"],["连同","連同"],["连哄带骗","連哄帶騙"],["连回","連回"],["连城之价","連城之價"],["连带关系","連帶關係"],["连年丰收","連年豐收"],["连庄","連莊"],["连战连胜","連戰連勝"],["连杆","連桿"],["连杆机构","連桿機構"],["连枝分叶","連枝分葉"],["连枝带叶","連枝帶葉"],["连根拔出","連根拔出"],["连珠合璧","連珠合璧"],["连登云路","連登雲路"],["连种","連種"],["连系","連繫"],["连系词","連繫詞"],["连系起来","連繫起來"],["连胜","連勝"],["连胜文","連勝文"],["连采","連採"],["连镳并轸","連鑣並軫"],["连须胡子","連鬚鬍子"],["连鬓胡子","連鬢鬍子"],["连鬼也不见一个","連鬼也不見一個"],["迟了","遲了"],["迟发性损伤","遲發性損傷"],["迟回","遲迴"],["迟回观望","遲回觀望"],["迢迢千里","迢迢千里"],["迥不相同","迥不相同"],["迥乎不同","迥乎不同"],["迥别","迥別"],["迥然不同","迥然不同"],["迥然回异","迥然迴異"],["迥然有别","迥然有別"],["迦叶","迦葉"],["迦叶佛","迦葉佛"],["迦叶尊者","迦葉尊者"],["迪克","迪克"],["迪克斯","迪克斯"],["迪化厂","迪化廠"],["迪吉苏斯","迪吉蘇斯"],["迪拉萨布里","迪拉薩布里"],["迪雅巴克","迪雅巴克"],["迪黑苏斯","迪黑蘇斯"],["迫于","迫於"],["迫于形势","迫於形勢"],["迫于眉睫","迫於眉睫"],["迭出迭入","迭出迭入"],["迭有发现","迭有發現"],["迭有斩获","迭有斬獲"],["迭见杂出","迭見雜出"],["迷了","迷了"],["迷了心窍","迷了心竅"],["迷于","迷於"],["迷团","迷團"],["迷奸","迷姦"],["迷幻药","迷幻藥"],["迷彩","迷彩"],["迷彩服","迷彩服"],["迷彩裤","迷彩褲"],["迷暗","迷暗"],["迷胡","迷胡"],["迷药","迷藥"],["迷蒙","迷濛"],["迷迷蒙蒙","迷迷濛濛"],["迷魂药","迷魂藥"],["迸出","迸出"],["迸发","迸發"],["迸发出","迸發出"],["迹蹈","蹟蹈"],["追凶","追兇"],["追出","追出"],["追向","追向"],["追回","追回"],["追念","追念"],["追思弥撒","追思彌撒"],["追査出","追查出"],["追求幸福","追求幸福"],["退伍军人症","退伍軍人症"],["退伙","退夥"],["退党","退黨"],["退出","退出"],["退出运行","退出運行"],["退前缩后","退前縮後"],["退后","退後"],["退向","退向"],["退回","退回"],["退团","退團"],["退居幕后","退居幕後"],["退徙三舍","退徙三舍"],["退有后言","退有後言"],["退烧药","退燒藥"],["退藏于密","退藏於密"],["退避三舍","退避三舍"],["退针","退針"],["送个","送個"],["送了","送了"],["送修","送修"],["送出","送出"],["送别","送別"],["送君千里","送君千里"],["送回","送回"],["送客出门","送客出門"],["送客台","送客臺"],["送报夫","送報伕"],["送秋波","送秋波"],["适不适合","適不適合"],["适中","適中"],["适中下怀","適中下懷"],["适之","適之"],["适于","適於"],["适人","適人"],["适从","適從"],["适任","適任"],["适值","適值"],["适切","適切"],["适口","適口"],["适可而止","適可而止"],["适合","適合"],["适合于","適合於"],["适合者","適合者"],["适婚","適婚"],["适婚年龄","適婚年齡"],["适婚期","適婚期"],["适婚者","適婚者"],["适孙","適孫"],["适宜","適宜"],["适应","適應"],["适应力","適應力"],["适应性","適應性"],["适应期","適應期"],["适应环境","適應環境"],["适应症","適應症"],["适度","適度"],["适度微调","適度微調"],["适当","適當"],["适当地","適當地"],["适当性","適當性"],["适当的","適當的"],["适当范围","適當範圍"],["适得其反","適得其反"],["适得其所","適得其所"],["适性","適性"],["适意","適意"],["适才","適才"],["适时","適時"],["适时地","適時地"],["适材适用","適材適用"],["适来","適來"],["适法性","適法性"],["适然","適然"],["适用","適用"],["适用于","適用於"],["适用性","適用性"],["适用者","適用者"],["适用范围","適用範圍"],["适者","適者"],["适者生存","適者生存"],["适航性","適航性"],["适航指令","適航指令"],["适逢","適逢"],["适逢其会","適逢其會"],["适配器","適配器"],["适配层","適配層"],["适量","適量"],["适销","適銷"],["适销对路","適銷對路"],["适间","適間"],["适闷","適悶"],["适龄","適齡"],["逃不了","逃不了"],["逃不出","逃不出"],["逃不出手掌心","逃不出手掌心"],["逃了","逃了"],["逃债台","逃債臺"],["逃出","逃出"],["逃出去","逃出去"],["逃出来","逃出來"],["逃出生天","逃出生天"],["逃出虎口","逃出虎口"],["逃回","逃回"],["逃脱出","逃脫出"],["逆价差","逆價差"],["逆党","逆黨"],["逆入平出","逆入平出"],["逆向","逆向"],["逆向公车","逆向公車"],["逆向思考","逆向思考"],["逆向拥塞通知","逆向擁塞通知"],["逆向整合","逆向整合"],["逆向行驶","逆向行駛"],["逆折","逆折"],["逆时针","逆時針"],["逆转录","逆轉錄"],["逆转录病毒","逆轉錄病毒"],["逆转录酶","逆轉錄酶"],["逆钟","逆鐘"],["逆钟向","逆鐘向"],["选个","選個"],["选举人团","選舉人團"],["选举制","選舉制"],["选举制度","選舉制度"],["选修","選修"],["选修科","選修科"],["选修科目","選修科目"],["选修课","選修課"],["选出","選出"],["选出来","選出來"],["选后","選後"],["选录","選錄"],["选手表决","選手表決"],["选手表明","選手表明"],["选手表现","選手表現"],["选手表示","選手表示"],["选手表达","選手表達"],["选才","選才"],["选拔出","選拔出"],["选拔干部","選拔幹部"],["选择范围","選擇範圍"],["选曲","選曲"],["选校不选系","選校不選系"],["选民代表","選民代表"],["选民参加率","選民參加率"],["选派代表","選派代表"],["选种","選種"],["选系","選系"],["选系不选校","選系不選校"],["选美皇后","選美皇后"],["逊于","遜於"],["逊克","遜克"],["逊克县","遜克縣"],["逊志时敏","遜志時敏"],["逋发","逋髮"],["逋荡","逋蕩"],["逍遥游","逍遙遊"],["透了","透了"],["透出","透出"],["透出去","透出去"],["透出来","透出來"],["透漏出","透漏出"],["透辟","透闢"],["透露出","透露出"],["逐个","逐個"],["逐出","逐出"],["逐出门墙","逐出門牆"],["逐末舍本","逐末捨本"],["逐步升级","逐步升級"],["递了","遞了"],["递出","遞出"],["递出去","遞出去"],["递出来","遞出來"],["递升","遞升"],["递向","遞向"],["递回","遞迴"],["递回去","遞回去"],["递回来","遞回來"],["递推关系","遞推關係"],["递解出境","遞解出境"],["逗人发笑","逗人發笑"],["通了","通了"],["通事舍人","通事舍人"],["通于","通於"],["通人达才","通人達才"],["通便药","通便藥"],["通信技术","通信技術"],["通信系统","通信系統"],["通党库","通黨庫"],["通力合作","通力合作"],["通历","通曆"],["通合一气","通合一氣"],["通同","通同"],["通同一气","通同一氣"],["通向","通向"],["通奸","通姦"],["通奸罪","通姦罪"],["通布图","通佈圖"],["通庄","通莊"],["通心面","通心麪"],["通志","通志"],["通志馆","通志館"],["通才","通才"],["通才教育","通才教育"],["通才练识","通才練識"],["通汇","通匯"],["通用汉字标准交换码","通用漢字標準交換碼"],["通用资源识别号","通用資源識別號"],["通盘计划","通盤計劃"],["通联记录","通聯記錄"],["通讯录","通訊錄"],["通讯系统","通訊系統"],["通过事后","通過事後"],["通鉴","通鑑"],["逛了","逛了"],["逛出","逛出"],["逛出去","逛出去"],["逛出来","逛出來"],["逛回","逛回"],["逛回去","逛回去"],["逛回来","逛回來"],["逛荡","逛蕩"],["逞凶","逞兇"],["逞凶斗狠","逞兇鬥狠"],["逞凶鬥狠","逞兇鬥狠"],["逞异夸能","逞異誇能"],["逞志","逞志"],["逞恶","逞惡"],["逞欲","逞欲"],["速克达","速克達"],["速去速回","速去速回"],["速回","速回"],["速食面","速食麪"],["造价","造價"],["造出","造出"],["造出来","造出來"],["造型艺术","造型藝術"],["造天立极","造天立極"],["造就人才","造就人才"],["造就出","造就出"],["造岩矿物","造岩礦物"],["造币厂","造幣廠"],["造形艺术","造形藝術"],["造曲","造麴"],["造极登峰","造極登峯"],["造福万民","造福萬民"],["造纸厂","造紙廠"],["造纸术","造紙術"],["造船厂","造船廠"],["造船系","造船系"],["造血干","造血幹"],["造血干细胞","造血幹細胞"],["造钟","造鐘"],["造钟表","造鐘錶"],["逢人只说三分话","逢人只說三分話"],["逢低卖出","逢低賣出"],["逢凶化吉","逢凶化吉"],["逢君之恶","逢君之惡"],["逢蒙","逢蒙"],["逢高卖出","逢高賣出"],["連亘","連亙"],["逮系","逮繫"],["逮获","逮獲"],["逸出","逸出"],["逸出功","逸出功"],["逸周书","逸周書"],["逸才","逸才"],["逸欲","逸欲"],["逸游自恣","逸游自恣"],["逸群之才","逸羣之才"],["逸致","逸緻"],["逻辑链路控制","邏輯鏈路控制"],["逼上梁山","逼上梁山"],["逼下台","逼下臺"],["逼了","逼了"],["逼出","逼出"],["逼出去","逼出去"],["逼出来","逼出來"],["逼向","逼向"],["逼回","逼回"],["逼回去","逼回去"],["逼回来","逼回來"],["逼并","逼併"],["逾出","逾出"],["逾闲荡检","逾閑蕩檢"],["遂其所愿","遂其所願"],["遂愿","遂願"],["遄征","遄征"],["遇合","遇合"],["遇风后","遇風後"],["遍于","遍於"],["遍历","遍歷"],["遍布","遍佈"],["遏云","遏雲"],["遏云社","遏雲社"],["遏制","遏制"],["遏恶扬善","遏惡揚善"],["遐布","遐布"],["遐志","遐志"],["遐胄","遐胄"],["道不了","道不了"],["道不出","道不出"],["道不同不相为谋","道不同不相爲謀"],["道克鲁","道克魯"],["道出","道出"],["道别","道別"],["道合志同","道合志同"],["道同志合","道同志合"],["道听涂说","道聽塗說"],["道尔顿制","道爾頓制"],["道尽","道盡"],["道尽涂殚","道盡塗殫"],["道尽途穷","道盡途窮"],["道德发展","道德發展"],["道德困境","道德困境"],["道德规范","道德規範"],["道曲","道曲"],["道术","道術"],["道格拉斯麦克阿瑟","道格拉斯麥克阿瑟"],["道种智","道種智"],["道范","道範"],["道范长昭","道範長昭"],["道里","道里"],["道里区","道里區"],["遗传钟","遺傳鐘"],["遗体告别式","遺體告別式"],["遗害万年","遺害萬年"],["遗志","遺志"],["遗忘症","遺忘症"],["遗念","遺念"],["遗恨千古","遺恨千古"],["遗愿","遺願"],["遗才","遺才"],["遗胄","遺胄"],["遗臭万代","遺臭萬代"],["遗臭万年","遺臭萬年"],["遗臭万载","遺臭萬載"],["遗臭千年","遺臭千年"],["遗范","遺範"],["遗葑菲采","遺葑菲采"],["遗表","遺表"],["遗迹","遺蹟"],["遗风余","遺風餘"],["遣发","遣發"],["遣回","遣回"],["遣送出境","遣送出境"],["遣送回","遣送回"],["遣送回国","遣送回國"],["遥地里","遙地裏"],["遥念","遙念"],["遥测技术","遙測技術"],["遥胄","遙胄"],["遥遥华胄","遙遙華胄"],["遨游","遨遊"],["遨游四海","遨遊四海"],["遨游天下","遨遊天下"],["遭人暗算","遭人暗算"],["遭致","遭致"],["遮不了","遮不了"],["遮丑","遮醜"],["遮光板","遮光板"],["遮前掩后","遮前掩後"],["遮场面","遮場面"],["遮复","遮覆"],["遮头盖面","遮頭蓋面"],["遮护板","遮護板"],["遮挽","遮挽"],["遮羞布","遮羞布"],["遮道挽留","遮道挽留"],["遮阳板","遮陽板"],["遮面","遮面"],["遴选出","遴選出"],["遴选出来","遴選出來"],["避不见面","避不見面"],["避了","避了"],["避凶就吉","避凶就吉"],["避凶趋吉","避凶趨吉"],["避向","避向"],["避孕药","避孕藥"],["避恶","避惡"],["避暑胜地","避暑勝地"],["避雷针","避雷針"],["避风台","避風臺"],["邀天之幸","邀天之幸"],["邅回","邅回"],["邋里邋遢","邋里邋遢"],["邑里","邑里"],["邓布利多","鄧布利多"],["邢台","邢臺"],["邢台县","邢臺縣"],["邢台地区","邢臺地區"],["邢台市","邢臺市"],["那个","那個"],["那个人","那個人"],["那个猫儿不吃腥","那個貓兒不吃腥"],["那个耗子不偷油","那個耗子不偷油"],["那么","那麼"],["那么干","那麼幹"],["那么着","那麼着"],["那伙人","那夥人"],["那借","那借"],["那几","那幾"],["那几个","那幾個"],["那几天","那幾天"],["那几次","那幾次"],["那出剧","那齣劇"],["那出好戏","那齣好戲"],["那出电影","那齣電影"],["那卷","那捲"],["那只","那隻"],["那只是","那只是"],["那只有","那只有"],["那台","那臺"],["那回","那回"],["那当儿","那當兒"],["那斯达克","那斯達克"],["那方面","那方面"],["那曲","那曲"],["那曲县","那曲縣"],["那曲地区","那曲地區"],["那曲市","那曲市"],["那杯","那杯"],["那种","那種"],["那种人","那種人"],["那维克","那維克"],["那里","那裏"],["邪不干正","邪不干正"],["邪不胜正","邪不勝正"],["邪念","邪念"],["邪恶","邪惡"],["邪恶轴心","邪惡軸心"],["邪曲","邪曲"],["邪术","邪術"],["邪辟","邪辟"],["邮政储金转存制度","郵政儲金轉存制度"],["邮政划拨","郵政劃撥"],["邮政汇票","郵政匯票"],["邮汇","郵匯"],["邮汇局","郵匯局"],["邮购价格","郵購價格"],["邮购目录","郵購目錄"],["邱富郁","邱富郁"],["邱正杰","邱正傑"],["邱胜琦","邱勝琦"],["邱胜翊","邱勝翊"],["邱郁婷","邱郁婷"],["邵廷采","邵廷采"],["邵杰","邵傑"],["邵维杰","邵維傑"],["邸舍","邸舍"],["邻曲","鄰曲"],["邻舍","鄰舍"],["邻里","鄰里"],["邻里乡党","鄰里鄉黨"],["邻里长","鄰里長"],["郁伊","鬱伊"],["郁勃","鬱勃"],["郁卒","鬱卒"],["郁南","鬱南"],["郁南县","鬱南縣"],["郁哉","郁哉"],["郁垒","鬱壘"],["郁堙不偶","鬱堙不偶"],["郁塞","鬱塞"],["郁律","鬱律"],["郁悒","鬱悒"],["郁愤","鬱憤"],["郁抑","鬱抑"],["郁挹","鬱挹"],["郁朴","郁樸"],["郁李","郁李"],["郁林","鬱林"],["郁气","鬱氣"],["郁江","鬱江"],["郁沉沉","鬱沉沉"],["郁泱","鬱泱"],["郁火","鬱火"],["郁烈","郁烈"],["郁热","鬱熱"],["郁燠","鬱燠"],["郁症","鬱症"],["郁离子","郁離子"],["郁积","鬱積"],["郁穆","郁穆"],["郁纡","鬱紆"],["郁结","鬱結"],["郁蒸","鬱蒸"],["郁蓊","鬱蓊"],["郁血","鬱血"],["郁达夫","郁達夫"],["郁邑","鬱邑"],["郁郁","鬱郁"],["郁郁不乐","鬱鬱不樂"],["郁郁不平","鬱鬱不平"],["郁郁寡欢","鬱鬱寡歡"],["郁郁而终","鬱鬱而終"],["郁郁菲菲","郁郁菲菲"],["郁郁葱葱","鬱鬱蔥蔥"],["郁郁青青","郁郁青青"],["郁金","鬱金"],["郁金香","鬱金香"],["郁闭","鬱閉"],["郁闭度","鬱閉度"],["郁闷","鬱悶"],["郁闷不乐","鬱悶不樂"],["郁陶","鬱陶"],["郁馥","郁馥"],["郁黑","鬱黑"],["郇山隐修会","郇山隱修會"],["郊坛","郊壇"],["郊坛下窑","郊壇下窯"],["郊游","郊遊"],["郎个","郎個"],["郎之万","郎之萬"],["郎当","郎當"],["郎才女姿","郎才女姿"],["郎才女貌","郎才女貌"],["郎潜白发","郎潛白髮"],["郑丞杰","鄭丞傑"],["郑丰喜","鄭豐喜"],["郑余豪","鄭余豪"],["郑俊杰","鄭俊傑"],["郑克塽","鄭克塽"],["郑克爽","鄭克爽"],["郑凯云","鄭凱云"],["郑卫之曲","鄭衛之曲"],["郑家钟","鄭家鐘"],["郑幸娟","鄭幸娟"],["郑庄公","鄭莊公"],["郑志龙","鄭志龍"],["郑明修","鄭明修"],["郑易里","鄭易里"],["郑杰文","鄭傑文"],["郑板桥","鄭板橋"],["郑梦准","鄭夢準"],["郑苹如","鄭蘋如"],["郑荣松","鄭榮松"],["郑重宣布","鄭重宣佈"],["郘钟","郘鐘"],["郡县制","郡縣制"],["郡县制度","郡縣制度"],["郡国制","郡國制"],["部党","部黨"],["部发","部發"],["部曲","部曲"],["部胡林","部胡林"],["部落发","部落發"],["部落同盟","部落同盟"],["郭勇志","郭勇志"],["郭台成","郭臺成"],["郭台铭","郭臺銘"],["郭子干","郭子乾"],["郭志明","郭志明"],["郭松焘","郭松燾"],["郭泓志","郭泓志"],["郭采洁","郭采潔"],["都于","都於"],["都俞吁咈","都俞吁咈"],["都出","都出"],["都出去","都出去"],["都出来","都出來"],["都卜勒","都卜勒"],["都发","都發"],["都发局","都發局"],["都发局长","都發局長"],["都受了","都受了"],["都向","都向"],["都回","都回"],["都回去","都回去"],["都回来","都回來"],["都市计划","都市計劃"],["都必须","都必須"],["都念","都念"],["都肯干","都肯幹"],["都舍下","都捨下"],["鄂托克","鄂托克"],["鄂托克前旗","鄂托克前旗"],["鄂托克旗","鄂托克旗"],["鄂温克族","鄂溫克族"],["鄂温克族自治旗","鄂溫克族自治旗"],["鄂温克语","鄂溫克語"],["鄂霍次克海","鄂霍次克海"],["鄭凱云","鄭凱云"],["酋长制度","酋長制度"],["酌古御今","酌古御今"],["配了","配了"],["配享千秋","配享千秋"],["配件挂勾","配件掛勾"],["配位化合物","配位化合物"],["配出","配出"],["配出来","配出來"],["配制","配製"],["配制饲料","配制飼料"],["配发","配發"],["配合","配合"],["配合上","配合上"],["配合度","配合度"],["配合款","配合款"],["配合着","配合着"],["配合禁忌","配合禁忌"],["配合起来","配合起來"],["配合题","配合題"],["配水干管","配水幹管"],["配水系统","配水系統"],["配种","配種"],["配种季节","配種季節"],["配给制度","配給制度"],["配膳台","配膳檯"],["配药","配藥"],["配药师","配藥師"],["配送范围","配送範圍"],["酒入舌出","酒入舌出"],["酒厂","酒廠"],["酒后","酒後"],["酒后吐真言","酒後吐真言"],["酒后失态","酒後失態"],["酒后失言","酒後失言"],["酒后驾车","酒後駕車"],["酒后驾驶","酒後駕駛"],["酒困","酒困"],["酒坛","酒罈"],["酒娘子","酒娘子"],["酒已干","酒已乾"],["酒帘","酒帘"],["酒帘子","酒帘子"],["酒干了","酒乾了"],["酒干尽","酒乾盡"],["酒干掉","酒乾掉"],["酒恶","酒惡"],["酒曲","酒麴"],["酒有别肠","酒有別腸"],["酒杯","酒杯"],["酒柜","酒櫃"],["酒气冲天","酒氣沖天"],["酒气熏人","酒氣熏人"],["酒注子","酒注子"],["酒游花","酒游花"],["酒病酒药医","酒病酒藥醫"],["酒肴","酒餚"],["酒胡","酒胡"],["酒药","酒藥"],["酒逢知己千钟少","酒逢知己千鍾少"],["酒逢知己千锺少话不投机半句多","酒逢知己千鍾少話不投機半句多"],["酒醴曲蘖","酒醴麴櫱"],["酒面","酒面"],["酒食征逐","酒食徵逐"],["酝借","醞藉"],["酝酿出","醞釀出"],["酣嬉淋漓","酣嬉淋漓"],["酣畅淋漓","酣暢淋漓"],["酥松","酥鬆"],["酥松可口","酥鬆可口"],["酥松油脂","酥鬆油脂"],["酥签","酥簽"],["酩子里","酩子裏"],["酮体症","酮體症"],["酷刑折磨","酷刑折磨"],["酷毙了","酷斃了"],["酸懒","痠懶"],["酸疼","痠疼"],["酸痛","痠痛"],["酸软","痠軟"],["酸酸咸咸","酸酸鹹鹹"],["酸麻","痠麻"],["酿出","釀出"],["酿制","釀製"],["酿造出来","釀造出來"],["酿酒厂","釀酒廠"],["醇朴","醇樸"],["醇郁","醇郁"],["醉于","醉於"],["醉心于","醉心於"],["醉熏熏","醉熏熏"],["醋坛","醋罈"],["醋坛子","醋罈子"],["醋娘子要食杨梅","醋娘子要食楊梅"],["醋栗","醋栗"],["醋酸纤维","醋酸纖維"],["醒吾技术学院","醒吾技術學院"],["醒狮团","醒獅團"],["醣厂","醣廠"],["醮坛","醮壇"],["醯鸡甕里","醯雞甕裏"],["醲郁","醲郁"],["采下","採下"],["采下去","採下去"],["采下来","採下來"],["采为","採爲"],["采买","採買"],["采伐","採伐"],["采住","採住"],["采信","採信"],["采光","採光"],["采光剖璞","采光剖璞"],["采兰赠芍","采蘭贈芍"],["采兰赠药","採蘭贈藥"],["采写","採寫"],["采到","採到"],["采制","採製"],["采办","採辦"],["采区","採區"],["采去","採去"],["采及葑菲","采及葑菲"],["采取","採取"],["采取措施","採取措施"],["采取行动","採取行動"],["采回","採回"],["采回去","採回去"],["采回来","採回來"],["采在","採在"],["采地","采地"],["采场","採場"],["采声","采聲"],["采头","采頭"],["采女","采女"],["采好","採好"],["采录","採錄"],["采得","採得"],["采择","採擇"],["采拾","採拾"],["采挖","採挖"],["采掘","採掘"],["采摘","採摘"],["采摭","採摭"],["采撷","採擷"],["采收","採收"],["采收期","採收期"],["采收率","採收率"],["采料","採料"],["采景","採景"],["采暖","採暖"],["采果","採果"],["采树种","採樹種"],["采样","採樣"],["采样法","採樣法"],["采样率","採樣率"],["采桑","採桑"],["采棉机","採棉機"],["采椽不斲","采椽不斲"],["采樵人","採樵人"],["采气","採氣"],["采水","採水"],["采油","採油"],["采烈","采烈"],["采煤","採煤"],["采煤矿","採煤礦"],["采爲","採爲"],["采猎","採獵"],["采珠","採珠"],["采珠人","採珠人"],["采生折割","採生折割"],["采用","採用"],["采用到","採用到"],["采用率","採用率"],["采的","採的"],["采盐","採鹽"],["采石","採石"],["采石之役","采石之役"],["采石之战","采石之戰"],["采石之戰","采石之戰"],["采石厂","採石廠"],["采石场","採石場"],["采矿","採礦"],["采矿业","採礦業"],["采矿场","採礦場"],["采矿工","採礦工"],["采矿工业","採礦工業"],["采矿工程","採礦工程"],["采矿方法","採礦方法"],["采砂场","採砂場"],["采种","採種"],["采稿","採稿"],["采空区","採空區"],["采空采穗","採空採穗"],["采精","採精"],["采納","採納"],["采纳","採納"],["采给","採給"],["采绿","采綠"],["采缉","采緝"],["采编","採編"],["采脂","採脂"],["采色","采色"],["采芑","采芑"],["采花","採花"],["采花贼","採花賊"],["采芹","采芹"],["采芹人","採芹人"],["采苓","采苓"],["采茶","採茶"],["采茶戏","採茶戲"],["采茶歌","採茶歌"],["采药","採藥"],["采药人","採藥人"],["采莲","採蓮"],["采莲曲","採蓮曲"],["采莲船","採蓮船"],["采获","採獲"],["采菊","採菊"],["采菽","采菽"],["采葛","采葛"],["采薇","采薇"],["采薪","採薪"],["采薪之忧","采薪之憂"],["采薪之疾","采薪之疾"],["采蘩","采蘩"],["采蜜","採蜜"],["采血","採血"],["采行","採行"],["采衣","采衣"],["采补","採補"],["采认","採認"],["采访","採訪"],["采访使","採訪使"],["采访员","採訪員"],["采访团","採訪團"],["采访新闻","採訪新聞"],["采访权","採訪權"],["采访编辑","採訪編輯"],["采访记者","採訪記者"],["采证","採證"],["采诗","采詩"],["采购","採購"],["采购供应","採購供應"],["采购员","採購員"],["采购团","採購團"],["采购案","採購案"],["采购法","採購法"],["采购站","採購站"],["采购规则","採購規則"],["采购量","採購量"],["采过","採過"],["采过去","採過去"],["采过来","採過來"],["采运","採運"],["采选","採選"],["采邑","采邑"],["采采","采采"],["采金","採金"],["采铁","採鐵"],["采集","採集"],["采集到","採集到"],["采集法","採集法"],["采集起来","採集起來"],["采风","採風"],["采风录","采風錄"],["采风问俗","採風問俗"],["采食","採食"],["釉下彩","釉下彩"],["釉彩","釉彩"],["釉药","釉藥"],["释出","釋出"],["释卷","釋卷"],["释放出","釋放出"],["释放出来","釋放出來"],["释放出狱","釋放出獄"],["释迦佛也恼下莲台","釋迦佛也惱下蓮臺"],["里亚","里亞"],["里人","里人"],["里仁","里仁"],["里仁为美","里仁爲美"],["里克特","里克特"],["里党","里黨"],["里兹","里茲"],["里出外进","裏出外進"],["里加","里加"],["里勾外连","裏勾外連"],["里包恩","里包恩"],["里名","里名"],["里君","里君"],["里咽","裏咽"],["里士满","里士滿"],["里外","裏外"],["里奇蒙","里奇蒙"],["里契蒙","里契蒙"],["里奥","里奧"],["里奥斯","里奧斯"],["里奥格兰德","里奧格蘭德"],["里子","裏子"],["里实","裏實"],["里宰","里宰"],["里尔","里爾"],["里尔队","里爾隊"],["里尼","里尼"],["里层","裏層"],["里居","里居"],["里屋","裏屋"],["里巷","里巷"],["里布","里布"],["里希特霍芬","里希特霍芬"],["里带","裏帶"],["里应外合","裏應外合"],["里廉","裏廉"],["里弄","里弄"],["里弗赛德","里弗賽德"],["里弦","裏弦"],["里急后重","裏急後重"],["里手","裏手"],["里扣","里扣"],["里拉","里拉"],["里斯","里斯"],["里斯本","里斯本"],["里昂","里昂"],["里昂市","里昂市"],["里昂队","里昂隊"],["里根","里根"],["里欧","里歐"],["里欧斯","里歐斯"],["里正","里正"],["里氏","里氏"],["里氏震级","里氏震級"],["里民","里民"],["里民大会","里民大會"],["里海","裏海"],["里港","里港"],["里港乡","里港鄉"],["里牵绵","裏牽綿"],["里特维宁科","里特維寧科"],["里瓦几亚条约","里瓦幾亞條約"],["里瓦尔多","裏瓦爾多"],["里社","里社"],["里科","里科"],["里程","里程"],["里程碑","里程碑"],["里程碑式","里程碑式"],["里程表","里程錶"],["里程计","里程計"],["里约","里約"],["里约热內卢","里約熱內盧"],["里约热内卢","里約熱內盧"],["里纳","里納"],["里维拉","里維拉"],["里美","里美"],["里老","里老"],["里耳","里耳"],["里肌","里肌"],["里胥","里胥"],["里脊","裏脊"],["里脊肉","裏脊肉"],["里舍","里舍"],["里蒙诺夫","里蒙諾夫"],["里虚","裏虛"],["里衣","裏衣"],["里言","裏言"],["里语","里語"],["里谈巷议","里談巷議"],["里谚","里諺"],["里豪","里豪"],["里贝利","里貝利"],["里贾纳","里賈納"],["里路","里路"],["里踢","裏踢"],["里边","裏邊"],["里边儿","裏邊兒"],["里进外出","裏進外出"],["里通外国","裏通外國"],["里通外敌","裏通外敵"],["里邻长","里鄰長"],["里里","裏裏"],["里里外外","裏裏外外"],["里长","里長"],["里长伯","里長伯"],["里门","里門"],["里闬","里閈"],["里间","裏間"],["里闾","里閭"],["里面","裏面"],["里面儿","裏面兒"],["重于","重於"],["重于泰山","重於泰山"],["重价","重價"],["重估后","重估後"],["重修","重修"],["重修旧好","重修舊好"],["重出","重出"],["重划","重劃"],["重划区","重劃區"],["重划局","重劃局"],["重制","重製"],["重力摆","重力擺"],["重历旧游","重歷舊遊"],["重发","重發"],["重台","重臺"],["重合","重合"],["重回","重回"],["重复","重複"],["重复使用","重複使用"],["重复启动效应","重複啓動效應"],["重复式","重複式"],["重复本","重複本"],["重复法","重複法"],["重复节","重複節"],["重复记录","重複記錄"],["重复语境","重複語境"],["重复课税","重複課稅"],["重定向","重定向"],["重岩叠嶂","重巖疊嶂"],["重庆师范大学","重慶師範大學"],["重当","重當"],["重托","重託"],["重扣","重扣"],["重折","重摺"],["重新装修","重新裝修"],["重新评价","重新評價"],["重涂","重塗"],["重游","重遊"],["重游旧地","重遊舊地"],["重点采访","重點採訪"],["重生爷娘","重生爺孃"],["重症","重症"],["重罗面","重羅麪"],["重置价格","重置價格"],["重获","重獲"],["重见复出","重見複出"],["重蹈复辙","重蹈覆轍"],["重重困难","重重困難"],["重锤","重錘"],["野台","野臺"],["野台戏","野臺戲"],["野合","野合"],["野外定向","野外定向"],["野姜","野薑"],["野姜花","野薑花"],["野无遗才","野無遺才"],["野游","野遊"],["野种","野種"],["野胡萝卜","野胡蘿蔔"],["野草闲花","野草閒花"],["野获编","野獲編"],["野鹤闲云","野鶴閒雲"],["量了","量了"],["量入为出","量入爲出"],["量出","量出"],["量出制入","量出制入"],["量回","量回"],["量回去","量回去"],["量回来","量回來"],["量才录用","量才錄用"],["量材录用","量材錄用"],["量杯","量杯"],["量表","量表"],["量雨表","量雨表"],["金万福","金萬福"],["金乌西坠玉兔东升","金烏西墜玉兔東昇"],["金云母","金雲母"],["金仆姑","金僕姑"],["金仑溪","金崙溪"],["金价","金價"],["金伯利岩","金伯利岩"],["金光党","金光黨"],["金创药","金創藥"],["金升圭","金昇圭"],["金升渊","金升淵"],["金印如斗","金印如斗"],["金发","金髮"],["金发女郎","金髮女郎"],["金发碧眼","金髮碧眼"],["金台","金臺"],["金台区","金臺區"],["金叶","金葉"],["金合欢","金合歡"],["金周成","金周成"],["金坛","金壇"],["金坛市","金壇市"],["金基范","金基範"],["金头银面","金頭銀面"],["金属制","金屬製"],["金属杆","金屬桿"],["金属板","金屬板"],["金布道","金布道"],["金斗","金斗"],["金曲","金曲"],["金曲奖","金曲獎"],["金本位制","金本位制"],["金杯","金盃","金杯"],["金枝玉叶","金枝玉葉"],["金柜","金櫃"],["金柜石室","金櫃石室"],["金榜挂名","金榜掛名"],["金正云","金正雲"],["金氏纪录","金氏紀錄"],["金玉其表","金玉其表"],["金甲虫","金甲蟲"],["金疮药","金瘡藥"],["金盏银台","金盞銀臺"],["金石录","金石錄"],["金穗奖","金穗獎"],["金粉楼台","金粉樓臺"],["金线虫","金線蟲"],["金胄","金胄"],["金花虫","金花蟲"],["金范","金範"],["金虫","金蟲"],["金融杠杆","金融槓桿"],["金融系统","金融系統"],["金衡制","金衡制"],["金表","金錶"],["金表态","金表態"],["金表情","金表情"],["金表扬","金表揚"],["金表明","金表明"],["金表演","金表演"],["金表现","金表現"],["金表示","金表示"],["金表达","金表達"],["金表露","金表露"],["金表面","金表面"],["金装玉里","金裝玉裏"],["金谷","金谷"],["金谷园","金谷園"],["金谷堕楼","金谷墮樓"],["金谷酒数","金谷酒數"],["金里奇","金裏奇"],["金针","金針"],["金针山","金針山"],["金针度人","金針度人"],["金针花","金針花"],["金针菇","金針菇"],["金针菜","金針菜"],["金钟","金鐘"],["金钟罩","金鐘罩"],["金钟铲","金鐘鏟"],["金钱万能","金錢萬能"],["金钱挂帅","金錢掛帥"],["金钱松","金錢松"],["金钱游戏","金錢遊戲"],["金链","金鍊"],["金面","金面"],["金马仑道","金馬崙道"],["金马克","金馬克"],["釜底游魂","釜底遊魂"],["釜底游鱼","釜底游魚"],["釜里之鱼","釜裏之魚"],["鉴于","鑑於"],["鉴别","鑑別"],["鉴别力","鑑別力"],["鉴别器","鑑別器"],["鉴别能力","鑑別能力"],["鉴古推今","鑑古推今"],["鉴堂","鑑堂"],["鉴定","鑑定"],["鉴定为","鑑定爲"],["鉴定书","鑑定書"],["鉴定人","鑑定人"],["鉴定委员会","鑑定委員會"],["鉴定考试","鑑定考試"],["鉴宝","鑑寶"],["鉴察","鑑察"],["鉴往知来","鑑往知來"],["鉴戒","鑑戒"],["鉴明","鑑明"],["鉴核备査","鑑核備查"],["鉴此","鑑此"],["鉴毛辨色","鑑毛辨色"],["鉴泉","鑑泉"],["鉴湖","鑑湖"],["鉴湖女侠","鑑湖女俠"],["鉴照","鑑照"],["鉴相","鑑相"],["鉴真","鑑真"],["鉴真和尚","鑑真和尚"],["鉴藏印","鑑藏印"],["鉴证","鑑證"],["鉴识","鑑識"],["鉴诫","鑑誡"],["鉴谅","鑑諒"],["鉴貌辨色","鑑貌辨色"],["鉴赏","鑑賞"],["鉴赏力","鑑賞力"],["鉴赏印","鑑賞印"],["鉴赏家","鑑賞家"],["鉴赏能力","鑑賞能力"],["鉴频","鑑頻"],["鉴频器","鑑頻器"],["针关","鍼關"],["针具","針具"],["针刺","針刺"],["针刺麻醉","針刺麻醉"],["针剂","針劑"],["针口","鍼口"],["针叶","針葉"],["针叶林","針葉林"],["针叶树","針葉樹"],["针叶植物","針葉植物"],["针头","針頭"],["针孔","針孔"],["针孔摄影机","針孔攝影機"],["针孔照像","針孔照像"],["针孔照像机","針孔照像機"],["针孔现象","針孔現象"],["针对","針對"],["针对于","針對於"],["针对性","針對性"],["针尖","針尖"],["针尖儿","針尖兒"],["针工","針工"],["针布","針布"],["针形叶","針形葉"],["针扣","針釦"],["针指","針指"],["针挑刀挖","針挑刀挖"],["针梳机","針梳機"],["针毡","針氈"],["针法","針法"],["针灸","鍼灸"],["针灸铜人","鍼灸銅人"],["针灸麻醉","鍼灸麻醉"],["针炙","針炙"],["针状","針狀"],["针状物","針狀物"],["针盘","針盤"],["针眼","針眼"],["针眼子","針眼子"],["针砭","鍼砭"],["针神","針神"],["针笔","針筆"],["针笔匠","針筆匠"],["针筒","針筒"],["针箍","針箍"],["针箍儿","針箍兒"],["针线","針線"],["针线包","針線包"],["针线娘","針線娘"],["针线活","針線活"],["针线活计","針線活計"],["针线盒","針線盒"],["针线箔篱","針線箔籬"],["针织","針織"],["针织厂","針織廠"],["针织品","針織品"],["针织料","針織料"],["针脚","針腳"],["针芒","鍼芒"],["针芥相投","鍼芥相投"],["针针见血","針針見血"],["针铓","針鋩"],["针锋","針鋒"],["针锋相对","針鋒相對"],["针锋相投","針鋒相投"],["针饵莫减","針餌莫減"],["针骨","針骨"],["针鱼","針魚"],["针黹","針黹"],["针黹纺绩","針黹紡績"],["针鼹","針鼴"],["针鼻","針鼻"],["针鼻儿","針鼻兒"],["钉个","釘個"],["钉书针","釘書針"],["钉了","釘了"],["钉合","釘合"],["钉扣","釘釦"],["钉锤","釘錘"],["钓个","釣個"],["钓了","釣了"],["钓游旧地","釣遊舊地"],["钓鱼台","釣魚臺"],["钓鱼台列岛","釣魚臺列島"],["钓鱼杆","釣魚杆"],["钗云","釵雲"],["钛合金","鈦合金"],["钜万","鉅萬"],["钞录","鈔錄"],["钟上","鐘上"],["钟下","鐘下"],["钟不","鐘不"],["钟不扣不鸣","鐘不扣不鳴"],["钟不撞不鸣","鐘不撞不鳴"],["钟不敲不响","鐘不敲不響"],["钟不空则哑","鐘不空則啞"],["钟乐","鐘樂"],["钟乳洞","鐘乳洞"],["钟乳石","鐘乳石"],["钟体","鐘體"],["钟停","鐘停"],["钟关","鐘關"],["钟匠","鐘匠"],["钟发音","鐘發音"],["钟口","鐘口"],["钟响","鐘響"],["钟响声","鐘響聲"],["钟在寺里","鐘在寺裏"],["钟塔","鐘塔"],["钟壁","鐘壁"],["钟声","鐘聲"],["钟太","鐘太"],["钟头","鐘頭"],["钟好","鐘好"],["钟山","鐘山"],["钟山区","鐘山區"],["钟山县","鐘山縣"],["钟左右","鐘左右"],["钟差","鐘差"],["钟座","鐘座"],["钟形","鐘形"],["钟形虫","鐘形蟲"],["钟律","鐘律"],["钟快","鐘快"],["钟情","鍾情"],["钟意","鐘意"],["钟慢","鐘慢"],["钟摆","鐘擺"],["钟敲","鐘敲"],["钟无豔","鍾無豔"],["钟有","鐘有"],["钟楚红","鐘楚紅"],["钟楼","鐘樓"],["钟楼区","鐘樓區"],["钟楼怪人","鐘樓怪人"],["钟模","鐘模"],["钟欣桐","鍾欣桐"],["钟没","鐘沒"],["钟漏","鐘漏"],["钟点","鐘點"],["钟点房","鐘點房"],["钟点费","鐘點費"],["钟爱","鍾愛"],["钟王","鐘王"],["钟珮瑄","鐘珮瑄"],["钟琴","鐘琴"],["钟的","鐘的"],["钟盘","鐘盤"],["钟相","鐘相"],["钟磬","鐘磬"],["钟祥","鍾祥"],["钟祥县","鍾祥縣"],["钟祥市","鍾祥市"],["钟福松","鐘福松"],["钟纽","鐘紐"],["钟罩","鐘罩"],["钟腰","鐘腰"],["钟螺","鐘螺"],["钟行","鐘行"],["钟表","鐘錶"],["钟表停","鐘錶停"],["钟表盘","鐘表盤"],["钟被","鐘被"],["钟调","鐘調"],["钟身","鐘身"],["钟速","鐘速"],["钟面","鐘面"],["钟顶","鐘頂"],["钟馗","鍾馗"],["钟鸣","鐘鳴"],["钟鸣漏尽","鐘鳴漏盡"],["钟鸣鼎食","鐘鳴鼎食"],["钟鼎","鐘鼎"],["钟鼎之家","鐘鼎之家"],["钟鼎人家","鐘鼎人家"],["钟鼎山林","鐘鼎山林"],["钟鼎文","鐘鼎文"],["钟鼎款识","鐘鼎款識"],["钟鼎高门","鐘鼎高門"],["钟鼓","鐘鼓"],["钟鼓齐鸣","鐘鼓齊鳴"],["钢制","鋼製"],["钢制品","鋼製品"],["钢扣","鋼釦"],["钢曲尺","鋼曲尺"],["钢杯","鋼杯"],["钢板","鋼板"],["钢梁","鋼樑"],["钢琴曲","鋼琴曲"],["钢种","鋼種"],["钢笔杆","鋼筆桿"],["钢针","鋼針"],["钢铁厂","鋼鐵廠"],["钢铲","鋼鏟"],["钥匙链","鑰匙鏈"],["钧复","鈞覆"],["钧鉴","鈞鑒"],["钩党","鉤黨"],["钩心斗角","鉤心鬥角"],["钩深致远","鉤深致遠"],["钩花点叶","鉤花點葉"],["钩虫","鉤蟲"],["钩虫病","鉤蟲病"],["钩针","鉤針"],["钮扣","鈕釦"],["钱复","錢復"],["钱布","錢布"],["钱庄","錢莊"],["钱板儿","錢板兒"],["钱柜","錢櫃"],["钱柜杂志","錢櫃雜誌"],["钱玄同","錢玄同"],["钱眼里安身","錢眼裏安身"],["钱范","錢範"],["钱谷","錢穀"],["钱过北斗","錢過北斗"],["钱钟书","錢鍾書"],["钳制","鉗制"],["钻井平台","鑽井平臺"],["钻出","鑽出"],["钻台","鑽臺"],["钻心虫","鑽心蟲"],["钻懒帮闲","鑽懶幫閒"],["钻杆","鑽桿"],["钻皮出羽","鑽皮出羽"],["钻石项链","鑽石項鍊"],["钿合","鈿合"],["钿头云篦","鈿頭雲篦"],["铁云藏龟","鐵雲藏龜"],["铁价","鐵價"],["铁制","鐵製"],["铁厂","鐵廠"],["铁叶","鐵葉"],["铁合金","鐵合金"],["铁娘子","鐵娘子"],["铁托","鐵托"],["铁扣","鐵釦"],["铁拐","鐵柺"],["铁杆","鐵桿"],["铁杠","鐵槓"],["铁板","鐵板"],["铁板大鼓","鐵板大鼓"],["铁板快书","鐵板快書"],["铁板注脚","鐵板註腳"],["铁板烧","鐵板燒"],["铁板牛柳","鐵板牛柳"],["铁板牛肉","鐵板牛肉"],["铁板茄子","鐵板茄子"],["铁板路","鐵板路"],["铁板面","鐵板麪"],["铁柜","鐵櫃"],["铁栏杆","鐵欄杆"],["铁甲虫","鐵甲蟲"],["铁索郎当","鐵索郎當"],["铁胃团","鐵胃團"],["铁苏木","鐵蘇木"],["铁路干线","鐵路幹線"],["铁针","鐵針"],["铁钟","鐵鐘"],["铁铲","鐵鏟"],["铁链","鐵鏈"],["铁锤","鐵錘"],["铁雕","鐵雕"],["铁面","鐵面"],["铁面判官","鐵面判官"],["铁面御史","鐵面御史"],["铁面无情","鐵面無情"],["铁面无私","鐵面無私"],["铃虫","鈴蟲"],["铅制","鉛製"],["铅字合金","鉛字合金"],["铅板","鉛板"],["铉台","鉉臺"],["铜制","銅製"],["铜制品","銅製品"],["铜厂","銅廠"],["铜叶","銅葉"],["铜山西崩洛钟东应","銅山西崩洛鐘東應"],["铜扣","銅釦"],["铜斗儿","銅斗兒"],["铜斗儿家缘","銅斗兒家緣"],["铜板","銅板"],["铜梁","銅梁"],["铜梁县","銅梁縣"],["铜琵铁板","銅琵鐵板"],["铜范","銅範"],["铜钟","銅鐘"],["铜雀台","銅雀臺"],["铜雕","銅雕"],["铝制","鋁製"],["铝制品","鋁製品"],["铝合金","鋁合金"],["铝板","鋁板"],["铠胄","鎧冑"],["铯钟","銫鐘"],["铰链","鉸鏈"],["铰链叶","鉸鏈葉"],["铲下","剷下"],["铲伤","剷傷"],["铲倒","剷倒"],["铲出","剷出"],["铲凿","剷鑿"],["铲刀","剷刀"],["铲刈","剷刈"],["铲土","剷土"],["铲土机","鏟土機"],["铲头","鏟頭"],["铲子","鏟子"],["铲射","剷射"],["铲平","剷平"],["铲抢","剷搶"],["铲掉","剷掉"],["铲斗","剷鬥"],["铲断","剷斷"],["铲板","剷板"],["铲煤","剷煤"],["铲球","剷球"],["铲草","剷草"],["铲起","剷起"],["铲车","剷車"],["铲运机","鏟運機"],["铲运车","鏟運車"],["铲铲","剷剷"],["铲除","剷除"],["铲雪","剷雪"],["铲雪车","鏟雪車"],["银丝卷","銀絲捲"],["银价","銀價"],["银制","銀製"],["银发","銀髮"],["银发产业","銀髮產業"],["银发族","銀髮族"],["银台","銀臺"],["银合欢","銀合歡"],["银团","銀團"],["银本位制","銀本位制"],["银朱","銀硃"],["银杯","銀盃","銀杯"],["银杯羽化","銀杯羽化"],["银板","銀板"],["银柜","銀櫃"],["银核","銀核"],["银河系","銀河系"],["银纤维","銀纖維"],["银色冲浪手","銀色衝浪手"],["银行体系资金","銀行體系資金"],["银行借款","銀行借款"],["银行利害关系人","銀行利害關係人"],["银行团","銀行團"],["银行存折","銀行存摺"],["银针","銀針"],["银须","銀鬚"],["铸币厂","鑄幣廠"],["铸造出","鑄造出"],["铸钟","鑄鐘"],["铺了","鋪了"],["铺伙","鋪夥"],["铺出","鋪出"],["铺出去","鋪出去"],["铺出来","鋪出來"],["铺向","鋪向"],["铺地板","鋪地板"],["铺板","鋪板"],["铺盖卷儿","鋪蓋捲兒"],["铺眉蒙眼","鋪眉蒙眼"],["铺锦列绣","鋪錦列繡"],["铺面","鋪面"],["铺面临街房","鋪面臨街房"],["铺面房","鋪面房"],["链传动","鏈傳動"],["链反应","鏈反應"],["链坠","鍊墜"],["链套","鏈套"],["链子","鏈子"],["链式","鏈式"],["链式反应","鏈式反應"],["链式裂变反应","鏈式裂變反應"],["链形","鍊形"],["链扣","鏈釦"],["链接","鏈接"],["链条","鏈條"],["链椎","鏈椎"],["链烃","鏈烴"],["链环","鏈環"],["链球","鏈球"],["链球菌","鏈球菌"],["链甲","鍊甲"],["链罩","鏈罩"],["链表","鏈表"],["链路","鏈路"],["链路层","鏈路層"],["链轨","鏈軌"],["链轮","鏈輪"],["链钳子","鏈鉗子"],["链锁","鏈鎖"],["链锁反应","鏈鎖反應"],["链锯","鏈鋸"],["链霉素","鏈黴素"],["销了","銷了"],["销出","銷出"],["销售价格","銷售價格"],["销售时点情报系统","銷售時點情報系統"],["销回","銷回"],["销回去","銷回去"],["销回来","銷回來"],["销志","銷志"],["销毁","銷燬"],["销货折扣","銷貨折扣"],["锁扣","鎖釦"],["锁柜","鎖櫃"],["锁链","鎖鏈"],["锄奸","鋤奸"],["锄铲","鋤鏟"],["锅伙","鍋伙"],["锅台","鍋臺"],["锅庄","鍋莊"],["锅烟","鍋煙"],["锅烟子","鍋煙子"],["锅铲","鍋鏟"],["锆合金","鋯合金"],["锈病","鏽病"],["锈菌","鏽菌"],["锈蚀","鏽蝕"],["锋出","鋒出"],["锋发韵流","鋒發韻流"],["锋芒所向","鋒芒所向"],["锋面","鋒面"],["锋面雨","鋒面雨"],["锌板","鋅板"],["锐不可当","銳不可當"],["锐志","銳志"],["锐未可当","銳未可當"],["锕系元素","錒系元素"],["错不了","錯不了"],["错了","錯了"],["错了又错","錯了又錯"],["错别字","錯別字"],["错化合物","錯化合物"],["错彩镂金","錯彩鏤金"],["错综复杂","錯綜複雜"],["错落有致","錯落有致"],["错觉结合","錯覺結合"],["错觉结合的词","錯覺結合的詞"],["错误百出","錯誤百出"],["错误的结合","錯誤的結合"],["锚杆","錨杆"],["锚虫","錨蟲"],["锚链","錨鏈"],["锚链孔","錨鏈孔"],["锡克拜","錫克拜"],["锡克教","錫克教"],["锡克族","錫克族"],["锡当河","錫當河"],["锡杯","錫杯"],["锤儿","錘兒"],["锤头","錘頭"],["锤子","錘子"],["锤炼","錘鍊"],["锥虫病","錐蟲病"],["锥面","錐面"],["锦囊佳制","錦囊佳製"],["锦回文","錦迴文"],["锦熏笼","錦熏籠"],["锦绣","錦繡"],["锦绣花园","錦繡花園"],["锦胡同","錦衚衕"],["锯了","鋸了"],["锯了嘴的葫芦","鋸了嘴的葫蘆"],["锯出","鋸出"],["锯木厂","鋸木廠"],["锲而不舍","鍥而不捨"],["锹形虫","鍬形蟲"],["锺万梅","鍾萬梅"],["锺重发","鍾重發"],["锺馗","鍾馗"],["锻炼","鍛鍊"],["锻炼出","鍛煉出"],["锻炼身体","鍛鍊身體"],["镁合金","鎂合金"],["镂冰雕朽","鏤冰雕朽"],["镂彩摛文","鏤彩摛文"],["镂月裁云","鏤月裁雲"],["镂金错采","鏤金錯采"],["镇台","鎮臺"],["镇宁布依族苗族自治县","鎮寧布依族苗族自治縣"],["镇定药","鎮定藥"],["镇痛药","鎮痛藥"],["镇荣里","鎮榮里"],["镇静药","鎮靜藥"],["镍合金","鎳合金"],["镕岩","鎔岩"],["镜台","鏡臺"],["镜框舞台","鏡框舞臺"],["镜里孤鸾","鏡裏孤鸞"],["镜鉴","鏡鑑"],["镜面","鏡面"],["镜面呢","鏡面呢"],["镧系元素","鑭系元素"],["镭射印表机","鐳射印表機"],["镰仓","鎌倉"],["镰形血球贫血症","鐮形血球貧血症"],["镰状细胞血症","鐮狀細胞血症"],["镶了","鑲了"],["镶板","鑲板"],["长丰","長豐"],["长丰县","長豐縣"],["长了","長了"],["长于","長於"],["长他人志气灭自己威风","長他人志氣滅自己威風"],["长几","長几"],["长出","長出"],["长出来","長出來"],["长卷","長卷"],["长历","長曆"],["长发","長髮"],["长叹","長嘆"],["长吁","長吁"],["长吁短叹","長吁短嘆"],["长君之恶","長君之惡"],["长坂坡七进七出","長阪坡七進七出"],["长头布","長頭布"],["长寿烟","長壽菸"],["长寿面","長壽麪"],["长干巷","長干巷"],["长干曲","長干曲"],["长征","長征"],["长征军","長征軍"],["长恶不悛","長惡不悛"],["长才","長才"],["长春师范学院","長春師範學院"],["长期借款","長期借款"],["长板","長板"],["长板凳","長板凳"],["长林丰草","長林豐草"],["长歌当哭","長歌當哭"],["长江后浪","長江後浪"],["长江后浪催前浪一代新人换旧人","長江後浪催前浪一代新人換舊人"],["长烟","長煙"],["长烟一空","長煙一空"],["长生药","長生藥"],["长程计划","長程計劃"],["长绳系日","長繩繫日"],["长绳系景","長繩繫景"],["长胡","長鬍"],["长虫","長蟲"],["长谷","長谷"],["长谷川","長谷川"],["长辔远御","長轡遠御"],["长针","長針"],["长须","長鬚"],["长须鲸","長鬚鯨"],["长风万里","長風萬里"],["開發周期","開發周期"],["门前门后","門前門後"],["门吊儿","門吊兒"],["门帘","門簾"],["门当户对","門當戶對"],["门扣","門扣"],["门拐","門拐"],["门斗","門斗"],["门板","門板"],["门殚户尽","門殫戶盡"],["门皁","門皁"],["门胄","門胄"],["门里","門裏"],["门里人","門裏人"],["门里出身","門裏出身"],["门里安心","門裏安心"],["门里门外","門裏門外"],["门面","門面"],["门面话","門面話"],["闪了","閃了"],["闪出","閃出"],["闪含语系","閃含語系"],["闪念","閃念"],["闪电战术","閃電戰術"],["闪闪发光","閃閃發光"],["闫怀礼","閆懷禮"],["闭一只眼","閉一隻眼"],["闭卷","閉卷"],["闭卷考","閉卷考"],["闭卷考试","閉卷考試"],["闭合","閉合"],["闭合电路","閉合電路"],["闭门家里坐祸从天上来","閉門家裏坐禍從天上來"],["闭面","閉面"],["问个","問個"],["问个问题","問個問題"],["问了","問了"],["问出","問出"],["问卜","問卜"],["问卷","問卷"],["问卷大调査","問卷大調查"],["问卷调査","問卷調查"],["问卷调査表","問卷調查表"],["问当","問當"],["问政于民","問政於民"],["问舍求田","問舍求田"],["问道于盲","問道於盲"],["闯出","闖出"],["闯出去","闖出去"],["闯出来","闖出來"],["闯炼","闖鍊"],["闯荡","闖蕩"],["闯荡江湖","闖蕩江湖"],["闯进闯出","闖進闖出"],["闲下来","閒下來"],["闲不住","閒不住"],["闲云孤鹤","閒雲孤鶴"],["闲云野鹤","閒雲野鶴"],["闲人免进","閒人免進"],["闲余","閒餘"],["闲庭信步","閒庭信步"],["闲情逸致","閒情逸致"],["闲情逸趣","閒情逸趣"],["闲打牙儿","閒打牙兒"],["闲扯淡","閒扯淡"],["闲是闲非","閒是閒非"],["闲杂人员","閒雜人員"],["闲杂人等","閒雜人等"],["闲来无事","閒來無事"],["闲淘气","閒淘氣"],["闲游","閒遊"],["闲理会","閒理會"],["闲盘儿","閒盤兒"],["闲磕牙","閒磕牙"],["闲篇儿","閒篇兒"],["闲置不用","閒置不用"],["闲聊天","閒聊天"],["闲聒七","閒聒七"],["闲花野草","閒花野草"],["闲茶浪酒","閒茶浪酒"],["闲荡","閒蕩"],["闲言乱语","閒言亂語"],["闲言碎语","閒言碎語"],["闲言长语","閒言長語"],["闲言闲事","閒言閒事"],["闲言闲语","閒言閒語"],["闲话家常","閒話家常"],["闲话少说","閒話少說"],["闲适","閒適"],["闲邪存诚","閒邪存誠"],["间不容发","間不容髮"],["间充质干细胞","間充質幹細胞"],["间出","間出"],["间别","間別"],["间叶干","間葉幹"],["间奏曲","間奏曲"],["间接证据","間接證據"],["间深里","間深裏"],["闵凶","閔凶"],["闵子里","閔子裏"],["闵采尔","閔採爾"],["闷出","悶出"],["闷在心里","悶在心裏"],["闷板","悶板"],["闷着头儿干","悶着頭兒幹"],["闷表","悶錶"],["闸板","閘板"],["闹个","鬧個"],["闹了半天鬼","鬧了半天鬼"],["闹出","鬧出"],["闹出去","鬧出去"],["闹出来","鬧出來"],["闹出笑话","鬧出笑話"],["闹别扭","鬧彆扭"],["闹台","鬧臺"],["闹哄","鬧鬨"],["闹哄哄","鬧哄哄"],["闹拧了","鬧擰了"],["闹着玩儿","鬧着玩兒"],["闹表","鬧錶"],["闹钟","鬧鐘"],["闹铃时钟","鬧鈴時鐘"],["闹饥荒","鬧饑荒"],["闺范","閨範"],["闻了","聞了"],["闻出","聞出"],["闻名于世","聞名於世"],["闻风后","聞風後"],["闽台","閩臺"],["闽台地区","閩臺地區"],["闾党姻娅","閭黨姻婭"],["闾里","閭里"],["阀杆","閥杆"],["阃范","閫範"],["阅兵台","閱兵臺"],["阅卷","閱卷"],["阅卷组","閱卷組"],["阅历","閱歷"],["阉党","閹黨"],["阎云浚","閻雲浚"],["阎王好见小鬼难当","閻王好見小鬼難當"],["阎罗王面前须没放回的鬼","閻羅王面前須沒放回的鬼"],["阐发","闡發"],["阑尾切除术","闌尾切除術"],["阑干","闌干"],["阔别","闊別"],["阔别多年","闊別多年"],["阔叶林","闊葉林"],["阔叶树","闊葉樹"],["阙里","闕里"],["阜新蒙古族自治县","阜新蒙古族自治縣"],["阜阳师范学院","阜陽師範學院"],["队别","隊別"],["阡表","阡表"],["阨困","阨困"],["阮咸","阮咸"],["防不胜防","防不勝防"],["防个","防個"],["防了","防了"],["防人之口甚于防川","防人之口甚於防川"],["防修","防修"],["防制","防制"],["防制法","防制法"],["防卫过当","防衛過當"],["防台","防颱"],["防守战术","防守戰術"],["防御","防禦"],["防御力","防禦力"],["防御工事","防禦工事"],["防御性","防禦性"],["防御战","防禦戰"],["防御术","防禦術"],["防御率","防禦率"],["防御率王","防禦率王"],["防御网","防禦網"],["防患于未然","防患於未然"],["防护团","防護團"],["防护面具","防護面具"],["防晒","防曬"],["防毒斗篷","防毒斗篷"],["防毒面具","防毒面具"],["防民之口甚于防川","防民之口甚於防川"],["防水布","防水布"],["防水表","防水錶"],["防滑链","防滑鏈"],["防火布","防火布"],["防火系统","防火系統"],["防疫针","防疫針"],["防秋","防秋"],["防空识别区","防空識別區"],["防范","防範"],["防范体系","防範體系"],["防范得宜","防範得宜"],["防范意识","防範意識"],["防范控制","防範控制"],["防范措施","防範措施"],["防范未然","防範未然"],["防身术","防身術"],["防锁死煞车系统","防鎖死煞車系統"],["防锈","防鏽"],["防雨布","防雨布"],["阳历","陽曆"],["阳历年","陽曆年"],["阳台","陽臺"],["阳台云雨","陽臺雲雨"],["阳台春梦","陽臺春夢"],["阳春面","陽春麪"],["阳曲","陽曲"],["阳曲县","陽曲縣"],["阳极","陽極"],["阳极射线","陽極射線"],["阳极板","陽極板"],["阳极泥","陽極泥"],["阳电极","陽電極"],["阳秋","陽秋"],["阳虚发热","陽虛發熱"],["阳谷","陽谷"],["阳谷县","陽谷縣"],["阳面","陽面"],["阴丹布","陰丹布"],["阴云","陰雲"],["阴占","陰占"],["阴历","陰曆"],["阴历年","陰曆年"],["阴山背后","陰山背後"],["阴干","陰乾"],["阴恶","陰惡"],["阴暗","陰暗"],["阴暗处","陰暗處"],["阴暗面","陰暗面"],["阴极","陰極"],["阴极射线","陰極射線"],["阴极管","陰極管"],["阴核","陰核"],["阴沈","陰沈"],["阴沈沈","陰沈沈"],["阴沟里翻船","陰溝裏翻船"],["阴离子界面活性剂","陰離子界面活性劑"],["阴胜则寒","陰勝則寒"],["阴虚发热","陰虛發熱"],["阴郁","陰鬱"],["阴阳历","陰陽曆"],["阴阳合历","陰陽合曆"],["阴阴暗暗","陰陰暗暗"],["阴阴沈沈","陰陰沈沈"],["阴雕","陰雕"],["阴面","陰面"],["阵云","陣雲"],["阵发性","陣發性"],["阵线党","陣線黨"],["阵面上","陣面上"],["阶梯计价","階梯計價"],["阶级斗争","階級鬥爭"],["阻于","阻於"],["阻修","阻修"],["阻挡不了","阻擋不了"],["阻止不了","阻止不了"],["阿云","阿雲"],["阿什克隆","阿什克隆"],["阿仙药","阿仙藥"],["阿信曲","阿信曲"],["阿修罗","阿修羅"],["阿修罗道","阿修羅道"],["阿克伦","阿克倫"],["阿克伦河","阿克倫河"],["阿克塞县","阿克塞縣"],["阿克塞哈萨克族自治县","阿克塞哈薩克族自治縣"],["阿克拉","阿克拉"],["阿克苏","阿克蘇"],["阿克苏地区","阿克蘇地區"],["阿克苏市","阿克蘇市"],["阿克苏河","阿克蘇河"],["阿克赛钦","阿克賽欽"],["阿克达","阿克達"],["阿克陶","阿克陶"],["阿克陶县","阿克陶縣"],["阿党","阿黨"],["阿兹海默氏症","阿茲海默氏症"],["阿兹海默症","阿茲海默症"],["阿兹海默症病患","阿茲海默症病患"],["阿列克西斯","阿列克西斯"],["阿利托","阿利托"],["阿加莎克里斯蒂","阿加莎克里斯蒂"],["阿卜杜拉","阿卜杜拉"],["阿卡提里","阿卡提里"],["阿历山大","阿歷山大"],["阿叶德","阿葉德"],["阿合奇","阿合奇"],["阿合奇县","阿合奇縣"],["阿咸","阿咸"],["阿奇里斯","阿奇里斯"],["阿娘","阿孃"],["阿尔发粒子","阿爾發粒子"],["阿尔梅里亚","阿爾梅里亞"],["阿尔汉格尔斯克州","阿爾漢格爾斯克州"],["阿尔茨海默氏症","阿爾茨海默氏症"],["阿尔茨海默症","阿爾茨海默症"],["阿布","阿布"],["阿布加","阿布加"],["阿布叔醇","阿布叔醇"],["阿布哈兹","阿布哈茲"],["阿布尔","阿布爾"],["阿布扎比","阿布扎比"],["阿布扎比市","阿布扎比市"],["阿布杜拉","阿布杜拉"],["阿布杜拉曼","阿布杜拉曼"],["阿布沙伊夫","阿布沙伊夫"],["阿布沙耶夫","阿布沙耶夫"],["阿布瑞","阿布瑞"],["阿布瑞尤","阿布瑞尤"],["阿布贝卡","阿布貝卡"],["阿布贾","阿布賈"],["阿布贾里布","阿布賈里布"],["阿布达","阿布達"],["阿布达比","阿布達比"],["阿布雷尤","阿布雷尤"],["阿弥陀佛","阿彌陀佛"],["阿弥陀如来","阿彌陀如來"],["阿弥陀经","阿彌陀經"],["阿志","阿志"],["阿意曲从","阿意曲從"],["阿扎伦卡","阿紮倫卡"],["阿扎尼亚","阿扎尼亞"],["阿托品","阿托品"],["阿拉伯共同市场","阿拉伯共同市場"],["阿拉伯联合大公国","阿拉伯聯合大公國"],["阿拉伯联合酋长国","阿拉伯聯合酋長國"],["阿拉克","阿拉克"],["阿拉干山脉","阿拉乾山脈"],["阿斗","阿斗"],["阿斯图里亚斯","阿斯圖里亞斯"],["阿旺曲培","阿旺曲培"],["阿旺曲沛","阿旺曲沛"],["阿曼苏丹国","阿曼蘇丹國"],["阿朱","阿朱"],["阿杰","阿杰"],["阿松森岛","阿松森島"],["阿柏克兹亚","阿柏克茲亞"],["阿森松岛","阿森松島"],["阿波罗计划","阿波羅計劃"],["阿滋海默症","阿滋海默症"],["阿瓦里德","阿瓦里德"],["阿秋","阿秋"],["阿米巴原虫","阿米巴原蟲"],["阿米纳达布","阿米納達布"],["阿耳忒弥斯","阿耳忒彌斯"],["阿胡斯","阿胡斯"],["阿芝特克人","阿芝特剋人"],["阿芝特克语","阿芝特剋語"],["阿苏","阿蘇"],["阿苏山","阿蘇山"],["阿苏火山","阿蘇火山"],["阿蒙","阿蒙"],["阿谀苟合","阿諛苟合"],["阿贾克斯","阿賈克斯"],["阿赫蒂萨里","阿赫蒂薩裏"],["阿里","阿里"],["阿里亚斯","阿里亞斯"],["阿里地区","阿里地區"],["阿里山","阿里山"],["阿里山之歌","阿里山之歌"],["阿里山乡","阿里山鄉"],["阿里山区","阿里山區"],["阿里山山脉","阿里山山脈"],["阿里巴巴","阿里巴巴"],["阿里巴巴与四十大盗","阿里巴巴與四十大盜"],["阿里斯托芬","阿里斯托芬"],["阿里斯托芳","阿里斯託芳"],["阿里曼","阿里曼"],["阿里桑那","阿里桑那"],["阿里郎","阿里郎"],["附了","附了"],["附于","附於"],["附会假借","附會假借"],["附加价值","附加價值"],["附合","附合"],["附录","附錄"],["附注","附註"],["附膻逐秽","附膻逐穢"],["附膻逐腥","附膻逐腥"],["附膻逐臭","附膻逐臭"],["附致语","附致語"],["附表","附表"],["附面层","附面層"],["际会风云","際會風雲"],["陆丰","陸豐"],["陆丰市","陸豐市"],["陆云","陸雲"],["陆云浩","陸雲浩"],["陆克文","陸克文"],["陆均松","陸均松"],["陆征祥","陸徵祥"],["陆梁","陸梁"],["陆游","陸游"],["陆讋水栗","陸讋水慄"],["陆龟蒙","陸龜蒙"],["陇种","隴種"],["陈万松","陳萬松"],["陈万立","陳萬立"],["陈三五娘","陳三五娘"],["陈世杰","陳世杰"],["陈义丰","陳義豐"],["陈云","陳雲"],["陈云林","陳雲林"],["陈云程","陳雲程"],["陈俊杰","陳俊傑"],["陈克帆","陳克帆"],["陈冲","陳沖"],["陈列台","陳列臺"],["陈升","陳昇"],["陈同海","陳同海"],["陈后主","陳後主"],["陈嘉爵沈培智","陳嘉爵沈培智"],["陈尸","陳屍"],["陈尹杰","陳尹杰"],["陈布雷","陳布雷"],["陈希同","陳希同"],["陈幸","陳幸"],["陈幸妤","陳幸妤"],["陈幸嫚","陳倖嫚"],["陈建志","陳建志"],["陈志伟","陳志偉"],["陈志勇","陳志勇"],["陈志声","陳志聲"],["陈志强","陳志強"],["陈志忠","陳志忠"],["陈志明","陳志明"],["陈志玮","陳志瑋"],["陈志维","陳志維"],["陈志诚","陳志誠"],["陈志豪","陳志豪"],["陈志远","陳志遠"],["陈志鸿","陳志鴻"],["陈情表","陳情表"],["陈木胜","陳木勝"],["陈杰","陳杰"],["陈永丰","陳永豐"],["陈汉升","陳漢昇"],["陈瀛钟","陳瀛鐘"],["陈炼","陳鍊"],["陈秋婷","陳秋婷"],["陈秋扬","陳秋揚"],["陈秋火","陳秋火"],["陈胜","陳勝"],["陈胜在","陳勝在"],["陈胜宏","陳勝宏"],["陈胜福","陳勝福"],["陈致中","陳致中"],["陈致远","陳致遠"],["陈荣杰","陳榮傑"],["陈谷子烂芝麻","陳穀子爛芝麻"],["陈郁秀","陳郁秀"],["陈隆志","陳隆志"],["陈面谟","陳面謨"],["陈鼎击钟","陳鼎擊鐘"],["降了","降了"],["降于","降於"],["降价","降價"],["降价出售","降價出售"],["降价求售","降價求售"],["降升调","降升調"],["降压药","降壓藥"],["降噪","降噪"],["降回","降回"],["降回到","降回到"],["降回去","降回去"],["降回来","降回來"],["降志辱身","降志辱身"],["降血压药","降血壓藥"],["降血脂药","降血脂藥"],["降表","降表"],["限于","限於"],["限价","限價"],["限制","限制"],["限制住","限制住"],["限制住居","限制住居"],["限制器","限制器"],["限制式","限制式"],["限制性","限制性"],["限制是","限制是"],["限制类","限制類"],["限制级","限制級"],["限制词","限制詞"],["限制选举","限制選舉"],["限制酶","限制酶"],["限制酶图谱","限制酶圖譜"],["限尽","限盡"],["陕西师范大学","陝西師範大學"],["陕飞集团","陝飛集團"],["陡然升高","陡然升高"],["院系","院系"],["院里","院裏"],["除不尽","除不盡"],["除了","除了"],["除奸","除奸"],["除恶","除惡"],["除恶务尽","除惡務盡"],["除恶务本","除惡務本"],["除恶扶善","除惡扶善"],["除旧布新","除舊佈新"],["除臭药","除臭藥"],["除虫剂","除蟲劑"],["除虫菊","除蟲菊"],["陨获","隕穫"],["险恶","險惡"],["险症","險症"],["险胜","險勝"],["陪了","陪了"],["陪出","陪出"],["陪吊","陪弔"],["陪同","陪同"],["陪同到","陪同到"],["陪审制","陪審制"],["陪审制度","陪審制度"],["陪审团","陪審團"],["陵云","陵雲"],["陵土未干","陵土未乾"],["陵折","陵折"],["陵谷","陵谷"],["陶制","陶製"],["陶土制品","陶土製品"],["陶庵梦忆","陶庵夢憶"],["陶朱公","陶朱公"],["陶板屋","陶板屋"],["陶菲克","陶菲克"],["陷之死地而后生","陷之死地而後生"],["陷于","陷於"],["陷入困境","陷入困境"],["隆乳手术","隆乳手術"],["隆冬","隆冬"],["隆准","隆準"],["隆准许","隆准許"],["隆回","隆回"],["隆回县","隆回縣"],["隆极","隆極"],["隆河谷地","隆河谷地"],["随之而后","隨之而後"],["随于","隨於"],["随口胡诌","隨口胡謅"],["随同","隨同"],["随后","隨後"],["随后就到","隨後就到"],["随后就去","隨後就去"],["随后就来","隨後就來"],["随心所欲","隨心所欲"],["随想曲","隨想曲"],["随才器使","隨才器使"],["随时制宜","隨時制宜"],["隐于","隱於"],["隐修士","隱修士"],["隐修院","隱修院"],["隐几","隱几"],["隐占","隱佔"],["隐名合伙","隱名合夥"],["隐形涂料","隱形塗料"],["隐恶扬善","隱惡揚善"],["隐暗","隱暗"],["隐睪症","隱睪症"],["隐翅虫","隱翅蟲"],["隐身术","隱身術"],["隔了","隔了"],["隔出","隔出"],["隔出来","隔出來"],["隔别","隔別"],["隔向","隔向"],["隔周","隔週"],["隔山观虎斗","隔山觀虎鬥"],["隔年的皇历","隔年的皇曆"],["隔年皇历","隔年皇曆"],["隔房同辈","隔房同輩"],["隔断板","隔斷板"],["隔板","隔板"],["隔热板","隔熱板"],["隔舱板","隔艙板"],["隔音板","隔音板"],["隧道尽头的光亮","隧道盡頭的光亮"],["隧道症","隧道症"],["隶仆","隸僕"],["隶属于","隸屬於"],["难了","難了"],["难于","難於"],["难于上天","難於上天"],["难于接近","難於接近"],["难于登天","難於登天"],["难以出口","難以出口"],["难住了","難住了"],["难偿所愿","難償所願"],["难出","難出"],["难出手心","難出手心"],["难分难舍","難分難捨"],["难割难舍","難割難捨"],["难咽","難嚥"],["难容于","難容於"],["难当","難當"],["难当重任","難當重任"],["难得糊涂","難得糊塗"],["难挨","難捱"],["难控制","難控制"],["难施面目","難施面目"],["难易适中","難易適中"],["难舍","難捨"],["难舍难分","難捨難分"],["难舍难离","難捨難離"],["难荫","難廕"],["雀噪","雀噪"],["雁荡","雁蕩"],["雁荡山","雁蕩山"],["雄师百万","雄師百萬"],["雄心万丈","雄心萬丈"],["雄心壮志","雄心壯志"],["雄才","雄才"],["雄才大略","雄才大略"],["雄据一方","雄據一方"],["雄斗斗","雄斗斗"],["雄胜","雄勝"],["雅人深致","雅人深致"],["雅克","雅克"],["雅克萨","雅克薩"],["雅库次克","雅庫次克"],["雅游","雅游"],["雅筑","雅筑"],["雅致","雅緻"],["雅舍","雅舍"],["雅范","雅範"],["雅鲁藏布","雅魯藏布"],["雅鲁藏布大峡谷","雅魯藏布大峽谷"],["雅鲁藏布江","雅魯藏布江"],["集中托运","集中托運"],["集了","集了"],["集于","集於"],["集于一身","集於一身"],["集会游行法","集會遊行法"],["集体强奸","集體強姦"],["集合","集合"],["集合令","集合令"],["集合体","集合體"],["集合到","集合到"],["集合号","集合號"],["集合名词","集合名詞"],["集合地点","集合地點"],["集合式","集合式"],["集合时间","集合時間"],["集合点","集合點"],["集合论","集合論"],["集合起来","集合起來"],["集团","集團"],["集团主义","集團主義"],["集团军","集團軍"],["集团案","集團案"],["集团结婚","集團結婚"],["集团股","集團股"],["集录","集錄"],["集注","集註"],["集游法","集遊法"],["集电极","集電極"],["集训团","集訓團"],["集资合建","集資合建"],["雇主","僱主"],["雇于","僱於"],["雇人","僱人"],["雇佣","僱傭"],["雇农","僱農"],["雇到","僱到"],["雇员","僱員"],["雇工","僱工"],["雇用","僱用"],["雌核","雌核"],["雌雄同体","雌雄同體"],["雌雄同体人","雌雄同體人"],["雌雄同株","雌雄同株"],["雍容闲雅","雍容閒雅"],["雕丧","雕喪"],["雕丽","雕麗"],["雕云","雕雲"],["雕像","雕像"],["雕具座","鵰具座"],["雕出","雕出"],["雕凿","雕鑿"],["雕刻","雕刻"],["雕刻出","雕刻出"],["雕刻刀","雕刻刀"],["雕刻匠","雕刻匠"],["雕刻品","雕刻品"],["雕刻家","雕刻家"],["雕刻师","雕刻師"],["雕刻术","雕刻術"],["雕刻画","雕刻畫"],["雕励","雕勵"],["雕啄","雕啄"],["雕塑","雕塑"],["雕塑品","雕塑品"],["雕塑家","雕塑家"],["雕墙","雕牆"],["雕工","雕工"],["雕弓","雕弓"],["雕心雁爪","鵰心雁爪"],["雕悍","鵰悍"],["雕戈","雕戈"],["雕成","雕成"],["雕敝","雕敝"],["雕板","雕板"],["雕栏","雕欄"],["雕梁","雕樑"],["雕梁画柱","雕樑畫柱"],["雕梁画栋","雕樑畫棟"],["雕楹碧槛","雕楹碧檻"],["雕残","雕殘"],["雕漆","雕漆"],["雕版","雕版"],["雕版印刷","雕版印刷"],["雕琢","雕琢"],["雕瑑","雕瑑"],["雕砌","雕砌"],["雕空","雕空"],["雕章缋句","雕章繢句"],["雕章镂句","雕章鏤句"],["雕簇","雕簇"],["雕绘","雕繪"],["雕翎","鵰翎"],["雕翎扇","鵰翎扇"],["雕肝琢肾","雕肝琢腎"],["雕肝琢膂","雕肝琢膂"],["雕肝镂肾","雕肝鏤腎"],["雕胡米","雕胡米"],["雕色","雕色"],["雕花","雕花"],["雕花漆彩","雕花漆彩"],["雕虫","雕蟲"],["雕虫小技","雕蟲小技"],["雕虫小艺","雕蟲小藝"],["雕虫篆","雕蟲篆"],["雕虫篆刻","雕蟲篆刻"],["雕蚶镂蛤","雕蚶鏤蛤"],["雕谢","雕謝"],["雕镂","雕鏤"],["雕镌","雕鐫"],["雕零","雕零"],["雕青","雕青"],["雕题","雕題"],["雕飕","雕颼"],["雕饰","雕飾"],["雕饰品","雕飾品"],["雕骚","雕騷"],["雕鹗","鵰鶚"],["雕龙","雕龍"],["雨云","雨雲"],["雨余芳草斜阳","雨餘芳草斜陽"],["雨刮","雨刮"],["雨后","雨後"],["雨后春笋","雨後春筍"],["雨层云","雨層雲"],["雨布","雨布"],["雨散云收","雨散雲收"],["雨村曲话","雨村曲話"],["雨泽下注","雨澤下注"],["雨约云期","雨約雲期"],["雨花台","雨花臺"],["雨花台区","雨花臺區"],["雨魄云魂","雨魄雲魂"],["雩坛","雩壇"],["雪松","雪松"],["雪板","雪板"],["雪柜","雪櫃"],["雪狮子向火","雪獅子向火"],["雪窗萤几","雪窗螢几"],["雪耻复国","雪恥復國"],["雪耻报仇","雪恥報仇"],["雪茄烟","雪茄煙"],["雪里","雪裏"],["雪里红","雪裏紅"],["雪里蕻","雪裏蕻"],["雪里送炭","雪裏送炭"],["雪铲","雪鏟"],["零个","零個"],["零件厂","零件廠"],["零余","零餘"],["零余子","零餘子"],["零只","零隻"],["零周期","零週期"],["零售价","零售價"],["零售价格","零售價格"],["零多只","零多隻"],["零天后","零天後"],["零布","零布"],["零曲率","零曲率"],["零系数","零係數"],["雷云","雷雲"],["雷克","雷克"],["雷克南","雷克南"],["雷克坦跑道","雷克坦跑道"],["雷克斯","雷克斯"],["雷克斯暴龙","雷克斯暴龍"],["雷克萨斯","雷克薩斯"],["雷克雅维克","雷克雅維克"],["雷同","雷同"],["雷夫范恩斯","雷夫范恩斯"],["雷射血管成形术","雷射血管成形術"],["雷德克里夫","雷德克里夫"],["雷扎耶湖","雷扎耶湖"],["雷文克劳","雷文克勞"],["雷昂卡发洛","雷昂卡發洛"],["雷神进行曲","雷神進行曲"],["雷蒙","雷蒙"],["雷蒙德","雷蒙德"],["雷蒙德电","雷蒙德電"],["雷贾帕克斯","雷賈帕克斯"],["雷达搜索","雷達搜索"],["雷雨云","雷雨雲"],["雷霆万钧","雷霆萬鈞"],["雷霆万钧之势","雷霆萬鈞之勢"],["雷马克","雷馬克"],["雾台","霧臺"],["雾台乡","霧臺鄉"],["雾蒙蒙","霧濛濛"],["雾里","霧裏"],["雾里看花","霧裏看花"],["雾锁云埋","霧鎖雲埋"],["需才孔亟","需才孔亟"],["需求面","需求面"],["需要是发明之母","需要是發明之母"],["霁范","霽範"],["霁范永存","霽範永存"],["霄壤之别","霄壤之別"],["震于","震於"],["震天价响","震天價響"],["震旦方向","震旦方向"],["震栗","震慄"],["震波曲线","震波曲線"],["震源机制","震源機制"],["震耳欲聋","震耳欲聾"],["震荡","震盪"],["震荡不安","震盪不安"],["震荡性","震盪性"],["霉干菜","黴乾菜"],["霉毒","黴毒"],["霉气冲天","黴氣沖天"],["霉素","黴素"],["霉菌","黴菌"],["霉运当头","黴運當頭"],["霉黑","黴黑"],["霉黧","黴黧"],["霍乱杆菌","霍亂桿菌"],["霍克松","霍克松"],["霍克海姆","霍克海姆"],["霍尔布鲁克","霍爾布魯克"],["霍布斯","霍布斯"],["霍布森","霍布森"],["霍普曼杯","霍普曼杯"],["霍里","霍里"],["霑体涂足","霑體塗足"],["霓裳羽衣曲","霓裳羽衣曲"],["霜叶","霜葉"],["霞云","霞雲"],["霞彩","霞彩"],["霞表","霞表"],["露丑","露醜"],["露了","露了"],["露出","露出"],["露出了狐狸尾巴","露出了狐狸尾巴"],["露出原形","露出原形"],["露出去","露出去"],["露出来","露出來"],["露出破绽","露出破綻"],["露出马脚","露出馬腳"],["露台","露臺"],["露台弟子","露臺弟子"],["露复","露覆"],["露天开采","露天開採"],["露尸","露屍"],["露布","露布"],["露才","露才"],["露才扬己","露才揚己"],["露板","露板"],["露营休闲车旅游","露營休閒車旅遊"],["露面","露面"],["露面抛头","露面拋頭"],["霸占","霸佔"],["霸占住","霸佔住"],["霸才","霸才"],["霸据","霸據"],["霸术","霸術"],["霸王别姬","霸王別姬"],["霸陵折柳","霸陵折柳"],["霹雳游侠","霹靂遊俠"],["青云","青雲"],["青云之器","青雲之器"],["青云之士","青雲之士"],["青云志","青雲志"],["青云直上","青雲直上"],["青云谱","青雲譜"],["青云谱区","青雲譜區"],["青出于蓝","青出於藍"],["青出于蓝而胜于蓝","青出於藍而勝於藍"],["青发","青發"],["青叶","青葉"],["青少年团","青少年團"],["青山一发","青山一髮"],["青帘","青帘"],["青年党","青年黨"],["青年团","青年團"],["青年救国团","青年救國團"],["青康滇纵谷高原","青康滇縱谷高原"],["青杠","青槓"],["青松","青松"],["青果合作社","青果合作社"],["青海师范大学","青海師範大學"],["青灯黄卷","青燈黃卷"],["青烟","青煙"],["青瓦台","青瓦臺"],["青石板","青石板"],["青红皂白","青紅皁白"],["青苹","青苹"],["青苹果","青蘋果"],["青虫","青蟲"],["青蝇吊客","青蠅弔客"],["青过于蓝","青過於藍"],["青钱万选","青錢萬選"],["青霉","青黴"],["青霉素","青黴素"],["青面獠牙","青面獠牙"],["青鞋布袜","青鞋布襪"],["靖康传信录","靖康傳信錄"],["靖康要录","靖康要錄"],["静以制动","靜以制動"],["静修","靜修"],["静极思动","靜極思動"],["静脉曲张","靜脈曲張"],["静脉注入","靜脈注入"],["静脉注射","靜脈注射"],["静脉血栓症","靜脈血栓症"],["静舍","靜舍"],["静荡荡","靜蕩蕩"],["静配合","靜配合"],["静默致哀","靜默致哀"],["非于","非於"],["非借不可","非借不可"],["非党人士","非黨人士"],["非党员","非黨員"],["非出","非出"],["非出不可","非出不可"],["非占不可","非佔不可"],["非发不可","非發不可"],["非发光体","非發光體"],["非合并","非合併"],["非同","非同"],["非同儿戏","非同兒戲"],["非同容易","非同容易"],["非同寻常","非同尋常"],["非同小可","非同小可"],["非同步","非同步"],["非吸烟","非吸菸"],["非层岩","非層巖"],["非师范","非師範"],["非师范类","非師範類"],["非当","非當"],["非当不可","非當不可"],["非形象艺术","非形象藝術"],["非意相干","非意相干"],["非才","非才"],["非据","非據"],["非杠杆化","非槓桿化"],["非标准","非標準"],["非核","非核"],["非欧几何","非歐幾何"],["非欧几何学","非歐幾何學"],["非法勾当","非法勾當"],["非洲出血热","非洲出血熱"],["非洲团结组织","非洲團結組織"],["非洲大裂谷","非洲大裂谷"],["非洲开发银行","非洲開發銀行"],["非洲锥虫病","非洲錐蟲病"],["非涂不可","非塗不可"],["非游离辐射伤害","非游離輻射傷害"],["非确定性","非確定性"],["非种子","非種子"],["非签不可","非簽不可"],["非致命","非致命"],["非营业支出","非營業支出"],["非规范","非規範"],["非词重复测验","非詞重復測驗"],["非贸易创汇","非貿易創匯"],["靠了","靠了"],["靠前面","靠前面"],["靠后","靠後"],["靠后面","靠後面"],["靠外面","靠外面"],["靠外面走","靠外面走"],["靠水面","靠水面"],["靠里面","靠裏面"],["靠里面走","靠裏面走"],["靡不有初鲜克有终","靡不有初鮮克有終"],["靡然向风","靡然向風"],["面上","面上"],["面上无光","面上無光"],["面不改容","面不改容"],["面不改色","面不改色"],["面世","面世"],["面临","面臨"],["面临到","面臨到"],["面临困难","面臨困難"],["面交","面交"],["面人","麪人"],["面人儿","麪人兒"],["面从","面從"],["面价","麪價"],["面会","面會"],["面值","面值"],["面儿","面兒","麪兒"],["面允","面允"],["面光","面光"],["面具","面具"],["面分","面分"],["面刺","面刺"],["面前","面前"],["面包","麪包"],["面包刀","麪包刀"],["面包屑","麪包屑"],["面包师","麪包師"],["面包师傅","麪包師傅"],["面包店","麪包店"],["面包心","麪包心"],["面包房","麪包房"],["面包树","麪包樹"],["面包渣","麪包渣"],["面包片","麪包片"],["面包皮","麪包皮"],["面包粉","麪包粉"],["面包花","麪包花"],["面包车","麪包車"],["面北","面北"],["面北眉南","面北眉南"],["面厂","麪廠"],["面叙","面敘"],["面向","面向"],["面向对象的技术","面嚮對象的技術"],["面向对象语言","面嚮對象語言"],["面向连接","面向連接"],["面君","面君"],["面听","面聽"],["面呈","面呈"],["面告","面告"],["面命耳提","面命耳提"],["面商","面商"],["面善","面善"],["面善心恶","面善心惡"],["面善心狠","面善心狠"],["面嘱","面囑"],["面嘴","面嘴"],["面团","麪糰"],["面团团","面團團"],["面圆耳大","面圓耳大"],["面圣","面聖"],["面坊","麪坊"],["面坯儿","麪坯兒"],["面型","面型"],["面垢","面垢"],["面塑","麪塑"],["面墙","面牆"],["面墙而立","面牆而立"],["面壁","面壁"],["面壁下帷","面壁下帷"],["面壁功深","面壁功深"],["面壁坐禅","面壁坐禪"],["面壁思过","面壁思過"],["面奏","面奏"],["面如","面如"],["面如傅粉","面如傅粉"],["面如冠玉","面如冠玉"],["面如噀血","面如噀血"],["面如土色","面如土色"],["面如敷粉","面如敷粉"],["面如桃花","面如桃花"],["面如槁木","面如槁木"],["面如死灰","面如死灰"],["面如灰土","面如灰土"],["面如白纸","面如白紙"],["面如白蜡","面如白蠟"],["面如美玉","面如美玉"],["面如重枣","面如重棗"],["面如金纸","面如金紙"],["面如铁色","面如鐵色"],["面嫩","面嫩"],["面子","面子"],["面子上","面子上"],["面子上的人","面子上的人"],["面子上的差使","面子上的差使"],["面子上的话","面子上的話"],["面子情儿","面子情兒"],["面子药","麪子藥"],["面子话","面子話"],["面孔","面孔"],["面容","面容"],["面宽","面寬"],["面对","面對"],["面对现实","面對現實"],["面对面","面對面"],["面尘","面塵"],["面山","面山"],["面巾","面巾"],["面市","面市"],["面带","面帶"],["面带微笑","面帶微笑"],["面带忧容","面帶憂容"],["面带愁容","面帶愁容"],["面带病容","面帶病容"],["面带笑容","面帶笑容"],["面店","麪店"],["面庞","面龐"],["面弱","面弱"],["面形","面形"],["面影","面影"],["面心立方最密堆积","面心立方最密堆積"],["面恶","面惡"],["面恶心善","面惡心善"],["面情","面情"],["面折","面折"],["面折廷争","面折廷爭"],["面授","面授"],["面授机宜","面授機宜"],["面摊","麪攤"],["面摊子","麪攤子"],["面数","面數"],["面料","面料"],["面斥","面斥"],["面方口阔","面方口闊"],["面旋","面旋"],["面无","面無"],["面无人色","面無人色"],["面无血色","面無血色"],["面无表情","面無表情"],["面晤","面晤"],["面月印记","面月印記"],["面有","面有"],["面有喜色","面有喜色"],["面有忧色","面有憂色"],["面有菜色","面有菜色"],["面有难色","面有難色"],["面朋","面朋"],["面朝","面朝"],["面杖","麪杖"],["面杖吹火","麪杖吹火"],["面条","麪條"],["面条儿","麪條兒"],["面条目","麪條目"],["面板","面板"],["面板厂","面板廠"],["面板股","面板股"],["面染","面染"],["面桌","面桌"],["面條目","面條目"],["面水","面水"],["面汤","麪湯"],["面泛","面泛"],["面洽","面洽"],["面浆","麪漿"],["面海","面海"],["面灰","麪灰"],["面点","麪點"],["面点师","麪點師"],["面点王","麪點王"],["面熟","面熟"],["面版","面版"],["面甜","面甜"],["面生","面生"],["面生不熟","面生不熟"],["面疔","面疔"],["面疙瘩","麪疙瘩"],["面疱","面皰"],["面白无须","面白無鬚"],["面皂","面皂"],["面皮","麪皮"],["面皮厚","面皮厚"],["面皮失色","面皮失色"],["面皮焦黄","面皮焦黃"],["面皮薄","面皮薄"],["面皮铁青","面皮鐵青"],["面盆","面盆"],["面盘","面盤"],["面目","面目"],["面目一新","面目一新"],["面目全非","面目全非"],["面目可憎","面目可憎"],["面目清秀","面目清秀"],["面目狰狞","面目猙獰"],["面目黄瘦","面目黃瘦"],["面相","面相"],["面码儿","麪碼兒"],["面碗","麪碗"],["面票","麪票"],["面禀","面稟"],["面积","面積"],["面积分","面積分"],["面筋","麪筋"],["面粉","麪粉"],["面粉袋","麪粉袋"],["面糊","麪糊"],["面红","面紅"],["面红耳热","面紅耳熱"],["面红耳赤","面紅耳赤"],["面红过耳","面紅過耳"],["面红面赤","面紅面赤"],["面纱","面紗"],["面纸","面紙"],["面缚","面縛"],["面缚舆榇","面縛輿櫬"],["面缚衔璧","面縛銜璧"],["面缸","麪缸"],["面罄","面罄"],["面罩","面罩"],["面肥","麪肥"],["面膜","面膜"],["面致","面致"],["面般","面般"],["面色","面色"],["面色发白","面色發白"],["面色如土","面色如土"],["面色如生","面色如生"],["面色如金纸","面色如金紙"],["面色苍白","面色蒼白"],["面若春花","面若春花"],["面茶","麪茶"],["面薄","面薄"],["面薄腰纤","面薄腰纖"],["面衣","面衣"],["面西","面西"],["面见","面見"],["面见江东","面見江東"],["面誉","面譽"],["面誉背毁","面譽背譭"],["面议","面議"],["面试","面試"],["面试会","面試會"],["面试官","面試官"],["面试工作","面試工作"],["面请","面請"],["面谀","面諛"],["面谈","面談"],["面谒","面謁"],["面谕","面諭"],["面谢","面謝"],["面貌","面貌"],["面貌一新","面貌一新"],["面貌全非","面貌全非"],["面质","面質"],["面辞","面辭"],["面邀","面邀"],["面部","面部"],["面部表情","面部表情"],["面酱","麪醬"],["面重","面重"],["面门","面門"],["面阔口方","面闊口方"],["面陈","面陳"],["面霜","面霜"],["面露不悦","面露不悅"],["面霸","麪霸"],["面青脣白","面青脣白"],["面面","面面"],["面面俱全","面面俱全"],["面面俱到","面面俱到"],["面面俱圆","面面俱圓"],["面面厮觑","面面廝覷"],["面面相窥","面面相窺"],["面面相觑","面面相覷"],["面面观","面面觀"],["面靥","面靨"],["面颊","面頰"],["面颜","面顏"],["面额","面額"],["面食","麪食"],["面食类","麪食類"],["面饰","面飾"],["面饺","麪餃"],["面饼","麪餅"],["面馆","麪館"],["面首","面首"],["面驾","面駕"],["面黄","面黃"],["面黄肌瘦","面黃肌瘦"],["面黄肌闳","面黃肌閎"],["面黄脣白","面黃脣白"],["革出","革出"],["革出山门","革出山門"],["革出教门","革出教門"],["革制品","革製品"],["革命党","革命黨"],["革命党人","革命黨人"],["革命发展","革命發展"],["革命发展阶段论","革命發展階段論"],["革命干劲","革命幹勁"],["革命意志","革命意志"],["革命斗志","革命鬥志"],["革命积极","革命積極"],["革命积极性","革命積極性"],["革面","革面"],["革面洗心","革面洗心"],["靴后跟","靴後跟"],["靶台","靶臺"],["靶台上","靶臺上"],["鞋厂","鞋廠"],["鞋扣","鞋釦"],["鞋柜","鞋櫃"],["鞋里","鞋裏"],["鞋面","鞋面"],["鞠躬尽力","鞠躬盡力"],["鞠躬尽悴","鞠躬盡悴"],["鞠躬尽瘁","鞠躬盡瘁"],["鞠躬尽瘁死而后已","鞠躬盡瘁死而後已"],["鞣制","鞣製"],["鞭尸","鞭屍"],["鞭毛虫","鞭毛蟲"],["鞭虫","鞭蟲"],["鞭辟入里","鞭辟入裏"],["鞭辟近里","鞭辟近裏"],["韦后","韋后"],["韦娘","韋娘"],["韦布","韋布"],["韦布匹夫","韋布匹夫"],["韦布斯特","韋布斯特"],["韦庄","韋莊"],["韦陟朵云","韋陟朵雲"],["韧皮纤维","韌皮纖維"],["韩侂胄","韓侂冑"],["韩信登坛","韓信登壇"],["韩制","韓製"],["韩升洙","韓昇洙"],["韩国制","韓國製"],["韩国联合通讯社","韓國聯合通訊社"],["韩复矩","韓復榘"],["韩宗志","韓宗志"],["韩山师范学院","韓山師範學院"],["韩巴里","韓巴里"],["韩干","韓幹"],["韩干画马","韓幹畫馬"],["韩幸霖","韓幸霖"],["韩康卖药","韓康賣藥"],["韩彩英","韓彩英"],["韩海苏潮","韓海蘇潮"],["韩立克","韓立克"],["韩蒙德","韓蒙德"],["韫椟待价","韞櫝待價"],["韬戈卷甲","韜戈卷甲"],["音乐台","音樂臺"],["音乐团","音樂團"],["音乐系","音樂系"],["音像制品","音像製品"],["音准","音準"],["音同","音同"],["音声如钟","音聲如鐘"],["音系","音系"],["韵致","韻致"],["韶山冲","韶山沖"],["韶钢松山","韶鋼松山"],["頁面","頁面"],["页岩","頁岩"],["页面","頁面"],["顶个","頂個"],["顶了","頂了"],["顶凶","頂兇"],["顶叶","頂葉"],["顶回","頂回"],["顶回去","頂回去"],["顶回来","頂回來"],["顶多","頂多"],["顶夸克","頂夸克"],["顶板","頂板"],["顶核","頂核"],["顶梁柱","頂樑柱"],["顶梁骨走了真魂","頂梁骨走了真魂"],["顶针","頂針"],["顶针儿","頂針兒"],["顶针挨住","頂針捱住"],["顶门针","頂門針"],["顶面","頂面"],["项别骓","項別騅"],["项庄","項莊"],["项庄舞剑志在沛公","項莊舞劍志在沛公"],["项梁","項梁"],["项目表","項目表"],["项链","項鍊"],["顺于","順於"],["顺发","順發"],["顺向","順向"],["顺当","順當"],["顺德者吉逆天者凶","順德者吉逆天者凶"],["顺时针","順時針"],["顺时钟","順時鐘"],["顺朱儿","順硃兒"],["顺河回族区","順河回族區"],["顺适","順適"],["顺钟向","順鐘向"],["顺风后","順風後"],["须不是","須不是"],["须发","鬚髮"],["须发展","須發展"],["须发文","須發文"],["须发皆白","鬚髮皆白"],["须发表","須發表"],["须后水","鬚後水"],["须子","鬚子"],["须将有日思无日","須將有日思無日"],["须弥","須彌"],["须弥山","須彌山"],["须弥座","須彌座"],["须待","須待"],["须得","須得"],["须捷","須捷"],["须是","須是"],["须根","鬚根"],["须根据","須根據"],["须毛","鬚毛"],["须然","須然"],["须生","鬚生"],["须用","須用"],["须留","須留"],["须眉","鬚眉"],["须知","須知"],["须索","須索"],["须胡","鬚鬍"],["须至","須至"],["须臾","須臾"],["须菩堤","須菩堤"],["须虑","須慮"],["须要","須要"],["须陀洹","須陀洹"],["须须","鬚鬚"],["须髯","鬚髯"],["须髯如戟","鬚髯如戟"],["须鲨","鬚鯊"],["须鲸","鬚鯨"],["顽卤","頑鹵"],["顽症","頑症"],["顽童历险记","頑童歷險記"],["顽筑舞笈","頑筑舞笈"],["顽蒙","頑蒙"],["顾不了","顧不了"],["顾借","顧藉"],["顾前不顾后","顧前不顧後"],["顾前顾后","顧前顧後"],["顾后瞻前","顧後瞻前"],["顾复之恩","顧復之恩"],["顾念","顧念"],["顾曲","顧曲"],["顾曲周郎","顧曲周郎"],["顾正秋","顧正秋"],["顾问团","顧問團"],["顾面子","顧面子"],["顾颜面","顧顏面"],["顿了","頓了"],["顿涅斯克","頓涅斯克"],["顿涅茨克","頓涅茨克"],["颁出","頒出"],["颁发","頒發"],["颁发奖品","頒發獎品"],["颁发奖杯","頒發獎盃"],["颁发奖牌","頒發獎牌"],["颁发奖状","頒發獎狀"],["颁发奖金","頒發獎金"],["颁奖台","頒獎臺"],["颁布","頒佈"],["颂系","頌繫"],["颂赞","頌讚"],["预借","預借"],["预制","預製"],["预制构件","預製構件"],["预卜","預卜"],["预后","預後"],["预征","預徵"],["预想出","預想出"],["预托证券","預託證券"],["预扣","預扣"],["预料出","預料出"],["预期收入票据","預期收入票據"],["预测出","預測出"],["预算表","預算表"],["预警系统","預警系統"],["预防接种","預防接種"],["预防注射","預防注射"],["预防针","預防針"],["颅盖內出血","顱蓋內出血"],["颅顶叶","顱頂葉"],["领出","領出"],["领出去","領出去"],["领出来","領出來"],["领台","領檯"],["领回","領回"],["领回去","領回去"],["领回来","領回來"],["领域里","領域裏"],["领导制度","領導制度"],["领导干部","領導幹部"],["领带针","領帶針"],["领悟出","領悟出"],["领扣","領釦"],["领据","領據"],["领略出","領略出"],["领表","領表"],["领表格","領表格"],["领袖欲","領袖慾"],["颇复","頗覆"],["颇欲","頗欲"],["颈链","頸鍊"],["颊面","頰面"],["颊须","頰鬚"],["频危物种","頻危物種"],["频数分布","頻數分佈"],["频率合成","頻率合成"],["频率调制","頻率調製"],["颖脱而出","穎脫而出"],["题个","題個"],["题了","題了"],["题名录","題名錄"],["题库系统","題庫系統"],["题材范围","題材範圍"],["题材面","題材面"],["题签","題簽"],["颛制","顓制"],["颛蒙","顓蒙"],["颜回","顏回"],["颜志麟","顏志麟"],["颜范","顏範"],["颜面","顏面"],["颜面扫地","顏面掃地"],["颜面神经","顏面神經"],["颜面角","顏面角"],["颜面骨","顏面骨"],["额征","額徵"],["额我略历","額我略曆"],["额我略历史","額我略歷史"],["额贺福志郎","額賀福志郎"],["额面","額面"],["颟里颟顸","顢里顢頇"],["颠乾倒坤","顛乾倒坤"],["颠仆","顛仆"],["颠倒乾坤","顛倒乾坤"],["颠儿面","顛兒面"],["颠复","顛覆"],["颠复性","顛覆性"],["颠番面皮","顛番面皮"],["颠覆","顛覆"],["颠连困苦","顛連困苦"],["颠颠仆仆","顛顛仆仆"],["颤栗","顫慄"],["風采","風采"],["风举云摇","風舉雲搖"],["风云","風雲"],["风云不测","風雲不測"],["风云之志","風雲之志"],["风云人物","風雲人物"],["风云人物奖","風雲人物獎"],["风云变幻","風雲變幻"],["风云变态","風雲變態"],["风云变色","風雲變色"],["风云叱咤","風雲叱吒"],["风云开阖","風雲開闔"],["风云感会","風雲感會"],["风云月露","風雲月露"],["风云气候","風雲氣候"],["风云突变","風雲突變"],["风云车","風雲車"],["风云际会","風雲際會"],["风从虎云从龙","風從虎雲從龍"],["风入松","風入松"],["风兴云蒸","風興雲蒸"],["风刮","風颳"],["风力发电","風力發電"],["风卷","風捲"],["风卷残云","風捲殘雲"],["风发","風發"],["风后","風后"],["风向","風向"],["风向器","風向器"],["风向标","風向標"],["风向球","風向球"],["风向袋","風向袋"],["风向针","風向針"],["风吹两面倒","風吹兩面倒"],["风吹砂子迷了眼","風吹砂子迷了眼"],["风团","風團"],["风土志","風土誌"],["风在那里起雨在那里落","風在那裏起雨在那裏落"],["风尘仆仆","風塵僕僕"],["风尘恶俗","風塵惡俗"],["风尘表物","風塵表物"],["风干","風乾"],["风干机","風乾機"],["风情万种","風情萬種"],["风成砂岩","風成砂岩"],["风扫落叶","風掃落葉"],["风斗","風斗"],["风月宝鉴","風月寶鑑"],["风水术","風水術"],["风流云散","風流雲散"],["风流别致","風流別致"],["风流千古","風流千古"],["风流才子","風流才子"],["风流标致","風流標致"],["风流蕴借","風流蘊藉"],["风流酝借","風流醞藉"],["风浪板","風浪板"],["风湿症","風溼症"],["风溼性心脏病","風溼性心臟病"],["风烟","風煙"],["风物志","風物誌"],["风胡子","風胡子"],["风致","風致"],["风范","風範"],["风药","風藥"],["风虎云龙","風虎雲龍"],["风起云布","風起雲布"],["风起云涌","風起雲涌"],["风起云蒸","風起雲蒸"],["风轻云淡","風輕雲淡"],["风轻云淨","風輕雲淨"],["风速表","風速表"],["风采","風采"],["风采堂堂","風采堂堂"],["风里","風裏"],["风里杨花","風裏楊花"],["风里言","風裏言"],["风里语","風裏語"],["风铲","風鏟"],["风险与收益的关系","風險與收益的關係"],["风险防范","風險防範"],["风雨同舟","風雨同舟"],["风雨欲来","風雨欲來"],["风靡云涌","風靡雲涌"],["风靡云蒸","風靡雲蒸"],["风飞云会","風飛雲會"],["风马云车","風馬雲車"],["风马牛不相干","風馬牛不相干"],["风驰电卷","風馳電卷"],["飘出","飄出"],["飘向","飄向"],["飘回","飄回"],["飘摆","飄擺"],["飘游","飄遊"],["飘游四海","飄遊四海"],["飘然出世","飄然出世"],["飘荡","飄蕩"],["飘飘欲仙","飄飄欲仙"],["飘飘荡荡","飄飄蕩蕩"],["飙升","飆升"],["飙发电举","飆發電舉"],["飞个","飛個"],["飞了","飛了"],["飞云","飛雲"],["飞云掣电","飛雲掣電"],["飞出","飛出"],["飞出个未来","飛出個未來"],["飞出去","飛出去"],["飞出来","飛出來"],["飞刍挽粒","飛芻輓粒"],["飞刍挽粟","飛芻輓粟"],["飞刍挽粮","飛芻輓糧"],["飞升","飛昇"],["飞向","飛向"],["飞回","飛回"],["飞回去","飛回去"],["飞回来","飛回來"],["飞征","飛征"],["飞必冲天","飛必沖天"],["飞扎","飛紮"],["飞梁","飛樑"],["飞烟传","飛煙傳"],["飞燕游龙","飛燕游龍"],["飞粮挽秣","飛糧輓秣"],["飞腾之药","飛騰之藥"],["飞航资料记录器","飛航資料記錄器"],["飞虫","飛蟲"],["飞蚊症","飛蚊症"],["飞行云","飛行雲"],["飞行甲板","飛行甲板"],["飞行记录","飛行記錄"],["飞行记录仪","飛行記錄儀"],["飞行记录器","飛行記錄器"],["飞行钟","飛行鐘"],["飞谷","飛谷"],["飞车党","飛車黨"],["飞针走线","飛針走線"],["飞铲","飛鏟"],["飞鸟尽良弓藏","飛鳥盡良弓藏"],["飞龙乘云","飛龍乘雲"],["食不下咽","食不下咽"],["食不充饥","食不充飢"],["食不糊口","食不餬口"],["食品厂","食品廠"],["食品药品监督局","食品藥品監督局"],["食品药品监督管理局","食品藥品監督管理局"],["食心虫","食心蟲"],["食日万钱","食日萬錢"],["食欲","食慾"],["食欲不佳","食慾不佳"],["食欲不振","食慾不振"],["食物及药品管理局","食物及藥品管理局"],["食物柜","食物櫃"],["食物链","食物鏈"],["食用蜡烛木","食用蠟燭木"],["食虫植物","食蟲植物"],["食虫目","食蟲目"],["食虫虻","食蟲虻"],["食货志","食貨志"],["食野之苹","食野之苹"],["食面","食麪"],["飮胄","飮冑"],["餍于游乐","饜於游樂"],["餐台","餐檯"],["餐松啖柏","餐松啖柏"],["餐松食柏","餐松食柏"],["餐松饮涧","餐松飲澗"],["饥不可食寒不可衣","飢不可食寒不可衣"],["饥不择食","飢不擇食"],["饥冻交切","飢凍交切"],["饥困","飢困"],["饥寒","飢寒"],["饥寒交切","飢寒交切"],["饥寒交迫","飢寒交迫"],["饥年","饑年"],["饥民","饑民"],["饥渴","飢渴"],["饥渴交攻","飢渴交攻"],["饥渴交迫","飢渴交迫"],["饥溺","飢溺"],["饥火","飢火"],["饥火中焚","飢火中焚"],["饥火烧肠","飢火燒腸"],["饥者易为食","飢者易爲食"],["饥者甘糟糠","飢者甘糟糠"],["饥肠","飢腸"],["饥肠辘辘","飢腸轆轆"],["饥色","飢色"],["饥荒","饑荒"],["饥虎扑食","飢虎撲食"],["饥附饱飏","飢附飽颺"],["饥餐渴饮","飢餐渴飲"],["饥饱","飢飽"],["饥饿","飢餓"],["饥饿三十","飢餓三十"],["饥饿感","飢餓感"],["饥馁","飢餒"],["饥馑","饑饉"],["饥馑之岁","饑饉之歲"],["饥馑荐臻","饑饉薦臻"],["饥鹰饿虎","飢鷹餓虎"],["饬回","飭回"],["饭后","飯後"],["饭后服用","飯後服用"],["饭后漱口","飯後漱口"],["饭后百步走","飯後百步走"],["饭后钟","飯後鐘"],["饭团","飯糰"],["饭庄","飯莊"],["饭店回葱","飯店回蔥"],["饭店里买葱","飯店裏買蔥"],["饭饱生余事","飯飽生餘事"],["饮弹自尽","飲彈自盡"],["饮杯","飲杯"],["饮水曲肱","飲水曲肱"],["饯别","餞別"],["饰扣","飾釦"],["饰板","飾板"],["饰面","飾面"],["饱人不知饿人饥","飽人不知餓人飢"],["饱合","飽合"],["饱和化合物","飽和化合物"],["饱学秀才","飽學秀才"],["饱尝","飽嘗","飽嚐"],["饱当知人饥","飽當知人飢"],["饱暖思淫欲","飽暖思淫慾"],["饱暖生淫欲","飽暖生淫慾"],["饱汉不知饿汉饥","飽漢不知餓漢飢"],["饲养标准","飼養標準"],["饲喂","飼餵"],["饶舌歌曲","饒舌歌曲"],["饼干","餅乾"],["饼干店","餅乾店"],["饼干盒","餅乾盒"],["饿死了","餓死了"],["饿殍枕借","餓殍枕藉"],["饿虎饥鹰","餓虎飢鷹"],["馂余","餕餘"],["馄饨面","餛飩麪"],["馆舍","館舍"],["馆谷","館穀"],["馆里","館裏"],["馆际互借","館際互借"],["馋涎欲垂","饞涎欲垂"],["馋涎欲滴","饞涎欲滴"],["首丘夙愿","首丘夙願"],["首发","首發"],["首只","首隻"],["首台","首臺"],["首尔","首爾"],["首席代表","首席代表"],["首开纪录","首開紀錄"],["首当","首當"],["首当其冲","首當其衝"],["首恶","首惡"],["首部曲","首部曲"],["首都师范大学","首都師範大學"],["首都杯","首都盃"],["首长制","首長制"],["首面","首面"],["首须","首須"],["香干","香乾"],["香愿","香願"],["香斗","香斗"],["香格里拉","香格里拉"],["香格里拉县","香格裏拉縣"],["香格里拉怡咖啡","香格里拉怡咖啡"],["香榭丽舍","香榭麗舍"],["香榭丽舍大街","香榭麗舍大街"],["香榭里大道","香榭里大道"],["香港工会联合会","香港工會聯合會"],["香港游","香港遊"],["香港电台","香港電臺"],["香港贸易发展局","香港貿易發展局"],["香烟","香菸"],["香烟不绝","香煙不絕"],["香烟后代","香煙後代"],["香烟头","香菸頭"],["香烟盒","香菸盒"],["香熏","香薰"],["香熏疗法","香薰療法"],["香皂","香皂"],["香菜叶","香菜葉"],["香蜡","香蠟"],["香蜡店","香蠟店"],["香蜡纸马","香蠟紙馬"],["香蜡铺","香蠟鋪"],["香郁","香郁"],["馥郁","馥郁"],["馬占山","馬占山"],["馬格里布","馬格里布"],["马丁尼克","馬丁尼克"],["马丁杜里荷","馬丁杜里荷"],["马云","馬雲"],["马修连恩","馬修連恩"],["马修麦费狄恩","馬修麥費狄恩"],["马克","馬克"],["马克吐温","馬克吐溫"],["马克安东尼","馬克安東尼"],["马克安诺","馬克安諾"],["马克思","馬克思"],["马克思主义","馬克思主義"],["马克思列宁主义","馬克思列寧主義"],["马克数","馬克數"],["马克斯","馬克斯"],["马克斯主义","馬克斯主義"],["马克斯威尔","馬克斯威爾"],["马克斯普朗克","馬克斯普朗克"],["马克杯","馬克杯"],["马克沁","馬克沁"],["马克沁机枪","馬克沁機槍"],["马克笔","馬克筆"],["马克西米连","馬克西米連"],["马利布","馬利布"],["马占山","馬占山"],["马厂","馬廠"],["马厝卡舞曲","馬厝卡舞曲"],["马可波罗游记","馬可波羅遊記"],["马台","馬臺"],["马吊","馬吊"],["马后","馬後"],["马后炮","馬後炮"],["马后砲","馬後砲"],["马后练服","馬后練服"],["马噶尔尼使团","馬噶爾尼使團"],["马太受难曲","馬太受難曲"],["马夫","馬伕"],["马头娘","馬頭娘"],["马尔克奥雷利","馬爾克奧雷利"],["马尔扎赫","馬爾扎赫"],["马尔谷","馬爾谷"],["马尼托巴","馬尼托巴"],["马尾松","馬尾松"],["马布","馬布"],["马布瑞","馬布瑞"],["马干","馬乾"],["马德里","馬德里"],["马德里队","馬德里隊"],["马志英","馬志英"],["马戏团","馬戲團"],["马戏团表演","馬戲團表演"],["马戏表演","馬戲表演"],["马戛尔尼使团","馬戛爾尼使團"],["马扎","馬紮"],["马扎尔","馬扎爾"],["马扎尔语","馬扎爾語"],["马托格罗索","馬託格羅索"],["马拉巴栗","馬拉巴栗"],["马拉松","馬拉松"],["马拉松式","馬拉松式"],["马拉松组","馬拉松組"],["马拉松赛","馬拉松賽"],["马拉松赛跑","馬拉松賽跑"],["马提尼克","馬提尼克"],["马斯垂克","馬斯垂剋"],["马斯垂克条约","馬斯垂克條約"],["马斯特里赫特","馬斯特裏赫特"],["马普托","馬普托"],["马术","馬術"],["马术赛","馬術賽"],["马朱罗","馬朱羅"],["马杆","馬杆"],["马来亚玻里尼西亚语系","馬來亞玻里尼西亞語系"],["马杰明","馬傑明"],["马格里布","馬格里布"],["马桶里","馬桶裏"],["马死黄金尽","馬死黃金盡"],["马致远","馬致遠"],["马苏","馬蘇"],["马苏德","馬蘇德"],["马苏里拉","馬蘇裏拉"],["马表","馬錶"],["马车夫","馬車伕"],["马里亚纳","馬里亞納"],["马里亚纳海沟","馬裏亞納海溝"],["马里亚纳群岛","馬里亞納羣島"],["马里克","馬里克"],["马里兰","馬里蘭"],["马里兰州","馬里蘭州"],["马里内斯科","馬里內斯科"],["马里奇","馬里奇"],["马里奥","馬里奧"],["马里安纳海沟","馬里安納海溝"],["马里布","馬里布"],["马里斯","馬里斯"],["马面","馬面"],["马面战棚","馬面戰棚"],["马革裹尸","馬革裹屍"],["马鬣松","馬鬣松"],["驭兽术","馭獸術"],["驭夫有术","馭夫有術"],["驱出","驅出"],["驱恶向善","驅惡向善"],["驱虫","驅蟲"],["驱虫剂","驅蟲劑"],["驱虫效率","驅蟲效率"],["驱逐出","驅逐出"],["驱逐出境","驅逐出境"],["驳回","駁回"],["驳回去","駁回去"],["驳回来","駁回來"],["驳面子","駁面子"],["驴前马后","驢前馬後"],["驴蒙虎皮","驢蒙虎皮"],["驶出","駛出"],["驶向","駛向"],["驶回","駛回"],["驻台","駐臺"],["驻扎","駐紮"],["驻扎地","駐紮地"],["驻车制动","駐車制動"],["驻颜有术","駐顏有術"],["驽马十舍","駑馬十舍"],["驾了","駕了"],["驾云","駕雲"],["驾回","駕回"],["驾回去","駕回去"],["驾回来","駕回來"],["驾娘","駕娘"],["驾御","駕御"],["驾雾腾云","駕霧騰雲"],["驾鹤西游","駕鶴西遊"],["骀借","駘藉"],["骀荡","駘蕩"],["骂个","罵個"],["骂了","罵了"],["骋凶骋势","騁兇騁勢"],["骋志","騁志"],["验出","驗出"],["验尸","驗屍"],["验尸官","驗屍官"],["验收规范","驗收規範"],["验核","驗覈"],["骏业宏发","駿業宏發"],["骏发","駿發"],["骏豪集团","駿豪集團"],["骏马雕鞍","駿馬雕鞍"],["骑了","騎了"],["骑兵团","騎兵團"],["骑出","騎出"],["骑出去","騎出去"],["骑出来","騎出來"],["骑回","騎回"],["骑回去","騎回去"],["骑回来","騎回來"],["骑士团","騎士團"],["骑术","騎術"],["骗不了","騙不了"],["骗了","騙了"],["骗人布","騙人布"],["骗出","騙出"],["骗出去","騙出去"],["骗出来","騙出來"],["骗回","騙回"],["骗回去","騙回去"],["骗回来","騙回來"],["骗拐","騙拐"],["骗术","騙術"],["骗术奇谭","騙術奇譚"],["骨坛","骨罈"],["骨头里挣出来的钱才做得肉","骨頭裏掙出來的錢纔做得肉"],["骨子里","骨子裏"],["骨子里头","骨子裏頭"],["骨岩岩","骨巖巖"],["骨干","骨幹"],["骨干分子","骨幹分子"],["骨干网路","骨幹網路"],["骨折","骨折"],["骨灰坛","骨灰罈"],["骨肉团圆","骨肉團圓"],["骨肉团聚","骨肉團聚"],["骨肉团𪢮","骨肉團圞"],["骨质疏松","骨質疏鬆"],["骨质疏松症","骨質疏鬆症"],["骨质石化症","骨質石化症"],["骨质软化症","骨質軟化症"],["骨里骨碌","骨裏骨碌"],["骨针","骨針"],["骺软骨板","骺軟骨板"],["骾朴","骾朴"],["髀肉复生","髀肉復生"],["高个","高個"],["高个儿","高個兒"],["高个子","高個子"],["高丽参","高麗蔘"],["高了","高了"],["高于","高於"],["高云","高雲"],["高价","高價"],["高价位","高價位"],["高价股","高價股"],["高几","高几"],["高出","高出"],["高升","高升"],["高参","高參"],["高发","高發"],["高台","高臺"],["高台县","高臺縣"],["高周波","高周波"],["高唱入云","高唱入雲"],["高坛","高壇"],["高处不胜寒","高處不勝寒"],["高学历","高學歷"],["高尔基复合体","高爾基複合體"],["高尔察克","高爾察克"],["高层云","高層雲"],["高层建筑","高層建築"],["高山症","高山症"],["高岸深谷","高岸深谷"],["高干","高幹"],["高干扰","高干擾"],["高干预","高干預"],["高度自制","高度自制"],["高度表","高度表"],["高志尚","高志尚"],["高志纲","高志綱"],["高志航","高志航"],["高志鹏","高志鵬"],["高性价","高性價"],["高手如云","高手如雲"],["高才","高才"],["高才生","高才生"],["高技术","高技術"],["高抬身价","高擡身價"],["高挂","高掛"],["高政升","高政昇"],["高杆","高杆"],["高杠","高槓"],["高柏松","高柏松"],["高标准","高標準"],["高梁","高梁"],["高梁川","高梁川"],["高梁市","高梁市"],["高梁米","高梁米"],["高梁酒","高梁酒"],["高歌一曲","高歌一曲"],["高步云衢","高步雲衢"],["高水准","高水準"],["高清愿","高清愿"],["高球杯","高球杯"],["高票当选","高票當選"],["高积云","高積雲"],["高等师范","高等師範"],["高筋面粉","高筋麪粉"],["高纤","高纖"],["高纤维","高纖維"],["高级管理人才","高級管理人才"],["高耸入云","高聳入雲"],["高胄","高胄"],["高能烈性炸药","高能烈性炸藥"],["高脂血症","高脂血症"],["高脚杯","高腳杯"],["高致病性","高致病性"],["高致病性禽","高致病性禽"],["高良姜","高良薑"],["高英杰","高英傑"],["高血压症","高血壓症"],["高血压药","高血壓藥"],["高血脂症","高血脂症"],["高跳台","高跳臺"],["高郁淨","高郁淨"],["髡发","髡髮"],["髭胡","髭鬍"],["髭须","髭鬚"],["髯胡","髯鬍"],["髹饰录","髹飾錄"],["髼松","髼鬆"],["鬅松","鬅鬆"],["鬈发","鬈髮"],["鬈曲","鬈曲"],["鬒发","鬒髮"],["鬓云","鬢雲"],["鬓发","鬢髮"],["鬓发如银","鬢髮如銀"],["鬓发皆白","鬢髮皆白"],["鬓发皓然","鬢髮皓然"],["鬼出电入","鬼出電入"],["鬼录","鬼錄"],["鬼怕恶人","鬼怕惡人"],["鬼才","鬼才"],["鬼气冲天","鬼氣沖天"],["鬼片当道","鬼片當道"],["鬼胡油","鬼胡油"],["鬼胡由","鬼胡由"],["鬼谷子","鬼谷子"],["鬼迷了张天师","鬼迷了張天師"],["鬼针草","鬼針草"],["鬼门上占卦","鬼門上占卦"],["魁人党","魁人黨"],["魁北克","魁北克"],["魁北克市","魁北克市"],["魁北克省","魁北克省"],["魂不守舍","魂不守舍"],["魂牵梦系","魂牽夢繫"],["魏克","魏克"],["魏克菲尔","魏克菲爾"],["魏台复","魏臺復"],["魏幸雄","魏幸雄"],["魏征","魏徵"],["魏斯里史奈普","魏斯里史奈普"],["魏明谷","魏明谷"],["魏郁奇","魏郁奇"],["魔仆","魔僕"],["魔合罗","魔合羅"],["魔术","魔術"],["魔术家","魔術家"],["魔术师","魔術師"],["魔术数字","魔術數字"],["魔术方块","魔術方塊"],["魔术棒","魔術棒"],["魔术秀","魔術秀"],["魔术蛇","魔術蛇"],["魔术贴","魔術貼"],["魔术队","魔術隊"],["魔板","魔板"],["魔表","魔錶"],["魔赛克","魔賽克"],["鱼丸粗面","魚丸粗麪"],["鱼台","魚臺"],["鱼台县","魚臺縣"],["鱼头参政","魚頭參政"],["鱼尾板","魚尾板"],["鱼干","魚乾"],["鱼松","魚鬆"],["鱼板","魚板"],["鱼梁","魚梁"],["鱼沈雁杳","魚沈雁杳"],["鱼游釜中","魚游釜中"],["鱼游釜底","魚游釜底"],["鱼种","魚種"],["鱼篮宝卷","魚籃寶卷"],["鱼肉乡里","魚肉鄉里"],["鱼胄","魚冑"],["鱼虫","魚蟲"],["鱼贯而出","魚貫而出"],["鱼鳞松","魚鱗松"],["鱼鼓简板","魚鼓簡板"],["鲁克","魯克"],["鲁克斯","魯克斯"],["鲁毕克方块","魯畢克方塊"],["鲁般手里调大斧","魯般手裏調大斧"],["鲁适维","魯適維"],["鲇鱼","鮎魚"],["鲋鱼困涸辙难待西江水","鮒魚困涸轍難待西江水"],["鲍德里亚","鮑德里亞"],["鲜于","鮮于"],["鲜彩","鮮彩"],["鲜明个性","鮮明個性"],["鲜胄","鮮胄"],["鲜血淋漓","鮮血淋漓"],["鲜谷王","鮮穀王"],["鲸蜡","鯨蠟"],["鲸须","鯨鬚"],["鳃叶","鰓葉"],["鳌头独占","鰲頭獨佔"],["鳌里夺尊","鰲裏奪尊"],["鳝鱼面","鱔魚麪"],["鳞叶","鱗葉"],["鳞游","鱗游"],["鳞虫","鱗蟲"],["鳣舍","鱣舍"],["鸟卜","鳥卜"],["鸟尽弓藏","鳥盡弓藏"],["鸟松","鳥松"],["鸟松乡","鳥松鄉"],["鸟虫书","鳥蟲書"],["鸟里鸟气","鳥裏鳥氣"],["鸟面鹄形","鳥面鵠形"],["鸠占鹊巢","鳩佔鵲巢"],["鸠合","鳩合"],["鸠形鹄面","鳩形鵠面"],["鸡丝","雞絲"],["鸡丝面","雞絲麪"],["鸡争鹅斗","雞爭鵝鬥"],["鸡兔同笼","雞兔同籠"],["鸡口牛后","雞口牛後"],["鸡只","雞隻"],["鸡同鸭讲","雞同鴨講"],["鸡吵鹅斗","雞吵鵝鬥"],["鸡奸","雞姦"],["鸡尸牛从","雞尸牛從"],["鸡犬俱升","雞犬俱升"],["鸡犬升天","雞犬升天"],["鸡犬识新丰","雞犬識新豐"],["鸡皮栗子","雞皮栗子"],["鸡皮鹤发","雞皮鶴髮"],["鸡肤鹤发","雞膚鶴髮"],["鸡腿面","雞腿麪"],["鸡舍","雞舍"],["鸡虫得失","雞蟲得失"],["鸡蛋里挑骨头","雞蛋裏挑骨頭"],["鸡蛋面","雞蛋麪"],["鸣咽","鳴咽"],["鸣榔板","鳴榔板"],["鸣钟","鳴鐘"],["鸣钟列鼎","鳴鐘列鼎"],["鸦片烟","鴉片煙"],["鸦窝里出凤凰","鴉窩裏出鳳凰"],["鸭子划水","鴨子划水"],["鸳鸯折颈","鴛鴦折頸"],["鸷虫","鷙蟲"],["鸿志","鴻志"],["鸿案相庄","鴻案相莊"],["鸿篇巨制","鴻篇鉅製"],["鸿篇巨著","鴻篇鉅著"],["鸿胄","鴻胄"],["鸿范","鴻範"],["鸿蒙","鴻蒙"],["鸿运当头","鴻運當頭"],["鸿鹄之志","鴻鵠之志"],["鸿鹄大志","鴻鵠大志"],["鹄发","鵠髮"],["鹄志","鵠志"],["鹄面","鵠面"],["鹄面鸟形","鵠面鳥形"],["鹄面鸠形","鵠面鳩形"],["鹅准","鵝準"],["鹊噪","鵲噪"],["鹊巢鸠占","鵲巢鳩佔"],["鹍鸡曲","鵾雞曲"],["鹏程万里","鵬程萬里"],["鹘仑吞枣","鶻崙吞棗"],["鹤发","鶴髮"],["鹤发童颜","鶴髮童顏"],["鹤吊","鶴弔"],["鹤板","鶴板"],["鹤骨松姿","鶴骨松姿"],["鹰嘴豆面粉","鷹嘴豆麪粉"],["鹰扬万里","鷹揚萬里"],["鹰架栈台","鷹架棧臺"],["鹰雕","鷹鵰"],["鹿台","鹿臺"],["鹿谷","鹿谷"],["鹿谷乡","鹿谷鄉"],["鹿车共挽","鹿車共挽"],["鹿门采药","鹿門采藥"],["麟台","麟臺"],["麟游","麟遊"],["麟游县","麟遊縣"],["麟种","麟種"],["麦个子","麥個子"],["麦克","麥克"],["麦克伦堡","麥克倫堡"],["麦克尼尔","麥克尼爾"],["麦克拉伦","麥克拉倫"],["麦克斯","麥克斯"],["麦克斯韦","麥克斯韋"],["麦克林","麥克林"],["麦克林登","麥克林登"],["麦克格雷格","麥克格雷格"],["麦克白","麥克白"],["麦克白夫人","麥克白夫人"],["麦克米兰","麥克米蘭"],["麦克维","麥克維"],["麦克罗尼西亚人","麥克羅尼西亞人"],["麦克贝","麥克貝"],["麦克连","麥克連"],["麦克道格拉斯","麥克道格拉斯"],["麦克阿瑟","麥克阿瑟"],["麦克雷兰","麥克雷蘭"],["麦克雷兰说","麥克雷蘭說"],["麦克风","麥克風"],["麦冬","麥冬"],["麦卡托","麥卡托"],["麦可杰克森","麥可傑克森"],["麦可维克","麥可維克"],["麦布莱","麥布萊"],["麦当乐","麥當樂"],["麦当劳","麥當勞"],["麦当劳叔叔","麥當勞叔叔"],["麦当娜","麥當娜"],["麦托姆","麥托姆"],["麦格里","麥格里"],["麦特克","麥特克"],["麦特戴蒙","麥特戴蒙"],["麦秋","麥秋"],["麦科里","麥科里"],["麦穗","麥穗"],["麦穗两歧","麥穗兩歧"],["麦考马克","麥考馬克"],["麦考马克说","麥考馬克說"],["麦达克斯","麥達克斯"],["麸曲","麩曲"],["麸皮面包","麩皮麪包"],["麻了花儿","麻了花兒"],["麻做一团","麻做一團"],["麻叶皮","麻葉皮"],["麻吉死党","麻吉死黨"],["麻团","麻團"],["麻姑仙坛记","麻姑仙壇記"],["麻婆子的裹脚布","麻婆子的裹腳布"],["麻布","麻布"],["麻布袋","麻布袋"],["麻杆","麻桿"],["麻栗坡","麻栗坡"],["麻栗坡县","麻栗坡縣"],["麻油厂","麻油廠"],["麻痹不了","麻痹不了"],["麻痺不了","麻痺不了"],["麻胡","麻胡"],["麻药","麻藥"],["麻酱面","麻醬麪"],["麻醉药","麻醉藥"],["麻醉药品","麻醉藥品"],["麻醉针","麻醉針"],["麻雀在后","麻雀在後"],["麻雀虽小五脏俱全","麻雀雖小五臟俱全"],["麾之即去招则须来","麾之即去招則須來"],["黃鈺筑","黃鈺筑"],["黃长发","黃長發"],["黄上丰","黃上豐"],["黄世杰","黃世傑"],["黄东梁","黃東樑"],["黄了","黃了"],["黄仁杰","黃仁傑"],["黄仕杰","黃仕傑"],["黄俊杰","黃俊杰"],["黄克强","黃克強"],["黄凤秋","黃鳳秋"],["黄卷","黃卷"],["黄卷青灯","黃卷青燈"],["黄历","黃曆"],["黄发","黃髮"],["黄发儿齿","黃髮兒齒"],["黄发垂髫","黃髮垂髫"],["黄发鲐背","黃髮鮐背"],["黄同纸","黃同紙"],["黄嘉千","黃嘉千"],["黄天荡","黃天蕩"],["黄山谷","黃山谷"],["黄岩","黃岩"],["黄岩区","黃巖區"],["黄岩岛","黃巖島"],["黄州寒食诗卷","黃州寒食詩卷"],["黄干黑瘦","黃乾黑瘦"],["黄志中","黃志中"],["黄志伟","黃志偉"],["黄志勇","黃志勇"],["黄志强","黃志強"],["黄志成","黃志成"],["黄志玮","黃志瑋"],["黄志芳","黃志芳"],["黄志雄","黃志雄"],["黄志鹏","黃志鵬"],["黄志龙","黃志龍"],["黄旭升","黃旭昇"],["黄明志","黃明志"],["黄曲毒素","黃麴毒素"],["黄曲霉","黃麴黴"],["黄曲霉毒素","黃麴黴毒素"],["黄曲霉菌","黃麴黴菌"],["黄有才","黃有才"],["黄梁","黃梁"],["黄梁梦","黃梁夢"],["黄梁美梦","黃樑美夢"],["黄毛团儿","黃毛團兒"],["黄沙盖面","黃沙蓋面"],["黄河大合唱","黃河大合唱"],["黄炎贵胄","黃炎貴胄"],["黄珮筑","黃珮筑"],["黄白之术","黃白之術"],["黄石大峡谷","黃石大峽谷"],["黄石瀑布","黃石瀑布"],["黄秋庆","黃秋慶"],["黄秋燕","黃秋燕"],["黄秋生","黃秋生"],["黄秋葵","黃秋葵"],["黄种","黃種"],["黄种人","黃種人"],["黄老治术","黃老治術"],["黄育杰","黃育杰"],["黄色人种","黃色人種"],["黄色炸药","黃色炸藥"],["黄花后生","黃花後生"],["黄英杰","黃英傑"],["黄莺出谷","黃鶯出谷"],["黄菓树瀑布","黃菓樹瀑布"],["黄蜡","黃蠟"],["黄蝶翠谷","黃蝶翠谷"],["黄表纸","黃表紙"],["黄运杰","黃運傑"],["黄适卓","黃適卓"],["黄道周","黃道周"],["黄郁涵","黃郁涵"],["黄郁茹","黃郁茹"],["黄金入柜","黃金入櫃"],["黄金台","黃金臺"],["黄金周","黃金週"],["黄金存折","黃金存摺"],["黄金表","黃金錶"],["黄钟","黃鐘"],["黄钟大吕","黃鐘大呂"],["黄钟毁弃","黃鐘譭棄"],["黄钟长弃","黃鐘長棄"],["黄钰筑","黃鈺筑"],["黄雀在后","黃雀在後"],["黄须","黃鬚"],["黄鹰抓住了鹞子的脚","黃鷹抓住了鷂子的腳"],["黉舍","黌舍"],["黍谷生春","黍谷生春"],["黎明前的黑暗","黎明前的黑暗"],["黎曼几何","黎曼幾何"],["黎曼几何学","黎曼幾何學"],["黎曼曲面","黎曼曲面"],["黎曼面","黎曼面"],["黏了","黏了"],["黏合","黏合"],["黏合剂","黏合劑"],["黏合力","黏合力"],["黏合成","黏合成"],["黑不溜秋","黑不溜秋"],["黑了","黑了"],["黑云","黑雲"],["黑云母","黑雲母"],["黑亮发","黑亮髮"],["黑克索斯","黑克索斯"],["黑加仑","黑加侖"],["黑发","黑髮"],["黑发人","黑髮人"],["黑头虫","黑頭蟲"],["黑奴吁天录","黑奴籲天錄"],["黑尿症","黑尿症"],["黑布","黑布"],["黑手党","黑手黨"],["黑暗","黑暗"],["黑暗世界","黑暗世界"],["黑暗大陆","黑暗大陸"],["黑暗时代","黑暗時代"],["黑暗期","黑暗期"],["黑暗面","黑暗面"],["黑曜岩","黑曜岩"],["黑杰克","黑傑克"],["黑松","黑松"],["黑松汽水","黑松汽水"],["黑松沙士","黑松沙士"],["黑板","黑板"],["黑板报","黑板報"],["黑板擦","黑板擦"],["黑板树","黑板樹"],["黑气冲天","黑氣沖天"],["黑沈沈","黑沈沈"],["黑漆一团","黑漆一團"],["黑漆板凳","黑漆板凳"],["黑烟","黑煙"],["黑种","黑種"],["黑种人","黑種人"],["黑穗病","黑穗病"],["黑胡椒","黑胡椒"],["黑色棘皮症","黑色棘皮症"],["黑色火药","黑色火藥"],["黑色系","黑色系"],["黑豹党","黑豹黨"],["黑醋栗","黑醋栗"],["黑里","黑裏"],["黑面","黑麪"],["黑面包","黑麪包"],["黑面琵鹭","黑面琵鷺"],["黑须","黑鬚"],["黔南布依族苗族自治州","黔南布依族苗族自治州"],["黔西南布依族苗族自治州","黔西南布依族苗族自治州"],["默克","默克"],["默克尔","默克爾"],["默哀致意","默哀致意"],["默多克","默多克"],["默念","默唸"],["黛粉叶","黛粉葉"],["黝暗","黝暗"],["黥布","黥布"],["黥面","黥面"],["黮暗","黮闇"],["黯然欲绝","黯然欲絕"],["鼇头独占","鼇頭獨占"],["鼎折足","鼎折足"],["鼎泰丰","鼎泰豐"],["鼎食鸣钟","鼎食鳴鐘"],["鼓不打不响钟不撞不鸣","鼓不打不響鐘不撞不鳴"],["鼓出","鼓出"],["鼓出来","鼓出來"],["鼓台","鼓臺"],["鼓噪","鼓譟"],["鼓子曲","鼓子曲"],["鼓板","鼓板"],["鼓盆之戚","鼓盆之戚"],["鼓腹而游","鼓腹而遊"],["鼓荡","鼓盪"],["鼓足干劲","鼓足幹勁"],["鼓里","鼓裏"],["鼓面","鼓面"],["鼠得克","鼠得克"],["鼠曲草","鼠麴草"],["鼠疫杆菌","鼠疫桿菌"],["鼠肝虫臂","鼠肝蟲臂"],["鼠药","鼠藥"],["鼠面人","鼠面人"],["鼻中出火","鼻中出火"],["鼻准","鼻準"],["鼻出血","鼻出血"],["鼻咽","鼻咽"],["鼻头出火","鼻頭出火"],["鼻子上挂鲞鱼","鼻子上掛鯗魚"],["鼻子里笑","鼻子裏笑"],["鼻无梁柱","鼻無梁柱"],["鼻梁","鼻樑"],["鼻梁儿","鼻樑兒"],["鼻梁骨","鼻樑骨"],["鼻烟","鼻菸"],["鼻烟壶","鼻菸壺"],["鼻烟盒","鼻菸盒"],["鼻针疗法","鼻針療法"],["齐克果","齊克果"],["齐克隆","齊克隆"],["齐出","齊出"],["齐发","齊發"],["齐发式","齊發式"],["齐名并价","齊名並價"],["齐后破环","齊后破環"],["齐头并进","齊頭並進"],["齐姜","齊姜"],["齐庄","齊莊"],["齐心合力","齊心合力"],["齐心同力","齊心同力"],["齐心并力","齊心併力"],["齐打伙儿","齊打夥兒"],["齐梁世界","齊梁世界"],["齐梁体","齊梁體"],["齐民要术","齊民要術"],["齐烟九点","齊煙九點"],["齐王舍牛","齊王捨牛"],["齐足并驰","齊足並馳"],["齐足并驱","齊足並驅"],["齐驱并驾","齊驅並駕"],["齐驱并骤","齊驅並驟"],["齧合","齧合"],["齧蘗吞针","齧蘗吞針"],["齿危发秀","齒危髮秀"],["齿发","齒髮"],["齿录","齒錄"],["齿条千斤顶","齒條千斤頂"],["齿胄","齒胄"],["齿落发白","齒落髮白"],["龄虫","齡蟲"],["龙争虎斗","龍爭虎鬥"],["龙凤之表","龍鳳之表"],["龙利叶","龍利葉"],["龙卷","龍捲"],["龙卷风","龍捲風"],["龙发堂","龍發堂"],["龙团","龍團"],["龙困浅滩","龍困淺灘"],["龙岩","龍巖"],["龙岩市","龍巖市"],["龙岩村","龍巖村"],["龙嵩叶","龍嵩葉"],["龙斗虎伤","龍鬥虎傷"],["龙无云而不行","龍無雲而不行"],["龙游","龍遊"],["龙游县","龍遊縣"],["龙游浅水","龍游淺水"],["龙烟铁矿","龍煙鐵礦"],["龙眼干","龍眼乾"],["龙种","龍種"],["龙胄","龍胄"],["龙胜县","龍勝縣"],["龙虎并伏","龍虎並伏"],["龙虎斗","龍虎鬥"],["龙虾面","龍蝦麪"],["龙里","龍裏"],["龙里县","龍裏縣"],["龙钟","龍鍾"],["龙门吊","龍門吊"],["龙须","龍鬚"],["龙须友","龍鬚友"],["龙须沟","龍鬚溝"],["龙须茶","龍鬚茶"],["龙须草","龍鬚草"],["龙须菜","龍鬚菜"],["龙须面","龍鬚麪"],["龙龛手鉴","龍龕手鑑"],["龚照胜","龔照勝"],["龚胜","龔勝"],["龟卜","龜卜"],["龟鉴","龜鑑"]],"TSCharacters":[["㑮","𫝈"],["㑯","㑔"],["㑳","㑇"],["㑶","㐹"],["㒓","𠉂"],["㓄","𪠟"],["㓨","刾"],["㔋","𪟎"],["㖮","𪠵"],["㗲","𠵾"],["㗿","𪡛"],["㘉","𠰱"],["㘓","𪢌"],["㘔","㗷"],["㘚","㘎"],["㛝","𫝦"],["㜄","㚯"],["㜏","㛣"],["㜐","𫝧"],["㜗","𡞋"],["㜢","𡞱"],["㜷","𡝠"],["㞞","𪨊"],["㟺","𪩇"],["㠏","㟆"],["㢗","𪪑"],["㢝","𢋈"],["㥮","㤘"],["㦎","𢛯"],["㦛","𢗓"],["㦞","𪫷"],["㨻","𪮃"],["㩋","𪮋"],["㩜","㨫"],["㩳","㧐"],["㩵","擜"],["㪎","𪯋"],["㯤","𣘐"],["㰙","𣗙"],["㵗","𣳆"],["㵾","𪷍"],["㶆","𫞛"],["㷍","𤆢"],["㷿","𤈷"],["㸇","𤎺"],["㹽","𫞣"],["㺏","𤠋"],["㺜","𪺻"],["㻶","𪼋"],["㿖","𪽮"],["㿗","𤻊"],["㿧","𤽯"],["䀉","𥁢"],["䀹","𥅴"],["䁪","𥇢"],["䁻","䀥"],["䂎","𥎝"],["䃮","鿎"],["䅐","𫀨"],["䅳","𫀬"],["䆉","𫁂"],["䉑","𫁲"],["䉙","𥬀"],["䉬","𫂈"],["䉲","𥮜"],["䉶","𫁷"],["䊭","𥺅"],["䊷","䌶"],["䊺","𫄚"],["䋃","𫄜"],["䋔","𫄞"],["䋙","䌺"],["䋚","䌻"],["䋦","𫄩"],["䋹","䌿"],["䋻","䌾"],["䋼","𫄮"],["䋿","𦈓"],["䌈","𦈖"],["䌋","𦈘"],["䌖","𦈜"],["䌝","𦈟"],["䌟","𦈞"],["䌥","𦈠"],["䌰","𦈙"],["䍤","𫅅"],["䍦","䍠"],["䍽","𦍠"],["䎙","𫅭"],["䎱","䎬"],["䕤","𫟕"],["䕳","𦰴"],["䖅","𫟑"],["䗅","𫊪"],["䗿","𧉞"],["䙔","𫋲"],["䙡","䙌"],["䙱","𧜭"],["䚩","𫌯"],["䛄","𫍠"],["䛳","𫍫"],["䜀","䜧"],["䜖","𫟢"],["䝭","𫎧"],["䝻","𧹕"],["䝼","䞍"],["䞈","𧹑"],["䞋","𫎪"],["䞓","𫎭"],["䟃","𫎺"],["䟆","𫎳"],["䟐","𫎱"],["䠆","𫏃"],["䠱","𨅛"],["䡐","𫟤"],["䡩","𫟥"],["䡵","𫟦"],["䢨","𨑹"],["䤤","𫟺"],["䥄","𫠀"],["䥇","䦂"],["䥑","鿏"],["䥗","𫔋"],["䥩","𨱖"],["䥯","𫔆"],["䥱","䥾"],["䦘","𨸄"],["䦛","䦶"],["䦟","䦷"],["䦯","𫔵"],["䦳","𨷿"],["䧢","𨸟"],["䪊","𫖅"],["䪏","𩏼"],["䪗","𩐀"],["䪘","𩏿"],["䪴","𫖫"],["䪾","𫖬"],["䫀","𫖱"],["䫂","𫖰"],["䫟","𫖲"],["䫴","𩖗"],["䫶","𫖺"],["䫻","𫗇"],["䫾","𫠈"],["䬓","𫗊"],["䬘","𩙮"],["䬝","𩙯"],["䬞","𩙧"],["䬧","𫗟"],["䭀","𩠇"],["䭃","𩠈"],["䭑","𫗱"],["䭔","𫗰"],["䭿","𩧭"],["䮄","𫠊"],["䮝","𩧰"],["䮞","𩨁"],["䮠","𩧿"],["䮫","𩨇"],["䮰","𫘮"],["䮳","𩨏"],["䮾","𩧪"],["䯀","䯅"],["䯤","𩩈"],["䰾","鲃"],["䱀","𫚐"],["䱁","𫚏"],["䱙","𩾈"],["䱧","𫚠"],["䱬","𩾊"],["䱰","𩾋"],["䱷","䲣"],["䱸","𫠑"],["䱽","䲝"],["䲁","鳚"],["䲅","𫚜"],["䲖","𩾂"],["䲘","鳤"],["䲰","𪉂"],["䳜","𫛬"],["䳢","𫛰"],["䳤","𫛮"],["䳧","𫛺"],["䳫","𫛼"],["䴉","鹮"],["䴋","𫜅"],["䴬","𪎈"],["䴱","𫜒"],["䴴","𪎋"],["䴽","𫜔"],["䵳","𪑅"],["䵴","𫜙"],["䶕","𫜨"],["䶲","𫜳"],["万","万"],["丑","丑"],["丟","丢"],["並","并"],["丰","丰"],["么","么"],["乾","干","乾"],["亂","乱"],["了","了"],["于","于"],["云","云"],["亙","亘"],["亞","亚"],["仆","仆"],["仇","仇"],["价","价"],["仿","仿"],["伙","伙"],["佇","伫"],["佈","布"],["佔","占"],["余","余"],["佛","佛"],["佣","佣"],["併","并"],["來","来"],["侖","仑"],["侶","侣"],["侷","局"],["俁","俣"],["係","系"],["俊","俊"],["俓","𠇹"],["俔","伣"],["俠","侠"],["俥","伡"],["俬","私"],["修","修"],["倀","伥"],["倆","俩"],["倈","俫"],["倉","仓"],["個","个"],["們","们"],["倖","幸"],["借","借"],["倫","伦"],["倲","㑈"],["偉","伟"],["偑","㐽"],["側","侧"],["偵","侦"],["偽","伪"],["傌","㐷"],["傑","杰"],["傖","伧"],["傘","伞"],["備","备"],["傢","家"],["傭","佣"],["傯","偬"],["傳","传"],["傴","伛"],["債","债"],["傷","伤"],["傾","倾"],["僂","偻"],["僅","仅"],["僉","佥"],["僑","侨"],["僕","仆"],["僞","伪"],["僥","侥"],["僨","偾"],["僱","雇"],["僵","僵"],["價","价"],["儀","仪"],["儁","俊"],["儂","侬"],["億","亿"],["儈","侩"],["儉","俭"],["儎","傤"],["儐","傧"],["儔","俦"],["儕","侪"],["儘","尽","侭"],["償","偿"],["儣","𠆲"],["優","优"],["儭","𠋆"],["儲","储"],["儷","俪"],["儸","㑩"],["儺","傩"],["儻","傥"],["儼","俨"],["兇","凶"],["克","克"],["兌","兑"],["兒","儿"],["兗","兖"],["党","党"],["內","内"],["兩","两"],["冊","册"],["冑","胄"],["冪","幂"],["冬","冬"],["准","准"],["凈","净"],["凌","凌"],["凍","冻"],["凙","𪞝"],["凜","凛"],["几","几"],["凱","凯"],["凶","凶"],["出","出"],["划","划"],["別","别"],["刪","删"],["刮","刮"],["制","制"],["剄","刭"],["則","则"],["剋","克"],["剎","刹"],["剗","刬"],["剛","刚"],["剝","剥"],["剮","剐"],["剴","剀"],["創","创"],["剷","铲"],["剾","𠛅"],["劃","划","㓰"],["劇","剧"],["劉","刘"],["劊","刽"],["劌","刿"],["劍","剑"],["劏","㓥"],["劑","剂"],["劚","㔉"],["勁","劲"],["勑","𠡠"],["動","动"],["務","务"],["勛","勋"],["勝","胜"],["勞","劳"],["勢","势"],["勣","𪟝"],["勩","勚"],["勱","劢"],["勳","勋"],["勵","励"],["勸","劝"],["勻","匀"],["匭","匦"],["匯","汇"],["匱","匮"],["區","区"],["千","千"],["升","升"],["協","协"],["卜","卜"],["占","占"],["卷","卷"],["卹","恤"],["卻","却"],["卽","即"],["厂","厂"],["厘","厘"],["厙","厍"],["厠","厕"],["厤","历"],["厭","厌"],["厲","厉"],["厴","厣"],["參","参"],["叄","叁"],["叢","丛"],["只","只"],["台","台"],["叶","叶"],["吁","吁"],["合","合"],["吊","吊"],["同","同"],["后","后"],["向","向"],["吒","咤"],["吳","吴"],["吶","呐"],["呂","吕"],["周","周"],["咨","咨"],["咸","咸"],["咼","呙"],["咽","咽"],["哄","哄"],["員","员"],["哯","𠯟"],["唄","呗"],["唓","𪠳"],["唚","吣"],["唸","念"],["問","问"],["啓","启"],["啞","哑"],["啟","启"],["啢","唡"],["喂","喂"],["喎","㖞"],["喚","唤"],["喪","丧"],["喫","吃"],["喬","乔"],["單","单"],["喲","哟"],["嗆","呛"],["嗇","啬"],["嗊","唝"],["嗎","吗"],["嗚","呜"],["嗩","唢"],["嗰","𠮶"],["嗶","哔"],["嗹","𪡏"],["嘆","叹"],["嘍","喽"],["嘓","啯"],["嘔","呕"],["嘖","啧"],["嘗","尝"],["嘜","唛"],["嘩","哗"],["嘪","𪡃"],["嘮","唠"],["嘯","啸"],["嘰","叽"],["嘳","𪡞"],["嘵","哓"],["嘸","呒"],["嘺","𪡀"],["嘽","啴"],["噁","恶"],["噅","𠯠"],["噓","嘘"],["噚","㖊"],["噝","咝"],["噞","𪡋"],["噠","哒"],["噥","哝"],["噦","哕"],["噪","噪"],["噯","嗳"],["噲","哙"],["噴","喷"],["噸","吨"],["噹","当","𪠽"],["嚀","咛"],["嚇","吓"],["嚌","哜"],["嚐","尝"],["嚕","噜"],["嚙","啮"],["嚛","𪠸"],["嚥","咽"],["嚦","呖"],["嚧","𠰷"],["嚨","咙"],["嚮","向"],["嚲","亸"],["嚳","喾"],["嚴","严"],["嚶","嘤"],["嚽","𪢕"],["囀","啭"],["囁","嗫"],["囂","嚣"],["囃","𠱞"],["囅","冁"],["囈","呓"],["囉","啰"],["囌","苏"],["囑","嘱"],["囒","𪢠"],["回","回"],["囪","囱"],["困","困"],["圇","囵"],["國","国"],["圍","围"],["園","园"],["圓","圆"],["圖","图"],["團","团"],["圞","𪢮"],["坐","坐"],["垵","埯"],["埡","垭"],["埬","𪣆"],["埰","采"],["執","执"],["堅","坚"],["堊","垩"],["堖","垴"],["堚","𪣒"],["堝","埚"],["堯","尧"],["報","报"],["場","场"],["塊","块"],["塋","茔"],["塏","垲"],["塒","埘"],["塗","涂"],["塚","冢"],["塢","坞"],["塤","埙"],["塵","尘"],["塹","堑"],["塿","𪣻"],["墊","垫"],["墜","坠"],["墮","堕"],["墰","坛"],["墲","𪢸"],["墳","坟"],["墶","垯"],["墻","墙"],["墾","垦"],["壇","坛"],["壈","𡒄"],["壋","垱"],["壎","埙"],["壓","压"],["壗","𡋤"],["壘","垒"],["壙","圹"],["壚","垆"],["壜","坛"],["壞","坏"],["壟","垄"],["壠","垅"],["壢","坜"],["壣","𪤚"],["壩","坝"],["壪","塆"],["壯","壮"],["壺","壶"],["壼","壸"],["壽","寿"],["夠","够"],["夢","梦"],["夥","伙"],["夸","夸"],["夾","夹"],["奐","奂"],["奧","奥"],["奩","奁"],["奪","夺"],["奬","奖"],["奮","奋"],["奸","奸"],["奼","姹"],["妝","妆"],["姍","姗"],["姜","姜"],["姦","奸"],["娘","娘"],["娛","娱"],["婁","娄"],["婡","𫝫"],["婦","妇"],["婭","娅"],["媈","𫝨"],["媧","娲"],["媯","妫"],["媰","㛀"],["媼","媪"],["媽","妈"],["嫋","袅"],["嫗","妪"],["嫵","妩"],["嫺","娴"],["嫻","娴"],["嫿","婳"],["嬀","妫"],["嬃","媭"],["嬇","𫝬"],["嬈","娆"],["嬋","婵"],["嬌","娇"],["嬙","嫱"],["嬡","嫒"],["嬣","𪥰"],["嬤","嬷"],["嬦","𫝩"],["嬪","嫔"],["嬰","婴"],["嬸","婶"],["嬻","𪥿"],["孃","娘"],["孄","𫝮"],["孆","𫝭"],["孇","𪥫"],["孋","㛤"],["孌","娈"],["孎","𡠟"],["孫","孙"],["學","学"],["孻","𡥧"],["孾","𪧀"],["孿","孪"],["宮","宫"],["家","家"],["寀","采"],["寠","𪧘"],["寢","寝"],["實","实"],["寧","宁"],["審","审"],["寫","写"],["寬","宽"],["寵","宠"],["寶","宝"],["將","将"],["專","专"],["尋","寻"],["對","对"],["導","导"],["尷","尴"],["尸","尸"],["局","局"],["屆","届"],["屍","尸"],["屓","屃"],["屜","屉"],["屢","屡"],["層","层"],["屨","屦"],["屩","𪨗"],["屬","属"],["岡","冈"],["岩","岩"],["峯","峰"],["峴","岘"],["島","岛"],["峽","峡"],["崍","崃"],["崑","昆"],["崗","岗"],["崙","仑","𪨧"],["崢","峥"],["崬","岽"],["嵐","岚"],["嵗","岁"],["嵼","𡶴"],["嵾","㟥"],["嶁","嵝"],["嶄","崭"],["嶇","岖"],["嶈","𡺃"],["嶔","嵚"],["嶗","崂"],["嶘","𡺄"],["嶠","峤"],["嶢","峣"],["嶧","峄"],["嶨","峃"],["嶮","崄"],["嶴","岙"],["嶸","嵘"],["嶹","𫝵"],["嶺","岭"],["嶼","屿"],["嶽","岳"],["巊","𪩎"],["巋","岿"],["巒","峦"],["巔","巅"],["巖","岩"],["巗","𪨷"],["巘","𪩘"],["巨","巨"],["巰","巯"],["巹","卺"],["布","布"],["帘","帘"],["帥","帅"],["師","师"],["席","席"],["帳","帐"],["帶","带"],["幀","帧"],["幃","帏"],["幓","㡎"],["幗","帼"],["幘","帻"],["幝","𪩷"],["幟","帜"],["幣","币"],["幩","𪩸"],["幫","帮"],["幬","帱"],["干","干"],["幸","幸"],["幹","干"],["幺","幺"],["幾","几"],["广","广"],["座","座"],["庫","库"],["庵","庵"],["廁","厕"],["廂","厢"],["廄","厩"],["廈","厦"],["廎","庼"],["廕","荫"],["廚","厨"],["廝","厮"],["廟","庙"],["廠","厂"],["廡","庑"],["廢","废"],["廣","广"],["廧","𪪞"],["廩","廪"],["廬","庐","𪪏"],["廳","厅"],["弒","弑"],["弔","吊"],["弦","弦"],["弳","弪"],["張","张"],["強","强"],["彃","𪪼"],["彆","别"],["彈","弹"],["彌","弥"],["彎","弯"],["彔","录"],["彙","汇"],["彞","彝"],["彠","彟"],["彥","彦"],["彩","彩"],["彫","雕"],["彲","彨"],["彷","彷","仿"],["彿","佛"],["征","征"],["後","后"],["徑","径"],["從","从"],["徠","徕"],["御","御"],["復","复"],["徵","征","徵"],["徹","彻"],["徿","𪫌"],["志","志"],["念","念"],["恆","恒"],["恥","耻"],["悅","悦"],["悞","悮"],["悵","怅"],["悶","闷"],["悽","凄"],["惡","恶"],["惱","恼"],["惲","恽"],["惻","恻"],["愈","愈"],["愛","爱"],["愜","惬"],["愨","悫"],["愴","怆"],["愷","恺"],["愻","𢙏"],["愾","忾"],["愿","愿"],["慄","栗"],["態","态"],["慍","愠"],["慘","惨"],["慚","惭"],["慟","恸"],["慣","惯"],["慤","悫"],["慪","怄"],["慫","怂"],["慮","虑"],["慳","悭"],["慶","庆"],["慺","㥪"],["慼","戚"],["慾","欲"],["憂","忧"],["憊","惫"],["憐","怜"],["憑","凭"],["憒","愦"],["憖","慭"],["憚","惮"],["憢","𢙒"],["憤","愤"],["憫","悯"],["憮","怃"],["憲","宪"],["憶","忆"],["憸","𪫺"],["憹","𢙐"],["懀","𢙓"],["懇","恳"],["應","应"],["懌","怿"],["懍","懔"],["懎","𢠁"],["懞","蒙"],["懟","怼"],["懣","懑"],["懤","㤽"],["懨","恹"],["懲","惩"],["懶","懒"],["懷","怀"],["懸","悬"],["懺","忏"],["懼","惧"],["懾","慑"],["戀","恋"],["戇","戆"],["戔","戋"],["戚","戚"],["戧","戗"],["戩","戬"],["戰","战","𢧐"],["戱","戯"],["戲","戏"],["戶","户"],["才","才"],["扎","扎"],["托","托"],["扣","扣"],["折","折"],["拋","抛"],["拐","拐"],["拚","拚"],["挂","挂"],["挨","挨"],["挩","捝"],["挱","挲"],["挽","挽"],["挾","挟"],["捨","舍"],["捫","扪"],["据","据"],["捱","挨"],["捲","卷"],["掃","扫"],["掄","抡"],["掆","㧏"],["掗","挜"],["掙","挣"],["掚","𪭵"],["掛","挂"],["採","采"],["揀","拣"],["揚","扬"],["換","换"],["揮","挥"],["揯","搄"],["損","损"],["搖","摇"],["搗","捣"],["搜","搜"],["搵","揾"],["搶","抢"],["摋","𢫬"],["摐","𪭢"],["摑","掴"],["摜","掼"],["摟","搂"],["摯","挚"],["摳","抠"],["摶","抟"],["摺","折"],["摻","掺"],["撈","捞"],["撊","𪭾"],["撏","挦"],["撐","撑"],["撓","挠"],["撝","㧑"],["撟","挢"],["撣","掸"],["撥","拨"],["撧","𪮖"],["撫","抚"],["撲","扑"],["撳","揿"],["撻","挞"],["撾","挝"],["撿","捡"],["擁","拥"],["擄","掳"],["擇","择"],["擊","击"],["擋","挡"],["擓","㧟"],["擔","担"],["據","据"],["擟","𪭧"],["擠","挤"],["擡","抬"],["擣","捣","𢭏"],["擫","𢬍"],["擬","拟"],["擯","摈"],["擰","拧"],["擱","搁"],["擲","掷"],["擴","扩"],["擷","撷"],["擺","摆"],["擻","擞"],["擼","撸"],["擽","㧰"],["擾","扰"],["攄","摅"],["攆","撵"],["攋","𪮶"],["攏","拢"],["攔","拦"],["攖","撄"],["攙","搀"],["攛","撺"],["攜","携"],["攝","摄"],["攢","攒"],["攣","挛"],["攤","摊"],["攪","搅"],["攬","揽"],["敎","教"],["敓","敚"],["敗","败"],["敘","叙"],["敵","敌"],["數","数"],["斂","敛"],["斃","毙"],["斅","𢽾"],["斆","敩"],["斕","斓"],["斗","斗"],["斬","斩"],["斷","断"],["斸","𣃁"],["於","于","於"],["旂","旗"],["旣","既"],["昆","昆"],["昇","升"],["時","时"],["晉","晋"],["晝","昼"],["暈","晕"],["暉","晖"],["暗","暗"],["暘","旸"],["暢","畅"],["暫","暂"],["曄","晔"],["曆","历"],["曇","昙"],["曉","晓"],["曊","𪰶"],["曏","向"],["曖","暧"],["曠","旷"],["曥","𣆐"],["曨","昽"],["曬","晒"],["曲","曲"],["書","书"],["會","会"],["朥","𦛨"],["朧","胧"],["朮","术"],["朱","朱"],["朴","朴"],["杆","杆"],["杠","杠"],["杯","杯"],["杰","杰"],["東","东"],["杴","锨"],["松","松"],["板","板"],["极","极"],["枴","拐"],["柜","柜"],["柵","栅"],["柺","拐"],["査","查"],["栗","栗"],["核","核"],["桱","𣐕"],["桿","杆"],["梁","梁"],["梔","栀"],["梖","𪱷"],["梘","枧"],["條","条"],["梟","枭"],["梲","棁"],["棄","弃"],["棊","棋"],["棖","枨"],["棗","枣"],["棟","栋"],["棡","㭎"],["棧","栈"],["棱","棱"],["棲","栖"],["棶","梾"],["椏","桠"],["椲","㭏"],["楇","𣒌"],["楊","杨"],["楓","枫"],["楨","桢"],["業","业"],["極","极"],["榘","矩"],["榦","干"],["榪","杩"],["榮","荣"],["榲","榅"],["榿","桤"],["構","构"],["槍","枪"],["槓","杠"],["槤","梿"],["槧","椠"],["槨","椁"],["槫","𣏢"],["槮","椮"],["槳","桨"],["槶","椢"],["槼","椝"],["樁","桩"],["樂","乐"],["樅","枞"],["樑","梁"],["樓","楼"],["標","标"],["樞","枢"],["樠","𣗊"],["樢","㭤"],["樣","样"],["樤","𣔌"],["樧","榝"],["樫","㭴"],["樳","桪"],["樸","朴"],["樹","树"],["樺","桦"],["樿","椫"],["橈","桡"],["橋","桥"],["機","机"],["橢","椭"],["橫","横"],["橯","𣓿"],["檁","檩"],["檉","柽"],["檔","档"],["檜","桧"],["檟","槚"],["檢","检"],["檣","樯"],["檭","𣘴"],["檮","梼"],["檯","台"],["檳","槟"],["檵","𪲛"],["檸","柠"],["檻","槛"],["檾","𦼖"],["櫃","柜"],["櫅","𪲎"],["櫓","橹"],["櫚","榈"],["櫛","栉"],["櫝","椟"],["櫞","橼"],["櫟","栎"],["櫠","𪲮"],["櫥","橱"],["櫧","槠"],["櫨","栌"],["櫪","枥"],["櫫","橥"],["櫬","榇"],["櫱","蘖"],["櫳","栊"],["櫸","榉"],["櫺","棂"],["櫻","樱"],["欄","栏"],["欅","榉"],["欇","𪳍"],["權","权"],["欍","𣐤"],["欏","椤"],["欐","𪲔"],["欑","𪴙"],["欒","栾"],["欓","𣗋"],["欖","榄"],["欘","𣚚"],["欞","棂"],["欲","欲"],["欽","钦"],["歎","叹"],["歐","欧"],["歟","欤"],["歡","欢"],["歲","岁"],["歷","历"],["歸","归"],["歿","殁"],["殘","残"],["殞","殒"],["殢","𣨼"],["殤","殇"],["殨","㱮"],["殫","殚"],["殭","僵"],["殮","殓"],["殯","殡"],["殰","㱩"],["殲","歼"],["殺","杀"],["殻","壳"],["殼","壳"],["毀","毁"],["毆","殴"],["毊","𪵑"],["毿","毵"],["氂","牦"],["氈","毡"],["氌","氇"],["氣","气"],["氫","氢"],["氬","氩"],["氭","𣱝"],["氳","氲"],["氾","泛"],["汎","泛"],["汙","污"],["決","决"],["沈","沈","沉"],["沒","没"],["沖","冲"],["況","况"],["泛","泛"],["泝","溯"],["注","注"],["洩","泄"],["洶","汹"],["浹","浃"],["涂","涂"],["涇","泾"],["涌","涌"],["涗","涚"],["涼","凉"],["淀","淀"],["淒","凄"],["淚","泪"],["淥","渌"],["淨","净"],["淩","凌"],["淪","沦"],["淵","渊"],["淶","涞"],["淺","浅"],["渙","涣"],["減","减"],["渢","沨"],["渦","涡"],["測","测"],["游","游"],["渾","浑"],["湊","凑"],["湋","𣲗"],["湞","浈"],["湧","涌"],["湯","汤"],["溈","沩"],["準","准"],["溝","沟"],["溡","𪶄"],["溫","温"],["溮","浉"],["溳","涢"],["溼","湿"],["滄","沧"],["滅","灭"],["滌","涤"],["滎","荥"],["滙","汇"],["滬","沪"],["滯","滞"],["滲","渗"],["滷","卤"],["滸","浒"],["滻","浐"],["滾","滚"],["滿","满"],["漁","渔"],["漊","溇"],["漓","漓"],["漚","沤"],["漢","汉"],["漣","涟"],["漬","渍"],["漲","涨"],["漵","溆"],["漸","渐"],["漿","浆"],["潁","颍"],["潑","泼"],["潔","洁"],["潕","𣲘"],["潙","沩"],["潚","㴋"],["潛","潜"],["潣","𫞗"],["潤","润"],["潯","浔"],["潰","溃"],["潷","滗"],["潿","涠"],["澀","涩"],["澅","𣶩"],["澆","浇"],["澇","涝"],["澐","沄"],["澗","涧"],["澠","渑"],["澤","泽"],["澦","滪"],["澩","泶"],["澬","𫞚"],["澮","浍"],["澱","淀"],["澾","㳠"],["濁","浊"],["濃","浓"],["濄","㳡"],["濆","𣸣"],["濕","湿"],["濘","泞"],["濚","溁"],["濛","蒙"],["濜","浕"],["濟","济"],["濤","涛"],["濧","㳔"],["濫","滥"],["濰","潍"],["濱","滨"],["濺","溅"],["濼","泺"],["濾","滤"],["濿","𪵱"],["瀂","澛"],["瀃","𣽷"],["瀅","滢"],["瀆","渎"],["瀇","㲿"],["瀉","泻"],["瀋","沈","渖"],["瀏","浏"],["瀕","濒"],["瀘","泸"],["瀝","沥"],["瀟","潇"],["瀠","潆"],["瀦","潴"],["瀧","泷"],["瀨","濑"],["瀰","弥","㳽"],["瀲","潋"],["瀾","澜"],["灃","沣"],["灄","滠"],["灍","𫞝"],["灑","洒"],["灒","𪷽"],["灕","漓"],["灘","滩"],["灙","𣺼"],["灝","灏"],["灡","㳕"],["灣","湾"],["灤","滦"],["灧","滟"],["灩","滟"],["災","灾"],["為","为"],["烏","乌"],["烴","烃"],["無","无"],["煇","𪸩"],["煉","炼"],["煒","炜"],["煙","烟"],["煢","茕"],["煥","焕"],["煩","烦"],["煬","炀"],["煱","㶽"],["熂","𪸕"],["熅","煴"],["熉","𤈶"],["熌","𤇄"],["熏","熏"],["熒","荧"],["熓","𤆡"],["熗","炝"],["熚","𤇹"],["熡","𤋏"],["熱","热"],["熲","颎"],["熾","炽"],["燁","烨"],["燈","灯"],["燉","炖"],["燒","烧"],["燙","烫"],["燜","焖"],["營","营"],["燦","灿"],["燬","毁"],["燭","烛"],["燴","烩"],["燶","㶶"],["燻","熏"],["燼","烬"],["燾","焘"],["爃","𫞡"],["爄","𤇃"],["爇","𦶟"],["爍","烁"],["爐","炉"],["爖","𤇭"],["爛","烂"],["爥","𪹳"],["爧","𫞠"],["爭","争"],["爲","为"],["爺","爷"],["爾","尔"],["牀","床"],["牆","墙"],["牘","牍"],["牴","牴","抵"],["牽","牵"],["犖","荦"],["犛","牦"],["犞","𪺭"],["犢","犊"],["犧","牺"],["狀","状"],["狹","狭"],["狽","狈"],["猌","𪺽"],["猙","狰"],["猶","犹"],["猻","狲"],["獁","犸"],["獃","呆"],["獄","狱"],["獅","狮"],["獊","𪺷"],["獎","奖"],["獨","独"],["獩","𤞃"],["獪","狯"],["獫","猃"],["獮","狝"],["獰","狞"],["獱","㺍"],["獲","获"],["獵","猎"],["獷","犷"],["獸","兽"],["獺","獭"],["獻","献"],["獼","猕"],["玀","猡"],["玁","𤞤"],["珼","𫞥"],["現","现"],["琱","雕"],["琺","珐"],["琿","珲"],["瑋","玮"],["瑒","玚"],["瑣","琐"],["瑤","瑶"],["瑩","莹"],["瑪","玛"],["瑲","玱"],["瑻","𪻲"],["瑽","𪻐"],["璉","琏"],["璊","𫞩"],["璝","𪻺"],["璡","琎"],["璣","玑"],["璦","瑷"],["璫","珰"],["璯","㻅"],["環","环"],["璵","玙"],["璸","瑸"],["璼","𫞨"],["璽","玺"],["璾","𫞦"],["瓄","𪻨"],["瓊","琼"],["瓏","珑"],["瓔","璎"],["瓕","𤦀"],["瓚","瓒"],["瓛","𤩽"],["瓮","瓮"],["甌","瓯"],["甕","瓮"],["產","产"],["産","产"],["甦","苏"],["甯","宁"],["畝","亩"],["畢","毕"],["畫","画","划"],["異","异"],["畵","画"],["當","当"],["畼","𪽈"],["疇","畴"],["疊","叠"],["症","症"],["痙","痉"],["痠","酸"],["痮","𪽪"],["痾","疴"],["瘂","痖"],["瘋","疯"],["瘍","疡"],["瘓","痪"],["瘞","瘗"],["瘡","疮"],["瘧","疟"],["瘮","瘆"],["瘱","𪽷"],["瘲","疭"],["瘺","瘘"],["瘻","瘘"],["療","疗"],["癆","痨"],["癇","痫"],["癉","瘅"],["癐","𤶊"],["癒","愈"],["癘","疠"],["癟","瘪"],["癡","痴"],["癢","痒"],["癤","疖"],["癥","症"],["癧","疬"],["癩","癞"],["癬","癣"],["癭","瘿"],["癮","瘾"],["癰","痈"],["癱","瘫"],["癲","癫"],["發","发"],["皁","皂"],["皚","皑"],["皟","𤾀"],["皰","疱"],["皸","皲"],["皺","皱"],["盃","杯"],["盜","盗"],["盞","盏"],["盡","尽"],["監","监"],["盤","盘"],["盧","卢"],["盨","𪾔"],["盪","荡"],["眝","𪾣"],["眞","真"],["眥","眦"],["眾","众"],["睍","𪾢"],["睏","困"],["睜","睁"],["睞","睐"],["睪","睾","睪"],["瞘","眍"],["瞜","䁖"],["瞞","瞒"],["瞤","𥆧"],["瞭","瞭","了"],["瞶","瞆"],["瞼","睑"],["矇","蒙"],["矉","𪾸"],["矑","𪾦"],["矓","眬"],["矚","瞩"],["矩","矩"],["矯","矫"],["硃","朱"],["硜","硁"],["硤","硖"],["硨","砗"],["确","确"],["硯","砚"],["碕","埼"],["碙","𥐻"],["碩","硕"],["碭","砀"],["碸","砜"],["確","确"],["碼","码"],["碽","䂵"],["磑","硙"],["磚","砖"],["磠","硵"],["磣","碜"],["磧","碛"],["磯","矶"],["磽","硗"],["磾","䃅"],["礄","硚"],["礆","硷"],["礎","础"],["礒","𥐟"],["礙","碍"],["礦","矿"],["礪","砺"],["礫","砾"],["礬","矾"],["礮","𪿫"],["礱","砻"],["祇","祇","只"],["祕","秘"],["祘","祘"],["祿","禄"],["禍","祸"],["禎","祯"],["禕","祎"],["禡","祃"],["禦","御"],["禪","禅"],["禮","礼"],["禰","祢"],["禱","祷"],["禿","秃"],["私","私"],["秈","籼"],["秋","秋"],["种","种"],["稅","税"],["稈","秆"],["稏","䅉"],["稜","棱"],["稟","禀"],["種","种"],["稱","称"],["穀","谷"],["穇","䅟"],["穌","稣"],["積","积"],["穎","颖"],["穗","穗"],["穠","秾"],["穡","穑"],["穢","秽"],["穩","稳"],["穫","获"],["穭","穞"],["窩","窝"],["窪","洼"],["窮","穷"],["窯","窑"],["窵","窎"],["窶","窭"],["窺","窥"],["竄","窜"],["竅","窍"],["竇","窦"],["竈","灶"],["竊","窃"],["竚","𥩟"],["竪","竖"],["竱","𫁟"],["競","竞"],["筆","笔"],["筍","笋"],["筑","筑"],["筧","笕"],["筴","䇲"],["箇","个"],["箋","笺"],["箏","筝"],["節","节"],["範","范"],["築","筑"],["篋","箧"],["篔","筼"],["篘","𥬠"],["篠","筿"],["篤","笃"],["篩","筛"],["篳","筚"],["篸","𥮾"],["簀","箦"],["簂","𫂆"],["簍","篓"],["簑","蓑"],["簞","箪"],["簡","简"],["簢","𫂃"],["簣","篑"],["簫","箫"],["簹","筜"],["簽","签"],["簾","帘"],["籃","篮"],["籅","𥫣"],["籋","𥬞"],["籌","筹"],["籔","䉤"],["籙","箓"],["籛","篯"],["籜","箨"],["籟","籁"],["籠","笼"],["籤","签"],["籩","笾"],["籪","簖"],["籬","篱"],["籮","箩"],["籲","吁"],["粵","粤"],["糉","粽"],["糝","糁"],["糞","粪"],["糧","粮"],["糰","团"],["糲","粝"],["糴","籴"],["糶","粜"],["糹","纟"],["糺","𫄙"],["系","系"],["糾","纠"],["紀","纪"],["紂","纣"],["約","约"],["紅","红"],["紆","纡"],["紇","纥"],["紈","纨"],["紉","纫"],["紋","纹"],["納","纳"],["紐","纽"],["紓","纾"],["純","纯"],["紕","纰"],["紖","纼"],["紗","纱"],["紘","纮"],["紙","纸"],["級","级"],["紛","纷"],["紜","纭"],["紝","纴"],["紟","𫄛"],["紡","纺"],["紬","䌷"],["紮","扎"],["累","累"],["細","细"],["紱","绂"],["紲","绁"],["紳","绅"],["紵","纻"],["紹","绍"],["紺","绀"],["紼","绋"],["紿","绐"],["絀","绌"],["絁","𫄟"],["終","终"],["絃","弦"],["組","组"],["絅","䌹"],["絆","绊"],["絍","𫟃"],["絎","绗"],["結","结"],["絕","绝"],["絙","𫄠"],["絛","绦"],["絝","绔"],["絞","绞"],["絡","络"],["絢","绚"],["絥","𫄢"],["給","给"],["絧","𫄡"],["絨","绒"],["絰","绖"],["統","统"],["絲","丝"],["絳","绛"],["絶","绝"],["絹","绢"],["絺","𫄨"],["綀","𦈌"],["綁","绑"],["綃","绡"],["綆","绠"],["綇","𦈋"],["綈","绨"],["綉","绣"],["綋","𫟄"],["綌","绤"],["綏","绥"],["綐","䌼"],["綑","捆"],["經","经"],["綖","𫄧"],["綜","综"],["綞","缍"],["綟","𫄫"],["綠","绿"],["綡","𫟅"],["綢","绸"],["綣","绻"],["綫","线"],["綬","绶"],["維","维"],["綯","绹"],["綰","绾"],["綱","纲"],["網","网"],["綳","绷"],["綴","缀"],["綵","彩","䌽"],["綸","纶"],["綹","绺"],["綺","绮"],["綻","绽"],["綽","绰"],["綾","绫"],["綿","绵"],["緄","绲"],["緇","缁"],["緊","紧"],["緋","绯"],["緍","𦈏"],["緑","绿"],["緒","绪"],["緓","绬"],["緔","绱"],["緗","缃"],["緘","缄"],["緙","缂"],["線","线","缐"],["緝","缉"],["緞","缎"],["緟","𫟆"],["締","缔"],["緡","缗"],["緣","缘"],["緤","𫄬"],["緦","缌"],["編","编"],["緩","缓"],["緬","缅"],["緮","𫄭"],["緯","纬"],["緰","𦈕"],["緱","缑"],["緲","缈"],["練","练"],["緶","缏"],["緷","𦈉"],["緸","𦈑"],["緹","缇"],["緻","致"],["緼","缊"],["縈","萦"],["縉","缙"],["縊","缢"],["縋","缒"],["縍","𫄰"],["縎","𦈔"],["縐","绉"],["縑","缣"],["縕","缊"],["縗","缞"],["縛","缚"],["縝","缜"],["縞","缟"],["縟","缛"],["縣","县"],["縧","绦"],["縫","缝"],["縬","𦈚"],["縭","缡"],["縮","缩"],["縰","𫄳"],["縱","纵"],["縲","缧"],["縳","䌸"],["縴","纤"],["縵","缦"],["縶","絷"],["縷","缕"],["縸","𫄲"],["縹","缥"],["縺","𦈐"],["總","总"],["績","绩"],["繂","𫄴"],["繃","绷"],["繅","缫"],["繆","缪"],["繈","𫄶"],["繏","𦈝"],["繐","穗"],["繒","缯"],["繓","𦈛"],["織","织"],["繕","缮"],["繚","缭"],["繞","绕"],["繟","𦈎"],["繡","绣"],["繢","缋"],["繨","𫄤"],["繩","绳"],["繪","绘"],["繫","系"],["繬","𫄱"],["繭","茧"],["繮","缰"],["繯","缳"],["繰","缲"],["繳","缴"],["繶","𫄷"],["繷","𫄣"],["繸","䍁"],["繹","绎"],["繻","𦈡"],["繼","继"],["繽","缤"],["繾","缱"],["繿","䍀"],["纁","𫄸"],["纇","颣"],["纈","缬"],["纊","纩"],["續","续"],["纍","累"],["纏","缠"],["纓","缨"],["纔","才"],["纖","纤"],["纗","𫄹"],["纘","缵"],["纚","𫄥"],["纜","缆"],["缽","钵"],["罃","䓨"],["罈","坛"],["罌","罂"],["罎","坛"],["罰","罚"],["罵","骂"],["罷","罢"],["羅","罗"],["羆","罴"],["羈","羁"],["羋","芈"],["羣","群"],["羥","羟"],["羨","羡"],["義","义"],["羵","𫅗"],["羶","膻"],["習","习"],["翬","翚"],["翹","翘"],["翽","翙"],["耬","耧"],["耮","耢"],["聖","圣"],["聞","闻"],["聯","联"],["聰","聪"],["聲","声"],["聳","耸"],["聵","聩"],["聶","聂"],["職","职"],["聹","聍"],["聻","𫆏"],["聽","听"],["聾","聋"],["肅","肃"],["肴","肴"],["胜","胜"],["胡","胡"],["脅","胁"],["脈","脉"],["脛","胫"],["脣","唇"],["脥","𣍰"],["脩","修"],["脫","脱"],["脹","胀"],["腊","腊"],["腌","腌"],["腎","肾"],["腖","胨"],["腡","脶"],["腦","脑"],["腪","𣍯"],["腫","肿"],["腳","脚"],["腸","肠"],["膃","腽"],["膕","腘"],["膚","肤"],["膞","䏝"],["膠","胶"],["膢","𦝼"],["膩","腻"],["膹","𪱥"],["膽","胆"],["膾","脍"],["膿","脓"],["臉","脸"],["臍","脐"],["臏","膑"],["臗","𣎑"],["臘","腊"],["臚","胪"],["臟","脏"],["臠","脔"],["臢","臜"],["臥","卧"],["臨","临"],["致","致"],["臺","台"],["與","与"],["興","兴"],["舉","举"],["舊","旧"],["舍","舍"],["舘","馆"],["艙","舱"],["艣","𫇛"],["艤","舣"],["艦","舰"],["艫","舻"],["艱","艰"],["艷","艳"],["芻","刍"],["苧","苎"],["苹","苹"],["范","范"],["茲","兹"],["荊","荆"],["荐","荐"],["莊","庄"],["莖","茎"],["莢","荚"],["莧","苋"],["菕","芲"],["華","华"],["菴","庵"],["菸","烟"],["萇","苌"],["萊","莱"],["萬","万"],["萴","荝"],["萵","莴"],["葉","叶"],["葒","荭"],["著","著"],["葝","𫈎"],["葤","荮"],["葦","苇"],["葯","药"],["葷","荤"],["蒍","𫇭"],["蒐","搜"],["蒓","莼"],["蒔","莳"],["蒕","蒀"],["蒙","蒙"],["蒞","莅"],["蒭","𫇴"],["蒼","苍"],["蓀","荪"],["蓆","席"],["蓋","盖"],["蓧","𦰏"],["蓮","莲"],["蓯","苁"],["蓴","莼"],["蓽","荜"],["蔑","蔑"],["蔔","卜"],["蔘","参"],["蔞","蒌"],["蔣","蒋"],["蔥","葱"],["蔦","茑"],["蔭","荫"],["蔯","𫈟"],["蔿","𫇭"],["蕁","荨"],["蕆","蒇"],["蕎","荞"],["蕒","荬"],["蕓","芸"],["蕕","莸"],["蕘","荛"],["蕝","𫈵"],["蕢","蒉"],["蕩","荡"],["蕪","芜"],["蕭","萧"],["蕳","𫈉"],["蕷","蓣"],["蕽","𫇽"],["薀","蕰"],["薆","𫉁"],["薈","荟"],["薊","蓟"],["薌","芗"],["薑","姜"],["薔","蔷"],["薘","荙"],["薟","莶"],["薦","荐"],["薩","萨"],["薰","薰","熏"],["薳","䓕"],["薴","苧"],["薵","䓓"],["薹","苔","薹"],["薺","荠"],["藉","藉","借"],["藍","蓝"],["藎","荩"],["藝","艺"],["藥","药"],["藪","薮"],["藭","䓖"],["藴","蕴"],["藶","苈"],["藷","𫉄"],["藹","蔼"],["藺","蔺"],["蘀","萚"],["蘄","蕲"],["蘆","芦"],["蘇","苏"],["蘊","蕴"],["蘋","苹","蘋"],["蘚","藓"],["蘞","蔹"],["蘟","𦻕"],["蘢","茏"],["蘭","兰"],["蘺","蓠"],["蘿","萝"],["虆","蔂"],["處","处"],["虛","虚"],["虜","虏"],["號","号"],["虧","亏"],["虫","虫"],["虯","虬"],["蛺","蛱"],["蛻","蜕"],["蜆","蚬"],["蜡","蜡"],["蝕","蚀"],["蝟","猬"],["蝦","虾"],["蝨","虱"],["蝸","蜗"],["螄","蛳"],["螞","蚂"],["螢","萤"],["螮","䗖"],["螻","蝼"],["螿","螀"],["蟂","𫋇"],["蟄","蛰"],["蟈","蝈"],["蟎","螨"],["蟘","𫋌"],["蟜","𫊸"],["蟣","虮"],["蟬","蝉"],["蟯","蛲"],["蟲","虫"],["蟳","𫊻"],["蟶","蛏"],["蟻","蚁"],["蠀","𧏗"],["蠁","蚃"],["蠅","蝇"],["蠆","虿"],["蠍","蝎"],["蠐","蛴"],["蠑","蝾"],["蠔","蚝"],["蠙","𧏖"],["蠟","蜡"],["蠣","蛎"],["蠦","𫊮"],["蠨","蟏"],["蠱","蛊"],["蠶","蚕"],["蠻","蛮"],["蠾","𧑏"],["衆","众"],["衊","蔑"],["術","术"],["衕","同"],["衚","胡"],["衛","卫"],["衝","冲"],["表","表"],["衹","衹","只"],["袞","衮"],["裊","袅"],["裏","里"],["補","补"],["裝","装"],["裡","里"],["製","制"],["複","复"],["褌","裈"],["褘","袆"],["褲","裤"],["褳","裢"],["褸","褛"],["褻","亵"],["襀","𫌀"],["襆","幞"],["襇","裥"],["襉","裥"],["襏","袯"],["襓","𫋹"],["襖","袄"],["襗","𫋷"],["襘","𫋻"],["襝","裣"],["襠","裆"],["襤","褴"],["襪","袜"],["襬","摆","䙓"],["襯","衬"],["襰","𧝝"],["襲","袭"],["襴","襕"],["襵","𫌇"],["覆","覆","复"],["覈","核"],["見","见"],["覎","觃"],["規","规"],["覓","觅"],["視","视"],["覘","觇"],["覛","𫌪"],["覡","觋"],["覥","觍"],["覦","觎"],["親","亲"],["覬","觊"],["覯","觏"],["覲","觐"],["覷","觑"],["覹","𫌭"],["覺","觉"],["覼","𫌨"],["覽","览"],["覿","觌"],["觀","观"],["觴","觞"],["觶","觯"],["觸","触"],["訁","讠"],["訂","订"],["訃","讣"],["計","计"],["訊","讯"],["訌","讧"],["討","讨"],["訐","讦"],["訑","𫍙"],["訒","讱"],["訓","训"],["訕","讪"],["訖","讫"],["託","托","讬"],["記","记"],["訛","讹"],["訜","𫍛"],["訝","讶"],["訞","𫍚"],["訟","讼"],["訢","䜣"],["訣","诀"],["訥","讷"],["訨","𫟞"],["訩","讻"],["訪","访"],["設","设"],["許","许"],["訴","诉"],["訶","诃"],["診","诊"],["註","注"],["証","证"],["詀","𧮪"],["詁","诂"],["詆","诋"],["詊","𫟟"],["詎","讵"],["詐","诈"],["詑","𫍡"],["詒","诒"],["詓","𫍜"],["詔","诏"],["評","评"],["詖","诐"],["詗","诇"],["詘","诎"],["詛","诅"],["詞","词"],["詠","咏"],["詡","诩"],["詢","询"],["詣","诣"],["試","试"],["詩","诗"],["詫","诧"],["詬","诟"],["詭","诡"],["詮","诠"],["詰","诘"],["話","话"],["該","该"],["詳","详"],["詵","诜"],["詷","𫍣"],["詼","诙"],["詿","诖"],["誂","𫍥"],["誄","诔"],["誅","诛"],["誆","诓"],["誇","夸"],["誋","𫍪"],["誌","志"],["認","认"],["誑","诳"],["誒","诶"],["誕","诞"],["誘","诱"],["誚","诮"],["語","语"],["誠","诚"],["誡","诫"],["誣","诬"],["誤","误"],["誥","诰"],["誦","诵"],["誨","诲"],["說","说"],["誫","𫍨"],["説","说"],["誰","谁"],["課","课"],["誳","𫍮"],["誴","𫟡"],["誶","谇"],["誷","𫍬"],["誹","诽"],["誺","𫍧"],["誼","谊"],["誾","訚"],["調","调"],["諂","谄"],["諄","谆"],["談","谈"],["諉","诿"],["請","请"],["諍","诤"],["諏","诹"],["諑","诼"],["諒","谅"],["論","论"],["諗","谂"],["諛","谀"],["諜","谍"],["諝","谞"],["諞","谝"],["諡","谥"],["諢","诨"],["諣","𫍩"],["諤","谔"],["諥","𫍳"],["諦","谛"],["諧","谐"],["諫","谏","𫍝"],["諭","谕"],["諮","咨","谘"],["諯","𫍱"],["諰","𫍰"],["諱","讳"],["諳","谙"],["諴","𫍯"],["諶","谌"],["諷","讽"],["諸","诸"],["諺","谚"],["諼","谖"],["諾","诺"],["謀","谋"],["謁","谒"],["謂","谓"],["謄","誊"],["謅","诌"],["謆","𫍸"],["謉","𫍷"],["謊","谎"],["謎","谜"],["謏","𫍲"],["謐","谧"],["謔","谑"],["謖","谡"],["謗","谤"],["謙","谦"],["謚","谥"],["講","讲"],["謝","谢"],["謠","谣"],["謡","谣"],["謨","谟"],["謫","谪"],["謬","谬"],["謭","谫"],["謯","𫍹"],["謱","𫍴"],["謳","讴"],["謸","𫍵"],["謹","谨"],["謾","谩"],["譁","哗"],["譂","𫟠"],["譅","䜧"],["譆","𫍻"],["證","证"],["譊","𫍢"],["譎","谲"],["譏","讥"],["譑","𫍤"],["譖","谮"],["識","识"],["譙","谯"],["譚","谭"],["譜","谱"],["譞","𫍽"],["譟","噪"],["譨","𫍦"],["譫","谵"],["譭","毁"],["譯","译"],["議","议"],["譴","谴"],["護","护"],["譸","诪"],["譽","誉"],["譾","谫","𫍿"],["讀","读"],["讅","谉"],["變","变"],["讋","詟"],["讌","䜩"],["讎","雠"],["讒","谗"],["讓","让"],["讕","谰"],["讖","谶"],["讚","赞"],["讜","谠"],["讞","谳"],["谷","谷"],["豈","岂"],["豎","竖"],["豐","丰"],["豔","艳"],["豬","猪"],["豵","𫎆"],["豶","豮"],["貓","猫"],["貗","𫎌"],["貙","䝙"],["貝","贝"],["貞","贞"],["貟","贠"],["負","负"],["財","财"],["貢","贡"],["貧","贫"],["貨","货"],["販","贩"],["貪","贪"],["貫","贯"],["責","责"],["貯","贮"],["貰","贳"],["貲","赀"],["貳","贰"],["貴","贵"],["貶","贬"],["買","买","𧹒"],["貸","贷"],["貺","贶"],["費","费"],["貼","贴"],["貽","贻"],["貿","贸"],["賀","贺"],["賁","贲"],["賂","赂"],["賃","赁"],["賄","贿"],["賅","赅"],["資","资"],["賈","贾"],["賊","贼"],["賑","赈"],["賒","赊"],["賓","宾"],["賕","赇"],["賙","赒"],["賚","赉"],["賜","赐"],["賝","𫎩"],["賞","赏"],["賟","𧹖"],["賠","赔"],["賡","赓"],["賢","贤"],["賣","卖"],["賤","贱"],["賦","赋"],["賧","赕"],["質","质"],["賫","赍"],["賬","账"],["賭","赌"],["賰","䞐"],["賴","赖"],["賵","赗"],["賺","赚"],["賻","赙"],["購","购"],["賽","赛"],["賾","赜"],["贃","𧹗"],["贄","贽"],["贅","赘"],["贇","赟"],["贈","赠"],["贉","𫎫"],["贊","赞"],["贋","赝"],["贍","赡"],["贏","赢"],["贐","赆"],["贑","𫎬"],["贓","赃"],["贔","赑"],["贖","赎"],["贗","赝"],["贚","𫎦"],["贛","赣"],["贜","赃"],["赬","赪"],["趕","赶"],["趙","赵"],["趨","趋"],["趲","趱"],["跡","迹"],["踊","踊"],["踐","践"],["踰","逾"],["踴","踊"],["蹌","跄"],["蹔","𫏐"],["蹕","跸"],["蹟","迹"],["蹣","蹒"],["蹤","踪"],["蹳","𫏆"],["蹺","跷"],["蹻","𫏋"],["躂","跶"],["躉","趸"],["躊","踌"],["躋","跻"],["躍","跃"],["躎","䟢"],["躑","踯"],["躒","跞"],["躓","踬"],["躕","蹰"],["躘","𨀁"],["躚","跹"],["躝","𨅬"],["躡","蹑"],["躥","蹿"],["躦","躜"],["躪","躏"],["軀","躯"],["軉","𨉗"],["車","车"],["軋","轧"],["軌","轨"],["軍","军"],["軏","𫐄"],["軑","轪"],["軒","轩"],["軔","轫"],["軕","𫐅"],["軗","𨐅"],["軛","轭"],["軜","𫐇"],["軟","软"],["軤","轷"],["軨","𫐉"],["軫","轸"],["軬","𫐊"],["軲","轱"],["軷","𫐈"],["軸","轴"],["軹","轵"],["軺","轺"],["軻","轲"],["軼","轶"],["軾","轼"],["軿","𫐌"],["較","较"],["輄","𨐈"],["輅","辂"],["輇","辁"],["輈","辀"],["載","载"],["輊","轾"],["輋","𪨶"],["輒","辄"],["輓","挽"],["輔","辅"],["輕","轻"],["輖","𫐏"],["輗","𫐐"],["輛","辆"],["輜","辎"],["輝","辉"],["輞","辋"],["輟","辍"],["輢","𫐎"],["輥","辊"],["輦","辇"],["輨","𫐑"],["輩","辈"],["輪","轮"],["輬","辌"],["輮","𫐓"],["輯","辑"],["輳","辏"],["輷","𫐒"],["輸","输"],["輻","辐"],["輼","辒"],["輾","辗"],["輿","舆"],["轀","辒"],["轂","毂"],["轄","辖"],["轅","辕"],["轆","辘"],["轇","𫐖"],["轉","转"],["轊","𫐕"],["轍","辙"],["轎","轿"],["轐","𫐗"],["轔","辚"],["轗","𫐘"],["轟","轰"],["轠","𫐙"],["轡","辔"],["轢","轹"],["轣","𫐆"],["轤","轳"],["辟","辟"],["辦","办"],["辭","辞"],["辮","辫"],["辯","辩"],["農","农"],["迴","回"],["适","适"],["逕","迳"],["這","这"],["連","连"],["週","周"],["進","进"],["遊","游"],["運","运"],["過","过"],["達","达"],["違","违"],["遙","遥"],["遜","逊"],["遞","递"],["遠","远"],["遡","溯"],["適","适"],["遱","𫐷"],["遲","迟"],["遷","迁"],["選","选"],["遺","遗"],["遼","辽"],["邁","迈"],["還","还"],["邇","迩"],["邊","边"],["邏","逻"],["邐","逦"],["郁","郁"],["郟","郏"],["郵","邮"],["鄆","郓"],["鄉","乡"],["鄒","邹"],["鄔","邬"],["鄖","郧"],["鄟","𫑘"],["鄧","邓"],["鄭","郑"],["鄰","邻"],["鄲","郸"],["鄳","𫑡"],["鄴","邺"],["鄶","郐"],["鄺","邝"],["酇","酂"],["酈","郦"],["酸","酸"],["醃","腌"],["醖","酝"],["醜","丑"],["醞","酝"],["醟","蒏"],["醣","糖"],["醫","医"],["醬","酱"],["醱","酦"],["醶","𫑷"],["釀","酿"],["釁","衅"],["釃","酾"],["釅","酽"],["采","采"],["釋","释"],["里","里"],["釐","厘"],["釒","钅"],["釓","钆"],["釔","钇"],["釕","钌"],["釗","钊"],["釘","钉"],["釙","钋"],["釚","𫟲"],["針","针"],["釟","𫓥"],["釣","钓"],["釤","钐"],["釦","扣"],["釧","钏"],["釨","𫓦"],["釩","钒"],["釲","𫟳"],["釳","𨰿"],["釵","钗"],["釷","钍"],["釹","钕"],["釺","钎"],["釾","䥺"],["鈀","钯"],["鈁","钫"],["鈃","钘"],["鈄","钭"],["鈅","钥"],["鈆","𫓪"],["鈇","𫓧"],["鈈","钚"],["鈉","钠"],["鈋","𨱂"],["鈍","钝"],["鈎","钩"],["鈐","钤"],["鈑","钣"],["鈒","钑"],["鈔","钞"],["鈕","钮","纽"],["鈖","𫟴"],["鈗","𫟵"],["鈛","𫓨"],["鈞","钧"],["鈠","𨱁"],["鈡","钟"],["鈣","钙"],["鈥","钬"],["鈦","钛"],["鈧","钪"],["鈮","铌"],["鈯","𨱄"],["鈰","铈"],["鈲","𨱃"],["鈳","钶"],["鈴","铃"],["鈷","钴"],["鈸","钹"],["鈹","铍"],["鈺","钰"],["鈽","钸"],["鈾","铀"],["鈿","钿"],["鉀","钾"],["鉁","𨱅"],["鉅","巨","钜"],["鉆","钻"],["鉈","铊"],["鉉","铉"],["鉋","铇"],["鉍","铋"],["鉑","铂"],["鉔","𫓬"],["鉕","钷"],["鉗","钳"],["鉚","铆"],["鉛","铅"],["鉝","𫟷"],["鉞","钺"],["鉠","𫓭"],["鉢","钵"],["鉤","钩"],["鉦","钲"],["鉬","钼"],["鉭","钽"],["鉳","锫"],["鉶","铏"],["鉷","𫟹"],["鉸","铰"],["鉺","铒"],["鉻","铬"],["鉽","𫟸"],["鉾","𫓴"],["鉿","铪"],["銀","银"],["銁","𫓲"],["銂","𫟻"],["銃","铳"],["銅","铜"],["銈","𫓯"],["銊","𫓰"],["銍","铚"],["銏","𫟶"],["銑","铣"],["銓","铨"],["銖","铢"],["銘","铭"],["銚","铫"],["銛","铦"],["銜","衔"],["銠","铑"],["銣","铷"],["銥","铱"],["銦","铟"],["銨","铵"],["銩","铥"],["銪","铕"],["銫","铯"],["銬","铐"],["銱","铞"],["銳","锐"],["銶","𨱇"],["銷","销"],["銹","锈"],["銻","锑"],["銼","锉"],["鋁","铝"],["鋂","镅"],["鋃","锒"],["鋅","锌"],["鋇","钡"],["鋉","𨱈"],["鋌","铤"],["鋏","铗"],["鋒","锋"],["鋗","𫓶"],["鋙","铻"],["鋝","锊"],["鋟","锓"],["鋠","𫓵"],["鋣","铘"],["鋤","锄"],["鋥","锃"],["鋦","锔"],["鋨","锇"],["鋩","铓"],["鋪","铺"],["鋭","锐"],["鋮","铖"],["鋯","锆"],["鋰","锂"],["鋱","铽"],["鋶","锍"],["鋸","锯"],["鋼","钢"],["錀","𬬭"],["錁","锞"],["錂","𨱋"],["錄","录"],["錆","锖"],["錇","锫"],["錈","锩"],["錏","铔"],["錐","锥"],["錒","锕"],["錕","锟"],["錘","锤"],["錙","锱"],["錚","铮"],["錛","锛"],["錜","𫓻"],["錝","𫓽"],["錟","锬"],["錠","锭"],["錡","锜"],["錢","钱"],["錤","𫓹"],["錥","𫓾"],["錦","锦"],["錨","锚"],["錩","锠"],["錫","锡"],["錮","锢"],["錯","错"],["録","录"],["錳","锰"],["錶","表"],["錸","铼"],["錼","镎"],["錽","𫓸"],["鍀","锝"],["鍁","锨"],["鍃","锪"],["鍄","𨱉"],["鍅","钫"],["鍆","钔"],["鍇","锴"],["鍈","锳"],["鍉","𫔂"],["鍊","炼","链","𫔀"],["鍋","锅"],["鍍","镀"],["鍒","𫔄"],["鍔","锷"],["鍘","铡"],["鍚","钖"],["鍛","锻"],["鍠","锽"],["鍤","锸"],["鍥","锲"],["鍩","锘"],["鍬","锹"],["鍮","𨱎"],["鍰","锾"],["鍵","键"],["鍶","锶"],["鍺","锗"],["鍼","针"],["鍾","钟","锺"],["鎂","镁"],["鎄","锿"],["鎇","镅"],["鎈","𫟿"],["鎊","镑"],["鎌","镰"],["鎍","𫔅"],["鎔","镕"],["鎖","锁"],["鎘","镉"],["鎙","𫔈"],["鎚","锤"],["鎛","镈"],["鎝","𨱏"],["鎞","𫔇"],["鎡","镃"],["鎢","钨"],["鎣","蓥"],["鎦","镏"],["鎧","铠"],["鎩","铩"],["鎪","锼"],["鎬","镐"],["鎭","镇"],["鎮","镇"],["鎯","𨱍"],["鎰","镒"],["鎲","镋"],["鎳","镍"],["鎵","镓"],["鎶","鿔"],["鎷","𨰾"],["鎸","镌"],["鎿","镎"],["鏃","镞"],["鏆","𨱌"],["鏇","镟"],["鏈","链"],["鏉","𨱒"],["鏌","镆"],["鏍","镙"],["鏐","镠"],["鏑","镝"],["鏗","铿"],["鏘","锵"],["鏚","戚"],["鏜","镗"],["鏝","镘"],["鏞","镛"],["鏟","铲"],["鏡","镜"],["鏢","镖"],["鏤","镂"],["鏥","𫔊"],["鏦","𫓩"],["鏨","錾"],["鏰","镚"],["鏵","铧"],["鏷","镤"],["鏹","镪"],["鏺","䥽"],["鏽","锈"],["鏾","𫔌"],["鐃","铙"],["鐄","𨱑"],["鐇","𫔍"],["鐈","𫓱"],["鐋","铴"],["鐍","𫔎"],["鐎","𨱓"],["鐏","𨱔"],["鐐","镣"],["鐒","铹"],["鐓","镦"],["鐔","镡"],["鐗","锏"],["鐘","钟"],["鐙","镫"],["鐝","镢"],["鐠","镨"],["鐥","䦅"],["鐦","锎"],["鐧","锏"],["鐨","镄"],["鐪","𫓺"],["鐫","镌"],["鐮","镰"],["鐯","䦃"],["鐲","镯"],["鐳","镭"],["鐵","铁"],["鐶","镮"],["鐸","铎"],["鐺","铛"],["鐼","𫔁"],["鐽","𫟼"],["鐿","镱"],["鑀","锿"],["鑄","铸"],["鑉","𫠁"],["鑊","镬"],["鑌","镔"],["鑑","鉴"],["鑒","鉴"],["鑔","镲"],["鑕","锧"],["鑞","镴"],["鑠","铄"],["鑣","镳"],["鑥","镥"],["鑪","𬬻"],["鑭","镧"],["鑰","钥"],["鑱","镵"],["鑲","镶"],["鑴","𫔔"],["鑷","镊"],["鑹","镩"],["鑼","锣"],["鑽","钻"],["鑾","銮"],["鑿","凿"],["钁","镢","䦆"],["钂","镋"],["镟","旋"],["長","长"],["門","门"],["閂","闩"],["閃","闪"],["閆","闫"],["閈","闬"],["閉","闭"],["開","开","𫔭"],["閌","闶"],["閍","𨸂"],["閎","闳"],["閏","闰"],["閐","𨸃"],["閑","闲"],["閒","闲","𫔮"],["間","间"],["閔","闵"],["閗","𫔯"],["閘","闸"],["閝","𫠂"],["閞","𫔰"],["閡","阂"],["閣","阁"],["閤","合"],["閥","阀"],["閨","闺"],["閩","闽"],["閫","阃"],["閬","阆"],["閭","闾"],["閱","阅"],["閲","阅"],["閵","𫔴"],["閶","阊"],["閹","阉"],["閻","阎"],["閼","阏"],["閽","阍"],["閾","阈"],["閿","阌"],["闃","阒"],["闆","板"],["闇","暗"],["闈","闱"],["闊","阔"],["闋","阕"],["闌","阑"],["闍","阇"],["闐","阗"],["闑","𫔶"],["闒","阘"],["闓","闿"],["闔","阖"],["闕","阙"],["闖","闯"],["關","关"],["闞","阚"],["闠","阓"],["闡","阐"],["闢","辟"],["闤","阛"],["闥","闼"],["阪","阪","坂"],["陘","陉"],["陝","陕"],["陞","升"],["陣","阵"],["陰","阴"],["陳","陈"],["陸","陆"],["陽","阳"],["隉","陧"],["隊","队"],["階","阶"],["隕","陨"],["際","际"],["隨","随"],["險","险"],["隯","陦"],["隱","隐"],["隴","陇"],["隸","隶"],["隻","只"],["雇","雇"],["雋","隽"],["雕","雕"],["雖","虽"],["雙","双"],["雛","雏"],["雜","杂"],["雞","鸡"],["離","离"],["難","难"],["雲","云"],["電","电"],["霢","霡"],["霣","𫕥"],["霧","雾"],["霼","𪵣"],["霽","霁"],["靂","雳"],["靄","霭"],["靆","叇"],["靈","灵"],["靉","叆"],["靚","靓"],["靜","静"],["靝","靔"],["面","面"],["靦","腼","䩄"],["靧","𫖃"],["靨","靥"],["鞀","鼗"],["鞏","巩"],["鞝","绱"],["鞦","秋"],["鞽","鞒"],["鞾","𫖇"],["韁","缰"],["韃","鞑"],["韆","千"],["韉","鞯"],["韋","韦"],["韌","韧"],["韍","韨"],["韓","韩"],["韙","韪"],["韚","𫠅"],["韛","𫖔"],["韜","韬"],["韝","鞲","𫖕"],["韞","韫"],["韠","𫖒"],["韻","韵"],["響","响"],["頁","页"],["頂","顶"],["頃","顷"],["項","项"],["順","顺"],["頇","顸"],["須","须"],["頊","顼"],["頌","颂"],["頍","𫠆"],["頎","颀"],["頏","颃"],["預","预"],["頑","顽"],["頒","颁"],["頓","顿"],["頗","颇"],["領","领"],["頜","颌"],["頡","颉"],["頤","颐"],["頦","颏"],["頫","𫖯"],["頭","头"],["頮","颒"],["頰","颊"],["頲","颋"],["頴","颕"],["頵","𫖳"],["頷","颔"],["頸","颈"],["頹","颓"],["頻","频"],["頽","颓"],["顂","𩓋"],["顃","𩖖"],["顅","𫖶"],["顆","颗"],["題","题"],["額","额"],["顎","颚"],["顏","颜"],["顒","颙"],["顓","颛"],["顔","颜"],["顗","𫖮"],["願","愿","𫖸"],["顙","颡"],["顛","颠"],["類","类"],["顢","颟"],["顣","𫖹"],["顥","颢"],["顧","顾"],["顫","颤"],["顬","颥"],["顯","显"],["顰","颦"],["顱","颅"],["顳","颞"],["顴","颧"],["風","风"],["颭","飐"],["颮","飑"],["颯","飒"],["颰","𩙥"],["颱","台"],["颳","刮"],["颶","飓"],["颷","𩙪"],["颸","飔"],["颺","飏"],["颻","飖"],["颼","飕"],["颾","𩙫"],["飀","飗"],["飄","飘"],["飆","飙"],["飈","飚"],["飋","𫗋"],["飛","飞"],["飠","饣"],["飢","饥"],["飣","饤"],["飥","饦"],["飦","𫗞"],["飩","饨"],["飪","饪"],["飫","饫"],["飭","饬"],["飯","饭"],["飱","飧"],["飲","饮"],["飴","饴"],["飵","𫗢"],["飶","𫗣"],["飼","饲"],["飽","饱"],["飾","饰"],["飿","饳"],["餃","饺"],["餄","饸"],["餅","饼"],["餉","饷"],["養","养"],["餌","饵"],["餎","饹"],["餏","饻"],["餑","饽"],["餒","馁"],["餓","饿"],["餔","𫗦"],["餕","馂"],["餖","饾"],["餗","𫗧"],["餘","余","馀"],["餚","肴"],["餛","馄"],["餜","馃"],["餞","饯"],["餡","馅"],["餦","𫗠"],["餧","𫗪"],["館","馆"],["餪","𫗬"],["餫","𫗥"],["餬","糊","𫗫"],["餭","𫗮"],["餱","糇","𫗯"],["餳","饧"],["餵","喂","𫗭"],["餶","馉"],["餷","馇"],["餸","𩠌"],["餺","馎"],["餼","饩"],["餾","馏"],["餿","馊"],["饁","馌"],["饃","馍"],["饅","馒"],["饈","馐"],["饉","馑"],["饊","馓"],["饋","馈"],["饌","馔"],["饑","饥"],["饒","饶"],["饗","飨"],["饘","𫗴"],["饜","餍"],["饞","馋"],["饟","𫗵"],["饠","𫗩"],["饢","馕"],["馬","马"],["馭","驭"],["馮","冯"],["馯","𫘛"],["馱","驮"],["馳","驰"],["馴","驯"],["馹","驲"],["馼","𫘜"],["駁","驳"],["駃","𫘝"],["駊","𫘟"],["駎","𩧨"],["駐","驻"],["駑","驽"],["駒","驹"],["駔","驵"],["駕","驾"],["駘","骀"],["駙","驸"],["駚","𩧫"],["駛","驶"],["駝","驼"],["駞","𫘞"],["駟","驷"],["駡","骂"],["駢","骈"],["駤","𫘠"],["駧","𩧲"],["駩","𩧴"],["駫","𫘡"],["駭","骇"],["駰","骃"],["駱","骆"],["駶","𩧺"],["駸","骎"],["駻","𫘣"],["駿","骏"],["騁","骋"],["騂","骍"],["騃","𫘤"],["騄","𫘧"],["騅","骓"],["騉","𫘥"],["騊","𫘦"],["騌","骔"],["騍","骒"],["騎","骑"],["騏","骐"],["騔","𩨀"],["騖","骛"],["騙","骗"],["騚","𩨊"],["騜","𫘩"],["騝","𩨃"],["騟","𩨈"],["騠","𫘨"],["騤","骙"],["騧","䯄"],["騪","𩨄"],["騫","骞"],["騭","骘"],["騮","骝"],["騰","腾"],["騱","𫘬"],["騴","𫘫"],["騵","𫘪"],["騶","驺"],["騷","骚"],["騸","骟"],["騻","𫘭"],["騼","𫠋"],["騾","骡"],["驀","蓦"],["驁","骜"],["驂","骖"],["驃","骠"],["驄","骢","𩨂"],["驅","驱"],["驊","骅"],["驋","𩧯"],["驌","骕"],["驍","骁"],["驏","骣"],["驓","𫘯"],["驕","骄"],["驗","验"],["驙","𫘰"],["驚","惊"],["驛","驿"],["驟","骤"],["驢","驴"],["驤","骧"],["驥","骥"],["驦","骦"],["驨","𫘱"],["驪","骊"],["驫","骉"],["骯","肮"],["髏","髅"],["髒","脏"],["體","体"],["髕","髌"],["髖","髋"],["髮","发"],["鬆","松"],["鬍","胡"],["鬖","𩭹"],["鬚","须"],["鬠","𫘽"],["鬢","鬓"],["鬥","斗"],["鬧","闹"],["鬨","哄"],["鬩","阋"],["鬮","阄"],["鬱","郁"],["鬹","鬶"],["魎","魉"],["魘","魇"],["魚","鱼"],["魛","鱽"],["魟","𫚉"],["魢","鱾"],["魥","𩽹"],["魦","𫚌"],["魨","鲀"],["魯","鲁"],["魴","鲂"],["魵","𫚍"],["魷","鱿"],["魺","鲄"],["魽","𫠐"],["鮁","鲅"],["鮃","鲆"],["鮄","𫚒"],["鮅","𫚑"],["鮆","𫚖"],["鮊","鲌"],["鮋","鲉"],["鮍","鲏"],["鮎","鲇"],["鮐","鲐"],["鮑","鲍"],["鮒","鲋"],["鮓","鲊"],["鮕","𩾀"],["鮚","鲒"],["鮜","鲘"],["鮝","鲞"],["鮞","鲕"],["鮟","𩽾"],["鮣","䲟"],["鮤","𫚓"],["鮦","鲖"],["鮪","鲔"],["鮫","鲛"],["鮭","鲑"],["鮮","鲜"],["鮯","𫚗"],["鮰","𫚔"],["鮳","鲓"],["鮵","𫚛"],["鮶","鲪"],["鮸","𩾃"],["鮺","鲝"],["鮿","𫚚"],["鯀","鲧"],["鯁","鲠"],["鯄","𩾁"],["鯆","𫚙"],["鯇","鲩"],["鯉","鲤"],["鯊","鲨"],["鯒","鲬"],["鯔","鲻"],["鯕","鲯"],["鯖","鲭"],["鯗","鲞"],["鯛","鲷"],["鯝","鲴"],["鯞","𫚡"],["鯡","鲱"],["鯢","鲵"],["鯤","鲲"],["鯧","鲳"],["鯨","鲸"],["鯪","鲮"],["鯫","鲰"],["鯬","𫚞"],["鯰","鲶"],["鯱","𩾇"],["鯴","鲺"],["鯶","𩽼"],["鯷","鳀"],["鯽","鲫"],["鯾","𫚣"],["鯿","鳊"],["鰁","鳈"],["鰂","鲗"],["鰃","鳂"],["鰆","䲠"],["鰈","鲽"],["鰉","鳇"],["鰋","𫚢"],["鰌","䲡"],["鰍","鳅"],["鰏","鲾"],["鰐","鳄"],["鰑","𫚊"],["鰒","鳆"],["鰓","鳃"],["鰕","𫚥"],["鰛","鳁"],["鰜","鳒"],["鰟","鳑"],["鰠","鳋"],["鰣","鲥"],["鰤","𫚕"],["鰥","鳏"],["鰦","𫚤"],["鰧","䲢"],["鰨","鳎"],["鰩","鳐"],["鰫","𫚦"],["鰭","鳍"],["鰮","鳁"],["鰱","鲢"],["鰲","鳌"],["鰳","鳓"],["鰵","鳘"],["鰷","鲦"],["鰹","鲣"],["鰺","鲹"],["鰻","鳗"],["鰼","鳛"],["鰽","𫚧"],["鰾","鳔"],["鱂","鳉"],["鱄","𫚋"],["鱅","鳙"],["鱆","𫠒"],["鱇","𩾌"],["鱈","鳕"],["鱉","鳖"],["鱊","𫚪"],["鱒","鳟"],["鱔","鳝"],["鱖","鳜"],["鱗","鳞"],["鱘","鲟"],["鱝","鲼"],["鱟","鲎"],["鱠","鲙"],["鱢","𫚫"],["鱣","鳣"],["鱤","鳡"],["鱧","鳢"],["鱨","鲿"],["鱭","鲚"],["鱮","𫚈"],["鱯","鳠"],["鱲","𫚭"],["鱷","鳄"],["鱸","鲈"],["鱺","鲡"],["鳥","鸟"],["鳧","凫"],["鳩","鸠"],["鳬","凫"],["鳲","鸤"],["鳳","凤"],["鳴","鸣"],["鳶","鸢"],["鳷","𫛛"],["鳼","𪉃"],["鳽","𫛚"],["鳾","䴓"],["鴀","𫛜"],["鴃","𫛞"],["鴅","𫛝"],["鴆","鸩"],["鴇","鸨"],["鴉","鸦"],["鴐","𫛤"],["鴒","鸰"],["鴔","𫛡"],["鴕","鸵"],["鴗","𫁡"],["鴛","鸳"],["鴜","𪉈"],["鴝","鸲"],["鴞","鸮"],["鴟","鸱"],["鴣","鸪"],["鴥","𫛣"],["鴦","鸯"],["鴨","鸭"],["鴮","𫛦"],["鴯","鸸"],["鴰","鸹"],["鴲","𪉆"],["鴳","𫛩"],["鴴","鸻"],["鴷","䴕"],["鴻","鸿"],["鴽","𫛪"],["鴿","鸽"],["鵁","䴔"],["鵂","鸺"],["鵃","鸼"],["鵊","𫛥"],["鵐","鹀"],["鵑","鹃"],["鵒","鹆"],["鵓","鹁"],["鵚","𪉍"],["鵜","鹈"],["鵝","鹅"],["鵟","𫛭"],["鵠","鹄"],["鵡","鹉"],["鵧","𫛨"],["鵩","𫛳"],["鵪","鹌"],["鵫","𫛱"],["鵬","鹏"],["鵮","鹐"],["鵯","鹎"],["鵰","雕","𫛲"],["鵲","鹊"],["鵷","鹓"],["鵾","鹍"],["鶄","䴖"],["鶇","鸫"],["鶉","鹑"],["鶊","鹒"],["鶌","𫛵"],["鶒","𫛶"],["鶓","鹋"],["鶖","鹙"],["鶗","𫛸"],["鶘","鹕"],["鶚","鹗"],["鶡","鹖"],["鶥","鹛"],["鶦","𫛷"],["鶩","鹜"],["鶪","䴗"],["鶬","鸧"],["鶭","𫛯"],["鶯","莺"],["鶰","𫛫"],["鶲","鹟"],["鶴","鹤"],["鶹","鹠"],["鶺","鹡"],["鶻","鹘"],["鶼","鹣"],["鶿","鹚"],["鷀","鹚"],["鷁","鹢"],["鷂","鹞"],["鷄","鸡"],["鷅","𫛽"],["鷈","䴘"],["鷉","䴘"],["鷊","鹝"],["鷐","𫜀"],["鷓","鹧"],["鷔","𪉑"],["鷖","鹥"],["鷗","鸥"],["鷙","鸷"],["鷚","鹨"],["鷣","𫜃"],["鷤","𫛴"],["鷥","鸶"],["鷦","鹪"],["鷨","𪉊"],["鷩","𫜁"],["鷫","鹔"],["鷯","鹩"],["鷲","鹫"],["鷳","鹇"],["鷴","鹇"],["鷷","𫜄"],["鷸","鹬"],["鷹","鹰"],["鷺","鹭"],["鷽","鸴"],["鷿","䴙"],["鸂","㶉"],["鸇","鹯"],["鸊","䴙"],["鸋","𫛢"],["鸌","鹱"],["鸏","鹲"],["鸕","鸬"],["鸗","𫛟"],["鸘","鹴"],["鸚","鹦"],["鸛","鹳"],["鸝","鹂"],["鸞","鸾"],["鹵","卤"],["鹹","咸"],["鹺","鹾"],["鹼","碱"],["鹽","盐"],["麗","丽"],["麥","麦"],["麨","𪎊"],["麩","麸"],["麪","面","麺"],["麫","面"],["麬","𤿲"],["麯","曲"],["麲","𪎉"],["麳","𪎌"],["麴","曲","麹"],["麵","面","麺"],["麷","𫜑"],["麼","么","麽"],["麽","么","麽"],["黃","黄"],["黌","黉"],["點","点"],["黨","党"],["黲","黪"],["黴","霉"],["黶","黡"],["黷","黩"],["黽","黾"],["黿","鼋"],["鼂","鼌"],["鼉","鼍"],["鼕","冬"],["鼴","鼹"],["齇","齄"],["齊","齐"],["齋","斋"],["齎","赍"],["齏","齑"],["齒","齿"],["齔","龀"],["齕","龁"],["齗","龂"],["齙","龅"],["齜","龇"],["齟","龃"],["齠","龆"],["齡","龄"],["齣","出"],["齦","龈"],["齧","啮","𫜩"],["齩","𫜪"],["齪","龊"],["齬","龉"],["齭","𫜭"],["齯","𫠜"],["齰","𫜬"],["齲","龋"],["齴","𫜮"],["齶","腭"],["齷","龌"],["齾","𫜰"],["龍","龙"],["龎","厐"],["龐","庞"],["龑","䶮"],["龓","𫜲"],["龔","龚"],["龕","龛"],["龜","龟"],["龭","𩨎"],["龯","𨱆"],["鿁","䜤"],["鿓","鿒"],["𠁞","𠀾"],["𠌥","𠆿"],["𠏢","𠉗"],["𠐊","𫝋"],["𠗣","㓆"],["𠞆","𠛆"],["𠠎","𠚳"],["𠬙","𪠡"],["𠽃","𪠺"],["𠿕","𪜎"],["𡂡","𪢒"],["𡃄","𪡺"],["𡃕","𠴛"],["𡃤","𪢐"],["𡄔","𠴢"],["𡄣","𠵸"],["𡅏","𠲥"],["𡅯","𪢖"],["𡑭","𡋗"],["𡓁","𪤄"],["𡓾","𡋀"],["𡔖","𡍣"],["𡞵","㛟"],["𡟫","𫝪"],["𡠹","㛿"],["𡡎","𡞱"],["𡢃","㛠"],["𡮉","𡭜"],["𡮣","𡭬"],["𡳳","𡳃"],["𡸗","𪨩"],["𡹬","𪨹"],["𡻕","岁"],["𡽗","𡸃"],["𡾱","㟜"],["𡿖","𪩛"],["𢍰","𪪴"],["𢠼","𢙑"],["𢣐","𪬚"],["𢣚","𢘝"],["𢣭","𢘞"],["𢤩","𪫡"],["𢤱","𢘙"],["𢤿","𪬯"],["𢯷","𪭝"],["𢶒","𪭯"],["𢶫","𢫞"],["𢷬","𢭏"],["𢷮","𢫊"],["𢹿","𢬦"],["𢺳","𪮳"],["𣈶","暅"],["𣋋","𣈣"],["𣍐","𠊉"],["𣙎","㭣"],["𣜬","𪳗"],["𣝕","𣘷"],["𣞻","𣘓"],["𣠩","𣞎"],["𣠲","𣑶"],["𣯩","𣯣"],["𣯴","𣭤"],["𣯶","毶"],["𣽏","𪶮"],["𣾷","㳢"],["𣿉","𣶫"],["𤁣","𣺽"],["𤄷","𪶒"],["𤅶","𣷷"],["𤑳","𤎻"],["𤑹","𪹀"],["𤒎","𤊀"],["𤒻","𪹹"],["𤓌","𪹠"],["𤓩","𤊰"],["𤘀","𪺣"],["𤛮","𤙯"],["𤛱","𫞢"],["𤜆","𪺪"],["𤠮","𪺸"],["𤢟","𤝢"],["𤢻","𢢐"],["𤩂","𫞧"],["𤪺","㻘"],["𤫩","㻏"],["𤬅","𪼴"],["𤳷","𪽝"],["𤳸","𤳄"],["𤷃","𪽭"],["𤸫","𤶧"],["𤺔","𪽴"],["𥊝","𥅿"],["𥌃","𥅘"],["𥏝","𪿊"],["𥕥","𥐰"],["𥖅","𥐯"],["𥖲","𪿞"],["𥗇","𪿵"],["𥜐","𫀓"],["𥜰","𫀌"],["𥞵","𥞦"],["𥢢","䅪"],["𥢶","𫞷"],["𥢷","𫀮"],["𥨐","𥧂"],["𥪂","𥩺"],["𥯤","𫁳"],["𥴨","𫂖"],["𥴼","𫁺"],["𥵃","𥱔"],["𥵊","𥭉"],["𥶽","𫁱"],["𥸠","𥮋"],["𥻦","𫂿"],["𥼽","𥹥"],["𥽖","𥺇"],["𥾯","𫄝"],["𥿊","𦈈"],["𦀖","𫄦"],["𦂅","𦈒"],["𦃄","𦈗"],["𦃩","𫄯"],["𦅇","𫄪"],["𦅈","𫄵"],["𦆲","𫟇"],["𦒀","𫅥"],["𦔖","𫅼"],["𦘧","𡳒"],["𦟼","𫆝"],["𦠅","𫞅"],["𦡝","𫆫"],["𦢈","𣍨"],["𦣎","𦟗"],["𦧺","𫇘"],["𦪙","䑽"],["𦪽","𦨩"],["𦱌","𫇪"],["𦾟","𦶻"],["𧎈","𧌥"],["𧒯","𫊹"],["𧔥","𧒭"],["𧕟","𧉐"],["𧜗","䘞"],["𧜵","䙊"],["𧝞","䘛"],["𧞫","𫌋"],["𧟀","𧝧"],["𧡴","𫌫"],["𧢄","𫌬"],["𧦝","𫍞"],["𧦧","𫍟"],["𧩕","𫍭"],["𧩙","䜥"],["𧩼","𫍶"],["𧫝","𫍺"],["𧬤","𫍼"],["𧭈","𫍾"],["𧭹","𫍐"],["𧳟","𧳕"],["𧵳","䞌"],["𧶔","𧹓"],["𧶧","䞎"],["𧷎","𪠀"],["𧸘","𫎨"],["𧹈","𪥠"],["𧽯","𫎸"],["𨂐","𫏌"],["𨄣","𨀱"],["𨅍","𨁴"],["𨆪","𫏕"],["𨇁","𧿈"],["𨇞","𨅫"],["𨇤","𫏨"],["𨇰","𫏞"],["𨇽","𫏑"],["𨈊","𨂺"],["𨈌","𨄄"],["𨊰","䢀"],["𨊸","䢁"],["𨊻","𨐆"],["𨋢","䢂"],["𨌈","𫐍"],["𨍰","𫐔"],["𨎌","𫐋"],["𨎮","𨐉"],["𨏠","𨐇"],["𨏥","𨐊"],["𨞺","𫟫"],["𨟊","𫟬"],["𨢿","𨡙"],["𨣈","𨡺"],["𨣞","𨟳"],["𨣧","𨠨"],["𨤻","𨤰"],["𨥛","𨱀"],["𨥟","𫓫"],["𨦫","䦀"],["𨧀","𬭊"],["𨧜","䦁"],["𨧰","𫟽"],["𨧱","𨱊"],["𨨏","𬭛"],["𨨛","𫓼"],["𨨢","𫓿"],["𨩰","𫟾"],["𨪕","𫓮"],["𨫒","𨱐"],["𨬖","𫔏"],["𨭆","𬭶"],["𨭎","𬭳"],["𨭖","𫔑"],["𨭸","𫔐"],["𨮂","𨱕"],["𨮳","𫔒"],["𨯅","䥿"],["𨯟","𫔓"],["𨰃","𫔉"],["𨰋","𫓳"],["𨰥","𫔕"],["𨰲","𫔃"],["𨲳","𫔖"],["𨳑","𨸁"],["𨳕","𨸀"],["𨴗","𨸅"],["𨴹","𫔲"],["𨵩","𨸆"],["𨵸","𨸇"],["𨶀","𨸉"],["𨶏","𨸊"],["𨶮","𨸌"],["𨶲","𨸋"],["𨷲","𨸎"],["𨼳","𫔽"],["𨽏","𨸘"],["𩀨","𫕚"],["𩅙","𫕨"],["𩎖","𫖑"],["𩎢","𩏾"],["𩏂","𫖓"],["𩏠","𫖖"],["𩏪","𩏽"],["𩏷","𫃗"],["𩑔","𫖪"],["𩒎","𫖭"],["𩓣","𩖕"],["𩓥","𫖵"],["𩔑","𫖷"],["𩔳","𫖴"],["𩖰","𫠇"],["𩗀","𩙦"],["𩗓","𫗈"],["𩗴","𫗉"],["𩘀","𩙩"],["𩘝","𩙭"],["𩘹","𩙨"],["𩘺","𩙬"],["𩙈","𩙰"],["𩚛","𩟿"],["𩚥","𩠀"],["𩚩","𫗡"],["𩚵","𩠁"],["𩛆","𩠂"],["𩛌","𫗤"],["𩛡","𫗨"],["𩛩","𩠃"],["𩜇","𩠉"],["𩜦","𩠆"],["𩜵","𩠊"],["𩝔","𩠋"],["𩝽","𫗳"],["𩞄","𩠎"],["𩞦","𩠏"],["𩞯","䭪"],["𩟐","𩠅"],["𩟗","𫗚"],["𩠴","𩠠"],["𩡣","𩡖"],["𩡺","𩧦"],["𩢡","𩧬"],["𩢴","𩧵"],["𩢸","𩧳"],["𩢾","𩧮"],["𩣏","𩧶"],["𩣑","䯃"],["𩣫","𩧸"],["𩣵","𩧻"],["𩣺","𩧼"],["𩤊","𩧩"],["𩤙","𩨆"],["𩤲","𩨉"],["𩤸","𩨅"],["𩥄","𩨋"],["𩥇","𩨍"],["𩥉","𩧱"],["𩥑","𩨌"],["𩦠","𫠌"],["𩧆","𩨐"],["𩭙","𩬣"],["𩯁","𫙂"],["𩯳","𩯒"],["𩰀","𩬤"],["𩰹","𩰰"],["𩳤","𩲒"],["𩴵","𩴌"],["𩵦","𫠏"],["𩵩","𩽺"],["𩵹","𩽻"],["𩶁","𫚎"],["𩶘","䲞"],["𩶰","𩽿"],["𩶱","𩽽"],["𩷰","𩾄"],["𩸃","𩾅"],["𩸄","𫚝"],["𩸡","𫚟"],["𩸦","𩾆"],["𩻗","𫚨"],["𩻬","𫚩"],["𩻮","𫚘"],["𩼶","𫚬"],["𩽇","𩾎"],["𩿅","𫠖"],["𩿤","𫛠"],["𩿪","𪉄"],["𪀖","𫛧"],["𪀦","𪉅"],["𪀾","𪉋"],["𪁈","𪉉"],["𪁖","𪉌"],["𪂆","𪉎"],["𪃍","𪉐"],["𪃏","𪉏"],["𪃒","𫛻"],["𪃧","𫛹"],["𪄆","𪉔"],["𪄕","𪉒"],["𪅂","𫜂"],["𪆷","𫛾"],["𪇳","𪉕"],["𪈼","𪉓"],["𪉸","𫜊"],["𪋿","𪎍"],["𪌭","𫜓"],["𪍠","𫜕"],["𪓰","𫜟"],["𪔵","𪔭"],["𪘀","𪚏"],["𪘯","𪚐"],["𪙏","𫜯"],["𪟖","𠛾"],["𪷓","𣶭"],["𫒡","𫓷"],["𫜦","𫜫"]],"TSPhrases":[["一目瞭然","一目了然"],["上鍊","上链"],["不瞭解","不了解"],["么麼","幺麽"],["么麽","幺麽"],["乾乾淨淨","干干净净"],["乾乾脆脆","干干脆脆"],["乾元","乾元"],["乾卦","乾卦"],["乾嘉","乾嘉"],["乾圖","乾图"],["乾坤","乾坤"],["乾坤一擲","乾坤一掷"],["乾坤再造","乾坤再造"],["乾坤大挪移","乾坤大挪移"],["乾宅","乾宅"],["乾斷","乾断"],["乾旦","乾旦"],["乾曜","乾曜"],["乾清宮","乾清宫"],["乾盛世","乾盛世"],["乾紅","乾红"],["乾綱","乾纲"],["乾縣","乾县"],["乾象","乾象"],["乾造","乾造"],["乾道","乾道"],["乾陵","乾陵"],["乾隆","乾隆"],["乾隆年間","乾隆年间"],["乾隆皇帝","乾隆皇帝"],["以免藉口","以免借口"],["以功覆過","以功复过"],["侔德覆載","侔德复载"],["傢俱","家具"],["傷亡枕藉","伤亡枕借"],["八濛山","八濛山"],["凌藉","凌借"],["出醜狼藉","出丑狼借"],["函覆","函复"],["千鍾粟","千锺粟"],["反反覆覆","反反复复"],["反覆","反复"],["反覆思維","反复思维"],["反覆思量","反复思量"],["反覆性","反复性"],["名覆金甌","名复金瓯"],["哪吒","哪吒"],["回覆","回复"],["壺裏乾坤","壶里乾坤"],["大目乾連冥間救母變文","大目乾连冥间救母变文"],["宫商角徵羽","宫商角徵羽"],["射覆","射复"],["尼乾陀","尼乾陀"],["幺麼","幺麽"],["幺麼小丑","幺麽小丑"],["幺麼小醜","幺麽小丑"],["康乾","康乾"],["張法乾","张法乾"],["彷彿","仿佛"],["彷徨","彷徨"],["徵弦","徵弦"],["徵絃","徵弦"],["徵聲","徵声"],["徵調","徵调"],["徵音","徵音"],["情有獨鍾","情有独钟","情有独锺"],["憑藉","凭借"],["憑藉着","凭借着"],["手鍊","手链"],["扭轉乾坤","扭转乾坤"],["找藉口","找借口"],["拉鍊","拉链"],["拉鍊工程","拉链工程"],["拜覆","拜复"],["據瞭解","据了解"],["文錦覆阱","文锦复阱"],["於世成","於世成"],["於乎","於乎"],["於仲完","於仲完"],["於倫","於伦"],["於其一","於其一"],["於則","於则"],["於勇明","於勇明"],["於呼哀哉","於呼哀哉"],["於單","於单"],["於坦","於坦"],["於崇文","於崇文"],["於忠祥","於忠祥"],["於惟一","於惟一"],["於戲","於戏"],["於敖","於敖"],["於梨華","於梨华"],["於清言","於清言"],["於琳","於琳"],["於穆","於穆"],["於竹屋","於竹屋"],["於菟","於菟"],["於邑","於邑"],["於陵子","於陵子"],["旋乾轉坤","旋乾转坤"],["旋轉乾坤","旋转乾坤"],["旋轉乾坤之力","旋转乾坤之力"],["明瞭","明了"],["明覆","明复"],["書中自有千鍾粟","书中自有千锺粟"],["朝乾夕惕","朝乾夕惕"],["木吒","木吒"],["李乾德","李乾德"],["李澤鉅","李泽钜"],["李鍊福","李链福"],["李鍾郁","李锺郁"],["樊於期","樊於期"],["沈沒","沉没"],["沈沒成本","沉没成本"],["沈積","沉积"],["沈船","沉船"],["沈默","沉默"],["流徵","流徵"],["浪蕩乾坤","浪荡乾坤"],["滑藉","滑借"],["牴牾","抵牾"],["牴觸","抵触"],["狐藉虎威","狐借虎威"],["珍珠項鍊","珍珠项链"],["甚鉅","甚钜"],["申覆","申复"],["畢昇","毕昇"],["發覆","发复"],["盼既示覆","盼既示复"],["瞭如","了如"],["瞭如指掌","了如指掌"],["瞭望","瞭望"],["瞭然","了然"],["瞭然於心","了然于心"],["瞭若指掌","了若指掌"],["瞭解","了解"],["瞭解到","了解到"],["示覆","示复"],["神祇","神祇"],["稟覆","禀复"],["答覆","答复"],["篤麼","笃麽"],["簡單明瞭","简单明了"],["籌畫","筹划"],["素藉","素借"],["老態龍鍾","老态龙钟","老态龙锺"],["肘手鍊足","肘手链足"],["茵藉","茵借"],["萬鍾","万锺"],["蒜薹","蒜薹"],["蕓薹","芸薹"],["蕩覆","荡复"],["蕭乾","萧乾"],["藉代","借代"],["藉以","借以"],["藉助","借助"],["藉助於","借助于"],["藉卉","借卉"],["藉口","借口"],["藉喻","借喻"],["藉寇兵","借寇兵"],["藉寇兵齎盜糧","借寇兵赍盗粮"],["藉手","借手"],["藉據","借据"],["藉故","借故"],["藉故推辭","借故推辞"],["藉方","借方"],["藉條","借条"],["藉槁","借槁"],["藉機","借机"],["藉此","借此"],["藉此機會","借此机会"],["藉甚","借甚"],["藉由","借由"],["藉着","借着"],["藉端","借端"],["藉端生事","借端生事"],["藉箸代籌","借箸代筹"],["藉草枕塊","借草枕块"],["藉藉","借借"],["藉藉无名","藉藉无名"],["藉詞","借词"],["藉讀","借读"],["藉資","借资"],["衹得","只得"],["衹見樹木","只见树木"],["衹見樹木不見森林","只见树木不见森林"],["袖裏乾坤","袖里乾坤"],["覆上","复上"],["覆住","复住"],["覆信","复信"],["覆冒","复冒"],["覆呈","复呈"],["覆命","复命"],["覆墓","复墓"],["覆宗","复宗"],["覆帳","复帐"],["覆幬","复帱"],["覆成","复成"],["覆按","复按"],["覆文","复文"],["覆杯","复杯"],["覆校","复校"],["覆瓿","复瓿"],["覆盂","复盂"],["覆盆","覆盆"],["覆盆子","覆盆子"],["覆盤","覆盘"],["覆育","复育"],["覆蕉尋鹿","复蕉寻鹿"],["覆逆","复逆"],["覆醢","复醢"],["覆醬瓿","复酱瓿"],["覆電","复电"],["覆露","复露"],["覆鹿尋蕉","复鹿寻蕉"],["覆鹿遺蕉","复鹿遗蕉"],["覆鼎","复鼎"],["見覆","见复"],["角徵","角徵"],["角徵羽","角徵羽"],["計畫","计划"],["變徵","变徵"],["變徵之聲","变徵之声"],["變徵之音","变徵之音"],["貂覆額","貂复额"],["買臣覆水","买臣复水"],["踅門瞭戶","踅门了户"],["躪藉","躏借"],["郭子乾","郭子乾"],["酒逢知己千鍾少","酒逢知己千锺少"],["酒逢知己千鍾少話不投機半句多","酒逢知己千锺少话不投机半句多"],["醞藉","酝借"],["重覆","重复"],["金吒","金吒"],["金鍊","金链"],["鈕釦","纽扣"],["鈞覆","钧复"],["鉅子","钜子"],["鉅萬","钜万"],["鉅防","钜防"],["鉸鍊","铰链"],["銀鍊","银链"],["錢鍾書","钱锺书"],["鍊墜","链坠"],["鍊子","链子"],["鍊形","链形"],["鍊條","链条"],["鍊錘","链锤"],["鍊鎖","链锁"],["鍛鍾","锻锺"],["鍾繇","钟繇","锺繇"],["鍾萬梅","锺万梅"],["鍾重發","锺重发"],["鍾鍛","锺锻"],["鍾馗","锺馗"],["鎖鍊","锁链"],["鐵鍊","铁链"],["鑽石項鍊","钻石项链"],["雁杳魚沈","雁杳鱼沉"],["雖覆能復","虽覆能复"],["電覆","电复"],["露覆","露复"],["項鍊","项链"],["頗覆","颇复"],["頸鍊","颈链"],["顛乾倒坤","颠乾倒坤"],["顛倒乾坤","颠倒乾坤"],["顧藉","顾借"],["麼些族","麽些族"],["黄鍾公","黄锺公"],["龍鍾","龙钟","龙锺"]],"TWPhrasesIT":[["PN結","PN接面"],["SQL注入","SQL隱碼攻擊"],["SQL注入攻擊","SQL隱碼攻擊"],["三極管","三極體"],["下拉列表","下拉選單"],["並行計算","平行計算"],["中間件","中介軟體"],["串口","串列埠"],["串行","序列"],["串行端口","串列埠"],["主引導記錄","主開機記錄"],["主板","主機板"],["二極管","二極體"],["互聯網","網際網路"],["交互","互動"],["交互式","互動式"],["人工智能","人工智慧"],["代碼","程式碼","代碼"],["代碼頁","內碼表"],["以太網","乙太網"],["任務欄","工作列"],["任務管理器","工作管理員"],["仿真","模擬"],["位圖","點陣圖"],["低級","低階","低級"],["便攜式","行動式","攜帶型"],["保存","儲存"],["信噪比","訊雜比"],["信息","資訊"],["信息安全","資訊保安"],["信息技術","資訊科技"],["信息論","資訊理論"],["信號","訊號","信號"],["信道","通道"],["傳感","感測"],["像素","畫素"],["僞代碼","虛擬碼"],["優先級","優先順序"],["元數據","後設資料"],["元編程","超程式設計"],["光標","游標"],["光盤","光碟"],["光驅","光碟機"],["免提","擴音"],["內存","記憶體"],["內核","核心"],["內置","內建"],["內聯函數","行內函數"],["全局","全域性"],["全角","全形"],["兼容","相容"],["冒泡排序","氣泡排序"],["函數","函式"],["函數式編程","函數語言程式設計"],["刀片服務器","刀鋒伺服器"],["分佈式","分散式"],["分區","分割槽"],["分辨率","解析度"],["刷新","重新整理"],["刻錄","燒錄"],["前綴","字首"],["剪切","剪下"],["剪貼板","剪貼簿"],["創建","建立"],["加載","載入"],["半角","半形"],["博客","部落格"],["卸載","解除安裝"],["原代碼","原始碼"],["參數","引數"],["參數表","參數列"],["句柄","控制代碼"],["可視化","視覺化"],["呼出","撥出"],["呼叫轉移","來電轉駁"],["命令式編程","指令式程式設計"],["命令行","命令列"],["命名空間","名稱空間"],["哈希","雜湊"],["單片機","微控制器"],["回調","回撥"],["固件","韌體"],["圖像","影象"],["圖庫","相簿"],["圖標","圖示"],["在線","線上"],["地址","地址","位址"],["地址欄","位址列"],["城域網","都會網路"],["堆棧","堆疊"],["場效應管","場效電晶體"],["壁紙","桌布","壁紙"],["外置","外接"],["外鍵","外來鍵"],["多任務","多工"],["多態","多型"],["多線程","多執行緒"],["字庫","字型檔"],["字段","欄位"],["字符","字元"],["字符串","字串"],["字符集","字符集"],["字節","位元組"],["字體","字型"],["存儲","儲存"],["存盤","存檔"],["宏","巨集"],["宏內核","單核心"],["寄存器","暫存器"],["密鑰","金鑰"],["實例","例項","實例"],["實模式","真實模式"],["審覈","稽覈"],["寫保護","防寫"],["寬帶","寬頻"],["尋址","定址"],["對話框","對話方塊"],["對象","物件","對象"],["導入","匯入"],["導出","匯出"],["局域網","區域網"],["局部","區域性"],["屏幕","螢幕"],["屏蔽","遮蔽"],["嵌套","巢狀"],["布爾","布林"],["帶寬","頻寬"],["引導程序","載入程式"],["彙編","彙編","組譯"],["彙編語言","組合語言"],["後綴","字尾"],["循環","迴圈","循環"],["性價比","價效比"],["性能","效能"],["截取","擷取"],["截屏","截圖"],["打印","列印"],["打印機","印表機"],["打開","開啟","打開"],["拋出","丟擲"],["持久性","永續性"],["指針","指標"],["捲積","摺積"],["掃描儀","掃描器"],["掛斷","結束通話"],["採樣","取樣"],["採樣率","取樣率"],["接口","介面"],["控件","控制元件"],["插件","外掛"],["搜索","搜尋"],["操作數","運算元"],["操作系統","作業系統"],["擴展","擴充套件"],["擴展名","副檔名"],["支持","支援"],["支持者","支持者"],["散列","雜湊"],["數字","數字","數位"],["數字印刷","數位印刷"],["數字電子","數位電子"],["數字電路","數位電路"],["數據","資料"],["數據倉庫","資料倉儲"],["數據報","資料包"],["數據庫","資料庫"],["數據挖掘","資料探勘"],["數據源","資料來源"],["數組","陣列"],["文件","檔案"],["文件名","檔名"],["文件夾","資料夾"],["文件擴展名","副檔名"],["文字處理","文書處理"],["文本","文字"],["文檔","文件"],["映射","對映"],["時分多址","分時多重進接"],["時分複用","分時多工"],["時鐘頻率","時脈頻率"],["晶閘管","閘流體"],["晶體管","電晶體"],["智能","智慧"],["最終用戶","終端使用者"],["有損壓縮","有失真壓縮"],["服務器","伺服器"],["本地代碼","原生代碼"],["析構函數","解構函式"],["枚舉","列舉"],["查找","查詢"],["查看","檢視"],["桌面型","桌上型"],["構造函數","建構函式"],["標識符","識別符號"],["模塊","模組"],["模擬","模擬","類比"],["模擬電子","類比電子"],["模擬電路","類比電路"],["權限","許可權"],["正則表達式","正規表示式"],["死機","宕機"],["殺毒","防毒"],["比特","位元"],["比特幣","比特幣"],["比特率","位元率"],["波分複用","波長分波多工"],["消息","訊息","消息"],["添加","新增"],["源代碼","原始碼"],["源文件","原始檔"],["源碼","原始碼"],["溢出","溢位"],["演示文稿","簡報"],["激光","鐳射"],["激活","啟用"],["無損壓縮","無失真壓縮"],["物理內存","實體記憶體"],["物理地址","實體地址"],["狀態欄","狀態列"],["用戶","使用者"],["用戶名","使用者名稱"],["界面","介面"],["異步","非同步"],["登錄","登入"],["發佈","釋出"],["發送","傳送"],["皮膚","面板"],["盤片","碟片"],["盤符","碟符"],["目標代碼","目的碼"],["相冊","相簿"],["矢量","向量"],["知識產權","智慧財產權"],["短信","簡訊"],["硬件","硬體"],["硬盤","硬碟"],["碼分多址","分碼多重進接"],["碼率","位元速率"],["磁盤","磁碟"],["磁道","磁軌"],["社區","社羣","社區"],["移動硬盤","行動硬碟"],["移動網絡","行動網路"],["移動資料","行動資料"],["移動通信","行動通訊"],["移動電話","行動電話"],["程序","程式"],["程序員","程式設計師"],["空分多址","分空間多重進接"],["空分複用","空間多工"],["窗口","視窗"],["端口","埠"],["筆記本電腦","膝上型電腦"],["算子","運算元"],["算法","演算法"],["範式","正規化"],["粘貼","貼上","粘貼"],["紅心大戰","傷心小棧"],["組件","元件"],["綁定","繫結"],["網上鄰居","網路上的芳鄰"],["網卡","網絡卡"],["網吧","網咖"],["網絡","網路"],["網關","閘道器"],["線程","執行緒"],["編程","程式設計"],["編程語言","程式語言"],["緩存","快取"],["縮略圖","縮圖"],["縮進","縮排"],["總線","匯流排"],["缺省","預設"],["聯繫","聯絡"],["聯繫歷史","通話記錄"],["聲卡","音效卡"],["聲明","宣告"],["脫機","離線"],["腳本","指令碼"],["自動轉屏","自動旋轉螢幕"],["臺式機","桌上型電腦"],["航天飛機","太空梭"],["芯片","晶片"],["菜單","選單","菜單"],["萬維網","全球資訊網"],["藍牙","藍芽"],["虛函數","虛擬函式"],["虛擬機","虛擬機器"],["表達式","表示式","運算式"],["複印","影印"],["複選按鈕","覈取按鈕"],["複選框","覈取方塊"],["視圖","檢視"],["視頻","視訊"],["解釋器","直譯器"],["觸摸","觸控"],["觸摸屏","觸控式螢幕"],["計算機安全","電腦保安"],["計算機科學","電腦科學"],["訪問","訪問","存取"],["設備","裝置"],["設置","設定"],["註冊機","序號產生器"],["註冊表","登錄檔"],["註銷","登出"],["調制","調變"],["調度","排程"],["調用","呼叫"],["調色板","調色盤"],["調製解調器","數據機"],["調試","除錯","偵錯"],["調試器","偵錯程式"],["變量","變數"],["軟件","軟體"],["軟驅","軟碟機"],["通信","通訊"],["通訊卡","通話卡"],["通配符","萬用字元"],["連接","連線"],["連接器","聯結器"],["進制","進位制"],["進程","程序","進程"],["運算符","運算子"],["運行","執行"],["過程式編程","程序式程式設計"],["遞歸","遞迴"],["遠程","遠端"],["適配器","介面卡"],["邏輯門","邏輯閘"],["重命名","重新命名"],["重裝","重灌"],["重載","過載"],["金屬氧化物半導體","金氧半導體"],["錄像","錄影"],["鏈接","連結"],["鏈表","連結串列"],["鏡像","映象"],["門戶網站","入口網站"],["門電路","閘電路"],["閃存","快閃記憶體"],["關係數據庫","關聯式資料庫"],["隊列","佇列"],["集成","整合"],["集成電路","積體電路"],["集羣","叢集"],["雲存儲","雲端儲存"],["雲計算","雲端計算"],["面向對象","物件導向"],["面向過程","程序導向"],["音頻","音訊"],["頁眉","頁首"],["頁腳","頁尾"],["項目","專案"],["預處理器","前處理器"],["頭文件","標頭檔案"],["頻分多址","分頻多重進接"],["頻分複用","分頻多工"],["類型","型別"],["類模板","類别範本"],["顯像管","映象管"],["顯卡","顯示卡"],["顯存","視訊記憶體"],["飛行模式","飛航模式"],["首席信息官","資訊長"],["首席執行官","執行長"],["首席技術官","技術長"],["首席運營官","營運長"],["高性能計算","高效能運算"],["高端","高階","進階"],["高級","高階","進階","高級"],["高速緩存","快取記憶體"],["默認","預設"],["默認值","預設值"],["點擊","點選"],["鼠標","滑鼠"]],"TWPhrasesName":[["乍得","查德"],["也門","葉門"],["仙童半導體","快捷半導體"],["伯利茲","貝里斯"],["佛得角","維德角"],["傅里葉","傅立葉"],["克羅地亞","克羅埃西亞"],["列支敦士登","列支敦斯登"],["利比里亞","賴比瑞亞"],["加納","迦納"],["加蓬","加彭"],["博茨瓦納","波札那"],["卡塔爾","卡達"],["危地馬拉","瓜地馬拉"],["厄瓜多爾","厄瓜多"],["厄立特里亞","厄利垂亞"],["吉布堤","吉布地"],["哈薩克斯坦","哈薩克"],["哥斯達黎加","哥斯大黎加"],["圖瓦盧","吐瓦魯"],["土庫曼斯坦","土庫曼"],["圭亞那","蓋亞那"],["坦桑尼亞","坦尚尼亞"],["埃塞俄比亞","衣索比亞"],["基里巴斯","吉里巴斯"],["塔吉克斯坦","塔吉克"],["塞拉利昂","獅子山"],["塞浦路斯","塞普勒斯"],["塞舌爾","塞席爾"],["多米尼加","多明尼加"],["安提瓜和巴布達","安地卡及巴布達"],["尼日利亞","奈及利亞"],["尼日爾","尼日"],["岡比亞","甘比亞"],["巴巴多斯","巴貝多"],["巴布亞新幾內亞","巴布亞紐幾內亞"],["布基納法索","布吉納法索"],["布隆迪","蒲隆地"],["帕勞","帛琉"],["幾內亞比紹","幾內亞比索"],["意大利","義大利"],["所羅門羣島","索羅門羣島"],["文萊","汶萊"],["斯威士蘭","史瓦濟蘭"],["斯洛文尼亞","斯洛維尼亞"],["新西蘭","紐西蘭"],["格林納達","格瑞那達"],["格魯吉亞","喬治亞"],["歐拉","尤拉"],["毛里塔尼亞","茅利塔尼亞"],["毛里求斯","模里西斯"],["沙特阿拉伯","沙烏地阿拉伯"],["波斯尼亞黑塞哥維那","波士尼亞赫塞哥維納"],["津巴布韋","辛巴威"],["洪都拉斯","宏都拉斯"],["溫納圖萬","那杜"],["烏茲別克斯坦","烏茲別克"],["特立尼達和多巴哥","千里達及托巴哥"],["瑙魯","諾魯"],["瓦努阿圖","萬那杜"],["盧旺達","盧安達"],["科摩羅","葛摩"],["科特迪瓦","象牙海岸"],["突尼斯","突尼西亞"],["索馬里","索馬利亞"],["老撾","寮國"],["聖基茨和尼維斯","聖克里斯多福及尼維斯"],["聖文森特和格林納丁斯","聖文森及格瑞那丁"],["聖盧西亞","聖露西亞"],["聖馬力諾","聖馬利諾"],["肯尼亞","肯亞"],["莫桑比克","莫三比克"],["萊索托","賴索托"],["萬象","永珍"],["蘇里南","蘇利南"],["貝寧","貝南"],["贊比亞","尚比亞"],["阿塞拜疆","亞塞拜然"],["阿拉伯聯合酋長國","阿拉伯聯合大公國"],["香農","夏農"],["馬爾代夫","馬爾地夫"],["馬里共和國","馬利共和國"]],"TWPhrasesOther":[["元音","母音"],["出租車","計程車"],["咖喱","咖哩"],["奔馳","賓士"],["奶酪","乳酪"],["方便麵","速食麵"],["涼菜","冷盤"],["砹","砈"],["硅","矽"],["納米","奈米"],["詞組","片語"],["蹦極","笨豬跳"],["輔音","子音"],["酰","醯"],["鈁","鍅"],["鈈","鈽"],["錇","鉳"],["鍀","鎝"],["鎄","鑀"],["鎇","鋂"],["鎿","錼"],["鐦","鉲"],["鑥","鎦"]],"TWVariants":[["僞","偽"],["兇","凶"],["啓","啟"],["嫺","嫻"],["嬀","媯"],["峯","峰"],["幺","么"],["擡","抬"],["曬","晒"],["棱","稜"],["檐","簷"],["污","汙"],["泄","洩"],["涌","湧"],["潙","溈"],["潨","潀"],["爲","為"],["牀","床"],["痹","痺"],["癡","痴"],["着","著"],["睾","睪"],["竈","灶"],["糉","粽"],["繮","韁"],["纔","才"],["羣","群"],["蔿","蒍"],["衆","眾"],["裏","裡"],["覈","核"],["踊","踴"],["鉢","缽"],["鮎","鯰"],["麪","麵"],["齶","顎"]],"TWVariantsRevPhrases":[["凶事","凶事"],["凶信","凶信"],["凶兆","凶兆"],["凶吉","凶吉"],["凶地","凶地"],["凶多吉少","凶多吉少"],["凶宅","凶宅"],["凶年","凶年"],["凶德","凶德"],["凶怪","凶怪"],["凶日","凶日"],["凶服","凶服"],["凶歲","凶歲"],["凶死","凶死"],["凶氣","凶氣"],["凶煞","凶煞"],["凶燄","凶燄"],["凶神","凶神"],["凶禮","凶禮"],["凶耗","凶耗"],["凶肆","凶肆"],["凶荒","凶荒"],["凶訊","凶訊"],["凶豎","凶豎"],["凶身","凶身"],["凶逆","凶逆"],["凶門","凶門"],["合著","合著"],["吉凶","吉凶"],["名著","名著"],["四凶","四凶"],["大凶","大凶"],["巨著","巨著"],["昭著","昭著"],["歲凶","歲凶"],["著作","著作"],["著名","著名"],["著式","著式"],["著志","著志"],["著於","著於"],["著書","著書"],["著白","著白"],["著稱","著稱"],["著者","著者"],["著述","著述"],["著錄","著錄"],["逢凶","逢凶"],["避凶","避凶"],["鉅著","鉅著"],["閔凶","閔凶"],["顯著","顯著"]]}')},function(e,t,n){var r;e.exports=function(i,o){var a,s,u=i.document,c=i.location,l=i.navigator,f=i.jQuery,h=i.$,p=Array.prototype.push,d=Array.prototype.slice,v=Array.prototype.indexOf,g=Object.prototype.toString,y=Object.prototype.hasOwnProperty,m=String.prototype.trim,b=function(e,t){return new b.fn.init(e,t,a)},_=/[\-+]?(?:\d*\.|)\d+(?:[eE][\-+]?\d+|)/.source,w=/\S/,x=/\s+/,T=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,C=/^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,E=/^<(\w+)\s*\/?>(?:<\/\1>|)$/,k=/^[\],:{}\s]*$/,S=/(?:^|:|,)(?:\s*\[)+/g,A=/\\(?:["\\\/bfnrt]|u[\da-fA-F]{4})/g,O=/"[^"\\\r\n]*"|true|false|null|-?(?:\d\d*\.|)\d+(?:[eE][\-+]?\d+|)/g,D=/^-ms-/,P=/-([\da-z])/gi,N=function(e,t){return(t+"").toUpperCase()},j=function(){u.addEventListener?(u.removeEventListener("DOMContentLoaded",j,!1),b.ready()):"complete"===u.readyState&&(u.detachEvent("onreadystatechange",j),b.ready())},L={};b.fn=b.prototype={constructor:b,init:function(e,t,n){var r,i,o;if(!e)return this;if(e.nodeType)return this.context=this[0]=e,this.length=1,this;if("string"==typeof e){if(!(r="<"===e.charAt(0)&&">"===e.charAt(e.length-1)&&e.length>=3?[null,e,null]:C.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1])return o=(t=t instanceof b?t[0]:t)&&t.nodeType?t.ownerDocument||t:u,e=b.parseHTML(r[1],o,!0),E.test(r[1])&&b.isPlainObject(t)&&this.attr.call(e,t,!0),b.merge(this,e);if((i=u.getElementById(r[2]))&&i.parentNode){if(i.id!==r[2])return n.find(e);this.length=1,this[0]=i}return this.context=u,this.selector=e,this}return b.isFunction(e)?n.ready(e):(void 0!==e.selector&&(this.selector=e.selector,this.context=e.context),b.makeArray(e,this))},selector:"",jquery:"1.8.1",length:0,size:function(){return this.length},toArray:function(){return d.call(this)},get:function(e){return null==e?this.toArray():e<0?this[this.length+e]:this[e]},pushStack:function(e,t,n){var r=b.merge(this.constructor(),e);return r.prevObject=this,r.context=this.context,"find"===t?r.selector=this.selector+(this.selector?" ":"")+n:t&&(r.selector=this.selector+"."+t+"("+n+")"),r},each:function(e,t){return b.each(this,e,t)},ready:function(e){return b.ready.promise().done(e),this},eq:function(e){return-1==(e=+e)?this.slice(e):this.slice(e,e+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(d.apply(this,arguments),"slice",d.call(arguments).join(","))},map:function(e){return this.pushStack(b.map(this,(function(t,n){return e.call(t,n,t)})))},end:function(){return this.prevObject||this.constructor(null)},push:p,sort:[].sort,splice:[].splice},b.fn.init.prototype=b.fn,b.extend=b.fn.extend=function(){var e,t,n,r,i,o,a=arguments[0]||{},s=1,u=arguments.length,c=!1;for("boolean"==typeof a&&(c=a,a=arguments[1]||{},s=2),"object"==typeof a||b.isFunction(a)||(a={}),u===s&&(a=this,--s);s<u;s++)if(null!=(e=arguments[s]))for(t in e)n=a[t],a!==(r=e[t])&&(c&&r&&(b.isPlainObject(r)||(i=b.isArray(r)))?(i?(i=!1,o=n&&b.isArray(n)?n:[]):o=n&&b.isPlainObject(n)?n:{},a[t]=b.extend(c,o,r)):void 0!==r&&(a[t]=r));return a},b.extend({noConflict:function(e){return i.$===b&&(i.$=h),e&&i.jQuery===b&&(i.jQuery=f),b},isReady:!1,readyWait:1,holdReady:function(e){e?b.readyWait++:b.ready(!0)},ready:function(e){if(!(!0===e?--b.readyWait:b.isReady)){if(!u.body)return setTimeout(b.ready,1);b.isReady=!0,!0!==e&&--b.readyWait>0||(s.resolveWith(u,[b]),b.fn.trigger&&b(u).trigger("ready").off("ready"))}},isFunction:function(e){return"function"===b.type(e)},isArray:Array.isArray||function(e){return"array"===b.type(e)},isWindow:function(e){return null!=e&&e==e.window},isNumeric:function(e){return!isNaN(parseFloat(e))&&isFinite(e)},type:function(e){return null==e?String(e):L[g.call(e)]||"object"},isPlainObject:function(e){if(!e||"object"!==b.type(e)||e.nodeType||b.isWindow(e))return!1;try{if(e.constructor&&!y.call(e,"constructor")&&!y.call(e.constructor.prototype,"isPrototypeOf"))return!1}catch(e){return!1}var t;for(t in e);return void 0===t||y.call(e,t)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},error:function(e){throw new Error(e)},parseHTML:function(e,t,n){var r;return e&&"string"==typeof e?("boolean"==typeof t&&(n=t,t=0),t=t||u,(r=E.exec(e))?[t.createElement(r[1])]:(r=b.buildFragment([e],t,n?null:[]),b.merge([],(r.cacheable?b.clone(r.fragment):r.fragment).childNodes))):null},parseJSON:function(e){return e&&"string"==typeof e?(e=b.trim(e),i.JSON&&i.JSON.parse?i.JSON.parse(e):k.test(e.replace(A,"@").replace(O,"]").replace(S,""))?new Function("return "+e)():void b.error("Invalid JSON: "+e)):null},parseXML:function(e){var t;if(!e||"string"!=typeof e)return null;try{i.DOMParser?t=(new DOMParser).parseFromString(e,"text/xml"):((t=new ActiveXObject("Microsoft.XMLDOM")).async="false",t.loadXML(e))}catch(e){t=void 0}return t&&t.documentElement&&!t.getElementsByTagName("parsererror").length||b.error("Invalid XML: "+e),t},noop:function(){},globalEval:function(e){e&&w.test(e)&&(i.execScript||function(e){i.eval.call(i,e)})(e)},camelCase:function(e){return e.replace(D,"ms-").replace(P,N)},nodeName:function(e,t){return e.nodeName&&e.nodeName.toUpperCase()===t.toUpperCase()},each:function(e,t,n){var r,i=0,o=e.length,a=void 0===o||b.isFunction(e);if(n)if(a){for(r in e)if(!1===t.apply(e[r],n))break}else for(;i<o&&!1!==t.apply(e[i++],n););else if(a){for(r in e)if(!1===t.call(e[r],r,e[r]))break}else for(;i<o&&!1!==t.call(e[i],i,e[i++]););return e},trim:m&&!m.call("\ufeff ")?function(e){return null==e?"":m.call(e)}:function(e){return null==e?"":e.toString().replace(T,"")},makeArray:function(e,t){var n,r=t||[];return null!=e&&(n=b.type(e),null==e.length||"string"===n||"function"===n||"regexp"===n||b.isWindow(e)?p.call(r,e):b.merge(r,e)),r},inArray:function(e,t,n){var r;if(t){if(v)return v.call(t,e,n);for(r=t.length,n=n?n<0?Math.max(0,r+n):n:0;n<r;n++)if(n in t&&t[n]===e)return n}return-1},merge:function(e,t){var n=t.length,r=e.length,i=0;if("number"==typeof n)for(;i<n;i++)e[r++]=t[i];else for(;void 0!==t[i];)e[r++]=t[i++];return e.length=r,e},grep:function(e,t,n){var r=[],i=0,o=e.length;for(n=!!n;i<o;i++)n!==!!t(e[i],i)&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=[],a=0,s=e.length;if(e instanceof b||void 0!==s&&"number"==typeof s&&(s>0&&e[0]&&e[s-1]||0===s||b.isArray(e)))for(;a<s;a++)null!=(r=t(e[a],a,n))&&(o[o.length]=r);else for(i in e)null!=(r=t(e[i],i,n))&&(o[o.length]=r);return o.concat.apply([],o)},guid:1,proxy:function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),b.isFunction(e))return r=d.call(arguments,2),(i=function(){return e.apply(t,r.concat(d.call(arguments)))}).guid=e.guid=e.guid||i.guid||b.guid++,i},access:function(e,t,n,r,i,o,a){var s,u=null==n,c=0,l=e.length;if(n&&"object"==typeof n){for(c in n)b.access(e,t,c,n[c],1,o,r);i=1}else if(void 0!==r){if(s=void 0===a&&b.isFunction(r),u&&(s?(s=t,t=function(e,t,n){return s.call(b(e),n)}):(t.call(e,r),t=null)),t)for(;c<l;c++)t(e[c],n,s?r.call(e[c],c,t(e[c],n)):r,a);i=1}return i?e:u?t.call(e):l?t(e[0],n):o},now:function(){return(new Date).getTime()}}),b.ready.promise=function(e){if(!s)if(s=b.Deferred(),"complete"===u.readyState)setTimeout(b.ready,1);else if(u.addEventListener)u.addEventListener("DOMContentLoaded",j,!1),i.addEventListener("load",b.ready,!1);else{u.attachEvent("onreadystatechange",j),i.attachEvent("onload",b.ready);var t=!1;try{t=null==i.frameElement&&u.documentElement}catch(e){}t&&t.doScroll&&function e(){if(!b.isReady){try{t.doScroll("left")}catch(t){return setTimeout(e,50)}b.ready()}}()}return s.promise(e)},b.each("Boolean Number String Function Array Date RegExp Object".split(" "),(function(e,t){L["[object "+t+"]"]=t.toLowerCase()})),a=b(u);var I={};b.Callbacks=function(e){e="string"==typeof e?I[e]||function(e){var t=I[e]={};return b.each(e.split(x),(function(e,n){t[n]=!0})),t}(e):b.extend({},e);var t,n,r,i,o,a,s=[],u=!e.once&&[],c=function(f){for(t=e.memory&&f,n=!0,a=i||0,i=0,o=s.length,r=!0;s&&a<o;a++)if(!1===s[a].apply(f[0],f[1])&&e.stopOnFalse){t=!1;break}r=!1,s&&(u?u.length&&c(u.shift()):t?s=[]:l.disable())},l={add:function(){if(s){var n=s.length;!function t(n){b.each(n,(function(n,r){var i=b.type(r);"function"!==i||e.unique&&l.has(r)?r&&r.length&&"string"!==i&&t(r):s.push(r)}))}(arguments),r?o=s.length:t&&(i=n,c(t))}return this},remove:function(){return s&&b.each(arguments,(function(e,t){for(var n;(n=b.inArray(t,s,n))>-1;)s.splice(n,1),r&&(n<=o&&o--,n<=a&&a--)})),this},has:function(e){return b.inArray(e,s)>-1},empty:function(){return s=[],this},disable:function(){return s=u=t=void 0,this},disabled:function(){return!s},lock:function(){return u=void 0,t||l.disable(),this},locked:function(){return!u},fireWith:function(e,t){return t=[e,(t=t||[]).slice?t.slice():t],!s||n&&!u||(r?u.push(t):c(t)),this},fire:function(){return l.fireWith(this,arguments),this},fired:function(){return!!n}};return l},b.extend({Deferred:function(e){var t=[["resolve","done",b.Callbacks("once memory"),"resolved"],["reject","fail",b.Callbacks("once memory"),"rejected"],["notify","progress",b.Callbacks("memory")]],n="pending",r={state:function(){return n},always:function(){return i.done(arguments).fail(arguments),this},then:function(){var e=arguments;return b.Deferred((function(n){b.each(t,(function(t,r){var o=r[0],a=e[t];i[r[1]](b.isFunction(a)?function(){var e=a.apply(this,arguments);e&&b.isFunction(e.promise)?e.promise().done(n.resolve).fail(n.reject).progress(n.notify):n[o+"With"](this===i?n:this,[e])}:n[o])})),e=null})).promise()},promise:function(e){return"object"==typeof e?b.extend(e,r):r}},i={};return r.pipe=r.then,b.each(t,(function(e,o){var a=o[2],s=o[3];r[o[1]]=a.add,s&&a.add((function(){n=s}),t[1^e][2].disable,t[2][2].lock),i[o[0]]=a.fire,i[o[0]+"With"]=a.fireWith})),r.promise(i),e&&e.call(i,i),i},when:function(e){var t,n,r,i=0,o=d.call(arguments),a=o.length,s=1!==a||e&&b.isFunction(e.promise)?a:0,u=1===s?e:b.Deferred(),c=function(e,n,r){return function(i){n[e]=this,r[e]=arguments.length>1?d.call(arguments):i,r===t?u.notifyWith(n,r):--s||u.resolveWith(n,r)}};if(a>1)for(t=new Array(a),n=new Array(a),r=new Array(a);i<a;i++)o[i]&&b.isFunction(o[i].promise)?o[i].promise().done(c(i,r,o)).fail(u.reject).progress(c(i,n,t)):--s;return s||u.resolveWith(r,o),u.promise()}}),b.support=function(){var e,t,n,r,o,a,s,c,l,f,h,p=u.createElement("div");if(p.setAttribute("className","t"),p.innerHTML="  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>",t=p.getElementsByTagName("*"),(n=p.getElementsByTagName("a")[0]).style.cssText="top:1px;float:left;opacity:.5",!t||!t.length||!n)return{};o=(r=u.createElement("select")).appendChild(u.createElement("option")),a=p.getElementsByTagName("input")[0],e={leadingWhitespace:3===p.firstChild.nodeType,tbody:!p.getElementsByTagName("tbody").length,htmlSerialize:!!p.getElementsByTagName("link").length,style:/top/.test(n.getAttribute("style")),hrefNormalized:"/a"===n.getAttribute("href"),opacity:/^0.5/.test(n.style.opacity),cssFloat:!!n.style.cssFloat,checkOn:"on"===a.value,optSelected:o.selected,getSetAttribute:"t"!==p.className,enctype:!!u.createElement("form").enctype,html5Clone:"<:nav></:nav>"!==u.createElement("nav").cloneNode(!0).outerHTML,boxModel:"CSS1Compat"===u.compatMode,submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0,boxSizingReliable:!0,pixelPosition:!1},a.checked=!0,e.noCloneChecked=a.cloneNode(!0).checked,r.disabled=!0,e.optDisabled=!o.disabled;try{delete p.test}catch(t){e.deleteExpando=!1}if(!p.addEventListener&&p.attachEvent&&p.fireEvent&&(p.attachEvent("onclick",h=function(){e.noCloneEvent=!1}),p.cloneNode(!0).fireEvent("onclick"),p.detachEvent("onclick",h)),(a=u.createElement("input")).value="t",a.setAttribute("type","radio"),e.radioValue="t"===a.value,a.setAttribute("checked","checked"),a.setAttribute("name","t"),p.appendChild(a),(s=u.createDocumentFragment()).appendChild(p.lastChild),e.checkClone=s.cloneNode(!0).cloneNode(!0).lastChild.checked,e.appendChecked=a.checked,s.removeChild(a),s.appendChild(p),p.attachEvent)for(l in{submit:!0,change:!0,focusin:!0})(f=(c="on"+l)in p)||(p.setAttribute(c,"return;"),f="function"==typeof p[c]),e[l+"Bubbles"]=f;return b((function(){var t,n,r,o,a="padding:0;margin:0;border:0;display:block;overflow:hidden;",s=u.getElementsByTagName("body")[0];s&&((t=u.createElement("div")).style.cssText="visibility:hidden;border:0;width:0;height:0;position:static;top:0;margin-top:1px",s.insertBefore(t,s.firstChild),n=u.createElement("div"),t.appendChild(n),n.innerHTML="<table><tr><td></td><td>t</td></tr></table>",(r=n.getElementsByTagName("td"))[0].style.cssText="padding:0;margin:0;border:0;display:none",f=0===r[0].offsetHeight,r[0].style.display="",r[1].style.display="none",e.reliableHiddenOffsets=f&&0===r[0].offsetHeight,n.innerHTML="",n.style.cssText="box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;padding:1px;border:1px;display:block;width:4px;margin-top:1%;position:absolute;top:1%;",e.boxSizing=4===n.offsetWidth,e.doesNotIncludeMarginInBodyOffset=1!==s.offsetTop,i.getComputedStyle&&(e.pixelPosition="1%"!==(i.getComputedStyle(n,null)||{}).top,e.boxSizingReliable="4px"===(i.getComputedStyle(n,null)||{width:"4px"}).width,(o=u.createElement("div")).style.cssText=n.style.cssText=a,o.style.marginRight=o.style.width="0",n.style.width="1px",n.appendChild(o),e.reliableMarginRight=!parseFloat((i.getComputedStyle(o,null)||{}).marginRight)),void 0!==n.style.zoom&&(n.innerHTML="",n.style.cssText=a+"width:1px;padding:1px;display:inline;zoom:1",e.inlineBlockNeedsLayout=3===n.offsetWidth,n.style.display="block",n.style.overflow="visible",n.innerHTML="<div></div>",n.firstChild.style.width="5px",e.shrinkWrapBlocks=3!==n.offsetWidth,t.style.zoom=1),s.removeChild(t),t=n=r=o=null)})),s.removeChild(p),t=n=r=o=a=s=p=null,e}();var M=/(?:\{[\s\S]*\}|\[[\s\S]*\])$/,R=/([A-Z])/g;function B(e,t,n){if(void 0===n&&1===e.nodeType){var r="data-"+t.replace(R,"-$1").toLowerCase();if("string"==typeof(n=e.getAttribute(r))){try{n="true"===n||"false"!==n&&("null"===n?null:+n+""===n?+n:M.test(n)?b.parseJSON(n):n)}catch(e){}b.data(e,t,n)}else n=void 0}return n}function $(e){var t;for(t in e)if(("data"!==t||!b.isEmptyObject(e[t]))&&"toJSON"!==t)return!1;return!0}b.extend({cache:{},deletedIds:[],uuid:0,expando:"jQuery"+(b.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(e){return!!(e=e.nodeType?b.cache[e[b.expando]]:e[b.expando])&&!$(e)},data:function(e,t,n,r){if(b.acceptData(e)){var i,o,a=b.expando,s="string"==typeof t,u=e.nodeType,c=u?b.cache:e,l=u?e[a]:e[a]&&a;if(l&&c[l]&&(r||c[l].data)||!s||void 0!==n)return l||(u?e[a]=l=b.deletedIds.pop()||++b.uuid:l=a),c[l]||(c[l]={},u||(c[l].toJSON=b.noop)),"object"!=typeof t&&"function"!=typeof t||(r?c[l]=b.extend(c[l],t):c[l].data=b.extend(c[l].data,t)),i=c[l],r||(i.data||(i.data={}),i=i.data),void 0!==n&&(i[b.camelCase(t)]=n),s?null==(o=i[t])&&(o=i[b.camelCase(t)]):o=i,o}},removeData:function(e,t,n){if(b.acceptData(e)){var r,i,o,a=e.nodeType,s=a?b.cache:e,u=a?e[b.expando]:b.expando;if(s[u]){if(t&&(r=n?s[u]:s[u].data)){b.isArray(t)||(t=t in r||(t=b.camelCase(t))in r?[t]:t.split(" "));for(i=0,o=t.length;i<o;i++)delete r[t[i]];if(!(n?$:b.isEmptyObject)(r))return}(n||(delete s[u].data,$(s[u])))&&(a?b.cleanData([e],!0):b.support.deleteExpando||s!=s.window?delete s[u]:s[u]=null)}}},_data:function(e,t,n){return b.data(e,t,n,!0)},acceptData:function(e){var t=e.nodeName&&b.noData[e.nodeName.toLowerCase()];return!t||!0!==t&&e.getAttribute("classid")===t}}),b.fn.extend({data:function(e,t){var n,r,i,o,a,s=this[0],u=0,c=null;if(void 0===e){if(this.length&&(c=b.data(s),1===s.nodeType&&!b._data(s,"parsedAttrs"))){for(a=(i=s.attributes).length;u<a;u++)0===(o=i[u].name).indexOf("data-")&&(o=b.camelCase(o.substring(5)),B(s,o,c[o]));b._data(s,"parsedAttrs",!0)}return c}return"object"==typeof e?this.each((function(){b.data(this,e)})):((n=e.split(".",2))[1]=n[1]?"."+n[1]:"",r=n[1]+"!",b.access(this,(function(t){if(void 0===t)return void 0===(c=this.triggerHandler("getData"+r,[n[0]]))&&s&&(c=b.data(s,e),c=B(s,e,c)),void 0===c&&n[1]?this.data(n[0]):c;n[1]=t,this.each((function(){var i=b(this);i.triggerHandler("setData"+r,n),b.data(this,e,t),i.triggerHandler("changeData"+r,n)}))}),null,t,arguments.length>1,null,!1))},removeData:function(e){return this.each((function(){b.removeData(this,e)}))}}),b.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=b._data(e,t),n&&(!r||b.isArray(n)?r=b._data(e,t,b.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=b.queue(e,t),r=n.length,i=n.shift(),o=b._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,(function(){b.dequeue(e,t)}),o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return b._data(e,n)||b._data(e,n,{empty:b.Callbacks("once memory").add((function(){b.removeData(e,t+"queue",!0),b.removeData(e,n,!0)}))})}}),b.fn.extend({queue:function(e,t){var n=2;return"string"!=typeof e&&(t=e,e="fx",n--),arguments.length<n?b.queue(this[0],e):void 0===t?this:this.each((function(){var n=b.queue(this,e,t);b._queueHooks(this,e),"fx"===e&&"inprogress"!==n[0]&&b.dequeue(this,e)}))},dequeue:function(e){return this.each((function(){b.dequeue(this,e)}))},delay:function(e,t){return e=b.fx&&b.fx.speeds[e]||e,t=t||"fx",this.queue(t,(function(t,n){var r=setTimeout(t,e);n.stop=function(){clearTimeout(r)}}))},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=b.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";a--;)(n=b._data(o[a],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(t)}});var q,F,H,U=/[\t\r\n]/g,W=/\r/g,z=/^(?:button|input)$/i,K=/^(?:button|input|object|select|textarea)$/i,V=/^a(?:rea|)$/i,X=/^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,Y=b.support.getSetAttribute;b.fn.extend({attr:function(e,t){return b.access(this,b.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each((function(){b.removeAttr(this,e)}))},prop:function(e,t){return b.access(this,b.prop,e,t,arguments.length>1)},removeProp:function(e){return e=b.propFix[e]||e,this.each((function(){try{this[e]=void 0,delete this[e]}catch(e){}}))},addClass:function(e){var t,n,r,i,o,a,s;if(b.isFunction(e))return this.each((function(t){b(this).addClass(e.call(this,t,this.className))}));if(e&&"string"==typeof e)for(t=e.split(x),n=0,r=this.length;n<r;n++)if(1===(i=this[n]).nodeType)if(i.className||1!==t.length){for(o=" "+i.className+" ",a=0,s=t.length;a<s;a++)~o.indexOf(" "+t[a]+" ")||(o+=t[a]+" ");i.className=b.trim(o)}else i.className=e;return this},removeClass:function(e){var t,n,r,i,o,a,s;if(b.isFunction(e))return this.each((function(t){b(this).removeClass(e.call(this,t,this.className))}));if(e&&"string"==typeof e||void 0===e)for(t=(e||"").split(x),a=0,s=this.length;a<s;a++)if(1===(r=this[a]).nodeType&&r.className){for(n=(" "+r.className+" ").replace(U," "),i=0,o=t.length;i<o;i++)for(;n.indexOf(" "+t[i]+" ")>-1;)n=n.replace(" "+t[i]+" "," ");r.className=e?b.trim(n):""}return this},toggleClass:function(e,t){var n=typeof e,r="boolean"==typeof t;return b.isFunction(e)?this.each((function(n){b(this).toggleClass(e.call(this,n,this.className,t),t)})):this.each((function(){if("string"===n)for(var i,o=0,a=b(this),s=t,u=e.split(x);i=u[o++];)s=r?s:!a.hasClass(i),a[s?"addClass":"removeClass"](i);else"undefined"!==n&&"boolean"!==n||(this.className&&b._data(this,"__className__",this.className),this.className=this.className||!1===e?"":b._data(this,"__className__")||"")}))},hasClass:function(e){for(var t=" "+e+" ",n=0,r=this.length;n<r;n++)if(1===this[n].nodeType&&(" "+this[n].className+" ").replace(U," ").indexOf(t)>-1)return!0;return!1},val:function(e){var t,n,r,i=this[0];return arguments.length?(r=b.isFunction(e),this.each((function(n){var i,o=b(this);1===this.nodeType&&(null==(i=r?e.call(this,n,o.val()):e)?i="":"number"==typeof i?i+="":b.isArray(i)&&(i=b.map(i,(function(e){return null==e?"":e+""}))),(t=b.valHooks[this.type]||b.valHooks[this.nodeName.toLowerCase()])&&"set"in t&&void 0!==t.set(this,i,"value")||(this.value=i))}))):i?(t=b.valHooks[i.type]||b.valHooks[i.nodeName.toLowerCase()])&&"get"in t&&void 0!==(n=t.get(i,"value"))?n:"string"==typeof(n=i.value)?n.replace(W,""):null==n?"":n:void 0}}),b.extend({valHooks:{option:{get:function(e){var t=e.attributes.value;return!t||t.specified?e.value:e.text}},select:{get:function(e){var t,n,r,i,o=e.selectedIndex,a=[],s=e.options,u="select-one"===e.type;if(o<0)return null;for(n=u?o:0,r=u?o+1:s.length;n<r;n++)if((i=s[n]).selected&&(b.support.optDisabled?!i.disabled:null===i.getAttribute("disabled"))&&(!i.parentNode.disabled||!b.nodeName(i.parentNode,"optgroup"))){if(t=b(i).val(),u)return t;a.push(t)}return u&&!a.length&&s.length?b(s[o]).val():a},set:function(e,t){var n=b.makeArray(t);return b(e).find("option").each((function(){this.selected=b.inArray(b(this).val(),n)>=0})),n.length||(e.selectedIndex=-1),n}}},attrFn:{},attr:function(e,t,n,r){var i,o,a,s=e.nodeType;if(e&&3!==s&&8!==s&&2!==s)return r&&b.isFunction(b.fn[t])?b(e)[t](n):void 0===e.getAttribute?b.prop(e,t,n):((a=1!==s||!b.isXMLDoc(e))&&(t=t.toLowerCase(),o=b.attrHooks[t]||(X.test(t)?F:q)),void 0!==n?null===n?void b.removeAttr(e,t):o&&"set"in o&&a&&void 0!==(i=o.set(e,n,t))?i:(e.setAttribute(t,""+n),n):o&&"get"in o&&a&&null!==(i=o.get(e,t))?i:null===(i=e.getAttribute(t))?void 0:i)},removeAttr:function(e,t){var n,r,i,o,a=0;if(t&&1===e.nodeType)for(r=t.split(x);a<r.length;a++)(i=r[a])&&(n=b.propFix[i]||i,(o=X.test(i))||b.attr(e,i,""),e.removeAttribute(Y?i:n),o&&n in e&&(e[n]=!1))},attrHooks:{type:{set:function(e,t){if(z.test(e.nodeName)&&e.parentNode)b.error("type property can't be changed");else if(!b.support.radioValue&&"radio"===t&&b.nodeName(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}},value:{get:function(e,t){return q&&b.nodeName(e,"button")?q.get(e,t):t in e?e.value:null},set:function(e,t,n){if(q&&b.nodeName(e,"button"))return q.set(e,t,n);e.value=t}}},propFix:{tabindex:"tabIndex",readonly:"readOnly",for:"htmlFor",class:"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder",contenteditable:"contentEditable"},prop:function(e,t,n){var r,i,o=e.nodeType;if(e&&3!==o&&8!==o&&2!==o)return(1!==o||!b.isXMLDoc(e))&&(t=b.propFix[t]||t,i=b.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=e.getAttributeNode("tabindex");return t&&t.specified?parseInt(t.value,10):K.test(e.nodeName)||V.test(e.nodeName)&&e.href?0:void 0}}}}),F={get:function(e,t){var n,r=b.prop(e,t);return!0===r||"boolean"!=typeof r&&(n=e.getAttributeNode(t))&&!1!==n.nodeValue?t.toLowerCase():void 0},set:function(e,t,n){var r;return!1===t?b.removeAttr(e,n):((r=b.propFix[n]||n)in e&&(e[r]=!0),e.setAttribute(n,n.toLowerCase())),n}},Y||(H={name:!0,id:!0,coords:!0},q=b.valHooks.button={get:function(e,t){var n;return(n=e.getAttributeNode(t))&&(H[t]?""!==n.value:n.specified)?n.value:void 0},set:function(e,t,n){var r=e.getAttributeNode(n);return r||(r=u.createAttribute(n),e.setAttributeNode(r)),r.value=t+""}},b.each(["width","height"],(function(e,t){b.attrHooks[t]=b.extend(b.attrHooks[t],{set:function(e,n){if(""===n)return e.setAttribute(t,"auto"),n}})})),b.attrHooks.contenteditable={get:q.get,set:function(e,t,n){""===t&&(t="false"),q.set(e,t,n)}}),b.support.hrefNormalized||b.each(["href","src","width","height"],(function(e,t){b.attrHooks[t]=b.extend(b.attrHooks[t],{get:function(e){var n=e.getAttribute(t,2);return null===n?void 0:n}})})),b.support.style||(b.attrHooks.style={get:function(e){return e.style.cssText.toLowerCase()||void 0},set:function(e,t){return e.style.cssText=""+t}}),b.support.optSelected||(b.propHooks.selected=b.extend(b.propHooks.selected,{get:function(e){var t=e.parentNode;return t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex),null}})),b.support.enctype||(b.propFix.enctype="encoding"),b.support.checkOn||b.each(["radio","checkbox"],(function(){b.valHooks[this]={get:function(e){return null===e.getAttribute("value")?"on":e.value}}})),b.each(["radio","checkbox"],(function(){b.valHooks[this]=b.extend(b.valHooks[this],{set:function(e,t){if(b.isArray(t))return e.checked=b.inArray(b(e).val(),t)>=0}})}));var G=/^(?:textarea|input|select)$/i,J=/^([^\.]*|)(?:\.(.+)|)$/,Z=/(?:^|\s)hover(\.\S+|)\b/,Q=/^key/,ee=/^(?:mouse|contextmenu)|click/,te=/^(?:focusinfocus|focusoutblur)$/,ne=function(e){return b.event.special.hover?e:e.replace(Z,"mouseenter$1 mouseleave$1")};function re(){return!1}function ie(){return!0}b.event={add:function(e,t,n,r,i){var o,a,s,u,c,l,f,h,p,d,v;if(3!==e.nodeType&&8!==e.nodeType&&t&&n&&(o=b._data(e))){for(n.handler&&(n=(p=n).handler,i=p.selector),n.guid||(n.guid=b.guid++),(s=o.events)||(o.events=s={}),(a=o.handle)||(o.handle=a=function(e){return void 0===b||e&&b.event.triggered===e.type?void 0:b.event.dispatch.apply(a.elem,arguments)},a.elem=e),t=b.trim(ne(t)).split(" "),u=0;u<t.length;u++)l=(c=J.exec(t[u])||[])[1],f=(c[2]||"").split(".").sort(),v=b.event.special[l]||{},l=(i?v.delegateType:v.bindType)||l,v=b.event.special[l]||{},h=b.extend({type:l,origType:c[1],data:r,handler:n,guid:n.guid,selector:i,namespace:f.join(".")},p),(d=s[l])||((d=s[l]=[]).delegateCount=0,v.setup&&!1!==v.setup.call(e,r,f,a)||(e.addEventListener?e.addEventListener(l,a,!1):e.attachEvent&&e.attachEvent("on"+l,a))),v.add&&(v.add.call(e,h),h.handler.guid||(h.handler.guid=n.guid)),i?d.splice(d.delegateCount++,0,h):d.push(h),b.event.global[l]=!0;e=null}},global:{},remove:function(e,t,n,r,i){var o,a,s,u,c,l,f,h,p,d,v,g=b.hasData(e)&&b._data(e);if(g&&(h=g.events)){for(t=b.trim(ne(t||"")).split(" "),o=0;o<t.length;o++)if(s=u=(a=J.exec(t[o])||[])[1],c=a[2],s){for(p=b.event.special[s]||{},l=(d=h[s=(r?p.delegateType:p.bindType)||s]||[]).length,c=c?new RegExp("(^|\\.)"+c.split(".").sort().join("\\.(?:.*\\.|)")+"(\\.|$)"):null,f=0;f<d.length;f++)v=d[f],!i&&u!==v.origType||n&&n.guid!==v.guid||c&&!c.test(v.namespace)||r&&r!==v.selector&&("**"!==r||!v.selector)||(d.splice(f--,1),v.selector&&d.delegateCount--,p.remove&&p.remove.call(e,v));0===d.length&&l!==d.length&&(p.teardown&&!1!==p.teardown.call(e,c,g.handle)||b.removeEvent(e,s,g.handle),delete h[s])}else for(s in h)b.event.remove(e,s+t[o],n,r,!0);b.isEmptyObject(h)&&(delete g.handle,b.removeData(e,"events",!0))}},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(e,t,n,r){if(!n||3!==n.nodeType&&8!==n.nodeType){var o,a,s,c,l,f,h,p,d,v,g=e.type||e,y=[];if(!te.test(g+b.event.triggered)&&(g.indexOf("!")>=0&&(g=g.slice(0,-1),a=!0),g.indexOf(".")>=0&&(y=g.split("."),g=y.shift(),y.sort()),n&&!b.event.customEvent[g]||b.event.global[g]))if((e="object"==typeof e?e[b.expando]?e:new b.Event(g,e):new b.Event(g)).type=g,e.isTrigger=!0,e.exclusive=a,e.namespace=y.join("."),e.namespace_re=e.namespace?new RegExp("(^|\\.)"+y.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,f=g.indexOf(":")<0?"on"+g:"",n){if(e.result=void 0,e.target||(e.target=n),(t=null!=t?b.makeArray(t):[]).unshift(e),!(h=b.event.special[g]||{}).trigger||!1!==h.trigger.apply(n,t)){if(d=[[n,h.bindType||g]],!r&&!h.noBubble&&!b.isWindow(n)){for(v=h.delegateType||g,c=te.test(v+g)?n:n.parentNode,l=n;c;c=c.parentNode)d.push([c,v]),l=c;l===(n.ownerDocument||u)&&d.push([l.defaultView||l.parentWindow||i,v])}for(s=0;s<d.length&&!e.isPropagationStopped();s++)c=d[s][0],e.type=d[s][1],(p=(b._data(c,"events")||{})[e.type]&&b._data(c,"handle"))&&p.apply(c,t),(p=f&&c[f])&&b.acceptData(c)&&!1===p.apply(c,t)&&e.preventDefault();return e.type=g,r||e.isDefaultPrevented()||h._default&&!1!==h._default.apply(n.ownerDocument,t)||"click"===g&&b.nodeName(n,"a")||!b.acceptData(n)||f&&n[g]&&("focus"!==g&&"blur"!==g||0!==e.target.offsetWidth)&&!b.isWindow(n)&&((l=n[f])&&(n[f]=null),b.event.triggered=g,n[g](),b.event.triggered=void 0,l&&(n[f]=l)),e.result}}else for(s in o=b.cache)o[s].events&&o[s].events[g]&&b.event.trigger(e,t,o[s].handle.elem,!0)}},dispatch:function(e){e=b.event.fix(e||i.event);var t,n,r,o,a,s,u,c,l,f=(b._data(this,"events")||{})[e.type]||[],h=f.delegateCount,p=[].slice.call(arguments),d=!e.exclusive&&!e.namespace,v=b.event.special[e.type]||{},g=[];if(p[0]=e,e.delegateTarget=this,!v.preDispatch||!1!==v.preDispatch.call(this,e)){if(h&&(!e.button||"click"!==e.type))for(r=e.target;r!=this;r=r.parentNode||this)if(!0!==r.disabled||"click"!==e.type){for(a={},u=[],t=0;t<h;t++)void 0===a[l=(c=f[t]).selector]&&(a[l]=b(l,this).index(r)>=0),a[l]&&u.push(c);u.length&&g.push({elem:r,matches:u})}for(f.length>h&&g.push({elem:this,matches:f.slice(h)}),t=0;t<g.length&&!e.isPropagationStopped();t++)for(s=g[t],e.currentTarget=s.elem,n=0;n<s.matches.length&&!e.isImmediatePropagationStopped();n++)c=s.matches[n],(d||!e.namespace&&!c.namespace||e.namespace_re&&e.namespace_re.test(c.namespace))&&(e.data=c.data,e.handleObj=c,void 0!==(o=((b.event.special[c.origType]||{}).handle||c.handler).apply(s.elem,p))&&(e.result=o,!1===o&&(e.preventDefault(),e.stopPropagation())));return v.postDispatch&&v.postDispatch.call(this,e),e.result}},props:"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(e,t){return null==e.which&&(e.which=null!=t.charCode?t.charCode:t.keyCode),e}},mouseHooks:{props:"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(e,t){var n,r,i,o=t.button,a=t.fromElement;return null==e.pageX&&null!=t.clientX&&(r=(n=e.target.ownerDocument||u).documentElement,i=n.body,e.pageX=t.clientX+(r&&r.scrollLeft||i&&i.scrollLeft||0)-(r&&r.clientLeft||i&&i.clientLeft||0),e.pageY=t.clientY+(r&&r.scrollTop||i&&i.scrollTop||0)-(r&&r.clientTop||i&&i.clientTop||0)),!e.relatedTarget&&a&&(e.relatedTarget=a===e.target?t.toElement:a),e.which||void 0===o||(e.which=1&o?1:2&o?3:4&o?2:0),e}},fix:function(e){if(e[b.expando])return e;var t,n,r=e,i=b.event.fixHooks[e.type]||{},o=i.props?this.props.concat(i.props):this.props;for(e=b.Event(r),t=o.length;t;)e[n=o[--t]]=r[n];return e.target||(e.target=r.srcElement||u),3===e.target.nodeType&&(e.target=e.target.parentNode),e.metaKey=!!e.metaKey,i.filter?i.filter(e,r):e},special:{load:{noBubble:!0},focus:{delegateType:"focusin"},blur:{delegateType:"focusout"},beforeunload:{setup:function(e,t,n){b.isWindow(this)&&(this.onbeforeunload=n)},teardown:function(e,t){this.onbeforeunload===t&&(this.onbeforeunload=null)}}},simulate:function(e,t,n,r){var i=b.extend(new b.Event,n,{type:e,isSimulated:!0,originalEvent:{}});r?b.event.trigger(i,null,t):b.event.dispatch.call(t,i),i.isDefaultPrevented()&&n.preventDefault()}},b.event.handle=b.event.dispatch,b.removeEvent=u.removeEventListener?function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n,!1)}:function(e,t,n){var r="on"+t;e.detachEvent&&(void 0===e[r]&&(e[r]=null),e.detachEvent(r,n))},b.Event=function(e,t){if(!(this instanceof b.Event))return new b.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||!1===e.returnValue||e.getPreventDefault&&e.getPreventDefault()?ie:re):this.type=e,t&&b.extend(this,t),this.timeStamp=e&&e.timeStamp||b.now(),this[b.expando]=!0},b.Event.prototype={preventDefault:function(){this.isDefaultPrevented=ie;var e=this.originalEvent;e&&(e.preventDefault?e.preventDefault():e.returnValue=!1)},stopPropagation:function(){this.isPropagationStopped=ie;var e=this.originalEvent;e&&(e.stopPropagation&&e.stopPropagation(),e.cancelBubble=!0)},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=ie,this.stopPropagation()},isDefaultPrevented:re,isPropagationStopped:re,isImmediatePropagationStopped:re},b.each({mouseenter:"mouseover",mouseleave:"mouseout"},(function(e,t){b.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,o=e.handleObj;return o.selector,i&&(i===r||b.contains(r,i))||(e.type=o.origType,n=o.handler.apply(this,arguments),e.type=t),n}}})),b.support.submitBubbles||(b.event.special.submit={setup:function(){if(b.nodeName(this,"form"))return!1;b.event.add(this,"click._submit keypress._submit",(function(e){var t=e.target,n=b.nodeName(t,"input")||b.nodeName(t,"button")?t.form:void 0;n&&!b._data(n,"_submit_attached")&&(b.event.add(n,"submit._submit",(function(e){e._submit_bubble=!0})),b._data(n,"_submit_attached",!0))}))},postDispatch:function(e){e._submit_bubble&&(delete e._submit_bubble,this.parentNode&&!e.isTrigger&&b.event.simulate("submit",this.parentNode,e,!0))},teardown:function(){if(b.nodeName(this,"form"))return!1;b.event.remove(this,"._submit")}}),b.support.changeBubbles||(b.event.special.change={setup:function(){if(G.test(this.nodeName))return"checkbox"!==this.type&&"radio"!==this.type||(b.event.add(this,"propertychange._change",(function(e){"checked"===e.originalEvent.propertyName&&(this._just_changed=!0)})),b.event.add(this,"click._change",(function(e){this._just_changed&&!e.isTrigger&&(this._just_changed=!1),b.event.simulate("change",this,e,!0)}))),!1;b.event.add(this,"beforeactivate._change",(function(e){var t=e.target;G.test(t.nodeName)&&!b._data(t,"_change_attached")&&(b.event.add(t,"change._change",(function(e){!this.parentNode||e.isSimulated||e.isTrigger||b.event.simulate("change",this.parentNode,e,!0)})),b._data(t,"_change_attached",!0))}))},handle:function(e){var t=e.target;if(this!==t||e.isSimulated||e.isTrigger||"radio"!==t.type&&"checkbox"!==t.type)return e.handleObj.handler.apply(this,arguments)},teardown:function(){return b.event.remove(this,"._change"),!G.test(this.nodeName)}}),b.support.focusinBubbles||b.each({focus:"focusin",blur:"focusout"},(function(e,t){var n=0,r=function(e){b.event.simulate(t,e.target,b.event.fix(e),!0)};b.event.special[t]={setup:function(){0==n++&&u.addEventListener(e,r,!0)},teardown:function(){0==--n&&u.removeEventListener(e,r,!0)}}})),b.fn.extend({on:function(e,t,n,r,i){var o,a;if("object"==typeof e){for(a in"string"!=typeof t&&(n=n||t,t=void 0),e)this.on(a,t,n,e[a],i);return this}if(null==n&&null==r?(r=t,n=t=void 0):null==r&&("string"==typeof t?(r=n,n=void 0):(r=n,n=t,t=void 0)),!1===r)r=re;else if(!r)return this;return 1===i&&(o=r,(r=function(e){return b().off(e),o.apply(this,arguments)}).guid=o.guid||(o.guid=b.guid++)),this.each((function(){b.event.add(this,e,r,n,t)}))},one:function(e,t,n,r){return this.on(e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,b(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=re),this.each((function(){b.event.remove(this,e,n,t)}))},bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},live:function(e,t,n){return b(this.context).on(e,this.selector,t,n),this},die:function(e,t){return b(this.context).off(e,this.selector||"**",t),this},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1==arguments.length?this.off(e,"**"):this.off(t,e||"**",n)},trigger:function(e,t){return this.each((function(){b.event.trigger(e,t,this)}))},triggerHandler:function(e,t){if(this[0])return b.event.trigger(e,t,this[0],!0)},toggle:function(e){var t=arguments,n=e.guid||b.guid++,r=0,i=function(n){var i=(b._data(this,"lastToggle"+e.guid)||0)%r;return b._data(this,"lastToggle"+e.guid,i+1),n.preventDefault(),t[i].apply(this,arguments)||!1};for(i.guid=n;r<t.length;)t[r++].guid=n;return this.click(i)},hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),b.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),(function(e,t){b.fn[t]=function(e,n){return null==n&&(n=e,e=null),arguments.length>0?this.on(t,null,e,n):this.trigger(t)},Q.test(t)&&(b.event.fixHooks[t]=b.event.keyHooks),ee.test(t)&&(b.event.fixHooks[t]=b.event.mouseHooks)})),
/*!
 * Sizzle CSS Selector Engine
 *  Copyright 2012 jQuery Foundation and other contributors
 *  Released under the MIT license
 *  http://sizzlejs.com/
 */
function(e,t){var n,r,i,o,a,s,u,c,l,f,h,p,d,v,g,y,m,_,w=("sizcache"+Math.random()).replace(".",""),x=e.document,T=x.documentElement,C=0,E=[].slice,k=[].push,S=function(e,t){return e[w]=t||!0,e},A=function(){var e={},t=[];return S((function(n,r){return t.push(n)>o.cacheLength&&delete e[t.shift()],e[n]=r}),e)},O=A(),D=A(),P=A(),N="[\\x20\\t\\r\\n\\f]",j="(?:\\\\.|[-\\w]|[^\\x00-\\xa0])+",L=j.replace("w","w#"),I="\\["+N+"*("+j+")"+N+"*(?:([*^$|!~]?=)"+N+"*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|("+L+")|)|)"+N+"*\\]",M=":("+j+")(?:\\((?:(['\"])((?:\\\\.|[^\\\\])*?)\\2|([^()[\\]]*|(?:(?:"+I+")|[^:]|\\\\.)*|.*))\\)|)",R=":(nth|eq|gt|lt|first|last|even|odd)(?:\\(((?:-\\d)?\\d*)\\)|)(?=[^-]|$)",B=new RegExp("^"+N+"+|((?:^|[^\\\\])(?:\\\\.)*)"+N+"+$","g"),$=new RegExp("^"+N+"*,"+N+"*"),q=new RegExp("^"+N+"*([\\x20\\t\\r\\n\\f>+~])"+N+"*"),F=new RegExp(M),H=/^(?:#([\w\-]+)|(\w+)|\.([\w\-]+))$/,U=/[\x20\t\r\n\f]*[+~]/,W=/:not\($/,z=/h\d/i,K=/input|select|textarea|button/i,V=/\\(?!\\)/g,X={ID:new RegExp("^#("+j+")"),CLASS:new RegExp("^\\.("+j+")"),NAME:new RegExp("^\\[name=['\"]?("+j+")['\"]?\\]"),TAG:new RegExp("^("+j.replace("w","w*")+")"),ATTR:new RegExp("^"+I),PSEUDO:new RegExp("^"+M),CHILD:new RegExp("^:(only|nth|last|first)-child(?:\\("+N+"*(even|odd|(([+-]|)(\\d*)n|)"+N+"*(?:([+-]|)"+N+"*(\\d+)|))"+N+"*\\)|)","i"),POS:new RegExp(R,"ig"),needsContext:new RegExp("^"+N+"*[>+~]|"+R,"i")},Y=function(e){var t=x.createElement("div");try{return e(t)}catch(e){return!1}finally{t=null}},G=Y((function(e){return e.appendChild(x.createComment("")),!e.getElementsByTagName("*").length})),J=Y((function(e){return e.innerHTML="<a href='#'></a>",e.firstChild&&void 0!==e.firstChild.getAttribute&&"#"===e.firstChild.getAttribute("href")})),Z=Y((function(e){e.innerHTML="<select></select>";var t=typeof e.lastChild.getAttribute("multiple");return"boolean"!==t&&"string"!==t})),Q=Y((function(e){return e.innerHTML="<div class='hidden e'></div><div class='hidden'></div>",!(!e.getElementsByClassName||!e.getElementsByClassName("e").length)&&(e.lastChild.className="e",2===e.getElementsByClassName("e").length)})),ee=Y((function(e){e.id=w+0,e.innerHTML="<a name='"+w+"'></a><div name='"+w+"'></div>",T.insertBefore(e,T.firstChild);var t=x.getElementsByName&&x.getElementsByName(w).length===2+x.getElementsByName(w+0).length;return i=!x.getElementById(w),T.removeChild(e),t}));try{E.call(T.childNodes,0)[0].nodeType}catch(e){E=function(e){for(var t,n=[];t=this[e];e++)n.push(t);return n}}function te(e,t,n,r){n=n||[];var i,o,a,c,l=(t=t||x).nodeType;if(1!==l&&9!==l)return[];if(!e||"string"!=typeof e)return n;if(!(a=s(t))&&!r&&(i=H.exec(e)))if(c=i[1]){if(9===l){if(!(o=t.getElementById(c))||!o.parentNode)return n;if(o.id===c)return n.push(o),n}else if(t.ownerDocument&&(o=t.ownerDocument.getElementById(c))&&u(t,o)&&o.id===c)return n.push(o),n}else{if(i[2])return k.apply(n,E.call(t.getElementsByTagName(e),0)),n;if((c=i[3])&&Q&&t.getElementsByClassName)return k.apply(n,E.call(t.getElementsByClassName(c),0)),n}return fe(e,t,n,r,a)}function ne(e){return function(t){return"input"===t.nodeName.toLowerCase()&&t.type===e}}function re(e){return function(t){var n=t.nodeName.toLowerCase();return("input"===n||"button"===n)&&t.type===e}}function ie(e,t,n){if(e===t)return n;for(var r=e.nextSibling;r;){if(r===t)return-1;r=r.nextSibling}return 1}function oe(e,t,n,r){var i,a,s,u,c,l,f,h,p,d=!n&&t!==x,v=(d?"<s>":"")+e.replace(B,"$1<s>"),g=D[w][v];if(g)return r?0:E.call(g,0);for(c=e,l=[],h=o.preFilter,p=o.filter;c;){for(u in i&&!(a=$.exec(c))||(a&&(c=c.slice(a[0].length),s.selector=f),l.push(s=[]),f="",d&&(c=" "+c)),i=!1,(a=q.exec(c))&&(f+=a[0],c=c.slice(a[0].length),i=s.push({part:a.pop().replace(B," "),string:a[0],captures:a})),p)!(a=X[u].exec(c))||h[u]&&!(a=h[u](a,t,n))||(f+=a[0],c=c.slice(a[0].length),i=s.push({part:u,string:a.shift(),captures:a}));if(!i)break}return f&&(s.selector=f),r?c.length:c?te.error(e):E.call(D(v,l),0)}function ae(e,t,i,o){var a=t.dir,s=C++;return e||(e=function(e){return e===i}),t.first?function(t){for(;t=t[a];)if(1===t.nodeType)return e(t)&&t}:o?function(t){for(;t=t[a];)if(1===t.nodeType&&e(t))return t}:function(t){for(var i,o=s+"."+n,u=o+"."+r;t=t[a];)if(1===t.nodeType){if((i=t[w])===u)return t.sizset;if("string"==typeof i&&0===i.indexOf(o)){if(t.sizset)return t}else{if(t[w]=u,e(t))return t.sizset=!0,t;t.sizset=!1}}}}function se(e,t){return e?function(n){var r=t(n);return r&&e(!0===r?n:r)}:t}function ue(e,t,n){for(var r,i,a=0;r=e[a];a++)i=o.relative[r.part]?ae(i,o.relative[r.part],t,n):se(i,o.filter[r.part].apply(null,r.captures.concat(t,n)));return i}function ce(e,t,n,r){for(var i=0,o=t.length;i<o;i++)te(e,t[i],n,r)}function le(e,t,n,r,i,a){var s,u=o.setFilters[t.toLowerCase()];return u||te.error(t),!e&&(s=i)||ce(e||"*",r,s=[],i),s.length>0?u(s,n,a):[]}function fe(e,t,i,a,s){var u,l,f,h,p,d,v,g,y,m=oe(e=e.replace(B,"$1"),t,s),b=t.nodeType;if(X.POS.test(e))return function(e,t,n,r){for(var i,o,a,s,u,c,l,f,h,p,d,v,g,y=0,m=e.length,b=X.POS,_=new RegExp("^"+b.source+"(?!"+N+")","i"),w=function(){for(var e=1,t=arguments.length-2;e<t;e++)void 0===arguments[e]&&(h[e]=void 0)};y<m;y++){for(o="",f=r,a=0,s=(i=e[y]).length;a<s;a++){if(c=(u=i[a]).string,"PSEUDO"===u.part)for(b.exec(""),l=0;h=b.exec(c);)p=!0,(d=b.lastIndex=h.index+h[0].length)>l&&(o+=c.slice(l,h.index),l=d,v=[t],q.test(o)&&(f&&(v=f),f=r),(g=W.test(o))&&(o=o.slice(0,-5).replace(q,"$&*"),l++),h.length>1&&h[0].replace(_,w),f=le(o,h[1],h[2],v,f,g)),o="";p||(o+=c),p=!1}o?q.test(o)?ce(o,f||[t],n,r):te(o,t,n,r?r.concat(f):f):k.apply(n,f)}return 1===m?n:te.uniqueSort(n)}(m,t,i,a);if(a)u=E.call(a,0);else if(1===m.length){if((p=E.call(m[0],0)).length>2&&"ID"===(d=p[0]).part&&9===b&&!s&&o.relative[p[1].part]){if(!(t=o.find.ID(d.captures[0].replace(V,""),t,s)[0]))return i;e=e.slice(p.shift().string.length)}for(g=(m=U.exec(p[0].string))&&!m.index&&t.parentNode||t,v="",h=p.length-1;h>=0&&(y=(d=p[h]).part,v=d.string+v,!o.relative[y]);h--)if(o.order.test(y)){if(null==(u=o.find[y](d.captures[0].replace(V,""),g,s)))continue;(e=e.slice(0,e.length-v.length)+v.replace(X[y],""))||k.apply(i,E.call(u,0));break}}if(e)for(l=c(e,t,s),n=l.dirruns++,null==u&&(u=o.find.TAG("*",U.test(e)&&t.parentNode||t)),h=0;f=u[h];h++)r=l.runs++,l(f)&&i.push(f);return i}te.matches=function(e,t){return te(e,null,null,t)},te.matchesSelector=function(e,t){return te(t,null,null,[e]).length>0},a=te.getText=function(e){var t,n="",r=0,i=e.nodeType;if(i){if(1===i||9===i||11===i){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=a(e)}else if(3===i||4===i)return e.nodeValue}else for(;t=e[r];r++)n+=a(t);return n},s=te.isXML=function(e){var t=e&&(e.ownerDocument||e).documentElement;return!!t&&"HTML"!==t.nodeName},u=te.contains=T.contains?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!!(r&&1===r.nodeType&&n.contains&&n.contains(r))}:T.compareDocumentPosition?function(e,t){return t&&!!(16&e.compareDocumentPosition(t))}:function(e,t){for(;t=t.parentNode;)if(t===e)return!0;return!1},te.attr=function(e,t){var n,r=s(e);return r||(t=t.toLowerCase()),o.attrHandle[t]?o.attrHandle[t](e):Z||r?e.getAttribute(t):(n=e.getAttributeNode(t))?"boolean"==typeof e[t]?e[t]?t:null:n.specified?n.value:null:null},o=te.selectors={cacheLength:50,createPseudo:S,match:X,order:new RegExp("ID|TAG"+(ee?"|NAME":"")+(Q?"|CLASS":"")),attrHandle:J?{}:{href:function(e){return e.getAttribute("href",2)},type:function(e){return e.getAttribute("type")}},find:{ID:i?function(e,t,n){if(void 0!==t.getElementById&&!n){var r=t.getElementById(e);return r&&r.parentNode?[r]:[]}}:function(e,t,n){if(void 0!==t.getElementById&&!n){var r=t.getElementById(e);return r?r.id===e||void 0!==r.getAttributeNode&&r.getAttributeNode("id").value===e?[r]:void 0:[]}},TAG:G?function(e,t){if(void 0!==t.getElementsByTagName)return t.getElementsByTagName(e)}:function(e,t){var n=t.getElementsByTagName(e);if("*"===e){for(var r,i=[],o=0;r=n[o];o++)1===r.nodeType&&i.push(r);return i}return n},NAME:function(e,t){if(void 0!==t.getElementsByName)return t.getElementsByName(name)},CLASS:function(e,t,n){if(void 0!==t.getElementsByClassName&&!n)return t.getElementsByClassName(e)}},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(V,""),e[3]=(e[4]||e[5]||"").replace(V,""),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1]?(e[2]||te.error(e[0]),e[3]=+(e[3]?e[4]+(e[5]||1):2*("even"===e[2]||"odd"===e[2])),e[4]=+(e[6]+e[7]||"odd"===e[2])):e[2]&&te.error(e[0]),e},PSEUDO:function(e,t,n){var r,i;return X.CHILD.test(e[0])?null:(e[3]?e[2]=e[3]:(r=e[4])&&(F.test(r)&&(i=oe(r,t,n,!0))&&(i=r.indexOf(")",r.length-i)-r.length)&&(r=r.slice(0,i),e[0]=e[0].slice(0,i)),e[2]=r),e.slice(0,3))}},filter:{ID:i?function(e){return e=e.replace(V,""),function(t){return t.getAttribute("id")===e}}:function(e){return e=e.replace(V,""),function(t){var n=void 0!==t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}},TAG:function(e){return"*"===e?function(){return!0}:(e=e.replace(V,"").toLowerCase(),function(t){return t.nodeName&&t.nodeName.toLowerCase()===e})},CLASS:function(e){var t=O[w][e];return t||(t=O(e,new RegExp("(^|"+N+")"+e+"("+N+"|$)"))),function(e){return t.test(e.className||void 0!==e.getAttribute&&e.getAttribute("class")||"")}},ATTR:function(e,t,n){return t?function(r){var i=te.attr(r,e),o=i+"";if(null==i)return"!="===t;switch(t){case"=":return o===n;case"!=":return o!==n;case"^=":return n&&0===o.indexOf(n);case"*=":return n&&o.indexOf(n)>-1;case"$=":return n&&o.substr(o.length-n.length)===n;case"~=":return(" "+o+" ").indexOf(n)>-1;case"|=":return o===n||o.substr(0,n.length+1)===n+"-"}}:function(t){return null!=te.attr(t,e)}},CHILD:function(e,t,n,r){if("nth"===e){var i=C++;return function(e){var t,o,a=0,s=e;if(1===n&&0===r)return!0;if((t=e.parentNode)&&(t[w]!==i||!e.sizset)){for(s=t.firstChild;s&&(1!==s.nodeType||(s.sizset=++a,s!==e));s=s.nextSibling);t[w]=i}return o=e.sizset-r,0===n?0===o:o%n==0&&o/n>=0}}return function(t){var n=t;switch(e){case"only":case"first":for(;n=n.previousSibling;)if(1===n.nodeType)return!1;if("first"===e)return!0;n=t;case"last":for(;n=n.nextSibling;)if(1===n.nodeType)return!1;return!0}}},PSEUDO:function(e,t,n,r){var i,a=o.pseudos[e]||o.pseudos[e.toLowerCase()];return a||te.error("unsupported pseudo: "+e),a[w]?a(t,n,r):a.length>1?(i=[e,e,"",t],function(e){return a(e,0,i)}):a}},pseudos:{not:S((function(e,t,n){var r=c(e.replace(B,"$1"),t,n);return function(e){return!r(e)}})),enabled:function(e){return!1===e.disabled},disabled:function(e){return!0===e.disabled},checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},parent:function(e){return!o.pseudos.empty(e)},empty:function(e){var t;for(e=e.firstChild;e;){if(e.nodeName>"@"||3===(t=e.nodeType)||4===t)return!1;e=e.nextSibling}return!0},contains:S((function(e){return function(t){return(t.textContent||t.innerText||a(t)).indexOf(e)>-1}})),has:S((function(e){return function(t){return te(e,t).length>0}})),header:function(e){return z.test(e.nodeName)},text:function(e){var t,n;return"input"===e.nodeName.toLowerCase()&&"text"===(t=e.type)&&(null==(n=e.getAttribute("type"))||n.toLowerCase()===t)},radio:ne("radio"),checkbox:ne("checkbox"),file:ne("file"),password:ne("password"),image:ne("image"),submit:re("submit"),reset:re("reset"),button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},input:function(e){return K.test(e.nodeName)},focus:function(e){var t=e.ownerDocument;return e===t.activeElement&&(!t.hasFocus||t.hasFocus())&&!(!e.type&&!e.href)},active:function(e){return e===e.ownerDocument.activeElement}},setFilters:{first:function(e,t,n){return n?e.slice(1):[e[0]]},last:function(e,t,n){var r=e.pop();return n?e:[r]},even:function(e,t,n){for(var r=[],i=n?1:0,o=e.length;i<o;i+=2)r.push(e[i]);return r},odd:function(e,t,n){for(var r=[],i=n?0:1,o=e.length;i<o;i+=2)r.push(e[i]);return r},lt:function(e,t,n){return n?e.slice(+t):e.slice(0,+t)},gt:function(e,t,n){return n?e.slice(0,+t+1):e.slice(+t+1)},eq:function(e,t,n){var r=e.splice(+t,1);return n?e:r}}},l=T.compareDocumentPosition?function(e,t){return e===t?(f=!0,0):(e.compareDocumentPosition&&t.compareDocumentPosition?4&e.compareDocumentPosition(t):e.compareDocumentPosition)?-1:1}:function(e,t){if(e===t)return f=!0,0;if(e.sourceIndex&&t.sourceIndex)return e.sourceIndex-t.sourceIndex;var n,r,i=[],o=[],a=e.parentNode,s=t.parentNode,u=a;if(a===s)return ie(e,t);if(!a)return-1;if(!s)return 1;for(;u;)i.unshift(u),u=u.parentNode;for(u=s;u;)o.unshift(u),u=u.parentNode;n=i.length,r=o.length;for(var c=0;c<n&&c<r;c++)if(i[c]!==o[c])return ie(i[c],o[c]);return c===n?ie(e,o[c],-1):ie(i[c],t,1)},[0,0].sort(l),h=!f,te.uniqueSort=function(e){var t,n=1;if(f=h,e.sort(l),f)for(;t=e[n];n++)t===e[n-1]&&e.splice(n--,1);return e},te.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},c=te.compile=function(e,t,n){var r,i,o,a,s=P[w][e];if(s&&s.context===t)return s;for(i=0,o=(r=oe(e,t,n)).length;i<o;i++)r[i]=ue(r[i],t,n);return(s=P(e,(a=r,function(e){for(var t,n=0;t=a[n];n++)if(t(e))return!0;return!1}))).context=t,s.runs=s.dirruns=0,s},x.querySelectorAll&&(d=fe,v=/'|\\/g,g=/\=[\x20\t\r\n\f]*([^'"\]]*)[\x20\t\r\n\f]*\]/g,y=[],m=[":active"],_=T.matchesSelector||T.mozMatchesSelector||T.webkitMatchesSelector||T.oMatchesSelector||T.msMatchesSelector,Y((function(e){e.innerHTML="<select><option selected=''></option></select>",e.querySelectorAll("[selected]").length||y.push("\\["+N+"*(?:checked|disabled|ismap|multiple|readonly|selected|value)"),e.querySelectorAll(":checked").length||y.push(":checked")})),Y((function(e){e.innerHTML="<p test=''></p>",e.querySelectorAll("[test^='']").length&&y.push("[*^$]="+N+"*(?:\"\"|'')"),e.innerHTML="<input type='hidden'/>",e.querySelectorAll(":enabled").length||y.push(":enabled",":disabled")})),y=y.length&&new RegExp(y.join("|")),fe=function(e,t,n,r,i){if(!(r||i||y&&y.test(e)))if(9===t.nodeType)try{return k.apply(n,E.call(t.querySelectorAll(e),0)),n}catch(e){}else if(1===t.nodeType&&"object"!==t.nodeName.toLowerCase()){var o,a,s,u=t.getAttribute("id"),c=u||w,l=U.test(e)&&t.parentNode||t;for(u?c=c.replace(v,"\\$&"):t.setAttribute("id",c),c="[id='"+c+"']",a=0,s=(o=oe(e,t,i)).length;a<s;a++)o[a]=c+o[a].selector;try{return k.apply(n,E.call(l.querySelectorAll(o.join(",")),0)),n}catch(e){}finally{u||t.removeAttribute("id")}}return d(e,t,n,r,i)},_&&(Y((function(e){p=_.call(e,"div");try{_.call(e,"[test!='']:sizzle"),m.push(X.PSEUDO.source,X.POS.source,"!=")}catch(e){}})),m=new RegExp(m.join("|")),te.matchesSelector=function(e,t){if(t=t.replace(g,"='$1']"),!(s(e)||m.test(t)||y&&y.test(t)))try{var n=_.call(e,t);if(n||p||e.document&&11!==e.document.nodeType)return n}catch(e){}return te(t,null,null,[e]).length>0})),o.setFilters.nth=o.setFilters.eq,o.filters=o.pseudos,te.attr=b.attr,b.find=te,b.expr=te.selectors,b.expr[":"]=b.expr.pseudos,b.unique=te.uniqueSort,b.text=te.getText,b.isXMLDoc=te.isXML,b.contains=te.contains}(i);var oe=/Until$/,ae=/^(?:parents|prev(?:Until|All))/,se=/^.[^:#\[\.,]*$/,ue=b.expr.match.needsContext,ce={children:!0,contents:!0,next:!0,prev:!0};function le(e){return!e||!e.parentNode||11===e.parentNode.nodeType}function fe(e,t){do{e=e[t]}while(e&&1!==e.nodeType);return e}function he(e,t,n){if(t=t||0,b.isFunction(t))return b.grep(e,(function(e,r){return!!t.call(e,r,e)===n}));if(t.nodeType)return b.grep(e,(function(e,r){return e===t===n}));if("string"==typeof t){var r=b.grep(e,(function(e){return 1===e.nodeType}));if(se.test(t))return b.filter(t,r,!n);t=b.filter(t,r)}return b.grep(e,(function(e,r){return b.inArray(e,t)>=0===n}))}function pe(e){var t=ge.split("|"),n=e.createDocumentFragment();if(n.createElement)for(;t.length;)n.createElement(t.pop());return n}b.fn.extend({find:function(e){var t,n,r,i,o,a,s=this;if("string"!=typeof e)return b(e).filter((function(){for(t=0,n=s.length;t<n;t++)if(b.contains(s[t],this))return!0}));for(a=this.pushStack("","find",e),t=0,n=this.length;t<n;t++)if(r=a.length,b.find(e,this[t],a),t>0)for(i=r;i<a.length;i++)for(o=0;o<r;o++)if(a[o]===a[i]){a.splice(i--,1);break}return a},has:function(e){var t,n=b(e,this),r=n.length;return this.filter((function(){for(t=0;t<r;t++)if(b.contains(this,n[t]))return!0}))},not:function(e){return this.pushStack(he(this,e,!1),"not",e)},filter:function(e){return this.pushStack(he(this,e,!0),"filter",e)},is:function(e){return!!e&&("string"==typeof e?ue.test(e)?b(e,this.context).index(this[0])>=0:b.filter(e,this).length>0:this.filter(e).length>0)},closest:function(e,t){for(var n,r=0,i=this.length,o=[],a=ue.test(e)||"string"!=typeof e?b(e,t||this.context):0;r<i;r++)for(n=this[r];n&&n.ownerDocument&&n!==t&&11!==n.nodeType;){if(a?a.index(n)>-1:b.find.matchesSelector(n,e)){o.push(n);break}n=n.parentNode}return o=o.length>1?b.unique(o):o,this.pushStack(o,"closest",e)},index:function(e){return e?"string"==typeof e?b.inArray(this[0],b(e)):b.inArray(e.jquery?e[0]:e,this):this[0]&&this[0].parentNode?this.prevAll().length:-1},add:function(e,t){var n="string"==typeof e?b(e,t):b.makeArray(e&&e.nodeType?[e]:e),r=b.merge(this.get(),n);return this.pushStack(le(n[0])||le(r[0])?r:b.unique(r))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),b.fn.andSelf=b.fn.addBack,b.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return b.dir(e,"parentNode")},parentsUntil:function(e,t,n){return b.dir(e,"parentNode",n)},next:function(e){return fe(e,"nextSibling")},prev:function(e){return fe(e,"previousSibling")},nextAll:function(e){return b.dir(e,"nextSibling")},prevAll:function(e){return b.dir(e,"previousSibling")},nextUntil:function(e,t,n){return b.dir(e,"nextSibling",n)},prevUntil:function(e,t,n){return b.dir(e,"previousSibling",n)},siblings:function(e){return b.sibling((e.parentNode||{}).firstChild,e)},children:function(e){return b.sibling(e.firstChild)},contents:function(e){return b.nodeName(e,"iframe")?e.contentDocument||e.contentWindow.document:b.merge([],e.childNodes)}},(function(e,t){b.fn[e]=function(n,r){var i=b.map(this,t,n);return oe.test(e)||(r=n),r&&"string"==typeof r&&(i=b.filter(r,i)),i=this.length>1&&!ce[e]?b.unique(i):i,this.length>1&&ae.test(e)&&(i=i.reverse()),this.pushStack(i,e,d.call(arguments).join(","))}})),b.extend({filter:function(e,t,n){return n&&(e=":not("+e+")"),1===t.length?b.find.matchesSelector(t[0],e)?[t[0]]:[]:b.find.matches(e,t)},dir:function(e,t,n){for(var r=[],i=e[t];i&&9!==i.nodeType&&(void 0===n||1!==i.nodeType||!b(i).is(n));)1===i.nodeType&&r.push(i),i=i[t];return r},sibling:function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n}});var de,ve,ge="abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",ye=/ jQuery\d+="(?:null|\d+)"/g,me=/^\s+/,be=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,_e=/<([\w:]+)/,we=/<tbody/i,xe=/<|&#?\w+;/,Te=/<(?:script|style|link)/i,Ce=/<(?:script|object|embed|option|style)/i,Ee=new RegExp("<(?:"+ge+")[\\s/>]","i"),ke=/^(?:checkbox|radio)$/,Se=/checked\s*(?:[^=]|=\s*.checked.)/i,Ae=/\/(java|ecma)script/i,Oe=/^\s*<!(?:\[CDATA\[|\-\-)|[\]\-]{2}>\s*$/g,De={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]},Pe=pe(u),Ne=Pe.appendChild(u.createElement("div"));function je(e,t){if(1===t.nodeType&&b.hasData(e)){var n,r,i,o=b._data(e),a=b._data(t,o),s=o.events;if(s)for(n in delete a.handle,a.events={},s)for(r=0,i=s[n].length;r<i;r++)b.event.add(t,n,s[n][r]);a.data&&(a.data=b.extend({},a.data))}}function Le(e,t){var n;1===t.nodeType&&(t.clearAttributes&&t.clearAttributes(),t.mergeAttributes&&t.mergeAttributes(e),"object"===(n=t.nodeName.toLowerCase())?(t.parentNode&&(t.outerHTML=e.outerHTML),b.support.html5Clone&&e.innerHTML&&!b.trim(t.innerHTML)&&(t.innerHTML=e.innerHTML)):"input"===n&&ke.test(e.type)?(t.defaultChecked=t.checked=e.checked,t.value!==e.value&&(t.value=e.value)):"option"===n?t.selected=e.defaultSelected:"input"===n||"textarea"===n?t.defaultValue=e.defaultValue:"script"===n&&t.text!==e.text&&(t.text=e.text),t.removeAttribute(b.expando))}function Ie(e){return void 0!==e.getElementsByTagName?e.getElementsByTagName("*"):void 0!==e.querySelectorAll?e.querySelectorAll("*"):[]}function Me(e){ke.test(e.type)&&(e.defaultChecked=e.checked)}De.optgroup=De.option,De.tbody=De.tfoot=De.colgroup=De.caption=De.thead,De.th=De.td,b.support.htmlSerialize||(De._default=[1,"X<div>","</div>"]),b.fn.extend({text:function(e){return b.access(this,(function(e){return void 0===e?b.text(this):this.empty().append((this[0]&&this[0].ownerDocument||u).createTextNode(e))}),null,e,arguments.length)},wrapAll:function(e){if(b.isFunction(e))return this.each((function(t){b(this).wrapAll(e.call(this,t))}));if(this[0]){var t=b(e,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&t.insertBefore(this[0]),t.map((function(){for(var e=this;e.firstChild&&1===e.firstChild.nodeType;)e=e.firstChild;return e})).append(this)}return this},wrapInner:function(e){return b.isFunction(e)?this.each((function(t){b(this).wrapInner(e.call(this,t))})):this.each((function(){var t=b(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)}))},wrap:function(e){var t=b.isFunction(e);return this.each((function(n){b(this).wrapAll(t?e.call(this,n):e)}))},unwrap:function(){return this.parent().each((function(){b.nodeName(this,"body")||b(this).replaceWith(this.childNodes)})).end()},append:function(){return this.domManip(arguments,!0,(function(e){1!==this.nodeType&&11!==this.nodeType||this.appendChild(e)}))},prepend:function(){return this.domManip(arguments,!0,(function(e){1!==this.nodeType&&11!==this.nodeType||this.insertBefore(e,this.firstChild)}))},before:function(){if(!le(this[0]))return this.domManip(arguments,!1,(function(e){this.parentNode.insertBefore(e,this)}));if(arguments.length){var e=b.clean(arguments);return this.pushStack(b.merge(e,this),"before",this.selector)}},after:function(){if(!le(this[0]))return this.domManip(arguments,!1,(function(e){this.parentNode.insertBefore(e,this.nextSibling)}));if(arguments.length){var e=b.clean(arguments);return this.pushStack(b.merge(this,e),"after",this.selector)}},remove:function(e,t){for(var n,r=0;null!=(n=this[r]);r++)e&&!b.filter(e,[n]).length||(t||1!==n.nodeType||(b.cleanData(n.getElementsByTagName("*")),b.cleanData([n])),n.parentNode&&n.parentNode.removeChild(n));return this},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)for(1===e.nodeType&&b.cleanData(e.getElementsByTagName("*"));e.firstChild;)e.removeChild(e.firstChild);return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map((function(){return b.clone(this,e,t)}))},html:function(e){return b.access(this,(function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e)return 1===t.nodeType?t.innerHTML.replace(ye,""):void 0;if("string"==typeof e&&!Te.test(e)&&(b.support.htmlSerialize||!Ee.test(e))&&(b.support.leadingWhitespace||!me.test(e))&&!De[(_e.exec(e)||["",""])[1].toLowerCase()]){e=e.replace(be,"<$1></$2>");try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(b.cleanData(t.getElementsByTagName("*")),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)}),null,e,arguments.length)},replaceWith:function(e){return le(this[0])?this.length?this.pushStack(b(b.isFunction(e)?e():e),"replaceWith",e):this:b.isFunction(e)?this.each((function(t){var n=b(this),r=n.html();n.replaceWith(e.call(this,t,r))})):("string"!=typeof e&&(e=b(e).detach()),this.each((function(){var t=this.nextSibling,n=this.parentNode;b(this).remove(),t?b(t).before(e):b(n).append(e)})))},detach:function(e){return this.remove(e,!0)},domManip:function(e,t,n){var r,i,o,a,s,u,c=0,l=(e=[].concat.apply([],e))[0],f=[],h=this.length;if(!b.support.checkClone&&h>1&&"string"==typeof l&&Se.test(l))return this.each((function(){b(this).domManip(e,t,n)}));if(b.isFunction(l))return this.each((function(r){var i=b(this);e[0]=l.call(this,r,t?i.html():void 0),i.domManip(e,t,n)}));if(this[0]){if(i=(o=(r=b.buildFragment(e,this,f)).fragment).firstChild,1===o.childNodes.length&&(o=i),i)for(t=t&&b.nodeName(i,"tr"),a=r.cacheable||h-1;c<h;c++)n.call(t&&b.nodeName(this[c],"table")?(s=this[c],u="tbody",s.getElementsByTagName(u)[0]||s.appendChild(s.ownerDocument.createElement(u))):this[c],c===a?o:b.clone(o,!0,!0));o=i=null,f.length&&b.each(f,(function(e,t){t.src?b.ajax?b.ajax({url:t.src,type:"GET",dataType:"script",async:!1,global:!1,throws:!0}):b.error("no ajax"):b.globalEval((t.text||t.textContent||t.innerHTML||"").replace(Oe,"")),t.parentNode&&t.parentNode.removeChild(t)}))}return this}}),b.buildFragment=function(e,t,n){var r,i,o,a=e[0];return t=(t=!(t=t||u).nodeType&&t[0]||t).ownerDocument||t,!(1===e.length&&"string"==typeof a&&a.length<512&&t===u&&"<"===a.charAt(0))||Ce.test(a)||!b.support.checkClone&&Se.test(a)||!b.support.html5Clone&&Ee.test(a)||(i=!0,o=void 0!==(r=b.fragments[a])),r||(r=t.createDocumentFragment(),b.clean(e,t,r,n),i&&(b.fragments[a]=o&&r)),{fragment:r,cacheable:i}},b.fragments={},b.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},(function(e,t){b.fn[e]=function(n){var r,i=0,o=[],a=b(n),s=a.length,u=1===this.length&&this[0].parentNode;if((null==u||u&&11===u.nodeType&&1===u.childNodes.length)&&1===s)return a[t](this[0]),this;for(;i<s;i++)r=(i>0?this.clone(!0):this).get(),b(a[i])[t](r),o=o.concat(r);return this.pushStack(o,e,a.selector)}})),b.extend({clone:function(e,t,n){var r,i,o,a;if(b.support.html5Clone||b.isXMLDoc(e)||!Ee.test("<"+e.nodeName+">")?a=e.cloneNode(!0):(Ne.innerHTML=e.outerHTML,Ne.removeChild(a=Ne.firstChild)),!(b.support.noCloneEvent&&b.support.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||b.isXMLDoc(e)))for(Le(e,a),r=Ie(e),i=Ie(a),o=0;r[o];++o)i[o]&&Le(r[o],i[o]);if(t&&(je(e,a),n))for(r=Ie(e),i=Ie(a),o=0;r[o];++o)je(r[o],i[o]);return r=i=null,a},clean:function(e,t,n,r){var i,o,a,s,c,l,f,h,p,d,v,g=t===u&&Pe,y=[];for(t&&void 0!==t.createDocumentFragment||(t=u),i=0;null!=(a=e[i]);i++)if("number"==typeof a&&(a+=""),a){if("string"==typeof a)if(xe.test(a)){for(g=g||pe(t),f=t.createElement("div"),g.appendChild(f),a=a.replace(be,"<$1></$2>"),s=(_e.exec(a)||["",""])[1].toLowerCase(),l=(c=De[s]||De._default)[0],f.innerHTML=c[1]+a+c[2];l--;)f=f.lastChild;if(!b.support.tbody)for(h=we.test(a),o=(p="table"!==s||h?"<table>"!==c[1]||h?[]:f.childNodes:f.firstChild&&f.firstChild.childNodes).length-1;o>=0;--o)b.nodeName(p[o],"tbody")&&!p[o].childNodes.length&&p[o].parentNode.removeChild(p[o]);!b.support.leadingWhitespace&&me.test(a)&&f.insertBefore(t.createTextNode(me.exec(a)[0]),f.firstChild),a=f.childNodes,f.parentNode.removeChild(f)}else a=t.createTextNode(a);a.nodeType?y.push(a):b.merge(y,a)}if(f&&(a=f=g=null),!b.support.appendChecked)for(i=0;null!=(a=y[i]);i++)b.nodeName(a,"input")?Me(a):void 0!==a.getElementsByTagName&&b.grep(a.getElementsByTagName("input"),Me);if(n)for(d=function(e){if(!e.type||Ae.test(e.type))return r?r.push(e.parentNode?e.parentNode.removeChild(e):e):n.appendChild(e)},i=0;null!=(a=y[i]);i++)b.nodeName(a,"script")&&d(a)||(n.appendChild(a),void 0!==a.getElementsByTagName&&(v=b.grep(b.merge([],a.getElementsByTagName("script")),d),y.splice.apply(y,[i+1,0].concat(v)),i+=v.length));return y},cleanData:function(e,t){for(var n,r,i,o,a=0,s=b.expando,u=b.cache,c=b.support.deleteExpando,l=b.event.special;null!=(i=e[a]);a++)if((t||b.acceptData(i))&&(n=(r=i[s])&&u[r])){if(n.events)for(o in n.events)l[o]?b.event.remove(i,o):b.removeEvent(i,o,n.handle);u[r]&&(delete u[r],c?delete i[s]:i.removeAttribute?i.removeAttribute(s):i[s]=null,b.deletedIds.push(r))}}}),b.uaMatch=function(e){e=e.toLowerCase();var t=/(chrome)[ \/]([\w.]+)/.exec(e)||/(webkit)[ \/]([\w.]+)/.exec(e)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(e)||/(msie) ([\w.]+)/.exec(e)||e.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(e)||[];return{browser:t[1]||"",version:t[2]||"0"}},ve={},(de=b.uaMatch(l.userAgent)).browser&&(ve[de.browser]=!0,ve.version=de.version),ve.chrome?ve.webkit=!0:ve.webkit&&(ve.safari=!0),b.browser=ve,b.sub=function(){function e(t,n){return new e.fn.init(t,n)}b.extend(!0,e,this),e.superclass=this,e.fn=e.prototype=this(),e.fn.constructor=e,e.sub=this.sub,e.fn.init=function(n,r){return r&&r instanceof b&&!(r instanceof e)&&(r=e(r)),b.fn.init.call(this,n,r,t)},e.fn.init.prototype=e.fn;var t=e(u);return e};var Re,Be,$e,qe=/alpha\([^)]*\)/i,Fe=/opacity=([^)]*)/,He=/^(top|right|bottom|left)$/,Ue=/^(none|table(?!-c[ea]).+)/,We=/^margin/,ze=new RegExp("^("+_+")(.*)$","i"),Ke=new RegExp("^("+_+")(?!px)[a-z%]+$","i"),Ve=new RegExp("^([-+])=("+_+")","i"),Xe={},Ye={position:"absolute",visibility:"hidden",display:"block"},Ge={letterSpacing:0,fontWeight:400},Je=["Top","Right","Bottom","Left"],Ze=["Webkit","O","Moz","ms"],Qe=b.fn.toggle;function et(e,t){if(t in e)return t;for(var n=t.charAt(0).toUpperCase()+t.slice(1),r=t,i=Ze.length;i--;)if((t=Ze[i]+n)in e)return t;return r}function tt(e,t){return e=t||e,"none"===b.css(e,"display")||!b.contains(e.ownerDocument,e)}function nt(e,t){for(var n,r,i=[],o=0,a=e.length;o<a;o++)(n=e[o]).style&&(i[o]=b._data(n,"olddisplay"),t?(i[o]||"none"!==n.style.display||(n.style.display=""),""===n.style.display&&tt(n)&&(i[o]=b._data(n,"olddisplay",at(n.nodeName)))):(r=Re(n,"display"),i[o]||"none"===r||b._data(n,"olddisplay",r)));for(o=0;o<a;o++)(n=e[o]).style&&(t&&"none"!==n.style.display&&""!==n.style.display||(n.style.display=t?i[o]||"":"none"));return e}function rt(e,t,n){var r=ze.exec(t);return r?Math.max(0,r[1]-(n||0))+(r[2]||"px"):t}function it(e,t,n,r){for(var i=n===(r?"border":"content")?4:"width"===t?1:0,o=0;i<4;i+=2)"margin"===n&&(o+=b.css(e,n+Je[i],!0)),r?("content"===n&&(o-=parseFloat(Re(e,"padding"+Je[i]))||0),"margin"!==n&&(o-=parseFloat(Re(e,"border"+Je[i]+"Width"))||0)):(o+=parseFloat(Re(e,"padding"+Je[i]))||0,"padding"!==n&&(o+=parseFloat(Re(e,"border"+Je[i]+"Width"))||0));return o}function ot(e,t,n){var r="width"===t?e.offsetWidth:e.offsetHeight,i=!0,o=b.support.boxSizing&&"border-box"===b.css(e,"boxSizing");if(r<=0||null==r){if(((r=Re(e,t))<0||null==r)&&(r=e.style[t]),Ke.test(r))return r;i=o&&(b.support.boxSizingReliable||r===e.style[t]),r=parseFloat(r)||0}return r+it(e,t,n||(o?"border":"content"),i)+"px"}function at(e){if(Xe[e])return Xe[e];var t=b("<"+e+">").appendTo(u.body),n=t.css("display");return t.remove(),"none"!==n&&""!==n||(Be=u.body.appendChild(Be||b.extend(u.createElement("iframe"),{frameBorder:0,width:0,height:0})),$e&&Be.createElement||(($e=(Be.contentWindow||Be.contentDocument).document).write("<!doctype html><html><body>"),$e.close()),t=$e.body.appendChild($e.createElement(e)),n=Re(t,"display"),u.body.removeChild(Be)),Xe[e]=n,n}b.fn.extend({css:function(e,t){return b.access(this,(function(e,t,n){return void 0!==n?b.style(e,t,n):b.css(e,t)}),e,t,arguments.length>1)},show:function(){return nt(this,!0)},hide:function(){return nt(this)},toggle:function(e,t){var n="boolean"==typeof e;return b.isFunction(e)&&b.isFunction(t)?Qe.apply(this,arguments):this.each((function(){(n?e:tt(this))?b(this).show():b(this).hide()}))}}),b.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=Re(e,"opacity");return""===n?"1":n}}}},cssNumber:{fillOpacity:!0,fontWeight:!0,lineHeight:!0,opacity:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{float:b.support.cssFloat?"cssFloat":"styleFloat"},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,a,s=b.camelCase(t),u=e.style;if(t=b.cssProps[s]||(b.cssProps[s]=et(u,s)),a=b.cssHooks[t]||b.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(e,!1,r))?i:u[t];if("string"==(o=typeof n)&&(i=Ve.exec(n))&&(n=(i[1]+1)*i[2]+parseFloat(b.css(e,t)),o="number"),!(null==n||"number"===o&&isNaN(n)||("number"!==o||b.cssNumber[s]||(n+="px"),a&&"set"in a&&void 0===(n=a.set(e,n,r)))))try{u[t]=n}catch(e){}}},css:function(e,t,n,r){var i,o,a,s=b.camelCase(t);return t=b.cssProps[s]||(b.cssProps[s]=et(e.style,s)),(a=b.cssHooks[t]||b.cssHooks[s])&&"get"in a&&(i=a.get(e,!0,r)),void 0===i&&(i=Re(e,t)),"normal"===i&&t in Ge&&(i=Ge[t]),n||void 0!==r?(o=parseFloat(i),n||b.isNumeric(o)?o||0:i):i},swap:function(e,t,n){var r,i,o={};for(i in t)o[i]=e.style[i],e.style[i]=t[i];for(i in r=n.call(e),t)e.style[i]=o[i];return r}}),i.getComputedStyle?Re=function(e,t){var n,r,o,a,s=i.getComputedStyle(e,null),u=e.style;return s&&(""!==(n=s[t])||b.contains(e.ownerDocument,e)||(n=b.style(e,t)),Ke.test(n)&&We.test(t)&&(r=u.width,o=u.minWidth,a=u.maxWidth,u.minWidth=u.maxWidth=u.width=n,n=s.width,u.width=r,u.minWidth=o,u.maxWidth=a)),n}:u.documentElement.currentStyle&&(Re=function(e,t){var n,r,i=e.currentStyle&&e.currentStyle[t],o=e.style;return null==i&&o&&o[t]&&(i=o[t]),Ke.test(i)&&!He.test(t)&&(n=o.left,(r=e.runtimeStyle&&e.runtimeStyle.left)&&(e.runtimeStyle.left=e.currentStyle.left),o.left="fontSize"===t?"1em":i,i=o.pixelLeft+"px",o.left=n,r&&(e.runtimeStyle.left=r)),""===i?"auto":i}),b.each(["height","width"],(function(e,t){b.cssHooks[t]={get:function(e,n,r){if(n)return 0===e.offsetWidth&&Ue.test(Re(e,"display"))?b.swap(e,Ye,(function(){return ot(e,t,r)})):ot(e,t,r)},set:function(e,n,r){return rt(0,n,r?it(e,t,r,b.support.boxSizing&&"border-box"===b.css(e,"boxSizing")):0)}}})),b.support.opacity||(b.cssHooks.opacity={get:function(e,t){return Fe.test((t&&e.currentStyle?e.currentStyle.filter:e.style.filter)||"")?.01*parseFloat(RegExp.$1)+"":t?"1":""},set:function(e,t){var n=e.style,r=e.currentStyle,i=b.isNumeric(t)?"alpha(opacity="+100*t+")":"",o=r&&r.filter||n.filter||"";n.zoom=1,t>=1&&""===b.trim(o.replace(qe,""))&&n.removeAttribute&&(n.removeAttribute("filter"),r&&!r.filter)||(n.filter=qe.test(o)?o.replace(qe,i):o+" "+i)}}),b((function(){b.support.reliableMarginRight||(b.cssHooks.marginRight={get:function(e,t){return b.swap(e,{display:"inline-block"},(function(){if(t)return Re(e,"marginRight")}))}}),!b.support.pixelPosition&&b.fn.position&&b.each(["top","left"],(function(e,t){b.cssHooks[t]={get:function(e,n){if(n){var r=Re(e,t);return Ke.test(r)?b(e).position()[t]+"px":r}}}}))})),b.expr&&b.expr.filters&&(b.expr.filters.hidden=function(e){return 0===e.offsetWidth&&0===e.offsetHeight||!b.support.reliableHiddenOffsets&&"none"===(e.style&&e.style.display||Re(e,"display"))},b.expr.filters.visible=function(e){return!b.expr.filters.hidden(e)}),b.each({margin:"",padding:"",border:"Width"},(function(e,t){b.cssHooks[e+t]={expand:function(n){var r,i="string"==typeof n?n.split(" "):[n],o={};for(r=0;r<4;r++)o[e+Je[r]+t]=i[r]||i[r-2]||i[0];return o}},We.test(e)||(b.cssHooks[e+t].set=rt)}));var st=/%20/g,ut=/\[\]$/,ct=/\r?\n/g,lt=/^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,ft=/^(?:select|textarea)/i;function ht(e,t,n,r){var i;if(b.isArray(t))b.each(t,(function(t,i){n||ut.test(e)?r(e,i):ht(e+"["+("object"==typeof i?t:"")+"]",i,n,r)}));else if(n||"object"!==b.type(t))r(e,t);else for(i in t)ht(e+"["+i+"]",t[i],n,r)}b.fn.extend({serialize:function(){return b.param(this.serializeArray())},serializeArray:function(){return this.map((function(){return this.elements?b.makeArray(this.elements):this})).filter((function(){return this.name&&!this.disabled&&(this.checked||ft.test(this.nodeName)||lt.test(this.type))})).map((function(e,t){var n=b(this).val();return null==n?null:b.isArray(n)?b.map(n,(function(e,n){return{name:t.name,value:e.replace(ct,"\r\n")}})):{name:t.name,value:n.replace(ct,"\r\n")}})).get()}}),b.param=function(e,t){var n,r=[],i=function(e,t){t=b.isFunction(t)?t():null==t?"":t,r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(t)};if(void 0===t&&(t=b.ajaxSettings&&b.ajaxSettings.traditional),b.isArray(e)||e.jquery&&!b.isPlainObject(e))b.each(e,(function(){i(this.name,this.value)}));else for(n in e)ht(n,e[n],t,i);return r.join("&").replace(st,"+")};var pt,dt,vt=/#.*$/,gt=/^(.*?):[ \t]*([^\r\n]*)\r?$/gm,yt=/^(?:GET|HEAD)$/,mt=/^\/\//,bt=/\?/,_t=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,wt=/([?&])_=[^&]*/,xt=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,Tt=b.fn.load,Ct={},Et={},kt=["*/"]+["*"];try{pt=c.href}catch(e){(pt=u.createElement("a")).href="",pt=pt.href}function St(e){return function(t,n){"string"!=typeof t&&(n=t,t="*");var r,i,o=t.toLowerCase().split(x),a=0,s=o.length;if(b.isFunction(n))for(;a<s;a++)r=o[a],(i=/^\+/.test(r))&&(r=r.substr(1)||"*"),(e[r]=e[r]||[])[i?"unshift":"push"](n)}}function At(e,t,n,r,i,o){(o=o||{})[i=i||t.dataTypes[0]]=!0;for(var a,s=e[i],u=0,c=s?s.length:0,l=e===Ct;u<c&&(l||!a);u++)"string"==typeof(a=s[u](t,n,r))&&(!l||o[a]?a=void 0:(t.dataTypes.unshift(a),a=At(e,t,n,r,a,o)));return!l&&a||o["*"]||(a=At(e,t,n,r,"*",o)),a}function Ot(e,t){var n,r,i=b.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);r&&b.extend(!0,e,r)}dt=xt.exec(pt.toLowerCase())||[],b.fn.load=function(e,t,n){if("string"!=typeof e&&Tt)return Tt.apply(this,arguments);if(!this.length)return this;var r,i,o,a=this,s=e.indexOf(" ");return s>=0&&(r=e.slice(s,e.length),e=e.slice(0,s)),b.isFunction(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),b.ajax({url:e,type:i,dataType:"html",data:t,complete:function(e,t){n&&a.each(n,o||[e.responseText,t,e])}}).done((function(e){o=arguments,a.html(r?b("<div>").append(e.replace(_t,"")).find(r):e)})),this},b.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),(function(e,t){b.fn[t]=function(e){return this.on(t,e)}})),b.each(["get","post"],(function(e,t){b[t]=function(e,n,r,i){return b.isFunction(n)&&(i=i||r,r=n,n=void 0),b.ajax({type:t,url:e,data:n,success:r,dataType:i})}})),b.extend({getScript:function(e,t){return b.get(e,void 0,t,"script")},getJSON:function(e,t,n){return b.get(e,t,n,"json")},ajaxSetup:function(e,t){return t?Ot(e,b.ajaxSettings):(t=e,e=b.ajaxSettings),Ot(e,t),e},ajaxSettings:{url:pt,isLocal:/^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/.test(dt[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded; charset=UTF-8",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":kt},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":i.String,"text html":!0,"text json":b.parseJSON,"text xml":b.parseXML},flatOptions:{context:!0,url:!0}},ajaxPrefilter:St(Ct),ajaxTransport:St(Et),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var n,r,i,o,a,s,u,c,l=b.ajaxSetup({},t),f=l.context||l,h=f!==l&&(f.nodeType||f instanceof b)?b(f):b.event,p=b.Deferred(),d=b.Callbacks("once memory"),v=l.statusCode||{},g={},y={},m=0,_="canceled",w={readyState:0,setRequestHeader:function(e,t){if(!m){var n=e.toLowerCase();e=y[n]=y[n]||e,g[e]=t}return this},getAllResponseHeaders:function(){return 2===m?r:null},getResponseHeader:function(e){var t;if(2===m){if(!i)for(i={};t=gt.exec(r);)i[t[1].toLowerCase()]=t[2];t=i[e.toLowerCase()]}return void 0===t?null:t},overrideMimeType:function(e){return m||(l.mimeType=e),this},abort:function(e){return e=e||_,o&&o.abort(e),T(0,e),this}};function T(e,t,i,s){var c,g,y,_,x,T=t;2!==m&&(m=2,a&&clearTimeout(a),o=void 0,r=s||"",w.readyState=e>0?4:0,i&&(_=function(e,t,n){var r,i,o,a,s=e.contents,u=e.dataTypes,c=e.responseFields;for(i in c)i in n&&(t[c[i]]=n[i]);for(;"*"===u[0];)u.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("content-type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||e.converters[i+" "+u[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==u[0]&&u.unshift(o),n[o]}(l,w,i)),e>=200&&e<300||304===e?(l.ifModified&&((x=w.getResponseHeader("Last-Modified"))&&(b.lastModified[n]=x),(x=w.getResponseHeader("Etag"))&&(b.etag[n]=x)),304===e?(T="notmodified",c=!0):(T=(c=function(e,t){var n,r,i,o,a=e.dataTypes.slice(),s=a[0],u={},c=0;if(e.dataFilter&&(t=e.dataFilter(t,e.dataType)),a[1])for(n in e.converters)u[n.toLowerCase()]=e.converters[n];for(;i=a[++c];)if("*"!==i){if("*"!==s&&s!==i){if(!(n=u[s+" "+i]||u["* "+i]))for(r in u)if((o=r.split(" "))[1]===i&&(n=u[s+" "+o[0]]||u["* "+o[0]])){!0===n?n=u[r]:!0!==u[r]&&(i=o[0],a.splice(c--,0,i));break}if(!0!==n)if(n&&e.throws)t=n(t);else try{t=n(t)}catch(e){return{state:"parsererror",error:n?e:"No conversion from "+s+" to "+i}}}s=i}return{state:"success",data:t}}(l,_)).state,g=c.data,c=!(y=c.error))):(y=T,T&&!e||(T="error",e<0&&(e=0))),w.status=e,w.statusText=""+(t||T),c?p.resolveWith(f,[g,T,w]):p.rejectWith(f,[w,T,y]),w.statusCode(v),v=void 0,u&&h.trigger("ajax"+(c?"Success":"Error"),[w,l,c?g:y]),d.fireWith(f,[w,T]),u&&(h.trigger("ajaxComplete",[w,l]),--b.active||b.event.trigger("ajaxStop")))}if(p.promise(w),w.success=w.done,w.error=w.fail,w.complete=d.add,w.statusCode=function(e){var t;if(e)if(m<2)for(t in e)v[t]=[v[t],e[t]];else t=e[w.status],w.always(t);return this},l.url=((e||l.url)+"").replace(vt,"").replace(mt,dt[1]+"//"),l.dataTypes=b.trim(l.dataType||"*").toLowerCase().split(x),null==l.crossDomain&&(s=xt.exec(l.url.toLowerCase()),l.crossDomain=!(!s||s[1]==dt[1]&&s[2]==dt[2]&&(s[3]||("http:"===s[1]?80:443))==(dt[3]||("http:"===dt[1]?80:443)))),l.data&&l.processData&&"string"!=typeof l.data&&(l.data=b.param(l.data,l.traditional)),At(Ct,l,t,w),2===m)return w;if(u=l.global,l.type=l.type.toUpperCase(),l.hasContent=!yt.test(l.type),u&&0==b.active++&&b.event.trigger("ajaxStart"),!l.hasContent&&(l.data&&(l.url+=(bt.test(l.url)?"&":"?")+l.data,delete l.data),n=l.url,!1===l.cache)){var C=b.now(),E=l.url.replace(wt,"$1_="+C);l.url=E+(E===l.url?(bt.test(l.url)?"&":"?")+"_="+C:"")}for(c in(l.data&&l.hasContent&&!1!==l.contentType||t.contentType)&&w.setRequestHeader("Content-Type",l.contentType),l.ifModified&&(n=n||l.url,b.lastModified[n]&&w.setRequestHeader("If-Modified-Since",b.lastModified[n]),b.etag[n]&&w.setRequestHeader("If-None-Match",b.etag[n])),w.setRequestHeader("Accept",l.dataTypes[0]&&l.accepts[l.dataTypes[0]]?l.accepts[l.dataTypes[0]]+("*"!==l.dataTypes[0]?", "+kt+"; q=0.01":""):l.accepts["*"]),l.headers)w.setRequestHeader(c,l.headers[c]);if(l.beforeSend&&(!1===l.beforeSend.call(f,w,l)||2===m))return w.abort();for(c in _="abort",{success:1,error:1,complete:1})w[c](l[c]);if(o=At(Et,l,t,w)){w.readyState=1,u&&h.trigger("ajaxSend",[w,l]),l.async&&l.timeout>0&&(a=setTimeout((function(){w.abort("timeout")}),l.timeout));try{m=1,o.send(g,T)}catch(e){if(!(m<2))throw e;T(-1,e)}}else T(-1,"No Transport");return w},active:0,lastModified:{},etag:{}});var Dt=[],Pt=/\?/,Nt=/(=)\?(?=&|$)|\?\?/,jt=b.now();b.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Dt.pop()||b.expando+"_"+jt++;return this[e]=!0,e}}),b.ajaxPrefilter("json jsonp",(function(e,t,n){var r,o,a,s=e.data,u=e.url,c=!1!==e.jsonp,l=c&&Nt.test(u),f=c&&!l&&"string"==typeof s&&!(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&Nt.test(s);if("jsonp"===e.dataTypes[0]||l||f)return r=e.jsonpCallback=b.isFunction(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,o=i[r],l?e.url=u.replace(Nt,"$1"+r):f?e.data=s.replace(Nt,"$1"+r):c&&(e.url+=(Pt.test(u)?"&":"?")+e.jsonp+"="+r),e.converters["script json"]=function(){return a||b.error(r+" was not called"),a[0]},e.dataTypes[0]="json",i[r]=function(){a=arguments},n.always((function(){i[r]=o,e[r]&&(e.jsonpCallback=t.jsonpCallback,Dt.push(r)),a&&b.isFunction(o)&&o(a[0]),a=o=void 0})),"script"})),b.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(e){return b.globalEval(e),e}}}),b.ajaxPrefilter("script",(function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET",e.global=!1)})),b.ajaxTransport("script",(function(e){if(e.crossDomain){var t,n=u.head||u.getElementsByTagName("head")[0]||u.documentElement;return{send:function(r,i){(t=u.createElement("script")).async="async",e.scriptCharset&&(t.charset=e.scriptCharset),t.src=e.url,t.onload=t.onreadystatechange=function(e,r){(r||!t.readyState||/loaded|complete/.test(t.readyState))&&(t.onload=t.onreadystatechange=null,n&&t.parentNode&&n.removeChild(t),t=void 0,r||i(200,"success"))},n.insertBefore(t,n.firstChild)},abort:function(){t&&t.onload(0,1)}}}}));var Lt,It,Mt=!!i.ActiveXObject&&function(){for(var e in Lt)Lt[e](0,1)},Rt=0;function Bt(){try{return new i.XMLHttpRequest}catch(e){}}b.ajaxSettings.xhr=i.ActiveXObject?function(){return!this.isLocal&&Bt()||function(){try{return new i.ActiveXObject("Microsoft.XMLHTTP")}catch(e){}}()}:Bt,It=b.ajaxSettings.xhr(),b.extend(b.support,{ajax:!!It,cors:!!It&&"withCredentials"in It}),b.support.ajax&&b.ajaxTransport((function(e){var t;if(!e.crossDomain||b.support.cors)return{send:function(n,r){var o,a,s=e.xhr();if(e.username?s.open(e.type,e.url,e.async,e.username,e.password):s.open(e.type,e.url,e.async),e.xhrFields)for(a in e.xhrFields)s[a]=e.xhrFields[a];e.mimeType&&s.overrideMimeType&&s.overrideMimeType(e.mimeType),e.crossDomain||n["X-Requested-With"]||(n["X-Requested-With"]="XMLHttpRequest");try{for(a in n)s.setRequestHeader(a,n[a])}catch(e){}s.send(e.hasContent&&e.data||null),t=function(n,i){var a,u,c,l,f;try{if(t&&(i||4===s.readyState))if(t=void 0,o&&(s.onreadystatechange=b.noop,Mt&&delete Lt[o]),i)4!==s.readyState&&s.abort();else{a=s.status,c=s.getAllResponseHeaders(),l={},(f=s.responseXML)&&f.documentElement&&(l.xml=f);try{l.text=s.responseText}catch(n){}try{u=s.statusText}catch(e){u=""}a||!e.isLocal||e.crossDomain?1223===a&&(a=204):a=l.text?200:404}}catch(e){i||r(-1,e)}l&&r(a,u,l,c)},e.async?4===s.readyState?setTimeout(t,0):(o=++Rt,Mt&&(Lt||(Lt={},b(i).unload(Mt)),Lt[o]=t),s.onreadystatechange=t):t()},abort:function(){t&&t(0,1)}}}));var $t,qt,Ft=/^(?:toggle|show|hide)$/,Ht=new RegExp("^(?:([-+])=|)("+_+")([a-z%]*)$","i"),Ut=/queueHooks$/,Wt=[function(e,t,n){var r,i,o,a,s,u,c,l,f=this,h=e.style,p={},d=[],v=e.nodeType&&tt(e);for(r in n.queue||(null==(c=b._queueHooks(e,"fx")).unqueued&&(c.unqueued=0,l=c.empty.fire,c.empty.fire=function(){c.unqueued||l()}),c.unqueued++,f.always((function(){f.always((function(){c.unqueued--,b.queue(e,"fx").length||c.empty.fire()}))}))),1===e.nodeType&&("height"in t||"width"in t)&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],"inline"===b.css(e,"display")&&"none"===b.css(e,"float")&&(b.support.inlineBlockNeedsLayout&&"inline"!==at(e.nodeName)?h.zoom=1:h.display="inline-block")),n.overflow&&(h.overflow="hidden",b.support.shrinkWrapBlocks||f.done((function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]}))),t)if(o=t[r],Ft.exec(o)){if(delete t[r],o===(v?"hide":"show"))continue;d.push(r)}if(a=d.length)for(s=b._data(e,"fxshow")||b._data(e,"fxshow",{}),v?b(e).show():f.done((function(){b(e).hide()})),f.done((function(){var t;for(t in b.removeData(e,"fxshow",!0),p)b.style(e,t,p[t])})),r=0;r<a;r++)i=d[r],u=f.createTween(i,v?s[i]:0),p[i]=s[i]||b.style(e,i),i in s||(s[i]=u.start,v&&(u.end=u.start,u.start="width"===i||"height"===i?1:0))}],zt={"*":[function(e,t){var n,r,i,o=this.createTween(e,t),a=Ht.exec(t),s=o.cur(),u=+s||0,c=1;if(a){if(n=+a[2],"px"!==(r=a[3]||(b.cssNumber[e]?"":"px"))&&u){u=b.css(o.elem,e,!0)||n||1;do{i=c=c||".5",u/=c,b.style(o.elem,e,u+r),c=o.cur()/s}while(1!==c&&c!==i)}o.unit=r,o.start=u,o.end=a[1]?u+(a[1]+1)*n:n}return o}]};function Kt(){return setTimeout((function(){$t=void 0}),0),$t=b.now()}function Vt(e,t,n){var r,i=0,o=Wt.length,a=b.Deferred().always((function(){delete s.elem})),s=function(){for(var t=$t||Kt(),n=Math.max(0,u.startTime+u.duration-t),r=1-(n/u.duration||0),i=0,o=u.tweens.length;i<o;i++)u.tweens[i].run(r);return a.notifyWith(e,[u,r,n]),r<1&&o?n:(a.resolveWith(e,[u]),!1)},u=a.promise({elem:e,props:b.extend({},t),opts:b.extend(!0,{specialEasing:{}},n),originalProperties:t,originalOptions:n,startTime:$t||Kt(),duration:n.duration,tweens:[],createTween:function(t,n,r){var i=b.Tween(e,u.opts,t,n,u.opts.specialEasing[t]||u.opts.easing);return u.tweens.push(i),i},stop:function(t){for(var n=0,r=t?u.tweens.length:0;n<r;n++)u.tweens[n].run(1);return t?a.resolveWith(e,[u,t]):a.rejectWith(e,[u,t]),this}}),c=u.props;for(function(e,t){var n,r,i,o,a;for(n in e)if(r=b.camelCase(n),i=t[r],o=e[n],b.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(a=b.cssHooks[r])&&"expand"in a)for(n in o=a.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(c,u.opts.specialEasing);i<o;i++)if(r=Wt[i].call(u,e,c,u.opts))return r;return function(e,t){b.each(t,(function(t,n){for(var r=(zt[t]||[]).concat(zt["*"]),i=0,o=r.length;i<o;i++)if(r[i].call(e,t,n))return}))}(u,c),b.isFunction(u.opts.start)&&u.opts.start.call(e,u),b.fx.timer(b.extend(s,{anim:u,queue:u.opts.queue,elem:e})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function Xt(e,t,n,r,i){return new Xt.prototype.init(e,t,n,r,i)}function Yt(e,t){var n,r={height:e},i=0;for(t=t?1:0;i<4;i+=2-t)r["margin"+(n=Je[i])]=r["padding"+n]=e;return t&&(r.opacity=r.width=e),r}b.Animation=b.extend(Vt,{tweener:function(e,t){b.isFunction(e)?(t=e,e=["*"]):e=e.split(" ");for(var n,r=0,i=e.length;r<i;r++)n=e[r],zt[n]=zt[n]||[],zt[n].unshift(t)},prefilter:function(e,t){t?Wt.unshift(e):Wt.push(e)}}),b.Tween=Xt,Xt.prototype={constructor:Xt,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||"swing",this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(b.cssNumber[n]?"":"px")},cur:function(){var e=Xt.propHooks[this.prop];return e&&e.get?e.get(this):Xt.propHooks._default.get(this)},run:function(e){var t,n=Xt.propHooks[this.prop];return this.options.duration?this.pos=t=b.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):Xt.propHooks._default.set(this),this}},Xt.prototype.init.prototype=Xt.prototype,Xt.propHooks={_default:{get:function(e){var t;return null==e.elem[e.prop]||e.elem.style&&null!=e.elem.style[e.prop]?(t=b.css(e.elem,e.prop,!1,""))&&"auto"!==t?t:0:e.elem[e.prop]},set:function(e){b.fx.step[e.prop]?b.fx.step[e.prop](e):e.elem.style&&(null!=e.elem.style[b.cssProps[e.prop]]||b.cssHooks[e.prop])?b.style(e.elem,e.prop,e.now+e.unit):e.elem[e.prop]=e.now}}},Xt.propHooks.scrollTop=Xt.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},b.each(["toggle","show","hide"],(function(e,t){var n=b.fn[t];b.fn[t]=function(r,i,o){return null==r||"boolean"==typeof r||!e&&b.isFunction(r)&&b.isFunction(i)?n.apply(this,arguments):this.animate(Yt(t,!0),r,i,o)}})),b.fn.extend({fadeTo:function(e,t,n,r){return this.filter(tt).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=b.isEmptyObject(e),o=b.speed(t,n,r),a=function(){var t=Vt(this,b.extend({},e),o);i&&t.stop(!0)};return i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(e,t,n){var r=function(e){var t=e.stop;delete e.stop,t(n)};return"string"!=typeof e&&(n=t,t=e,e=void 0),t&&!1!==e&&this.queue(e||"fx",[]),this.each((function(){var t=!0,i=null!=e&&e+"queueHooks",o=b.timers,a=b._data(this);if(i)a[i]&&a[i].stop&&r(a[i]);else for(i in a)a[i]&&a[i].stop&&Ut.test(i)&&r(a[i]);for(i=o.length;i--;)o[i].elem!==this||null!=e&&o[i].queue!==e||(o[i].anim.stop(n),t=!1,o.splice(i,1));!t&&n||b.dequeue(this,e)}))}}),b.each({slideDown:Yt("show"),slideUp:Yt("hide"),slideToggle:Yt("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},(function(e,t){b.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}})),b.speed=function(e,t,n){var r=e&&"object"==typeof e?b.extend({},e):{complete:n||!n&&t||b.isFunction(e)&&e,duration:e,easing:n&&t||t&&!b.isFunction(t)&&t};return r.duration=b.fx.off?0:"number"==typeof r.duration?r.duration:r.duration in b.fx.speeds?b.fx.speeds[r.duration]:b.fx.speeds._default,null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){b.isFunction(r.old)&&r.old.call(this),r.queue&&b.dequeue(this,r.queue)},r},b.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2}},b.timers=[],b.fx=Xt.prototype.init,b.fx.tick=function(){for(var e,t=b.timers,n=0;n<t.length;n++)(e=t[n])()||t[n]!==e||t.splice(n--,1);t.length||b.fx.stop()},b.fx.timer=function(e){e()&&b.timers.push(e)&&!qt&&(qt=setInterval(b.fx.tick,b.fx.interval))},b.fx.interval=13,b.fx.stop=function(){clearInterval(qt),qt=null},b.fx.speeds={slow:600,fast:200,_default:400},b.fx.step={},b.expr&&b.expr.filters&&(b.expr.filters.animated=function(e){return b.grep(b.timers,(function(t){return e===t.elem})).length});var Gt=/^(?:body|html)$/i;function Jt(e){return b.isWindow(e)?e:9===e.nodeType&&(e.defaultView||e.parentWindow)}return b.fn.offset=function(e){if(arguments.length)return void 0===e?this:this.each((function(t){b.offset.setOffset(this,e,t)}));var t,n,r,i,o,a,s,u,c=this[0],l=c&&c.ownerDocument;return l?(r=l.body)===c?b.offset.bodyOffset(c):(n=l.documentElement,b.contains(n,c)?(t=c.getBoundingClientRect(),i=Jt(l),o=n.clientTop||r.clientTop||0,a=n.clientLeft||r.clientLeft||0,s=i.pageYOffset||n.scrollTop,u=i.pageXOffset||n.scrollLeft,{top:t.top+s-o,left:t.left+u-a}):{top:0,left:0}):void 0},b.offset={bodyOffset:function(e){var t=e.offsetTop,n=e.offsetLeft;return b.support.doesNotIncludeMarginInBodyOffset&&(t+=parseFloat(b.css(e,"marginTop"))||0,n+=parseFloat(b.css(e,"marginLeft"))||0),{top:t,left:n}},setOffset:function(e,t,n){var r=b.css(e,"position");"static"===r&&(e.style.position="relative");var i,o,a=b(e),s=a.offset(),u=b.css(e,"top"),c=b.css(e,"left"),l={},f={};("absolute"===r||"fixed"===r)&&b.inArray("auto",[u,c])>-1?(i=(f=a.position()).top,o=f.left):(i=parseFloat(u)||0,o=parseFloat(c)||0),b.isFunction(t)&&(t=t.call(e,n,s)),null!=t.top&&(l.top=t.top-s.top+i),null!=t.left&&(l.left=t.left-s.left+o),"using"in t?t.using.call(e,l):a.css(l)}},b.fn.extend({position:function(){if(this[0]){var e=this[0],t=this.offsetParent(),n=this.offset(),r=Gt.test(t[0].nodeName)?{top:0,left:0}:t.offset();return n.top-=parseFloat(b.css(e,"marginTop"))||0,n.left-=parseFloat(b.css(e,"marginLeft"))||0,r.top+=parseFloat(b.css(t[0],"borderTopWidth"))||0,r.left+=parseFloat(b.css(t[0],"borderLeftWidth"))||0,{top:n.top-r.top,left:n.left-r.left}}},offsetParent:function(){return this.map((function(){for(var e=this.offsetParent||u.body;e&&!Gt.test(e.nodeName)&&"static"===b.css(e,"position");)e=e.offsetParent;return e||u.body}))}}),b.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},(function(e,t){var n=/Y/.test(t);b.fn[e]=function(r){return b.access(this,(function(e,r,i){var o=Jt(e);if(void 0===i)return o?t in o?o[t]:o.document.documentElement[r]:e[r];o?o.scrollTo(n?b(o).scrollLeft():i,n?i:b(o).scrollTop()):e[r]=i}),e,r,arguments.length,null)}})),b.each({Height:"height",Width:"width"},(function(e,t){b.each({padding:"inner"+e,content:t,"":"outer"+e},(function(n,r){b.fn[r]=function(r,i){var o=arguments.length&&(n||"boolean"!=typeof r),a=n||(!0===r||!0===i?"margin":"border");return b.access(this,(function(t,n,r){var i;return b.isWindow(t)?t.document.documentElement["client"+e]:9===t.nodeType?(i=t.documentElement,Math.max(t.body["scroll"+e],i["scroll"+e],t.body["offset"+e],i["offset"+e],i["client"+e])):void 0===r?b.css(t,n,r,a):b.style(t,n,r,a)}),t,o?r:void 0,o,null)}}))})),i.jQuery=i.$=b,n(37).jQuery&&(void 0===(r=function(){return b}.apply(t,[]))||(e.exports=r)),b}(window)},function(e,t){(function(t){e.exports=t}).call(this,{})},function(e,t,n){var r;
/*!
 * jQuery Mousewheel 3.1.13
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 */r=function(e){var t,n,r=["wheel","mousewheel","DOMMouseScroll","MozMousePixelScroll"],i="onwheel"in document||document.documentMode>=9?["wheel"]:["mousewheel","DomMouseScroll","MozMousePixelScroll"],o=Array.prototype.slice;if(e.event.fixHooks)for(var a=r.length;a;)e.event.fixHooks[r[--a]]=e.event.mouseHooks;var s=e.event.special.mousewheel={version:"3.1.12",setup:function(){if(this.addEventListener)for(var t=i.length;t;)this.addEventListener(i[--t],u,!1);else this.onmousewheel=u;e.data(this,"mousewheel-line-height",s.getLineHeight(this)),e.data(this,"mousewheel-page-height",s.getPageHeight(this))},teardown:function(){if(this.removeEventListener)for(var t=i.length;t;)this.removeEventListener(i[--t],u,!1);else this.onmousewheel=null;e.removeData(this,"mousewheel-line-height"),e.removeData(this,"mousewheel-page-height")},getLineHeight:function(t){var n=e(t),r=n["offsetParent"in e.fn?"offsetParent":"parent"]();return r.length||(r=e("body")),parseInt(r.css("fontSize"),10)||parseInt(n.css("fontSize"),10)||16},getPageHeight:function(t){return e(t).height()},settings:{adjustOldDeltas:!0,normalizeOffset:!0}};function u(r){var i=r||window.event,a=o.call(arguments,1),u=0,f=0,h=0,p=0,d=0,v=0;if((r=e.event.fix(i)).type="mousewheel","detail"in i&&(h=-1*i.detail),"wheelDelta"in i&&(h=i.wheelDelta),"wheelDeltaY"in i&&(h=i.wheelDeltaY),"wheelDeltaX"in i&&(f=-1*i.wheelDeltaX),"axis"in i&&i.axis===i.HORIZONTAL_AXIS&&(f=-1*h,h=0),u=0===h?f:h,"deltaY"in i&&(u=h=-1*i.deltaY),"deltaX"in i&&(f=i.deltaX,0===h&&(u=-1*f)),0!==h||0!==f){if(1===i.deltaMode){var g=e.data(this,"mousewheel-line-height");u*=g,h*=g,f*=g}else if(2===i.deltaMode){var y=e.data(this,"mousewheel-page-height");u*=y,h*=y,f*=y}if(p=Math.max(Math.abs(h),Math.abs(f)),(!n||p<n)&&(n=p,l(i,p)&&(n/=40)),l(i,p)&&(u/=40,f/=40,h/=40),u=Math[u>=1?"floor":"ceil"](u/n),f=Math[f>=1?"floor":"ceil"](f/n),h=Math[h>=1?"floor":"ceil"](h/n),s.settings.normalizeOffset&&this.getBoundingClientRect){var m=this.getBoundingClientRect();d=r.clientX-m.left,v=r.clientY-m.top}return r.deltaX=f,r.deltaY=h,r.deltaFactor=n,r.offsetX=d,r.offsetY=v,r.deltaMode=0,a.unshift(r,u,f,h),t&&clearTimeout(t),t=setTimeout(c,200),(e.event.dispatch||e.event.handle).apply(this,a)}}function c(){n=null}function l(e,t){return s.settings.adjustOldDeltas&&"mousewheel"===e.type&&t%120==0}e.fn.extend({mousewheel:function(e){return e?this.bind("mousewheel",e):this.trigger("mousewheel")},unmousewheel:function(e){return this.unbind("mousewheel",e)}})},e.exports=r},function(e,t,n){(function(){var t,r,i,o,a,s,u,c,l={}.hasOwnProperty;u=n(15),s=n(7).Module,t=n(43),a=n(14),r=n(68),c=n(69),o=n(81),i=n(28),e.exports=function(e){function s(e){this.file=new t(e),this.parsed=!1,this.header=null,Object.defineProperty(this,"layers",{get:function(){return this.layerMask.layers}}),u.on("error",(function(e){return console.error(e)}))}return function(e,t){for(var n in t)l.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(s,e),s.Node={Root:n(129)},s.extends(n(135)),s.prototype.parse=function(){if(!this.parsed)return this.parseHeader(),this.parseResources(),this.parseLayerMask(),this.parseImage(),this.parsed=!0},s.prototype.parseHeader=function(){return this.header=new r(this.file),this.header.parse()},s.prototype.parseResources=function(){var e;return e=new c(this.file),this.resources=new a(e,this.file).now("skip").later("parse").get()},s.prototype.parseLayerMask=function(){var e;return e=new o(this.file,this.header),this.layerMask=new a(e,this.file).now("skip").later("parse").get()},s.prototype.parseImage=function(){var e;return e=new i(this.file,this.header),this.image=new a(e,this.file).later("parse").ignore("width","height").get()},s.prototype.tree=function(){return new s.Node.Root(this)},s}(s)}).call(this)},function(e,t,n){(function(e,t){!function(e,n){"use strict";if(!e.setImmediate){var r,i,o,a,s,u=1,c={},l=!1,f=e.document,h=Object.getPrototypeOf&&Object.getPrototypeOf(e);h=h&&h.setTimeout?h:e,"[object process]"==={}.toString.call(e.process)?r=function(e){t.nextTick((function(){d(e)}))}:!function(){if(e.postMessage&&!e.importScripts){var t=!0,n=e.onmessage;return e.onmessage=function(){t=!1},e.postMessage("","*"),e.onmessage=n,t}}()?e.MessageChannel?((o=new MessageChannel).port1.onmessage=function(e){d(e.data)},r=function(e){o.port2.postMessage(e)}):f&&"onreadystatechange"in f.createElement("script")?(i=f.documentElement,r=function(e){var t=f.createElement("script");t.onreadystatechange=function(){d(e),t.onreadystatechange=null,i.removeChild(t),t=null},i.appendChild(t)}):r=function(e){setTimeout(d,0,e)}:(a="setImmediate$"+Math.random()+"$",s=function(t){t.source===e&&"string"==typeof t.data&&0===t.data.indexOf(a)&&d(+t.data.slice(a.length))},e.addEventListener?e.addEventListener("message",s,!1):e.attachEvent("onmessage",s),r=function(t){e.postMessage(a+t,"*")}),h.setImmediate=function(e){"function"!=typeof e&&(e=new Function(""+e));for(var t=new Array(arguments.length-1),n=0;n<t.length;n++)t[n]=arguments[n+1];var i={callback:e,args:t};return c[u]=i,r(u),u++},h.clearImmediate=p}function p(e){delete c[e]}function d(e){if(l)setTimeout(d,0,e);else{var t=c[e];if(t){l=!0;try{!function(e){var t=e.callback,n=e.args;switch(n.length){case 0:t();break;case 1:t(n[0]);break;case 2:t(n[0],n[1]);break;case 3:t(n[0],n[1],n[2]);break;default:t.apply(void 0,n)}}(t)}finally{p(e),l=!1}}}}}("undefined"==typeof self?void 0===e?this:e:self)}).call(this,n(8),n(10))},function(e,t){},function(e,t){var n,r=[].indexOf||function(e){for(var t=0,n=this.length;t<n;t++)if(t in this&&this[t]===e)return t;return-1},i=[].slice;n=["extended","included"],t.Module=function(){function e(){}return e.extends=function(e){var t,i,o;for(t in e)i=e[t],r.call(n,t)<0&&(this[t]=i);return null!=(o=e.extended)&&o.call(this,this),this},e.includes=function(e){var t,i,o;for(t in e)i=e[t],r.call(n,t)<0&&(this.prototype[t]=i);return null!=(o=e.included)&&o.call(this,this),this},e.delegate=function(){var e,t,n,r,o,a;for(n=(e=1<=arguments.length?i.call(arguments,0):[]).pop(),a=[],r=0,o=e.length;r<o;r++)t=e[r],a.push(this.prototype[t]=n.prototype[t]);return a},e.aliasFunction=function(e,t){return this.prototype[e]=(n=this,function(){var e;return e=1<=arguments.length?i.call(arguments,0):[],n.prototype[t].apply(n,e)});var n},e.aliasProperty=function(e,t){return Object.defineProperty(this.prototype,e,{get:function(){return this[t]},set:function(e){return this[t]=e}})},e.included=function(e){return e.call(this,this.prototype)},e}()},function(e,t,n){(function(t){(function(){var r,i,o,a={}.hasOwnProperty;o=n(47).jspack,r=n(48),i=n(16),n(23),n(6),e.exports=function(){var e,n,s;for(s in n=function(e,t){return u.prototype["read"+e]=function(){return this.readf(t.code,t.length)}},e={Int:{code:">i",length:4},UInt:{code:">I",length:4},Short:{code:">h",length:2},UShort:{code:">H",length:2},Float:{code:">f",length:4},Double:{code:">d",length:8},LongLong:{code:">q",length:8}})a.call(e,s)&&n(s,e[s]);function u(e){this.data=e}return u.prototype.pos=0,u.prototype.tell=function(){return this.pos},u.prototype.read=function(e){var t,n,r;for(r=[],t=0,n=e;0<=n?t<n:t>n;0<=n?++t:--t)r.push(this.data[this.pos++]);return r},u.prototype.readf=function(e,t){var n;if(null==t&&(t=null),n=(n=o.Unpack(e,this.read(t||o.CalcLength(e))))[0],">q"===e){if((n=new r(n[0],n[1],n[2])).getNumBitsAbs()>32)throw"PSB is too large";n=n.toInt()}return n},u.prototype.seek=function(e,t){return null==t&&(t=!1),this.pos=t?this.pos+e:e},u.prototype.readString=function(e){return String.fromCharCode.apply(null,this.read(e)).replace(/\u0000/g,"")},u.prototype.readUnicodeString=function(e){return null==e&&(e=null),e||(e=this.readInt()),i.decode(new t(this.read(2*e)),"utf-16be").replace(/\u0000/g,"")},u.prototype.readByte=function(){return this.read(1)[0]},u.prototype.readBoolean=function(){return 0!==this.readByte()},u.prototype.readSpaceColor=function(){var e,t,n;for(t=this.readShort(),n=0;n<4;++n)e=this.readShort()>>8;return{colorSpace:t,components:e}},u.prototype.readPathNumber=function(){var e,t,n;return e=this.readByte(),n=(t=this.read(3))[0]<<16|t[1]<<8|t[2],parseFloat(e,10)+parseFloat(n/Math.pow(2,24),10)},u}()}).call(this)}).call(this,n(11).Buffer)},function(e,t,n){"use strict";t.byteLength=function(e){var t=c(e),n=t[0],r=t[1];return 3*(n+r)/4-r},t.toByteArray=function(e){var t,n,r=c(e),a=r[0],s=r[1],u=new o(function(e,t,n){return 3*(t+n)/4-n}(0,a,s)),l=0,f=s>0?a-4:a;for(n=0;n<f;n+=4)t=i[e.charCodeAt(n)]<<18|i[e.charCodeAt(n+1)]<<12|i[e.charCodeAt(n+2)]<<6|i[e.charCodeAt(n+3)],u[l++]=t>>16&255,u[l++]=t>>8&255,u[l++]=255&t;2===s&&(t=i[e.charCodeAt(n)]<<2|i[e.charCodeAt(n+1)]>>4,u[l++]=255&t);1===s&&(t=i[e.charCodeAt(n)]<<10|i[e.charCodeAt(n+1)]<<4|i[e.charCodeAt(n+2)]>>2,u[l++]=t>>8&255,u[l++]=255&t);return u},t.fromByteArray=function(e){for(var t,n=e.length,i=n%3,o=[],a=0,s=n-i;a<s;a+=16383)o.push(l(e,a,a+16383>s?s:a+16383));1===i?(t=e[n-1],o.push(r[t>>2]+r[t<<4&63]+"==")):2===i&&(t=(e[n-2]<<8)+e[n-1],o.push(r[t>>10]+r[t>>4&63]+r[t<<2&63]+"="));return o.join("")};for(var r=[],i=[],o="undefined"!=typeof Uint8Array?Uint8Array:Array,a="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",s=0,u=a.length;s<u;++s)r[s]=a[s],i[a.charCodeAt(s)]=s;function c(e){var t=e.length;if(t%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var n=e.indexOf("=");return-1===n&&(n=t),[n,n===t?0:4-n%4]}function l(e,t,n){for(var i,o,a=[],s=t;s<n;s+=3)i=(e[s]<<16&16711680)+(e[s+1]<<8&65280)+(255&e[s+2]),a.push(r[(o=i)>>18&63]+r[o>>12&63]+r[o>>6&63]+r[63&o]);return a.join("")}i["-".charCodeAt(0)]=62,i["_".charCodeAt(0)]=63},function(e,t){t.read=function(e,t,n,r,i){var o,a,s=8*i-r-1,u=(1<<s)-1,c=u>>1,l=-7,f=n?i-1:0,h=n?-1:1,p=e[t+f];for(f+=h,o=p&(1<<-l)-1,p>>=-l,l+=s;l>0;o=256*o+e[t+f],f+=h,l-=8);for(a=o&(1<<-l)-1,o>>=-l,l+=r;l>0;a=256*a+e[t+f],f+=h,l-=8);if(0===o)o=1-c;else{if(o===u)return a?NaN:1/0*(p?-1:1);a+=Math.pow(2,r),o-=c}return(p?-1:1)*a*Math.pow(2,o-r)},t.write=function(e,t,n,r,i,o){var a,s,u,c=8*o-i-1,l=(1<<c)-1,f=l>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=r?0:o-1,d=r?1:-1,v=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(s=isNaN(t)?1:0,a=l):(a=Math.floor(Math.log(t)/Math.LN2),t*(u=Math.pow(2,-a))<1&&(a--,u*=2),(t+=a+f>=1?h/u:h*Math.pow(2,1-f))*u>=2&&(a++,u/=2),a+f>=l?(s=0,a=l):a+f>=1?(s=(t*u-1)*Math.pow(2,i),a+=f):(s=t*Math.pow(2,f-1)*Math.pow(2,i),a=0));i>=8;e[n+p]=255&s,p+=d,s/=256,i-=8);for(a=a<<i|s,c+=i;c>0;e[n+p]=255&a,p+=d,a/=256,c-=8);e[n+p-d]|=128*v}},function(e,t){var n={}.toString;e.exports=Array.isArray||function(e){return"[object Array]"==n.call(e)}},function(e,t){t.jspack=new
/*!
 *  Copyright © 2008 Fair Oaks Labs, Inc.
 *  All rights reserved.
 */
function(){var e,t=!1,n=this;n._DeArray=function(e,t,n){return[e.slice(t,t+n)]},n._EnArray=function(e,t,n,r){for(var i=0;i<n;e[t+i]=r[i]?r[i]:0,i++);},n._DeChar=function(e,t){return String.fromCharCode(e[t])},n._EnChar=function(e,t,n){e[t]=n.charCodeAt(0)},n._DeInt=function(n,r){var i,o,a,s=t?e.len-1:0,u=t?-1:1,c=s+u*e.len;for(i=0,o=s,a=1;o!=c;i+=n[r+o]*a,o+=u,a*=256);return e.bSigned&&i&Math.pow(2,8*e.len-1)&&(i-=Math.pow(2,8*e.len)),i},n._EnInt=function(n,r,i){var o,a=t?e.len-1:0,s=t?-1:1,u=a+s*e.len;for(i=i<e.min?e.min:i>e.max?e.max:i,o=a;o!=u;n[r+o]=255&i,o+=s,i>>=8);},n._DeString=function(e,t,n){for(var r=new Array(n),i=0;i<n;r[i]=String.fromCharCode(e[t+i]),i++);return r.join("")},n._EnString=function(e,t,n,r){for(var i,o=0;o<n;e[t+o]=(i=r.charCodeAt(o))?i:0,o++);},n._De754=function(n,r){var i,o,a,s,u,c,l,f,h,p;for(l=e.mLen,h=(p=(1<<(f=8*e.len-e.mLen-1))-1)>>1,s=t?0:e.len-1,u=t?1:-1,i=n[r+s],s+=u,o=i&(1<<-(c=-7))-1,i>>=-c,c+=f;c>0;o=256*o+n[r+s],s+=u,c-=8);for(a=o&(1<<-c)-1,o>>=-c,c+=l;c>0;a=256*a+n[r+s],s+=u,c-=8);switch(o){case 0:o=1-h;break;case p:return a?NaN:1/0*(i?-1:1);default:a+=Math.pow(2,l),o-=h}return(i?-1:1)*a*Math.pow(2,o-l)},n._En754=function(n,r,i){var o,a,s,u,c,l,f,h,p,d;for(f=e.mLen,p=(d=(1<<(h=8*e.len-e.mLen-1))-1)>>1,o=i<0?1:0,i=Math.abs(i),isNaN(i)||i==1/0?(s=isNaN(i)?1:0,a=d):(a=Math.floor(Math.log(i)/Math.LN2),i*(l=Math.pow(2,-a))<1&&(a--,l*=2),(i+=a+p>=1?e.rt/l:e.rt*Math.pow(2,1-p))*l>=2&&(a++,l/=2),a+p>=d?(s=0,a=d):a+p>=1?(s=(i*l-1)*Math.pow(2,f),a+=p):(s=i*Math.pow(2,p-1)*Math.pow(2,f),a=0)),u=t?e.len-1:0,c=t?-1:1;f>=8;n[r+u]=255&s,u+=c,s/=256,f-=8);for(a=a<<f|s,h+=f;h>0;n[r+u]=255&a,u+=c,a/=256,h-=8);n[r+u-c]|=128*o},n._DeInt64=function(n,r){var i,o,a,s=t?0:7,u=t?1:-1,c=s+8*u,l=[0,0,!e.bSigned];for(i=s,a=1,o=0;i!=c;l[a]=(l[a]<<8>>>0)+n[r+i],i+=u,a=++o<4?1:0);return l},n._EnInt64=function(e,n,r){var i,o,a,s,u=t?0:7,c=t?1:-1,l=u+8*c;for(i=u,a=1,o=0,s=24;i!=l;e[n+i]=r[a]>>s&255,i+=c,a=++o<4?1:0,s=24-o%4*8);},n._sPattern="(\\d+)?([AxcbBhHsfdiIlLqQ])",n._lenLut={A:1,x:1,c:1,b:1,B:1,h:2,H:2,s:1,f:4,d:8,i:4,I:4,l:4,L:4,q:8,Q:8},n._elLut={A:{en:n._EnArray,de:n._DeArray},s:{en:n._EnString,de:n._DeString},c:{en:n._EnChar,de:n._DeChar},b:{en:n._EnInt,de:n._DeInt,len:1,bSigned:!0,min:-Math.pow(2,7),max:Math.pow(2,7)-1},B:{en:n._EnInt,de:n._DeInt,len:1,bSigned:!1,min:0,max:Math.pow(2,8)-1},h:{en:n._EnInt,de:n._DeInt,len:2,bSigned:!0,min:-Math.pow(2,15),max:Math.pow(2,15)-1},H:{en:n._EnInt,de:n._DeInt,len:2,bSigned:!1,min:0,max:Math.pow(2,16)-1},i:{en:n._EnInt,de:n._DeInt,len:4,bSigned:!0,min:-Math.pow(2,31),max:Math.pow(2,31)-1},I:{en:n._EnInt,de:n._DeInt,len:4,bSigned:!1,min:0,max:Math.pow(2,32)-1},l:{en:n._EnInt,de:n._DeInt,len:4,bSigned:!0,min:-Math.pow(2,31),max:Math.pow(2,31)-1},L:{en:n._EnInt,de:n._DeInt,len:4,bSigned:!1,min:0,max:Math.pow(2,32)-1},f:{en:n._En754,de:n._De754,len:4,mLen:23,rt:Math.pow(2,-24)-Math.pow(2,-77)},d:{en:n._En754,de:n._De754,len:8,mLen:52,rt:0},q:{en:n._EnInt64,de:n._DeInt64,bSigned:!0},Q:{en:n._EnInt64,de:n._DeInt64,bSigned:!1}},n._UnpackSeries=function(t,n,r,i){for(var o=e.de,a=[],s=0;s<t;a.push(o(r,i+s*n)),s++);return a},n._PackSeries=function(t,n,r,i,o,a){for(var s=e.en,u=0;u<t;s(r,i+u*n,o[a+u]),u++);},n.Unpack=function(n,r,i){t="<"!=n.charAt(0),i=i||0;for(var o,a,s,u=new RegExp(this._sPattern,"g"),c=[];o=u.exec(n);){if(i+(a=null==o[1]||""==o[1]?1:parseInt(o[1]))*(s=this._lenLut[o[2]])>r.length)return;switch(o[2]){case"A":case"s":c.push(this._elLut[o[2]].de(r,i,a));break;case"c":case"b":case"B":case"h":case"H":case"i":case"I":case"l":case"L":case"f":case"d":case"q":case"Q":e=this._elLut[o[2]],c.push(this._UnpackSeries(a,s,r,i))}i+=a*s}return Array.prototype.concat.apply([],c)},n.PackTo=function(n,r,i,o){t="<"!=n.charAt(0);for(var a,s,u,c,l=new RegExp(this._sPattern,"g"),f=0;a=l.exec(n);){if(i+(s=null==a[1]||""==a[1]?1:parseInt(a[1]))*(u=this._lenLut[a[2]])>r.length)return!1;switch(a[2]){case"A":case"s":if(f+1>o.length)return!1;this._elLut[a[2]].en(r,i,s,o[f]),f+=1;break;case"c":case"b":case"B":case"h":case"H":case"i":case"I":case"l":case"L":case"f":case"d":case"q":case"Q":if(e=this._elLut[a[2]],f+s>o.length)return!1;this._PackSeries(s,u,r,i,o,f),f+=s;break;case"x":for(c=0;c<s;c++)r[i+c]=0}i+=s*u}return r},n.Pack=function(e,t){return this.PackTo(e,new Array(this.CalcLength(e)),0,t)},n.CalcLength=function(e){for(var t,n=new RegExp(this._sPattern,"g"),r=0;t=n.exec(e);)r+=(null==t[1]||""==t[1]?1:parseInt(t[1]))*this._lenLut[t[2]];return r}}},function(e,t){e.exports=r;var n=null;try{n=new WebAssembly.Instance(new WebAssembly.Module(new Uint8Array([0,97,115,109,1,0,0,0,1,13,2,96,0,1,127,96,4,127,127,127,127,1,127,3,7,6,0,1,1,1,1,1,6,6,1,127,1,65,0,11,7,50,6,3,109,117,108,0,1,5,100,105,118,95,115,0,2,5,100,105,118,95,117,0,3,5,114,101,109,95,115,0,4,5,114,101,109,95,117,0,5,8,103,101,116,95,104,105,103,104,0,0,10,191,1,6,4,0,35,0,11,36,1,1,126,32,0,173,32,1,173,66,32,134,132,32,2,173,32,3,173,66,32,134,132,126,34,4,66,32,135,167,36,0,32,4,167,11,36,1,1,126,32,0,173,32,1,173,66,32,134,132,32,2,173,32,3,173,66,32,134,132,127,34,4,66,32,135,167,36,0,32,4,167,11,36,1,1,126,32,0,173,32,1,173,66,32,134,132,32,2,173,32,3,173,66,32,134,132,128,34,4,66,32,135,167,36,0,32,4,167,11,36,1,1,126,32,0,173,32,1,173,66,32,134,132,32,2,173,32,3,173,66,32,134,132,129,34,4,66,32,135,167,36,0,32,4,167,11,36,1,1,126,32,0,173,32,1,173,66,32,134,132,32,2,173,32,3,173,66,32,134,132,130,34,4,66,32,135,167,36,0,32,4,167,11])),{}).exports}catch(e){}function r(e,t,n){this.low=0|e,this.high=0|t,this.unsigned=!!n}function i(e){return!0===(e&&e.__isLong__)}r.prototype.__isLong__,Object.defineProperty(r.prototype,"__isLong__",{value:!0}),r.isLong=i;var o={},a={};function s(e,t){var n,r,i;return t?(i=0<=(e>>>=0)&&e<256)&&(r=a[e])?r:(n=c(e,(0|e)<0?-1:0,!0),i&&(a[e]=n),n):(i=-128<=(e|=0)&&e<128)&&(r=o[e])?r:(n=c(e,e<0?-1:0,!1),i&&(o[e]=n),n)}function u(e,t){if(isNaN(e))return t?m:y;if(t){if(e<0)return m;if(e>=d)return T}else{if(e<=-v)return C;if(e+1>=v)return x}return e<0?u(-e,t).neg():c(e%p|0,e/p|0,t)}function c(e,t,n){return new r(e,t,n)}r.fromInt=s,r.fromNumber=u,r.fromBits=c;var l=Math.pow;function f(e,t,n){if(0===e.length)throw Error("empty string");if("NaN"===e||"Infinity"===e||"+Infinity"===e||"-Infinity"===e)return y;if("number"==typeof t?(n=t,t=!1):t=!!t,(n=n||10)<2||36<n)throw RangeError("radix");var r;if((r=e.indexOf("-"))>0)throw Error("interior hyphen");if(0===r)return f(e.substring(1),t,n).neg();for(var i=u(l(n,8)),o=y,a=0;a<e.length;a+=8){var s=Math.min(8,e.length-a),c=parseInt(e.substring(a,a+s),n);if(s<8){var h=u(l(n,s));o=o.mul(h).add(u(c))}else o=(o=o.mul(i)).add(u(c))}return o.unsigned=t,o}function h(e,t){return"number"==typeof e?u(e,t):"string"==typeof e?f(e,t):c(e.low,e.high,"boolean"==typeof t?t:e.unsigned)}r.fromString=f,r.fromValue=h;var p=4294967296,d=p*p,v=d/2,g=s(1<<24),y=s(0);r.ZERO=y;var m=s(0,!0);r.UZERO=m;var b=s(1);r.ONE=b;var _=s(1,!0);r.UONE=_;var w=s(-1);r.NEG_ONE=w;var x=c(-1,2147483647,!1);r.MAX_VALUE=x;var T=c(-1,-1,!0);r.MAX_UNSIGNED_VALUE=T;var C=c(0,-2147483648,!1);r.MIN_VALUE=C;var E=r.prototype;E.toInt=function(){return this.unsigned?this.low>>>0:this.low},E.toNumber=function(){return this.unsigned?(this.high>>>0)*p+(this.low>>>0):this.high*p+(this.low>>>0)},E.toString=function(e){if((e=e||10)<2||36<e)throw RangeError("radix");if(this.isZero())return"0";if(this.isNegative()){if(this.eq(C)){var t=u(e),n=this.div(t),r=n.mul(t).sub(this);return n.toString(e)+r.toInt().toString(e)}return"-"+this.neg().toString(e)}for(var i=u(l(e,6),this.unsigned),o=this,a="";;){var s=o.div(i),c=(o.sub(s.mul(i)).toInt()>>>0).toString(e);if((o=s).isZero())return c+a;for(;c.length<6;)c="0"+c;a=""+c+a}},E.getHighBits=function(){return this.high},E.getHighBitsUnsigned=function(){return this.high>>>0},E.getLowBits=function(){return this.low},E.getLowBitsUnsigned=function(){return this.low>>>0},E.getNumBitsAbs=function(){if(this.isNegative())return this.eq(C)?64:this.neg().getNumBitsAbs();for(var e=0!=this.high?this.high:this.low,t=31;t>0&&0==(e&1<<t);t--);return 0!=this.high?t+33:t+1},E.isZero=function(){return 0===this.high&&0===this.low},E.eqz=E.isZero,E.isNegative=function(){return!this.unsigned&&this.high<0},E.isPositive=function(){return this.unsigned||this.high>=0},E.isOdd=function(){return 1==(1&this.low)},E.isEven=function(){return 0==(1&this.low)},E.equals=function(e){return i(e)||(e=h(e)),(this.unsigned===e.unsigned||this.high>>>31!=1||e.high>>>31!=1)&&(this.high===e.high&&this.low===e.low)},E.eq=E.equals,E.notEquals=function(e){return!this.eq(e)},E.neq=E.notEquals,E.ne=E.notEquals,E.lessThan=function(e){return this.comp(e)<0},E.lt=E.lessThan,E.lessThanOrEqual=function(e){return this.comp(e)<=0},E.lte=E.lessThanOrEqual,E.le=E.lessThanOrEqual,E.greaterThan=function(e){return this.comp(e)>0},E.gt=E.greaterThan,E.greaterThanOrEqual=function(e){return this.comp(e)>=0},E.gte=E.greaterThanOrEqual,E.ge=E.greaterThanOrEqual,E.compare=function(e){if(i(e)||(e=h(e)),this.eq(e))return 0;var t=this.isNegative(),n=e.isNegative();return t&&!n?-1:!t&&n?1:this.unsigned?e.high>>>0>this.high>>>0||e.high===this.high&&e.low>>>0>this.low>>>0?-1:1:this.sub(e).isNegative()?-1:1},E.comp=E.compare,E.negate=function(){return!this.unsigned&&this.eq(C)?C:this.not().add(b)},E.neg=E.negate,E.add=function(e){i(e)||(e=h(e));var t=this.high>>>16,n=65535&this.high,r=this.low>>>16,o=65535&this.low,a=e.high>>>16,s=65535&e.high,u=e.low>>>16,l=0,f=0,p=0,d=0;return p+=(d+=o+(65535&e.low))>>>16,f+=(p+=r+u)>>>16,l+=(f+=n+s)>>>16,l+=t+a,c((p&=65535)<<16|(d&=65535),(l&=65535)<<16|(f&=65535),this.unsigned)},E.subtract=function(e){return i(e)||(e=h(e)),this.add(e.neg())},E.sub=E.subtract,E.multiply=function(e){if(this.isZero())return y;if(i(e)||(e=h(e)),n)return c(n.mul(this.low,this.high,e.low,e.high),n.get_high(),this.unsigned);if(e.isZero())return y;if(this.eq(C))return e.isOdd()?C:y;if(e.eq(C))return this.isOdd()?C:y;if(this.isNegative())return e.isNegative()?this.neg().mul(e.neg()):this.neg().mul(e).neg();if(e.isNegative())return this.mul(e.neg()).neg();if(this.lt(g)&&e.lt(g))return u(this.toNumber()*e.toNumber(),this.unsigned);var t=this.high>>>16,r=65535&this.high,o=this.low>>>16,a=65535&this.low,s=e.high>>>16,l=65535&e.high,f=e.low>>>16,p=65535&e.low,d=0,v=0,m=0,b=0;return m+=(b+=a*p)>>>16,v+=(m+=o*p)>>>16,m&=65535,v+=(m+=a*f)>>>16,d+=(v+=r*p)>>>16,v&=65535,d+=(v+=o*f)>>>16,v&=65535,d+=(v+=a*l)>>>16,d+=t*p+r*f+o*l+a*s,c((m&=65535)<<16|(b&=65535),(d&=65535)<<16|(v&=65535),this.unsigned)},E.mul=E.multiply,E.divide=function(e){if(i(e)||(e=h(e)),e.isZero())throw Error("division by zero");var t,r,o;if(n)return this.unsigned||-2147483648!==this.high||-1!==e.low||-1!==e.high?c((this.unsigned?n.div_u:n.div_s)(this.low,this.high,e.low,e.high),n.get_high(),this.unsigned):this;if(this.isZero())return this.unsigned?m:y;if(this.unsigned){if(e.unsigned||(e=e.toUnsigned()),e.gt(this))return m;if(e.gt(this.shru(1)))return _;o=m}else{if(this.eq(C))return e.eq(b)||e.eq(w)?C:e.eq(C)?b:(t=this.shr(1).div(e).shl(1)).eq(y)?e.isNegative()?b:w:(r=this.sub(e.mul(t)),o=t.add(r.div(e)));if(e.eq(C))return this.unsigned?m:y;if(this.isNegative())return e.isNegative()?this.neg().div(e.neg()):this.neg().div(e).neg();if(e.isNegative())return this.div(e.neg()).neg();o=y}for(r=this;r.gte(e);){t=Math.max(1,Math.floor(r.toNumber()/e.toNumber()));for(var a=Math.ceil(Math.log(t)/Math.LN2),s=a<=48?1:l(2,a-48),f=u(t),p=f.mul(e);p.isNegative()||p.gt(r);)p=(f=u(t-=s,this.unsigned)).mul(e);f.isZero()&&(f=b),o=o.add(f),r=r.sub(p)}return o},E.div=E.divide,E.modulo=function(e){return i(e)||(e=h(e)),n?c((this.unsigned?n.rem_u:n.rem_s)(this.low,this.high,e.low,e.high),n.get_high(),this.unsigned):this.sub(this.div(e).mul(e))},E.mod=E.modulo,E.rem=E.modulo,E.not=function(){return c(~this.low,~this.high,this.unsigned)},E.and=function(e){return i(e)||(e=h(e)),c(this.low&e.low,this.high&e.high,this.unsigned)},E.or=function(e){return i(e)||(e=h(e)),c(this.low|e.low,this.high|e.high,this.unsigned)},E.xor=function(e){return i(e)||(e=h(e)),c(this.low^e.low,this.high^e.high,this.unsigned)},E.shiftLeft=function(e){return i(e)&&(e=e.toInt()),0==(e&=63)?this:e<32?c(this.low<<e,this.high<<e|this.low>>>32-e,this.unsigned):c(0,this.low<<e-32,this.unsigned)},E.shl=E.shiftLeft,E.shiftRight=function(e){return i(e)&&(e=e.toInt()),0==(e&=63)?this:e<32?c(this.low>>>e|this.high<<32-e,this.high>>e,this.unsigned):c(this.high>>e-32,this.high>=0?0:-1,this.unsigned)},E.shr=E.shiftRight,E.shiftRightUnsigned=function(e){if(i(e)&&(e=e.toInt()),0===(e&=63))return this;var t=this.high;return e<32?c(this.low>>>e|t<<32-e,t>>>e,this.unsigned):c(32===e?t:t>>>e-32,0,this.unsigned)},E.shru=E.shiftRightUnsigned,E.shr_u=E.shiftRightUnsigned,E.toSigned=function(){return this.unsigned?c(this.low,this.high,!1):this},E.toUnsigned=function(){return this.unsigned?this:c(this.low,this.high,!0)},E.toBytes=function(e){return e?this.toBytesLE():this.toBytesBE()},E.toBytesLE=function(){var e=this.high,t=this.low;return[255&t,t>>>8&255,t>>>16&255,t>>>24,255&e,e>>>8&255,e>>>16&255,e>>>24]},E.toBytesBE=function(){var e=this.high,t=this.low;return[e>>>24,e>>>16&255,e>>>8&255,255&e,t>>>24,t>>>16&255,t>>>8&255,255&t]},r.fromBytes=function(e,t,n){return n?r.fromBytesLE(e,t):r.fromBytesBE(e,t)},r.fromBytesLE=function(e,t){return new r(e[0]|e[1]<<8|e[2]<<16|e[3]<<24,e[4]|e[5]<<8|e[6]<<16|e[7]<<24,t)},r.fromBytesBE=function(e,t){return new r(e[4]<<24|e[5]<<16|e[6]<<8|e[7],e[0]<<24|e[1]<<16|e[2]<<8|e[3],t)}},function(e,t,n){"use strict";function r(e,t){this.encoder=e,this.addBOM=!0}function i(e,t){this.decoder=e,this.pass=!1,this.options=t||{}}t.PrependBOM=r,r.prototype.write=function(e){return this.addBOM&&(e="\ufeff"+e,this.addBOM=!1),this.encoder.write(e)},r.prototype.end=function(){return this.encoder.end()},t.StripBOM=i,i.prototype.write=function(e){var t=this.decoder.write(e);return this.pass||!t||("\ufeff"===t[0]&&(t=t.slice(1),"function"==typeof this.options.stripBOM&&this.options.stripBOM()),this.pass=!0),t},i.prototype.end=function(){return this.decoder.end()}},function(e,t,n){"use strict";for(var r=[n(51),n(54),n(55),n(56),n(57),n(58),n(59),n(60)],i=0;i<r.length;i++){e=r[i];for(var o in e)Object.prototype.hasOwnProperty.call(e,o)&&(t[o]=e[o])}},function(e,t,n){"use strict";var r=n(9).Buffer;function i(e,t){this.enc=e.encodingName,this.bomAware=e.bomAware,"base64"===this.enc?this.encoder=u:"cesu8"===this.enc&&(this.enc="utf8",this.encoder=c,"💩"!==r.from("eda0bdedb2a9","hex").toString()&&(this.decoder=l,this.defaultCharUnicode=t.defaultCharUnicode))}e.exports={utf8:{type:"_internal",bomAware:!0},cesu8:{type:"_internal",bomAware:!0},unicode11utf8:"utf8",ucs2:{type:"_internal",bomAware:!0},utf16le:"ucs2",binary:{type:"_internal"},base64:{type:"_internal"},hex:{type:"_internal"},_internal:i},i.prototype.encoder=s,i.prototype.decoder=a;var o=n(52).StringDecoder;function a(e,t){o.call(this,t.enc)}function s(e,t){this.enc=t.enc}function u(e,t){this.prevStr=""}function c(e,t){}function l(e,t){this.acc=0,this.contBytes=0,this.accBytes=0,this.defaultCharUnicode=t.defaultCharUnicode}o.prototype.end||(o.prototype.end=function(){}),a.prototype=o.prototype,s.prototype.write=function(e){return r.from(e,this.enc)},s.prototype.end=function(){},u.prototype.write=function(e){var t=(e=this.prevStr+e).length-e.length%4;return this.prevStr=e.slice(t),e=e.slice(0,t),r.from(e,"base64")},u.prototype.end=function(){return r.from(this.prevStr,"base64")},c.prototype.write=function(e){for(var t=r.alloc(3*e.length),n=0,i=0;i<e.length;i++){var o=e.charCodeAt(i);o<128?t[n++]=o:o<2048?(t[n++]=192+(o>>>6),t[n++]=128+(63&o)):(t[n++]=224+(o>>>12),t[n++]=128+(o>>>6&63),t[n++]=128+(63&o))}return t.slice(0,n)},c.prototype.end=function(){},l.prototype.write=function(e){for(var t=this.acc,n=this.contBytes,r=this.accBytes,i="",o=0;o<e.length;o++){var a=e[o];128!=(192&a)?(n>0&&(i+=this.defaultCharUnicode,n=0),a<128?i+=String.fromCharCode(a):a<224?(t=31&a,n=1,r=1):a<240?(t=15&a,n=2,r=1):i+=this.defaultCharUnicode):n>0?(t=t<<6|63&a,r++,0===--n&&(i+=2===r&&t<128&&t>0||3===r&&t<2048?this.defaultCharUnicode:String.fromCharCode(t))):i+=this.defaultCharUnicode}return this.acc=t,this.contBytes=n,this.accBytes=r,i},l.prototype.end=function(){var e=0;return this.contBytes>0&&(e+=this.defaultCharUnicode),e}},function(e,t,n){"use strict";var r=n(53).Buffer,i=r.isEncoding||function(e){switch((e=""+e)&&e.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}};function o(e){var t;switch(this.encoding=function(e){var t=function(e){if(!e)return"utf8";for(var t;;)switch(e){case"utf8":case"utf-8":return"utf8";case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return"utf16le";case"latin1":case"binary":return"latin1";case"base64":case"ascii":case"hex":return e;default:if(t)return;e=(""+e).toLowerCase(),t=!0}}(e);if("string"!=typeof t&&(r.isEncoding===i||!i(e)))throw new Error("Unknown encoding: "+e);return t||e}(e),this.encoding){case"utf16le":this.text=u,this.end=c,t=4;break;case"utf8":this.fillLast=s,t=4;break;case"base64":this.text=l,this.end=f,t=3;break;default:return this.write=h,void(this.end=p)}this.lastNeed=0,this.lastTotal=0,this.lastChar=r.allocUnsafe(t)}function a(e){return e<=127?0:e>>5==6?2:e>>4==14?3:e>>3==30?4:e>>6==2?-1:-2}function s(e){var t=this.lastTotal-this.lastNeed,n=function(e,t,n){if(128!=(192&t[0]))return e.lastNeed=0,"�";if(e.lastNeed>1&&t.length>1){if(128!=(192&t[1]))return e.lastNeed=1,"�";if(e.lastNeed>2&&t.length>2&&128!=(192&t[2]))return e.lastNeed=2,"�"}}(this,e);return void 0!==n?n:this.lastNeed<=e.length?(e.copy(this.lastChar,t,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(e.copy(this.lastChar,t,0,e.length),void(this.lastNeed-=e.length))}function u(e,t){if((e.length-t)%2==0){var n=e.toString("utf16le",t);if(n){var r=n.charCodeAt(n.length-1);if(r>=55296&&r<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1],n.slice(0,-1)}return n}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=e[e.length-1],e.toString("utf16le",t,e.length-1)}function c(e){var t=e&&e.length?this.write(e):"";if(this.lastNeed){var n=this.lastTotal-this.lastNeed;return t+this.lastChar.toString("utf16le",0,n)}return t}function l(e,t){var n=(e.length-t)%3;return 0===n?e.toString("base64",t):(this.lastNeed=3-n,this.lastTotal=3,1===n?this.lastChar[0]=e[e.length-1]:(this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1]),e.toString("base64",t,e.length-n))}function f(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+this.lastChar.toString("base64",0,3-this.lastNeed):t}function h(e){return e.toString(this.encoding)}function p(e){return e&&e.length?this.write(e):""}t.StringDecoder=o,o.prototype.write=function(e){if(0===e.length)return"";var t,n;if(this.lastNeed){if(void 0===(t=this.fillLast(e)))return"";n=this.lastNeed,this.lastNeed=0}else n=0;return n<e.length?t?t+this.text(e,n):this.text(e,n):t||""},o.prototype.end=function(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+"�":t},o.prototype.text=function(e,t){var n=function(e,t,n){var r=t.length-1;if(r<n)return 0;var i=a(t[r]);if(i>=0)return i>0&&(e.lastNeed=i-1),i;if(--r<n||-2===i)return 0;if((i=a(t[r]))>=0)return i>0&&(e.lastNeed=i-2),i;if(--r<n||-2===i)return 0;if((i=a(t[r]))>=0)return i>0&&(2===i?i=0:e.lastNeed=i-3),i;return 0}(this,e,t);if(!this.lastNeed)return e.toString("utf8",t);this.lastTotal=n;var r=e.length-(n-this.lastNeed);return e.copy(this.lastChar,0,r),e.toString("utf8",t,r)},o.prototype.fillLast=function(e){if(this.lastNeed<=e.length)return e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,e.length),this.lastNeed-=e.length}},function(e,t,n){var r=n(11),i=r.Buffer;function o(e,t){for(var n in e)t[n]=e[n]}function a(e,t,n){return i(e,t,n)}i.from&&i.alloc&&i.allocUnsafe&&i.allocUnsafeSlow?e.exports=r:(o(r,t),t.Buffer=a),o(i,a),a.from=function(e,t,n){if("number"==typeof e)throw new TypeError("Argument must not be a number");return i(e,t,n)},a.alloc=function(e,t,n){if("number"!=typeof e)throw new TypeError("Argument must be a number");var r=i(e);return void 0!==t?"string"==typeof n?r.fill(t,n):r.fill(t):r.fill(0),r},a.allocUnsafe=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return i(e)},a.allocUnsafeSlow=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return r.SlowBuffer(e)}},function(e,t,n){"use strict";var r=n(9).Buffer;function i(){}function o(){}function a(){this.overflowByte=-1}function s(e,t){this.iconv=t}function u(e,t){void 0===(e=e||{}).addBOM&&(e.addBOM=!0),this.encoder=t.iconv.getEncoder("utf-16le",e)}function c(e,t){this.decoder=null,this.initialBytes=[],this.initialBytesLen=0,this.options=e||{},this.iconv=t.iconv}function l(e,t){var n=t||"utf-16le";if(e.length>=2)if(254==e[0]&&255==e[1])n="utf-16be";else if(255==e[0]&&254==e[1])n="utf-16le";else{for(var r=0,i=0,o=Math.min(e.length-e.length%2,64),a=0;a<o;a+=2)0===e[a]&&0!==e[a+1]&&i++,0!==e[a]&&0===e[a+1]&&r++;i>r?n="utf-16be":i<r&&(n="utf-16le")}return n}t.utf16be=i,i.prototype.encoder=o,i.prototype.decoder=a,i.prototype.bomAware=!0,o.prototype.write=function(e){for(var t=r.from(e,"ucs2"),n=0;n<t.length;n+=2){var i=t[n];t[n]=t[n+1],t[n+1]=i}return t},o.prototype.end=function(){},a.prototype.write=function(e){if(0==e.length)return"";var t=r.alloc(e.length+1),n=0,i=0;for(-1!==this.overflowByte&&(t[0]=e[0],t[1]=this.overflowByte,n=1,i=2);n<e.length-1;n+=2,i+=2)t[i]=e[n+1],t[i+1]=e[n];return this.overflowByte=n==e.length-1?e[e.length-1]:-1,t.slice(0,i).toString("ucs2")},a.prototype.end=function(){},t.utf16=s,s.prototype.encoder=u,s.prototype.decoder=c,u.prototype.write=function(e){return this.encoder.write(e)},u.prototype.end=function(){return this.encoder.end()},c.prototype.write=function(e){if(!this.decoder){if(this.initialBytes.push(e),this.initialBytesLen+=e.length,this.initialBytesLen<16)return"";var t=l(e=r.concat(this.initialBytes),this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(t,this.options),this.initialBytes.length=this.initialBytesLen=0}return this.decoder.write(e)},c.prototype.end=function(){if(!this.decoder){var e=r.concat(this.initialBytes),t=l(e,this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(t,this.options);var n=this.decoder.write(e),i=this.decoder.end();return i?n+i:n}return this.decoder.end()}},function(e,t,n){"use strict";var r=n(9).Buffer;function i(e,t){this.iconv=t}t.utf7=i,t.unicode11utf7="utf7",i.prototype.encoder=a,i.prototype.decoder=s,i.prototype.bomAware=!0;var o=/[^A-Za-z0-9'\(\),-\.\/:\? \n\r\t]+/g;function a(e,t){this.iconv=t.iconv}function s(e,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=""}a.prototype.write=function(e){return r.from(e.replace(o,function(e){return"+"+("+"===e?"":this.iconv.encode(e,"utf16-be").toString("base64").replace(/=+$/,""))+"-"}.bind(this)))},a.prototype.end=function(){};for(var u=/[A-Za-z0-9\/+]/,c=[],l=0;l<256;l++)c[l]=u.test(String.fromCharCode(l));var f="+".charCodeAt(0),h="-".charCodeAt(0),p="&".charCodeAt(0);function d(e,t){this.iconv=t}function v(e,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=r.alloc(6),this.base64AccumIdx=0}function g(e,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=""}s.prototype.write=function(e){for(var t="",n=0,i=this.inBase64,o=this.base64Accum,a=0;a<e.length;a++)if(i){if(!c[e[a]]){if(a==n&&e[a]==h)t+="+";else{var s=o+e.slice(n,a).toString();t+=this.iconv.decode(r.from(s,"base64"),"utf16-be")}e[a]!=h&&a--,n=a+1,i=!1,o=""}}else e[a]==f&&(t+=this.iconv.decode(e.slice(n,a),"ascii"),n=a+1,i=!0);if(i){var u=(s=o+e.slice(n).toString()).length-s.length%8;o=s.slice(u),s=s.slice(0,u),t+=this.iconv.decode(r.from(s,"base64"),"utf16-be")}else t+=this.iconv.decode(e.slice(n),"ascii");return this.inBase64=i,this.base64Accum=o,t},s.prototype.end=function(){var e="";return this.inBase64&&this.base64Accum.length>0&&(e=this.iconv.decode(r.from(this.base64Accum,"base64"),"utf16-be")),this.inBase64=!1,this.base64Accum="",e},t.utf7imap=d,d.prototype.encoder=v,d.prototype.decoder=g,d.prototype.bomAware=!0,v.prototype.write=function(e){for(var t=this.inBase64,n=this.base64Accum,i=this.base64AccumIdx,o=r.alloc(5*e.length+10),a=0,s=0;s<e.length;s++){var u=e.charCodeAt(s);32<=u&&u<=126?(t&&(i>0&&(a+=o.write(n.slice(0,i).toString("base64").replace(/\//g,",").replace(/=+$/,""),a),i=0),o[a++]=h,t=!1),t||(o[a++]=u,u===p&&(o[a++]=h))):(t||(o[a++]=p,t=!0),t&&(n[i++]=u>>8,n[i++]=255&u,i==n.length&&(a+=o.write(n.toString("base64").replace(/\//g,","),a),i=0)))}return this.inBase64=t,this.base64AccumIdx=i,o.slice(0,a)},v.prototype.end=function(){var e=r.alloc(10),t=0;return this.inBase64&&(this.base64AccumIdx>0&&(t+=e.write(this.base64Accum.slice(0,this.base64AccumIdx).toString("base64").replace(/\//g,",").replace(/=+$/,""),t),this.base64AccumIdx=0),e[t++]=h,this.inBase64=!1),e.slice(0,t)};var y=c.slice();y[",".charCodeAt(0)]=!0,g.prototype.write=function(e){for(var t="",n=0,i=this.inBase64,o=this.base64Accum,a=0;a<e.length;a++)if(i){if(!y[e[a]]){if(a==n&&e[a]==h)t+="&";else{var s=o+e.slice(n,a).toString().replace(/,/g,"/");t+=this.iconv.decode(r.from(s,"base64"),"utf16-be")}e[a]!=h&&a--,n=a+1,i=!1,o=""}}else e[a]==p&&(t+=this.iconv.decode(e.slice(n,a),"ascii"),n=a+1,i=!0);if(i){var u=(s=o+e.slice(n).toString().replace(/,/g,"/")).length-s.length%8;o=s.slice(u),s=s.slice(0,u),t+=this.iconv.decode(r.from(s,"base64"),"utf16-be")}else t+=this.iconv.decode(e.slice(n),"ascii");return this.inBase64=i,this.base64Accum=o,t},g.prototype.end=function(){var e="";return this.inBase64&&this.base64Accum.length>0&&(e=this.iconv.decode(r.from(this.base64Accum,"base64"),"utf16-be")),this.inBase64=!1,this.base64Accum="",e}},function(e,t,n){"use strict";var r=n(9).Buffer;function i(e,t){if(!e)throw new Error("SBCS codec is called without the data.");if(!e.chars||128!==e.chars.length&&256!==e.chars.length)throw new Error("Encoding '"+e.type+"' has incorrect 'chars' (must be of len 128 or 256)");if(128===e.chars.length){for(var n="",i=0;i<128;i++)n+=String.fromCharCode(i);e.chars=n+e.chars}this.decodeBuf=r.from(e.chars,"ucs2");var o=r.alloc(65536,t.defaultCharSingleByte.charCodeAt(0));for(i=0;i<e.chars.length;i++)o[e.chars.charCodeAt(i)]=i;this.encodeBuf=o}function o(e,t){this.encodeBuf=t.encodeBuf}function a(e,t){this.decodeBuf=t.decodeBuf}t._sbcs=i,i.prototype.encoder=o,i.prototype.decoder=a,o.prototype.write=function(e){for(var t=r.alloc(e.length),n=0;n<e.length;n++)t[n]=this.encodeBuf[e.charCodeAt(n)];return t},o.prototype.end=function(){},a.prototype.write=function(e){for(var t=this.decodeBuf,n=r.alloc(2*e.length),i=0,o=0,a=0;a<e.length;a++)i=2*e[a],n[o=2*a]=t[i],n[o+1]=t[i+1];return n.toString("ucs2")},a.prototype.end=function(){}},function(e,t,n){"use strict";e.exports={10029:"maccenteuro",maccenteuro:{type:"_sbcs",chars:"ÄĀāÉĄÖÜáąČäčĆćéŹźĎíďĒēĖóėôöõúĚěü†°Ę£§•¶ß®©™ę¨≠ģĮįĪ≤≥īĶ∂∑łĻļĽľĹĺŅņŃ¬√ńŇ∆«»… ňŐÕőŌ–—“”‘’÷◊ōŔŕŘ‹›řŖŗŠ‚„šŚśÁŤťÍŽžŪÓÔūŮÚůŰűŲųÝýķŻŁżĢˇ"},808:"cp808",ibm808:"cp808",cp808:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№€■ "},mik:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя└┴┬├─┼╣║╚╔╩╦╠═╬┐░▒▓│┤№§╗╝┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ascii8bit:"ascii",usascii:"ascii",ansix34:"ascii",ansix341968:"ascii",ansix341986:"ascii",csascii:"ascii",cp367:"ascii",ibm367:"ascii",isoir6:"ascii",iso646us:"ascii",iso646irv:"ascii",us:"ascii",latin1:"iso88591",latin2:"iso88592",latin3:"iso88593",latin4:"iso88594",latin5:"iso88599",latin6:"iso885910",latin7:"iso885913",latin8:"iso885914",latin9:"iso885915",latin10:"iso885916",csisolatin1:"iso88591",csisolatin2:"iso88592",csisolatin3:"iso88593",csisolatin4:"iso88594",csisolatincyrillic:"iso88595",csisolatinarabic:"iso88596",csisolatingreek:"iso88597",csisolatinhebrew:"iso88598",csisolatin5:"iso88599",csisolatin6:"iso885910",l1:"iso88591",l2:"iso88592",l3:"iso88593",l4:"iso88594",l5:"iso88599",l6:"iso885910",l7:"iso885913",l8:"iso885914",l9:"iso885915",l10:"iso885916",isoir14:"iso646jp",isoir57:"iso646cn",isoir100:"iso88591",isoir101:"iso88592",isoir109:"iso88593",isoir110:"iso88594",isoir144:"iso88595",isoir127:"iso88596",isoir126:"iso88597",isoir138:"iso88598",isoir148:"iso88599",isoir157:"iso885910",isoir166:"tis620",isoir179:"iso885913",isoir199:"iso885914",isoir203:"iso885915",isoir226:"iso885916",cp819:"iso88591",ibm819:"iso88591",cyrillic:"iso88595",arabic:"iso88596",arabic8:"iso88596",ecma114:"iso88596",asmo708:"iso88596",greek:"iso88597",greek8:"iso88597",ecma118:"iso88597",elot928:"iso88597",hebrew:"iso88598",hebrew8:"iso88598",turkish:"iso88599",turkish8:"iso88599",thai:"iso885911",thai8:"iso885911",celtic:"iso885914",celtic8:"iso885914",isoceltic:"iso885914",tis6200:"tis620",tis62025291:"tis620",tis62025330:"tis620",1e4:"macroman",10006:"macgreek",10007:"maccyrillic",10079:"maciceland",10081:"macturkish",cspc8codepage437:"cp437",cspc775baltic:"cp775",cspc850multilingual:"cp850",cspcp852:"cp852",cspc862latinhebrew:"cp862",cpgr:"cp869",msee:"cp1250",mscyrl:"cp1251",msansi:"cp1252",msgreek:"cp1253",msturk:"cp1254",mshebr:"cp1255",msarab:"cp1256",winbaltrim:"cp1257",cp20866:"koi8r",20866:"koi8r",ibm878:"koi8r",cskoi8r:"koi8r",cp21866:"koi8u",21866:"koi8u",ibm1168:"koi8u",strk10482002:"rk1048",tcvn5712:"tcvn",tcvn57121:"tcvn",gb198880:"iso646cn",cn:"iso646cn",csiso14jisc6220ro:"iso646jp",jisc62201969ro:"iso646jp",jp:"iso646jp",cshproman8:"hproman8",r8:"hproman8",roman8:"hproman8",xroman8:"hproman8",ibm1051:"hproman8",mac:"macintosh",csmacintosh:"macintosh"}},function(e,t,n){"use strict";e.exports={437:"cp437",737:"cp737",775:"cp775",850:"cp850",852:"cp852",855:"cp855",856:"cp856",857:"cp857",858:"cp858",860:"cp860",861:"cp861",862:"cp862",863:"cp863",864:"cp864",865:"cp865",866:"cp866",869:"cp869",874:"windows874",922:"cp922",1046:"cp1046",1124:"cp1124",1125:"cp1125",1129:"cp1129",1133:"cp1133",1161:"cp1161",1162:"cp1162",1163:"cp1163",1250:"windows1250",1251:"windows1251",1252:"windows1252",1253:"windows1253",1254:"windows1254",1255:"windows1255",1256:"windows1256",1257:"windows1257",1258:"windows1258",28591:"iso88591",28592:"iso88592",28593:"iso88593",28594:"iso88594",28595:"iso88595",28596:"iso88596",28597:"iso88597",28598:"iso88598",28599:"iso88599",28600:"iso885910",28601:"iso885911",28603:"iso885913",28604:"iso885914",28605:"iso885915",28606:"iso885916",windows874:{type:"_sbcs",chars:"€����…�����������‘’“”•–—�������� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},win874:"windows874",cp874:"windows874",windows1250:{type:"_sbcs",chars:"€�‚�„…†‡�‰Š‹ŚŤŽŹ�‘’“”•–—�™š›śťžź ˇ˘Ł¤Ą¦§¨©Ş«¬­®Ż°±˛ł´µ¶·¸ąş»Ľ˝ľżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"},win1250:"windows1250",cp1250:"windows1250",windows1251:{type:"_sbcs",chars:"ЂЃ‚ѓ„…†‡€‰Љ‹ЊЌЋЏђ‘’“”•–—�™љ›њќћџ ЎўЈ¤Ґ¦§Ё©Є«¬­®Ї°±Ііґµ¶·ё№є»јЅѕїАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},win1251:"windows1251",cp1251:"windows1251",windows1252:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰Š‹Œ�Ž��‘’“”•–—˜™š›œ�žŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},win1252:"windows1252",cp1252:"windows1252",windows1253:{type:"_sbcs",chars:"€�‚ƒ„…†‡�‰�‹�����‘’“”•–—�™�›���� ΅Ά£¤¥¦§¨©�«¬­®―°±²³΄µ¶·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"},win1253:"windows1253",cp1253:"windows1253",windows1254:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰Š‹Œ����‘’“”•–—˜™š›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"},win1254:"windows1254",cp1254:"windows1254",windows1255:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰�‹�����‘’“”•–—˜™�›���� ¡¢£₪¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾¿ְֱֲֳִֵֶַָֹֺֻּֽ־ֿ׀ׁׂ׃װױײ׳״�������אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"},win1255:"windows1255",cp1255:"windows1255",windows1256:{type:"_sbcs",chars:"€پ‚ƒ„…†‡ˆ‰ٹ‹Œچژڈگ‘’“”•–—ک™ڑ›œ‌‍ں ،¢£¤¥¦§¨©ھ«¬­®¯°±²³´µ¶·¸¹؛»¼½¾؟ہءآأؤإئابةتثجحخدذرزسشصض×طظعغـفقكàلâمنهوçèéêëىيîïًٌٍَôُِ÷ّùْûü‎‏ے"},win1256:"windows1256",cp1256:"windows1256",windows1257:{type:"_sbcs",chars:"€�‚�„…†‡�‰�‹�¨ˇ¸�‘’“”•–—�™�›�¯˛� �¢£¤�¦§Ø©Ŗ«¬­®Æ°±²³´µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž˙"},win1257:"windows1257",cp1257:"windows1257",windows1258:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰�‹Œ����‘’“”•–—˜™�›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},win1258:"windows1258",cp1258:"windows1258",iso88591:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},cp28591:"iso88591",iso88592:{type:"_sbcs",chars:" Ą˘Ł¤ĽŚ§¨ŠŞŤŹ­ŽŻ°ą˛ł´ľśˇ¸šşťź˝žżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"},cp28592:"iso88592",iso88593:{type:"_sbcs",chars:" Ħ˘£¤�Ĥ§¨İŞĞĴ­�Ż°ħ²³´µĥ·¸ışğĵ½�żÀÁÂ�ÄĊĈÇÈÉÊËÌÍÎÏ�ÑÒÓÔĠÖ×ĜÙÚÛÜŬŜßàáâ�äċĉçèéêëìíîï�ñòóôġö÷ĝùúûüŭŝ˙"},cp28593:"iso88593",iso88594:{type:"_sbcs",chars:" ĄĸŖ¤ĨĻ§¨ŠĒĢŦ­Ž¯°ą˛ŗ´ĩļˇ¸šēģŧŊžŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎĪĐŅŌĶÔÕÖ×ØŲÚÛÜŨŪßāáâãäåæįčéęëėíîīđņōķôõö÷øųúûüũū˙"},cp28594:"iso88594",iso88595:{type:"_sbcs",chars:" ЁЂЃЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђѓєѕіїјљњћќ§ўџ"},cp28595:"iso88595",iso88596:{type:"_sbcs",chars:" ���¤�������،­�������������؛���؟�ءآأؤإئابةتثجحخدذرزسشصضطظعغ�����ـفقكلمنهوىيًٌٍَُِّْ�������������"},cp28596:"iso88596",iso88597:{type:"_sbcs",chars:" ‘’£€₯¦§¨©ͺ«¬­�―°±²³΄΅Ά·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"},cp28597:"iso88597",iso88598:{type:"_sbcs",chars:" �¢£¤¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾��������������������������������‗אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"},cp28598:"iso88598",iso88599:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"},cp28599:"iso88599",iso885910:{type:"_sbcs",chars:" ĄĒĢĪĨĶ§ĻĐŠŦŽ­ŪŊ°ąēģīĩķ·ļđšŧž―ūŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎÏÐŅŌÓÔÕÖŨØŲÚÛÜÝÞßāáâãäåæįčéęëėíîïðņōóôõöũøųúûüýþĸ"},cp28600:"iso885910",iso885911:{type:"_sbcs",chars:" กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},cp28601:"iso885911",iso885913:{type:"_sbcs",chars:" ”¢£¤„¦§Ø©Ŗ«¬­®Æ°±²³“µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž’"},cp28603:"iso885913",iso885914:{type:"_sbcs",chars:" Ḃḃ£ĊċḊ§Ẁ©ẂḋỲ­®ŸḞḟĠġṀṁ¶ṖẁṗẃṠỳẄẅṡÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŴÑÒÓÔÕÖṪØÙÚÛÜÝŶßàáâãäåæçèéêëìíîïŵñòóôõöṫøùúûüýŷÿ"},cp28604:"iso885914",iso885915:{type:"_sbcs",chars:" ¡¢£€¥Š§š©ª«¬­®¯°±²³Žµ¶·ž¹º»ŒœŸ¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},cp28605:"iso885915",iso885916:{type:"_sbcs",chars:" ĄąŁ€„Š§š©Ș«Ź­źŻ°±ČłŽ”¶·žčș»ŒœŸżÀÁÂĂÄĆÆÇÈÉÊËÌÍÎÏĐŃÒÓÔŐÖŚŰÙÚÛÜĘȚßàáâăäćæçèéêëìíîïđńòóôőöśűùúûüęțÿ"},cp28606:"iso885916",cp437:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜ¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm437:"cp437",csibm437:"cp437",cp737:{type:"_sbcs",chars:"ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩαβγδεζηθικλμνξοπρσςτυφχψ░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀ωάέήϊίόύϋώΆΈΉΊΌΎΏ±≥≤ΪΫ÷≈°∙·√ⁿ²■ "},ibm737:"cp737",csibm737:"cp737",cp775:{type:"_sbcs",chars:"ĆüéāäģåćłēŖŗīŹÄÅÉæÆōöĢ¢ŚśÖÜø£Ø×¤ĀĪóŻżź”¦©®¬½¼Ł«»░▒▓│┤ĄČĘĖ╣║╗╝ĮŠ┐└┴┬├─┼ŲŪ╚╔╩╦╠═╬Žąčęėįšųūž┘┌█▄▌▐▀ÓßŌŃõÕµńĶķĻļņĒŅ’­±“¾¶§÷„°∙·¹³²■ "},ibm775:"cp775",csibm775:"cp775",cp850:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈıÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm850:"cp850",csibm850:"cp850",cp852:{type:"_sbcs",chars:"ÇüéâäůćçłëŐőîŹÄĆÉĹĺôöĽľŚśÖÜŤťŁ×čáíóúĄąŽžĘę¬źČş«»░▒▓│┤ÁÂĚŞ╣║╗╝Żż┐└┴┬├─┼Ăă╚╔╩╦╠═╬¤đĐĎËďŇÍÎě┘┌█▄ŢŮ▀ÓßÔŃńňŠšŔÚŕŰýÝţ´­˝˛ˇ˘§÷¸°¨˙űŘř■ "},ibm852:"cp852",csibm852:"cp852",cp855:{type:"_sbcs",chars:"ђЂѓЃёЁєЄѕЅіІїЇјЈљЉњЊћЋќЌўЎџЏюЮъЪаАбБцЦдДеЕфФгГ«»░▒▓│┤хХиИ╣║╗╝йЙ┐└┴┬├─┼кК╚╔╩╦╠═╬¤лЛмМнНоОп┘┌█▄Пя▀ЯрРсСтТуУжЖвВьЬ№­ыЫзЗшШэЭщЩчЧ§■ "},ibm855:"cp855",csibm855:"cp855",cp856:{type:"_sbcs",chars:"אבגדהוזחטיךכלםמןנסעףפץצקרשת�£�×����������®¬½¼�«»░▒▓│┤���©╣║╗╝¢¥┐└┴┬├─┼��╚╔╩╦╠═╬¤���������┘┌█▄¦�▀������µ�������¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm856:"cp856",csibm856:"cp856",cp857:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîıÄÅÉæÆôöòûùİÖÜø£ØŞşáíóúñÑĞğ¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ºªÊËÈ�ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµ�×ÚÛÙìÿ¯´­±�¾¶§÷¸°¨·¹³²■ "},ibm857:"cp857",csibm857:"cp857",cp858:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈ€ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm858:"cp858",csibm858:"cp858",cp860:{type:"_sbcs",chars:"ÇüéâãàÁçêÊèÍÔìÃÂÉÀÈôõòÚùÌÕÜ¢£Ù₧ÓáíóúñÑªº¿Ò¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm860:"cp860",csibm860:"cp860",cp861:{type:"_sbcs",chars:"ÇüéâäàåçêëèÐðÞÄÅÉæÆôöþûÝýÖÜø£Ø₧ƒáíóúÁÍÓÚ¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm861:"cp861",csibm861:"cp861",cp862:{type:"_sbcs",chars:"אבגדהוזחטיךכלםמןנסעףפץצקרשת¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm862:"cp862",csibm862:"cp862",cp863:{type:"_sbcs",chars:"ÇüéâÂà¶çêëèïî‗À§ÉÈÊôËÏûù¤ÔÜ¢£ÙÛƒ¦´óú¨¸³¯Î⌐¬½¼¾«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm863:"cp863",csibm863:"cp863",cp864:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#$٪&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~°·∙√▒─│┼┤┬├┴┐┌└┘β∞φ±½¼≈«»ﻷﻸ��ﻻﻼ� ­ﺂ£¤ﺄ��ﺎﺏﺕﺙ،ﺝﺡﺥ٠١٢٣٤٥٦٧٨٩ﻑ؛ﺱﺵﺹ؟¢ﺀﺁﺃﺅﻊﺋﺍﺑﺓﺗﺛﺟﺣﺧﺩﺫﺭﺯﺳﺷﺻﺿﻁﻅﻋﻏ¦¬÷×ﻉـﻓﻗﻛﻟﻣﻧﻫﻭﻯﻳﺽﻌﻎﻍﻡﹽّﻥﻩﻬﻰﻲﻐﻕﻵﻶﻝﻙﻱ■�"},ibm864:"cp864",csibm864:"cp864",cp865:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø₧ƒáíóúñÑªº¿⌐¬½¼¡«¤░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm865:"cp865",csibm865:"cp865",cp866:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№¤■ "},ibm866:"cp866",csibm866:"cp866",cp869:{type:"_sbcs",chars:"������Ά�·¬¦‘’Έ―ΉΊΪΌ��ΎΫ©Ώ²³ά£έήίϊΐόύΑΒΓΔΕΖΗ½ΘΙ«»░▒▓│┤ΚΛΜΝ╣║╗╝ΞΟ┐└┴┬├─┼ΠΡ╚╔╩╦╠═╬ΣΤΥΦΧΨΩαβγ┘┌█▄δε▀ζηθικλμνξοπρσςτ΄­±υφχ§ψ΅°¨ωϋΰώ■ "},ibm869:"cp869",csibm869:"cp869",cp922:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®‾°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŠÑÒÓÔÕÖ×ØÙÚÛÜÝŽßàáâãäåæçèéêëìíîïšñòóôõö÷øùúûüýžÿ"},ibm922:"cp922",csibm922:"cp922",cp1046:{type:"_sbcs",chars:"ﺈ×÷ﹱ■│─┐┌└┘ﹹﹻﹽﹿﹷﺊﻰﻳﻲﻎﻏﻐﻶﻸﻺﻼ ¤ﺋﺑﺗﺛﺟﺣ،­ﺧﺳ٠١٢٣٤٥٦٧٨٩ﺷ؛ﺻﺿﻊ؟ﻋءآأؤإئابةتثجحخدذرزسشصضطﻇعغﻌﺂﺄﺎﻓـفقكلمنهوىيًٌٍَُِّْﻗﻛﻟﻵﻷﻹﻻﻣﻧﻬﻩ�"},ibm1046:"cp1046",csibm1046:"cp1046",cp1124:{type:"_sbcs",chars:" ЁЂҐЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђґєѕіїјљњћќ§ўџ"},ibm1124:"cp1124",csibm1124:"cp1124",cp1125:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёҐґЄєІіЇї·√№¤■ "},ibm1125:"cp1125",csibm1125:"cp1125",cp1129:{type:"_sbcs",chars:" ¡¢£¤¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},ibm1129:"cp1129",csibm1129:"cp1129",cp1133:{type:"_sbcs",chars:" ກຂຄງຈສຊຍດຕຖທນບປຜຝພຟມຢຣລວຫອຮ���ຯະາຳິີຶືຸູຼັົຽ���ເແໂໃໄ່້໊໋໌ໍໆ�ໜໝ₭����������������໐໑໒໓໔໕໖໗໘໙��¢¬¦�"},ibm1133:"cp1133",csibm1133:"cp1133",cp1161:{type:"_sbcs",chars:"��������������������������������่กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู้๊๋€฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛¢¬¦ "},ibm1161:"cp1161",csibm1161:"cp1161",cp1162:{type:"_sbcs",chars:"€…‘’“”•–— กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},ibm1162:"cp1162",csibm1162:"cp1162",cp1163:{type:"_sbcs",chars:" ¡¢£€¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},ibm1163:"cp1163",csibm1163:"cp1163",maccroatian:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®Š™´¨≠ŽØ∞±≤≥∆µ∂∑∏š∫ªºΩžø¿¡¬√ƒ≈Ć«Č… ÀÃÕŒœĐ—“”‘’÷◊�©⁄¤‹›Æ»–·‚„‰ÂćÁčÈÍÎÏÌÓÔđÒÚÛÙıˆ˜¯πË˚¸Êæˇ"},maccyrillic:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°¢£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµ∂ЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"},macgreek:{type:"_sbcs",chars:"Ä¹²É³ÖÜ΅àâä΄¨çéèêë£™îï•½‰ôö¦­ùûü†ΓΔΘΛΞΠß®©ΣΪ§≠°·Α±≤≥¥ΒΕΖΗΙΚΜΦΫΨΩάΝ¬ΟΡ≈Τ«»… ΥΧΆΈœ–―“”‘’÷ΉΊΌΎέήίόΏύαβψδεφγηιξκλμνοπώρστθωςχυζϊϋΐΰ�"},maciceland:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûüÝ°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤ÐðÞþý·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macroman:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macromania:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ĂŞ∞±≤≥¥µ∂∑∏π∫ªºΩăş¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›Ţţ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macthai:{type:"_sbcs",chars:"«»…“”�•‘’� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู\ufeff​–—฿เแโใไๅๆ็่้๊๋์ํ™๏๐๑๒๓๔๕๖๗๘๙®©����"},macturkish:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸĞğİıŞş‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙ�ˆ˜¯˘˙˚¸˝˛ˇ"},macukraine:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°Ґ£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµґЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"},koi8r:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ё╓╔╕╖╗╘╙╚╛╜╝╞╟╠╡Ё╢╣╤╥╦╧╨╩╪╫╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8u:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґ╝╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪Ґ╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8ru:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґў╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪ҐЎ©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8t:{type:"_sbcs",chars:"қғ‚Ғ„…†‡�‰ҳ‹ҲҷҶ�Қ‘’“”•–—�™�›�����ӯӮё¤ӣ¦§���«¬­®�°±²Ё�Ӣ¶·�№�»���©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},armscii8:{type:"_sbcs",chars:" �և։)(»«—.՝,-֊…՜՛՞ԱաԲբԳգԴդԵեԶզԷէԸըԹթԺժԻիԼլԽխԾծԿկՀհՁձՂղՃճՄմՅյՆնՇշՈոՉչՊպՋջՌռՍսՎվՏտՐրՑցՒւՓփՔքՕօՖֆ՚�"},rk1048:{type:"_sbcs",chars:"ЂЃ‚ѓ„…†‡€‰Љ‹ЊҚҺЏђ‘’“”•–—�™љ›њқһџ ҰұӘ¤Ө¦§Ё©Ғ«¬­®Ү°±Ііөµ¶·ё№ғ»әҢңүАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},tcvn:{type:"_sbcs",chars:"\0ÚỤỪỬỮ\b\t\n\v\f\rỨỰỲỶỸÝỴ !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ÀẢÃÁẠẶẬÈẺẼÉẸỆÌỈĨÍỊÒỎÕÓỌỘỜỞỠỚỢÙỦŨ ĂÂÊÔƠƯĐăâêôơưđẶ̀̀̉̃́àảãáạẲằẳẵắẴẮẦẨẪẤỀặầẩẫấậèỂẻẽéẹềểễếệìỉỄẾỒĩíịòỔỏõóọồổỗốộờởỡớợùỖủũúụừửữứựỳỷỹýỵỐ"},georgianacademy:{type:"_sbcs",chars:"‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰჱჲჳჴჵჶçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},georgianps:{type:"_sbcs",chars:"‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზჱთიკლმნჲოპჟრსტჳუფქღყშჩცძწჭხჴჯჰჵæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},pt154:{type:"_sbcs",chars:"ҖҒӮғ„…ҶҮҲүҠӢҢҚҺҸҗ‘’“”•–—ҳҷҡӣңқһҹ ЎўЈӨҘҰ§Ё©Ә«¬ӯ®Ҝ°ұІіҙө¶·ё№ә»јҪҫҝАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},viscii:{type:"_sbcs",chars:"\0ẲẴẪ\b\t\n\v\f\rỶỸỴ !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ẠẮẰẶẤẦẨẬẼẸẾỀỂỄỆỐỒỔỖỘỢỚỜỞỊỎỌỈỦŨỤỲÕắằặấầẩậẽẹếềểễệốồổỗỠƠộờởịỰỨỪỬơớƯÀÁÂÃẢĂẳẵÈÉÊẺÌÍĨỳĐứÒÓÔạỷừửÙÚỹỵÝỡưàáâãảăữẫèéêẻìíĩỉđựòóôõỏọụùúũủýợỮ"},iso646cn:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#¥%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"},iso646jp:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[¥]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"},hproman8:{type:"_sbcs",chars:" ÀÂÈÊËÎÏ´ˋˆ¨˜ÙÛ₤¯Ýý°ÇçÑñ¡¿¤£¥§ƒ¢âêôûáéóúàèòùäëöüÅîØÆåíøæÄìÖÜÉïßÔÁÃãÐðÍÌÓÒÕõŠšÚŸÿÞþ·µ¶¾—¼½ªº«■»±�"},macintosh:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},ascii:{type:"_sbcs",chars:"��������������������������������������������������������������������������������������������������������������������������������"},tis620:{type:"_sbcs",chars:"���������������������������������กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"}}},function(e,t,n){"use strict";var r=n(9).Buffer;t._dbcs=a;for(var i=new Array(256),o=0;o<256;o++)i[o]=-1;function a(e,t){if(this.encodingName=e.encodingName,!e)throw new Error("DBCS codec is called without the data.");if(!e.table)throw new Error("Encoding '"+this.encodingName+"' has no data.");var n=e.table();this.decodeTables=[],this.decodeTables[0]=i.slice(0),this.decodeTableSeq=[];for(var r=0;r<n.length;r++)this._addDecodeChunk(n[r]);this.defaultCharUnicode=t.defaultCharUnicode,this.encodeTable=[],this.encodeTableSeq=[];var o={};if(e.encodeSkipVals)for(r=0;r<e.encodeSkipVals.length;r++){var a=e.encodeSkipVals[r];if("number"==typeof a)o[a]=!0;else for(var s=a.from;s<=a.to;s++)o[s]=!0}if(this._fillEncodeTable(0,0,o),e.encodeAdd)for(var u in e.encodeAdd)Object.prototype.hasOwnProperty.call(e.encodeAdd,u)&&this._setEncodeChar(u.charCodeAt(0),e.encodeAdd[u]);if(this.defCharSB=this.encodeTable[0][t.defaultCharSingleByte.charCodeAt(0)],-1===this.defCharSB&&(this.defCharSB=this.encodeTable[0]["?"]),-1===this.defCharSB&&(this.defCharSB="?".charCodeAt(0)),"function"==typeof e.gb18030){this.gb18030=e.gb18030();var c=this.decodeTables.length,l=this.decodeTables[c]=i.slice(0),f=this.decodeTables.length,h=this.decodeTables[f]=i.slice(0);for(r=129;r<=254;r++){var p=-1e3-this.decodeTables[0][r],d=this.decodeTables[p];for(s=48;s<=57;s++)d[s]=-1e3-c}for(r=129;r<=254;r++)l[r]=-1e3-f;for(r=48;r<=57;r++)h[r]=-2}}function s(e,t){this.leadSurrogate=-1,this.seqObj=void 0,this.encodeTable=t.encodeTable,this.encodeTableSeq=t.encodeTableSeq,this.defaultCharSingleByte=t.defCharSB,this.gb18030=t.gb18030}function u(e,t){this.nodeIdx=0,this.prevBuf=r.alloc(0),this.decodeTables=t.decodeTables,this.decodeTableSeq=t.decodeTableSeq,this.defaultCharUnicode=t.defaultCharUnicode,this.gb18030=t.gb18030}function c(e,t){if(e[0]>t)return-1;for(var n=0,r=e.length;n<r-1;){var i=n+Math.floor((r-n+1)/2);e[i]<=t?n=i:r=i}return n}a.prototype.encoder=s,a.prototype.decoder=u,a.prototype._getDecodeTrieNode=function(e){for(var t=[];e>0;e>>=8)t.push(255&e);0==t.length&&t.push(0);for(var n=this.decodeTables[0],r=t.length-1;r>0;r--){var o=n[t[r]];if(-1==o)n[t[r]]=-1e3-this.decodeTables.length,this.decodeTables.push(n=i.slice(0));else{if(!(o<=-1e3))throw new Error("Overwrite byte in "+this.encodingName+", addr: "+e.toString(16));n=this.decodeTables[-1e3-o]}}return n},a.prototype._addDecodeChunk=function(e){var t=parseInt(e[0],16),n=this._getDecodeTrieNode(t);t&=255;for(var r=1;r<e.length;r++){var i=e[r];if("string"==typeof i)for(var o=0;o<i.length;){var a=i.charCodeAt(o++);if(55296<=a&&a<56320){var s=i.charCodeAt(o++);if(!(56320<=s&&s<57344))throw new Error("Incorrect surrogate pair in "+this.encodingName+" at chunk "+e[0]);n[t++]=65536+1024*(a-55296)+(s-56320)}else if(4080<a&&a<=4095){for(var u=4095-a+2,c=[],l=0;l<u;l++)c.push(i.charCodeAt(o++));n[t++]=-10-this.decodeTableSeq.length,this.decodeTableSeq.push(c)}else n[t++]=a}else{if("number"!=typeof i)throw new Error("Incorrect type '"+typeof i+"' given in "+this.encodingName+" at chunk "+e[0]);var f=n[t-1]+1;for(o=0;o<i;o++)n[t++]=f++}}if(t>255)throw new Error("Incorrect chunk in "+this.encodingName+" at addr "+e[0]+": too long"+t)},a.prototype._getEncodeBucket=function(e){var t=e>>8;return void 0===this.encodeTable[t]&&(this.encodeTable[t]=i.slice(0)),this.encodeTable[t]},a.prototype._setEncodeChar=function(e,t){var n=this._getEncodeBucket(e),r=255&e;n[r]<=-10?this.encodeTableSeq[-10-n[r]][-1]=t:-1==n[r]&&(n[r]=t)},a.prototype._setEncodeSequence=function(e,t){var n,r=e[0],i=this._getEncodeBucket(r),o=255&r;i[o]<=-10?n=this.encodeTableSeq[-10-i[o]]:(n={},-1!==i[o]&&(n[-1]=i[o]),i[o]=-10-this.encodeTableSeq.length,this.encodeTableSeq.push(n));for(var a=1;a<e.length-1;a++){var s=n[r];"object"==typeof s?n=s:(n=n[r]={},void 0!==s&&(n[-1]=s))}n[r=e[e.length-1]]=t},a.prototype._fillEncodeTable=function(e,t,n){for(var r=this.decodeTables[e],i=0;i<256;i++){var o=r[i],a=t+i;n[a]||(o>=0?this._setEncodeChar(o,a):o<=-1e3?this._fillEncodeTable(-1e3-o,a<<8,n):o<=-10&&this._setEncodeSequence(this.decodeTableSeq[-10-o],a))}},s.prototype.write=function(e){for(var t=r.alloc(e.length*(this.gb18030?4:3)),n=this.leadSurrogate,i=this.seqObj,o=-1,a=0,s=0;;){if(-1===o){if(a==e.length)break;var u=e.charCodeAt(a++)}else{u=o;o=-1}if(55296<=u&&u<57344)if(u<56320){if(-1===n){n=u;continue}n=u,u=-1}else-1!==n?(u=65536+1024*(n-55296)+(u-56320),n=-1):u=-1;else-1!==n&&(o=u,u=-1,n=-1);var l=-1;if(void 0!==i&&-1!=u){var f=i[u];if("object"==typeof f){i=f;continue}"number"==typeof f?l=f:null==f&&void 0!==(f=i[-1])&&(l=f,o=u),i=void 0}else if(u>=0){var h=this.encodeTable[u>>8];if(void 0!==h&&(l=h[255&u]),l<=-10){i=this.encodeTableSeq[-10-l];continue}if(-1==l&&this.gb18030){var p=c(this.gb18030.uChars,u);if(-1!=p){l=this.gb18030.gbChars[p]+(u-this.gb18030.uChars[p]);t[s++]=129+Math.floor(l/12600),l%=12600,t[s++]=48+Math.floor(l/1260),l%=1260,t[s++]=129+Math.floor(l/10),l%=10,t[s++]=48+l;continue}}}-1===l&&(l=this.defaultCharSingleByte),l<256?t[s++]=l:l<65536?(t[s++]=l>>8,t[s++]=255&l):(t[s++]=l>>16,t[s++]=l>>8&255,t[s++]=255&l)}return this.seqObj=i,this.leadSurrogate=n,t.slice(0,s)},s.prototype.end=function(){if(-1!==this.leadSurrogate||void 0!==this.seqObj){var e=r.alloc(10),t=0;if(this.seqObj){var n=this.seqObj[-1];void 0!==n&&(n<256?e[t++]=n:(e[t++]=n>>8,e[t++]=255&n)),this.seqObj=void 0}return-1!==this.leadSurrogate&&(e[t++]=this.defaultCharSingleByte,this.leadSurrogate=-1),e.slice(0,t)}},s.prototype.findIdx=c,u.prototype.write=function(e){var t=r.alloc(2*e.length),n=this.nodeIdx,i=this.prevBuf,o=this.prevBuf.length,a=-this.prevBuf.length;o>0&&(i=r.concat([i,e.slice(0,10)]));for(var s=0,u=0;s<e.length;s++){var l,f=s>=0?e[s]:i[s+o];if((l=this.decodeTables[n][f])>=0);else if(-1===l)s=a,l=this.defaultCharUnicode.charCodeAt(0);else if(-2===l){var h=a>=0?e.slice(a,s+1):i.slice(a+o,s+1+o),p=12600*(h[0]-129)+1260*(h[1]-48)+10*(h[2]-129)+(h[3]-48),d=c(this.gb18030.gbChars,p);l=this.gb18030.uChars[d]+p-this.gb18030.gbChars[d]}else{if(l<=-1e3){n=-1e3-l;continue}if(!(l<=-10))throw new Error("iconv-lite internal error: invalid decoding table value "+l+" at "+n+"/"+f);for(var v=this.decodeTableSeq[-10-l],g=0;g<v.length-1;g++)l=v[g],t[u++]=255&l,t[u++]=l>>8;l=v[v.length-1]}if(l>65535){l-=65536;var y=55296+Math.floor(l/1024);t[u++]=255&y,t[u++]=y>>8,l=56320+l%1024}t[u++]=255&l,t[u++]=l>>8,n=0,a=s+1}return this.nodeIdx=n,this.prevBuf=a>=0?e.slice(a):i.slice(a+o),t.slice(0,u).toString("ucs2")},u.prototype.end=function(){for(var e="";this.prevBuf.length>0;){e+=this.defaultCharUnicode;var t=this.prevBuf.slice(1);this.prevBuf=r.alloc(0),this.nodeIdx=0,t.length>0&&(e+=this.write(t))}return this.nodeIdx=0,e}},function(e,t,n){"use strict";e.exports={shiftjis:{type:"_dbcs",table:function(){return n(61)},encodeAdd:{"¥":92,"‾":126},encodeSkipVals:[{from:60736,to:63808}]},csshiftjis:"shiftjis",mskanji:"shiftjis",sjis:"shiftjis",windows31j:"shiftjis",ms31j:"shiftjis",xsjis:"shiftjis",windows932:"shiftjis",ms932:"shiftjis",932:"shiftjis",cp932:"shiftjis",eucjp:{type:"_dbcs",table:function(){return n(62)},encodeAdd:{"¥":92,"‾":126}},gb2312:"cp936",gb231280:"cp936",gb23121980:"cp936",csgb2312:"cp936",csiso58gb231280:"cp936",euccn:"cp936",windows936:"cp936",ms936:"cp936",936:"cp936",cp936:{type:"_dbcs",table:function(){return n(17)}},gbk:{type:"_dbcs",table:function(){return n(17).concat(n(21))}},xgbk:"gbk",isoir58:"gbk",gb18030:{type:"_dbcs",table:function(){return n(17).concat(n(21))},gb18030:function(){return n(63)},encodeSkipVals:[128],encodeAdd:{"€":41699}},chinese:"gb18030",windows949:"cp949",ms949:"cp949",949:"cp949",cp949:{type:"_dbcs",table:function(){return n(64)}},cseuckr:"cp949",csksc56011987:"cp949",euckr:"cp949",isoir149:"cp949",korean:"cp949",ksc56011987:"cp949",ksc56011989:"cp949",ksc5601:"cp949",windows950:"cp950",ms950:"cp950",950:"cp950",cp950:{type:"_dbcs",table:function(){return n(22)}},big5:"big5hkscs",big5hkscs:{type:"_dbcs",table:function(){return n(22).concat(n(65))},encodeSkipVals:[41676]},cnbig5:"big5hkscs",csbig5:"big5hkscs",xxbig5:"big5hkscs"}},function(e){e.exports=JSON.parse('[["0","\\u0000",128],["a1","｡",62],["8140","　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈",9,"＋－±×"],["8180","÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇◆□■△▲▽▼※〒→←↑↓〓"],["81b8","∈∋⊆⊇⊂⊃∪∩"],["81c8","∧∨￢⇒⇔∀∃"],["81da","∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],["81f0","Å‰♯♭♪†‡¶"],["81fc","◯"],["824f","０",9],["8260","Ａ",25],["8281","ａ",25],["829f","ぁ",82],["8340","ァ",62],["8380","ム",22],["839f","Α",16,"Σ",6],["83bf","α",16,"σ",6],["8440","А",5,"ЁЖ",25],["8470","а",5,"ёж",7],["8480","о",17],["849f","─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],["8740","①",19,"Ⅰ",9],["875f","㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],["877e","㍻"],["8780","〝〟№㏍℡㊤",4,"㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],["889f","亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],["8940","院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円"],["8980","園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],["8a40","魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫"],["8a80","橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],["8b40","機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救"],["8b80","朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],["8c40","掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨"],["8c80","劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],["8d40","后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降"],["8d80","項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],["8e40","察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止"],["8e80","死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],["8f40","宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳"],["8f80","準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],["9040","拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨"],["9080","逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],["9140","繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻"],["9180","操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],["9240","叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄"],["9280","逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],["9340","邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬"],["9380","凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],["9440","如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅"],["9480","楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],["9540","鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷"],["9580","斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],["9640","法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆"],["9680","摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],["9740","諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲"],["9780","沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],["9840","蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],["989f","弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],["9940","僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭"],["9980","凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],["9a40","咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸"],["9a80","噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],["9b40","奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀"],["9b80","它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],["9c40","廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠"],["9c80","怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],["9d40","戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫"],["9d80","捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],["9e40","曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎"],["9e80","梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],["9f40","檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯"],["9f80","麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],["e040","漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝"],["e080","烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],["e140","瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿"],["e180","痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],["e240","磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰"],["e280","窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],["e340","紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷"],["e380","縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],["e440","隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤"],["e480","艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],["e540","蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬"],["e580","蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],["e640","襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧"],["e680","諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],["e740","蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜"],["e780","轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],["e840","錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙"],["e880","閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],["e940","顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃"],["e980","騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],["ea40","鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯"],["ea80","黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠堯槇遙瑤凜熙"],["ed40","纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏"],["ed80","塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],["ee40","犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙"],["ee80","蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],["eeef","ⅰ",9,"￢￤＇＂"],["f040","",62],["f080","",124],["f140","",62],["f180","",124],["f240","",62],["f280","",124],["f340","",62],["f380","",124],["f440","",62],["f480","",124],["f540","",62],["f580","",124],["f640","",62],["f680","",124],["f740","",62],["f780","",124],["f840","",62],["f880","",124],["f940",""],["fa40","ⅰ",9,"Ⅰ",9,"￢￤＇＂㈱№℡∵纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊"],["fa80","兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯"],["fb40","涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神"],["fb80","祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙"],["fc40","髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"]]')},function(e){e.exports=JSON.parse('[["0","\\u0000",127],["8ea1","｡",62],["a1a1","　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈",9,"＋－±×÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇"],["a2a1","◆□■△▲▽▼※〒→←↑↓〓"],["a2ba","∈∋⊆⊇⊂⊃∪∩"],["a2ca","∧∨￢⇒⇔∀∃"],["a2dc","∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],["a2f2","Å‰♯♭♪†‡¶"],["a2fe","◯"],["a3b0","０",9],["a3c1","Ａ",25],["a3e1","ａ",25],["a4a1","ぁ",82],["a5a1","ァ",85],["a6a1","Α",16,"Σ",6],["a6c1","α",16,"σ",6],["a7a1","А",5,"ЁЖ",25],["a7d1","а",5,"ёж",25],["a8a1","─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],["ada1","①",19,"Ⅰ",9],["adc0","㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],["addf","㍻〝〟№㏍℡㊤",4,"㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],["b0a1","亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],["b1a1","院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応"],["b2a1","押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],["b3a1","魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱"],["b4a1","粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],["b5a1","機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京"],["b6a1","供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],["b7a1","掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲"],["b8a1","検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],["b9a1","后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込"],["baa1","此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],["bba1","察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時"],["bca1","次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],["bda1","宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償"],["bea1","勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],["bfa1","拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾"],["c0a1","澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],["c1a1","繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎"],["c2a1","臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],["c3a1","叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵"],["c4a1","帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],["c5a1","邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到"],["c6a1","董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],["c7a1","如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦"],["c8a1","函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],["c9a1","鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服"],["caa1","福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],["cba1","法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満"],["cca1","漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],["cda1","諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃"],["cea1","痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],["cfa1","蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],["d0a1","弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],["d1a1","僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨"],["d2a1","辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],["d3a1","咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉"],["d4a1","圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],["d5a1","奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓"],["d6a1","屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],["d7a1","廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚"],["d8a1","悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],["d9a1","戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼"],["daa1","據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],["dba1","曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍"],["dca1","棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],["dda1","檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾"],["dea1","沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],["dfa1","漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼"],["e0a1","燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],["e1a1","瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰"],["e2a1","癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],["e3a1","磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐"],["e4a1","筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],["e5a1","紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺"],["e6a1","罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],["e7a1","隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙"],["e8a1","茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],["e9a1","蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙"],["eaa1","蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],["eba1","襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫"],["eca1","譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],["eda1","蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸"],["eea1","遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],["efa1","錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞"],["f0a1","陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],["f1a1","顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷"],["f2a1","髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],["f3a1","鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠"],["f4a1","堯槇遙瑤凜熙"],["f9a1","纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德"],["faa1","忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],["fba1","犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚"],["fca1","釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],["fcf1","ⅰ",9,"￢￤＇＂"],["8fa2af","˘ˇ¸˙˝¯˛˚～΄΅"],["8fa2c2","¡¦¿"],["8fa2eb","ºª©®™¤№"],["8fa6e1","ΆΈΉΊΪ"],["8fa6e7","Ό"],["8fa6e9","ΎΫ"],["8fa6ec","Ώ"],["8fa6f1","άέήίϊΐόςύϋΰώ"],["8fa7c2","Ђ",10,"ЎЏ"],["8fa7f2","ђ",10,"ўџ"],["8fa9a1","ÆĐ"],["8fa9a4","Ħ"],["8fa9a6","Ĳ"],["8fa9a8","ŁĿ"],["8fa9ab","ŊØŒ"],["8fa9af","ŦÞ"],["8fa9c1","æđðħıĳĸłŀŉŋøœßŧþ"],["8faaa1","ÁÀÄÂĂǍĀĄÅÃĆĈČÇĊĎÉÈËÊĚĖĒĘ"],["8faaba","ĜĞĢĠĤÍÌÏÎǏİĪĮĨĴĶĹĽĻŃŇŅÑÓÒÖÔǑŐŌÕŔŘŖŚŜŠŞŤŢÚÙÜÛŬǓŰŪŲŮŨǗǛǙǕŴÝŸŶŹŽŻ"],["8faba1","áàäâăǎāąåãćĉčçċďéèëêěėēęǵĝğ"],["8fabbd","ġĥíìïîǐ"],["8fabc5","īįĩĵķĺľļńňņñóòöôǒőōõŕřŗśŝšşťţúùüûŭǔűūųůũǘǜǚǖŵýÿŷźžż"],["8fb0a1","丂丄丅丌丒丟丣两丨丫丮丯丰丵乀乁乄乇乑乚乜乣乨乩乴乵乹乿亍亖亗亝亯亹仃仐仚仛仠仡仢仨仯仱仳仵份仾仿伀伂伃伈伋伌伒伕伖众伙伮伱你伳伵伷伹伻伾佀佂佈佉佋佌佒佔佖佘佟佣佪佬佮佱佷佸佹佺佽佾侁侂侄"],["8fb1a1","侅侉侊侌侎侐侒侓侔侗侙侚侞侟侲侷侹侻侼侽侾俀俁俅俆俈俉俋俌俍俏俒俜俠俢俰俲俼俽俿倀倁倄倇倊倌倎倐倓倗倘倛倜倝倞倢倧倮倰倲倳倵偀偁偂偅偆偊偌偎偑偒偓偗偙偟偠偢偣偦偧偪偭偰偱倻傁傃傄傆傊傎傏傐"],["8fb2a1","傒傓傔傖傛傜傞",4,"傪傯傰傹傺傽僀僃僄僇僌僎僐僓僔僘僜僝僟僢僤僦僨僩僯僱僶僺僾儃儆儇儈儋儌儍儎僲儐儗儙儛儜儝儞儣儧儨儬儭儯儱儳儴儵儸儹兂兊兏兓兕兗兘兟兤兦兾冃冄冋冎冘冝冡冣冭冸冺冼冾冿凂"],["8fb3a1","凈减凑凒凓凕凘凞凢凥凮凲凳凴凷刁刂刅划刓刕刖刘刢刨刱刲刵刼剅剉剕剗剘剚剜剟剠剡剦剮剷剸剹劀劂劅劊劌劓劕劖劗劘劚劜劤劥劦劧劯劰劶劷劸劺劻劽勀勄勆勈勌勏勑勔勖勛勜勡勥勨勩勪勬勰勱勴勶勷匀匃匊匋"],["8fb4a1","匌匑匓匘匛匜匞匟匥匧匨匩匫匬匭匰匲匵匼匽匾卂卌卋卙卛卡卣卥卬卭卲卹卾厃厇厈厎厓厔厙厝厡厤厪厫厯厲厴厵厷厸厺厽叀叅叏叒叓叕叚叝叞叠另叧叵吂吓吚吡吧吨吪启吱吴吵呃呄呇呍呏呞呢呤呦呧呩呫呭呮呴呿"],["8fb5a1","咁咃咅咈咉咍咑咕咖咜咟咡咦咧咩咪咭咮咱咷咹咺咻咿哆哊响哎哠哪哬哯哶哼哾哿唀唁唅唈唉唌唍唎唕唪唫唲唵唶唻唼唽啁啇啉啊啍啐啑啘啚啛啞啠啡啤啦啿喁喂喆喈喎喏喑喒喓喔喗喣喤喭喲喿嗁嗃嗆嗉嗋嗌嗎嗑嗒"],["8fb6a1","嗓嗗嗘嗛嗞嗢嗩嗶嗿嘅嘈嘊嘍",5,"嘙嘬嘰嘳嘵嘷嘹嘻嘼嘽嘿噀噁噃噄噆噉噋噍噏噔噞噠噡噢噣噦噩噭噯噱噲噵嚄嚅嚈嚋嚌嚕嚙嚚嚝嚞嚟嚦嚧嚨嚩嚫嚬嚭嚱嚳嚷嚾囅囉囊囋囏囐囌囍囙囜囝囟囡囤",4,"囱囫园"],["8fb7a1","囶囷圁圂圇圊圌圑圕圚圛圝圠圢圣圤圥圩圪圬圮圯圳圴圽圾圿坅坆坌坍坒坢坥坧坨坫坭",4,"坳坴坵坷坹坺坻坼坾垁垃垌垔垗垙垚垜垝垞垟垡垕垧垨垩垬垸垽埇埈埌埏埕埝埞埤埦埧埩埭埰埵埶埸埽埾埿堃堄堈堉埡"],["8fb8a1","堌堍堛堞堟堠堦堧堭堲堹堿塉塌塍塏塐塕塟塡塤塧塨塸塼塿墀墁墇墈墉墊墌墍墏墐墔墖墝墠墡墢墦墩墱墲壄墼壂壈壍壎壐壒壔壖壚壝壡壢壩壳夅夆夋夌夒夓夔虁夝夡夣夤夨夯夰夳夵夶夿奃奆奒奓奙奛奝奞奟奡奣奫奭"],["8fb9a1","奯奲奵奶她奻奼妋妌妎妒妕妗妟妤妧妭妮妯妰妳妷妺妼姁姃姄姈姊姍姒姝姞姟姣姤姧姮姯姱姲姴姷娀娄娌娍娎娒娓娞娣娤娧娨娪娭娰婄婅婇婈婌婐婕婞婣婥婧婭婷婺婻婾媋媐媓媖媙媜媞媟媠媢媧媬媱媲媳媵媸媺媻媿"],["8fbaa1","嫄嫆嫈嫏嫚嫜嫠嫥嫪嫮嫵嫶嫽嬀嬁嬈嬗嬴嬙嬛嬝嬡嬥嬭嬸孁孋孌孒孖孞孨孮孯孼孽孾孿宁宄宆宊宎宐宑宓宔宖宨宩宬宭宯宱宲宷宺宼寀寁寍寏寖",4,"寠寯寱寴寽尌尗尞尟尣尦尩尫尬尮尰尲尵尶屙屚屜屢屣屧屨屩"],["8fbba1","屭屰屴屵屺屻屼屽岇岈岊岏岒岝岟岠岢岣岦岪岲岴岵岺峉峋峒峝峗峮峱峲峴崁崆崍崒崫崣崤崦崧崱崴崹崽崿嵂嵃嵆嵈嵕嵑嵙嵊嵟嵠嵡嵢嵤嵪嵭嵰嵹嵺嵾嵿嶁嶃嶈嶊嶒嶓嶔嶕嶙嶛嶟嶠嶧嶫嶰嶴嶸嶹巃巇巋巐巎巘巙巠巤"],["8fbca1","巩巸巹帀帇帍帒帔帕帘帟帠帮帨帲帵帾幋幐幉幑幖幘幛幜幞幨幪",4,"幰庀庋庎庢庤庥庨庪庬庱庳庽庾庿廆廌廋廎廑廒廔廕廜廞廥廫异弆弇弈弎弙弜弝弡弢弣弤弨弫弬弮弰弴弶弻弽弿彀彄彅彇彍彐彔彘彛彠彣彤彧"],["8fbda1","彯彲彴彵彸彺彽彾徉徍徏徖徜徝徢徧徫徤徬徯徰徱徸忄忇忈忉忋忐",4,"忞忡忢忨忩忪忬忭忮忯忲忳忶忺忼怇怊怍怓怔怗怘怚怟怤怭怳怵恀恇恈恉恌恑恔恖恗恝恡恧恱恾恿悂悆悈悊悎悑悓悕悘悝悞悢悤悥您悰悱悷"],["8fbea1","悻悾惂惄惈惉惊惋惎惏惔惕惙惛惝惞惢惥惲惵惸惼惽愂愇愊愌愐",4,"愖愗愙愜愞愢愪愫愰愱愵愶愷愹慁慅慆慉慞慠慬慲慸慻慼慿憀憁憃憄憋憍憒憓憗憘憜憝憟憠憥憨憪憭憸憹憼懀懁懂懎懏懕懜懝懞懟懡懢懧懩懥"],["8fbfa1","懬懭懯戁戃戄戇戓戕戜戠戢戣戧戩戫戹戽扂扃扄扆扌扐扑扒扔扖扚扜扤扭扯扳扺扽抍抎抏抐抦抨抳抶抷抺抾抿拄拎拕拖拚拪拲拴拼拽挃挄挊挋挍挐挓挖挘挩挪挭挵挶挹挼捁捂捃捄捆捊捋捎捒捓捔捘捛捥捦捬捭捱捴捵"],["8fc0a1","捸捼捽捿掂掄掇掊掐掔掕掙掚掞掤掦掭掮掯掽揁揅揈揎揑揓揔揕揜揠揥揪揬揲揳揵揸揹搉搊搐搒搔搘搞搠搢搤搥搩搪搯搰搵搽搿摋摏摑摒摓摔摚摛摜摝摟摠摡摣摭摳摴摻摽撅撇撏撐撑撘撙撛撝撟撡撣撦撨撬撳撽撾撿"],["8fc1a1","擄擉擊擋擌擎擐擑擕擗擤擥擩擪擭擰擵擷擻擿攁攄攈攉攊攏攓攔攖攙攛攞攟攢攦攩攮攱攺攼攽敃敇敉敐敒敔敟敠敧敫敺敽斁斅斊斒斕斘斝斠斣斦斮斲斳斴斿旂旈旉旎旐旔旖旘旟旰旲旴旵旹旾旿昀昄昈昉昍昑昒昕昖昝"],["8fc2a1","昞昡昢昣昤昦昩昪昫昬昮昰昱昳昹昷晀晅晆晊晌晑晎晗晘晙晛晜晠晡曻晪晫晬晾晳晵晿晷晸晹晻暀晼暋暌暍暐暒暙暚暛暜暟暠暤暭暱暲暵暻暿曀曂曃曈曌曎曏曔曛曟曨曫曬曮曺朅朇朎朓朙朜朠朢朳朾杅杇杈杌杔杕杝"],["8fc3a1","杦杬杮杴杶杻极构枎枏枑枓枖枘枙枛枰枱枲枵枻枼枽柹柀柂柃柅柈柉柒柗柙柜柡柦柰柲柶柷桒栔栙栝栟栨栧栬栭栯栰栱栳栻栿桄桅桊桌桕桗桘桛桫桮",4,"桵桹桺桻桼梂梄梆梈梖梘梚梜梡梣梥梩梪梮梲梻棅棈棌棏"],["8fc4a1","棐棑棓棖棙棜棝棥棨棪棫棬棭棰棱棵棶棻棼棽椆椉椊椐椑椓椖椗椱椳椵椸椻楂楅楉楎楗楛楣楤楥楦楨楩楬楰楱楲楺楻楿榀榍榒榖榘榡榥榦榨榫榭榯榷榸榺榼槅槈槑槖槗槢槥槮槯槱槳槵槾樀樁樃樏樑樕樚樝樠樤樨樰樲"],["8fc5a1","樴樷樻樾樿橅橆橉橊橎橐橑橒橕橖橛橤橧橪橱橳橾檁檃檆檇檉檋檑檛檝檞檟檥檫檯檰檱檴檽檾檿櫆櫉櫈櫌櫐櫔櫕櫖櫜櫝櫤櫧櫬櫰櫱櫲櫼櫽欂欃欆欇欉欏欐欑欗欛欞欤欨欫欬欯欵欶欻欿歆歊歍歒歖歘歝歠歧歫歮歰歵歽"],["8fc6a1","歾殂殅殗殛殟殠殢殣殨殩殬殭殮殰殸殹殽殾毃毄毉毌毖毚毡毣毦毧毮毱毷毹毿氂氄氅氉氍氎氐氒氙氟氦氧氨氬氮氳氵氶氺氻氿汊汋汍汏汒汔汙汛汜汫汭汯汴汶汸汹汻沅沆沇沉沔沕沗沘沜沟沰沲沴泂泆泍泏泐泑泒泔泖"],["8fc7a1","泚泜泠泧泩泫泬泮泲泴洄洇洊洎洏洑洓洚洦洧洨汧洮洯洱洹洼洿浗浞浟浡浥浧浯浰浼涂涇涑涒涔涖涗涘涪涬涴涷涹涽涿淄淈淊淎淏淖淛淝淟淠淢淥淩淯淰淴淶淼渀渄渞渢渧渲渶渹渻渼湄湅湈湉湋湏湑湒湓湔湗湜湝湞"],["8fc8a1","湢湣湨湳湻湽溍溓溙溠溧溭溮溱溳溻溿滀滁滃滇滈滊滍滎滏滫滭滮滹滻滽漄漈漊漌漍漖漘漚漛漦漩漪漯漰漳漶漻漼漭潏潑潒潓潗潙潚潝潞潡潢潨潬潽潾澃澇澈澋澌澍澐澒澓澔澖澚澟澠澥澦澧澨澮澯澰澵澶澼濅濇濈濊"],["8fc9a1","濚濞濨濩濰濵濹濼濽瀀瀅瀆瀇瀍瀗瀠瀣瀯瀴瀷瀹瀼灃灄灈灉灊灋灔灕灝灞灎灤灥灬灮灵灶灾炁炅炆炔",4,"炛炤炫炰炱炴炷烊烑烓烔烕烖烘烜烤烺焃",4,"焋焌焏焞焠焫焭焯焰焱焸煁煅煆煇煊煋煐煒煗煚煜煞煠"],["8fcaa1","煨煹熀熅熇熌熒熚熛熠熢熯熰熲熳熺熿燀燁燄燋燌燓燖燙燚燜燸燾爀爇爈爉爓爗爚爝爟爤爫爯爴爸爹牁牂牃牅牎牏牐牓牕牖牚牜牞牠牣牨牫牮牯牱牷牸牻牼牿犄犉犍犎犓犛犨犭犮犱犴犾狁狇狉狌狕狖狘狟狥狳狴狺狻"],["8fcba1","狾猂猄猅猇猋猍猒猓猘猙猞猢猤猧猨猬猱猲猵猺猻猽獃獍獐獒獖獘獝獞獟獠獦獧獩獫獬獮獯獱獷獹獼玀玁玃玅玆玎玐玓玕玗玘玜玞玟玠玢玥玦玪玫玭玵玷玹玼玽玿珅珆珉珋珌珏珒珓珖珙珝珡珣珦珧珩珴珵珷珹珺珻珽"],["8fcca1","珿琀琁琄琇琊琑琚琛琤琦琨",9,"琹瑀瑃瑄瑆瑇瑋瑍瑑瑒瑗瑝瑢瑦瑧瑨瑫瑭瑮瑱瑲璀璁璅璆璇璉璏璐璑璒璘璙璚璜璟璠璡璣璦璨璩璪璫璮璯璱璲璵璹璻璿瓈瓉瓌瓐瓓瓘瓚瓛瓞瓟瓤瓨瓪瓫瓯瓴瓺瓻瓼瓿甆"],["8fcda1","甒甖甗甠甡甤甧甩甪甯甶甹甽甾甿畀畃畇畈畎畐畒畗畞畟畡畯畱畹",5,"疁疅疐疒疓疕疙疜疢疤疴疺疿痀痁痄痆痌痎痏痗痜痟痠痡痤痧痬痮痯痱痹瘀瘂瘃瘄瘇瘈瘊瘌瘏瘒瘓瘕瘖瘙瘛瘜瘝瘞瘣瘥瘦瘩瘭瘲瘳瘵瘸瘹"],["8fcea1","瘺瘼癊癀癁癃癄癅癉癋癕癙癟癤癥癭癮癯癱癴皁皅皌皍皕皛皜皝皟皠皢",6,"皪皭皽盁盅盉盋盌盎盔盙盠盦盨盬盰盱盶盹盼眀眆眊眎眒眔眕眗眙眚眜眢眨眭眮眯眴眵眶眹眽眾睂睅睆睊睍睎睏睒睖睗睜睞睟睠睢"],["8fcfa1","睤睧睪睬睰睲睳睴睺睽瞀瞄瞌瞍瞔瞕瞖瞚瞟瞢瞧瞪瞮瞯瞱瞵瞾矃矉矑矒矕矙矞矟矠矤矦矪矬矰矱矴矸矻砅砆砉砍砎砑砝砡砢砣砭砮砰砵砷硃硄硇硈硌硎硒硜硞硠硡硣硤硨硪确硺硾碊碏碔碘碡碝碞碟碤碨碬碭碰碱碲碳"],["8fd0a1","碻碽碿磇磈磉磌磎磒磓磕磖磤磛磟磠磡磦磪磲磳礀磶磷磺磻磿礆礌礐礚礜礞礟礠礥礧礩礭礱礴礵礻礽礿祄祅祆祊祋祏祑祔祘祛祜祧祩祫祲祹祻祼祾禋禌禑禓禔禕禖禘禛禜禡禨禩禫禯禱禴禸离秂秄秇秈秊秏秔秖秚秝秞"],["8fd1a1","秠秢秥秪秫秭秱秸秼稂稃稇稉稊稌稑稕稛稞稡稧稫稭稯稰稴稵稸稹稺穄穅穇穈穌穕穖穙穜穝穟穠穥穧穪穭穵穸穾窀窂窅窆窊窋窐窑窔窞窠窣窬窳窵窹窻窼竆竉竌竎竑竛竨竩竫竬竱竴竻竽竾笇笔笟笣笧笩笪笫笭笮笯笰"],["8fd2a1","笱笴笽笿筀筁筇筎筕筠筤筦筩筪筭筯筲筳筷箄箉箎箐箑箖箛箞箠箥箬箯箰箲箵箶箺箻箼箽篂篅篈篊篔篖篗篙篚篛篨篪篲篴篵篸篹篺篼篾簁簂簃簄簆簉簋簌簎簏簙簛簠簥簦簨簬簱簳簴簶簹簺籆籊籕籑籒籓籙",5],["8fd3a1","籡籣籧籩籭籮籰籲籹籼籽粆粇粏粔粞粠粦粰粶粷粺粻粼粿糄糇糈糉糍糏糓糔糕糗糙糚糝糦糩糫糵紃紇紈紉紏紑紒紓紖紝紞紣紦紪紭紱紼紽紾絀絁絇絈絍絑絓絗絙絚絜絝絥絧絪絰絸絺絻絿綁綂綃綅綆綈綋綌綍綑綖綗綝"],["8fd4a1","綞綦綧綪綳綶綷綹緂",4,"緌緍緎緗緙縀緢緥緦緪緫緭緱緵緶緹緺縈縐縑縕縗縜縝縠縧縨縬縭縯縳縶縿繄繅繇繎繐繒繘繟繡繢繥繫繮繯繳繸繾纁纆纇纊纍纑纕纘纚纝纞缼缻缽缾缿罃罄罇罏罒罓罛罜罝罡罣罤罥罦罭"],["8fd5a1","罱罽罾罿羀羋羍羏羐羑羖羗羜羡羢羦羪羭羴羼羿翀翃翈翎翏翛翟翣翥翨翬翮翯翲翺翽翾翿耇耈耊耍耎耏耑耓耔耖耝耞耟耠耤耦耬耮耰耴耵耷耹耺耼耾聀聄聠聤聦聭聱聵肁肈肎肜肞肦肧肫肸肹胈胍胏胒胔胕胗胘胠胭胮"],["8fd6a1","胰胲胳胶胹胺胾脃脋脖脗脘脜脞脠脤脧脬脰脵脺脼腅腇腊腌腒腗腠腡腧腨腩腭腯腷膁膐膄膅膆膋膎膖膘膛膞膢膮膲膴膻臋臃臅臊臎臏臕臗臛臝臞臡臤臫臬臰臱臲臵臶臸臹臽臿舀舃舏舓舔舙舚舝舡舢舨舲舴舺艃艄艅艆"],["8fd7a1","艋艎艏艑艖艜艠艣艧艭艴艻艽艿芀芁芃芄芇芉芊芎芑芔芖芘芚芛芠芡芣芤芧芨芩芪芮芰芲芴芷芺芼芾芿苆苐苕苚苠苢苤苨苪苭苯苶苷苽苾茀茁茇茈茊茋荔茛茝茞茟茡茢茬茭茮茰茳茷茺茼茽荂荃荄荇荍荎荑荕荖荗荰荸"],["8fd8a1","荽荿莀莂莄莆莍莒莔莕莘莙莛莜莝莦莧莩莬莾莿菀菇菉菏菐菑菔菝荓菨菪菶菸菹菼萁萆萊萏萑萕萙莭萯萹葅葇葈葊葍葏葑葒葖葘葙葚葜葠葤葥葧葪葰葳葴葶葸葼葽蒁蒅蒒蒓蒕蒞蒦蒨蒩蒪蒯蒱蒴蒺蒽蒾蓀蓂蓇蓈蓌蓏蓓"],["8fd9a1","蓜蓧蓪蓯蓰蓱蓲蓷蔲蓺蓻蓽蔂蔃蔇蔌蔎蔐蔜蔞蔢蔣蔤蔥蔧蔪蔫蔯蔳蔴蔶蔿蕆蕏",4,"蕖蕙蕜",6,"蕤蕫蕯蕹蕺蕻蕽蕿薁薅薆薉薋薌薏薓薘薝薟薠薢薥薧薴薶薷薸薼薽薾薿藂藇藊藋藎薭藘藚藟藠藦藨藭藳藶藼"],["8fdaa1","藿蘀蘄蘅蘍蘎蘐蘑蘒蘘蘙蘛蘞蘡蘧蘩蘶蘸蘺蘼蘽虀虂虆虒虓虖虗虘虙虝虠",4,"虩虬虯虵虶虷虺蚍蚑蚖蚘蚚蚜蚡蚦蚧蚨蚭蚱蚳蚴蚵蚷蚸蚹蚿蛀蛁蛃蛅蛑蛒蛕蛗蛚蛜蛠蛣蛥蛧蚈蛺蛼蛽蜄蜅蜇蜋蜎蜏蜐蜓蜔蜙蜞蜟蜡蜣"],["8fdba1","蜨蜮蜯蜱蜲蜹蜺蜼蜽蜾蝀蝃蝅蝍蝘蝝蝡蝤蝥蝯蝱蝲蝻螃",6,"螋螌螐螓螕螗螘螙螞螠螣螧螬螭螮螱螵螾螿蟁蟈蟉蟊蟎蟕蟖蟙蟚蟜蟟蟢蟣蟤蟪蟫蟭蟱蟳蟸蟺蟿蠁蠃蠆蠉蠊蠋蠐蠙蠒蠓蠔蠘蠚蠛蠜蠞蠟蠨蠭蠮蠰蠲蠵"],["8fdca1","蠺蠼衁衃衅衈衉衊衋衎衑衕衖衘衚衜衟衠衤衩衱衹衻袀袘袚袛袜袟袠袨袪袺袽袾裀裊",4,"裑裒裓裛裞裧裯裰裱裵裷褁褆褍褎褏褕褖褘褙褚褜褠褦褧褨褰褱褲褵褹褺褾襀襂襅襆襉襏襒襗襚襛襜襡襢襣襫襮襰襳襵襺"],["8fdda1","襻襼襽覉覍覐覔覕覛覜覟覠覥覰覴覵覶覷覼觔",4,"觥觩觫觭觱觳觶觹觽觿訄訅訇訏訑訒訔訕訞訠訢訤訦訫訬訯訵訷訽訾詀詃詅詇詉詍詎詓詖詗詘詜詝詡詥詧詵詶詷詹詺詻詾詿誀誃誆誋誏誐誒誖誗誙誟誧誩誮誯誳"],["8fdea1","誶誷誻誾諃諆諈諉諊諑諓諔諕諗諝諟諬諰諴諵諶諼諿謅謆謋謑謜謞謟謊謭謰謷謼譂",4,"譈譒譓譔譙譍譞譣譭譶譸譹譼譾讁讄讅讋讍讏讔讕讜讞讟谸谹谽谾豅豇豉豋豏豑豓豔豗豘豛豝豙豣豤豦豨豩豭豳豵豶豻豾貆"],["8fdfa1","貇貋貐貒貓貙貛貜貤貹貺賅賆賉賋賏賖賕賙賝賡賨賬賯賰賲賵賷賸賾賿贁贃贉贒贗贛赥赩赬赮赿趂趄趈趍趐趑趕趞趟趠趦趫趬趯趲趵趷趹趻跀跅跆跇跈跊跎跑跔跕跗跙跤跥跧跬跰趼跱跲跴跽踁踄踅踆踋踑踔踖踠踡踢"],["8fe0a1","踣踦踧踱踳踶踷踸踹踽蹀蹁蹋蹍蹎蹏蹔蹛蹜蹝蹞蹡蹢蹩蹬蹭蹯蹰蹱蹹蹺蹻躂躃躉躐躒躕躚躛躝躞躢躧躩躭躮躳躵躺躻軀軁軃軄軇軏軑軔軜軨軮軰軱軷軹軺軭輀輂輇輈輏輐輖輗輘輞輠輡輣輥輧輨輬輭輮輴輵輶輷輺轀轁"],["8fe1a1","轃轇轏轑",4,"轘轝轞轥辝辠辡辤辥辦辵辶辸达迀迁迆迊迋迍运迒迓迕迠迣迤迨迮迱迵迶迻迾适逄逈逌逘逛逨逩逯逪逬逭逳逴逷逿遃遄遌遛遝遢遦遧遬遰遴遹邅邈邋邌邎邐邕邗邘邙邛邠邡邢邥邰邲邳邴邶邽郌邾郃"],["8fe2a1","郄郅郇郈郕郗郘郙郜郝郟郥郒郶郫郯郰郴郾郿鄀鄄鄅鄆鄈鄍鄐鄔鄖鄗鄘鄚鄜鄞鄠鄥鄢鄣鄧鄩鄮鄯鄱鄴鄶鄷鄹鄺鄼鄽酃酇酈酏酓酗酙酚酛酡酤酧酭酴酹酺酻醁醃醅醆醊醎醑醓醔醕醘醞醡醦醨醬醭醮醰醱醲醳醶醻醼醽醿"],["8fe3a1","釂釃釅釓釔釗釙釚釞釤釥釩釪釬",5,"釷釹釻釽鈀鈁鈄鈅鈆鈇鈉鈊鈌鈐鈒鈓鈖鈘鈜鈝鈣鈤鈥鈦鈨鈮鈯鈰鈳鈵鈶鈸鈹鈺鈼鈾鉀鉂鉃鉆鉇鉊鉍鉎鉏鉑鉘鉙鉜鉝鉠鉡鉥鉧鉨鉩鉮鉯鉰鉵",4,"鉻鉼鉽鉿銈銉銊銍銎銒銗"],["8fe4a1","銙銟銠銤銥銧銨銫銯銲銶銸銺銻銼銽銿",4,"鋅鋆鋇鋈鋋鋌鋍鋎鋐鋓鋕鋗鋘鋙鋜鋝鋟鋠鋡鋣鋥鋧鋨鋬鋮鋰鋹鋻鋿錀錂錈錍錑錔錕錜錝錞錟錡錤錥錧錩錪錳錴錶錷鍇鍈鍉鍐鍑鍒鍕鍗鍘鍚鍞鍤鍥鍧鍩鍪鍭鍯鍰鍱鍳鍴鍶"],["8fe5a1","鍺鍽鍿鎀鎁鎂鎈鎊鎋鎍鎏鎒鎕鎘鎛鎞鎡鎣鎤鎦鎨鎫鎴鎵鎶鎺鎩鏁鏄鏅鏆鏇鏉",4,"鏓鏙鏜鏞鏟鏢鏦鏧鏹鏷鏸鏺鏻鏽鐁鐂鐄鐈鐉鐍鐎鐏鐕鐖鐗鐟鐮鐯鐱鐲鐳鐴鐻鐿鐽鑃鑅鑈鑊鑌鑕鑙鑜鑟鑡鑣鑨鑫鑭鑮鑯鑱鑲钄钃镸镹"],["8fe6a1","镾閄閈閌閍閎閝閞閟閡閦閩閫閬閴閶閺閽閿闆闈闉闋闐闑闒闓闙闚闝闞闟闠闤闦阝阞阢阤阥阦阬阱阳阷阸阹阺阼阽陁陒陔陖陗陘陡陮陴陻陼陾陿隁隂隃隄隉隑隖隚隝隟隤隥隦隩隮隯隳隺雊雒嶲雘雚雝雞雟雩雯雱雺霂"],["8fe7a1","霃霅霉霚霛霝霡霢霣霨霱霳靁靃靊靎靏靕靗靘靚靛靣靧靪靮靳靶靷靸靻靽靿鞀鞉鞕鞖鞗鞙鞚鞞鞟鞢鞬鞮鞱鞲鞵鞶鞸鞹鞺鞼鞾鞿韁韄韅韇韉韊韌韍韎韐韑韔韗韘韙韝韞韠韛韡韤韯韱韴韷韸韺頇頊頙頍頎頔頖頜頞頠頣頦"],["8fe8a1","頫頮頯頰頲頳頵頥頾顄顇顊顑顒顓顖顗顙顚顢顣顥顦顪顬颫颭颮颰颴颷颸颺颻颿飂飅飈飌飡飣飥飦飧飪飳飶餂餇餈餑餕餖餗餚餛餜餟餢餦餧餫餱",4,"餹餺餻餼饀饁饆饇饈饍饎饔饘饙饛饜饞饟饠馛馝馟馦馰馱馲馵"],["8fe9a1","馹馺馽馿駃駉駓駔駙駚駜駞駧駪駫駬駰駴駵駹駽駾騂騃騄騋騌騐騑騖騞騠騢騣騤騧騭騮騳騵騶騸驇驁驄驊驋驌驎驑驔驖驝骪骬骮骯骲骴骵骶骹骻骾骿髁髃髆髈髎髐髒髕髖髗髛髜髠髤髥髧髩髬髲髳髵髹髺髽髿",4],["8feaa1","鬄鬅鬈鬉鬋鬌鬍鬎鬐鬒鬖鬙鬛鬜鬠鬦鬫鬭鬳鬴鬵鬷鬹鬺鬽魈魋魌魕魖魗魛魞魡魣魥魦魨魪",4,"魳魵魷魸魹魿鮀鮄鮅鮆鮇鮉鮊鮋鮍鮏鮐鮔鮚鮝鮞鮦鮧鮩鮬鮰鮱鮲鮷鮸鮻鮼鮾鮿鯁鯇鯈鯎鯐鯗鯘鯝鯟鯥鯧鯪鯫鯯鯳鯷鯸"],["8feba1","鯹鯺鯽鯿鰀鰂鰋鰏鰑鰖鰘鰙鰚鰜鰞鰢鰣鰦",4,"鰱鰵鰶鰷鰽鱁鱃鱄鱅鱉鱊鱎鱏鱐鱓鱔鱖鱘鱛鱝鱞鱟鱣鱩鱪鱜鱫鱨鱮鱰鱲鱵鱷鱻鳦鳲鳷鳹鴋鴂鴑鴗鴘鴜鴝鴞鴯鴰鴲鴳鴴鴺鴼鵅鴽鵂鵃鵇鵊鵓鵔鵟鵣鵢鵥鵩鵪鵫鵰鵶鵷鵻"],["8feca1","鵼鵾鶃鶄鶆鶊鶍鶎鶒鶓鶕鶖鶗鶘鶡鶪鶬鶮鶱鶵鶹鶼鶿鷃鷇鷉鷊鷔鷕鷖鷗鷚鷞鷟鷠鷥鷧鷩鷫鷮鷰鷳鷴鷾鸊鸂鸇鸎鸐鸑鸒鸕鸖鸙鸜鸝鹺鹻鹼麀麂麃麄麅麇麎麏麖麘麛麞麤麨麬麮麯麰麳麴麵黆黈黋黕黟黤黧黬黭黮黰黱黲黵"],["8feda1","黸黿鼂鼃鼉鼏鼐鼑鼒鼔鼖鼗鼙鼚鼛鼟鼢鼦鼪鼫鼯鼱鼲鼴鼷鼹鼺鼼鼽鼿齁齃",4,"齓齕齖齗齘齚齝齞齨齩齭",4,"齳齵齺齽龏龐龑龒龔龖龗龞龡龢龣龥"]]')},function(e){e.exports=JSON.parse('{"uChars":[128,165,169,178,184,216,226,235,238,244,248,251,253,258,276,284,300,325,329,334,364,463,465,467,469,471,473,475,477,506,594,610,712,716,730,930,938,962,970,1026,1104,1106,8209,8215,8218,8222,8231,8241,8244,8246,8252,8365,8452,8454,8458,8471,8482,8556,8570,8596,8602,8713,8720,8722,8726,8731,8737,8740,8742,8748,8751,8760,8766,8777,8781,8787,8802,8808,8816,8854,8858,8870,8896,8979,9322,9372,9548,9588,9616,9622,9634,9652,9662,9672,9676,9680,9702,9735,9738,9793,9795,11906,11909,11913,11917,11928,11944,11947,11951,11956,11960,11964,11979,12284,12292,12312,12319,12330,12351,12436,12447,12535,12543,12586,12842,12850,12964,13200,13215,13218,13253,13263,13267,13270,13384,13428,13727,13839,13851,14617,14703,14801,14816,14964,15183,15471,15585,16471,16736,17208,17325,17330,17374,17623,17997,18018,18212,18218,18301,18318,18760,18811,18814,18820,18823,18844,18848,18872,19576,19620,19738,19887,40870,59244,59336,59367,59413,59417,59423,59431,59437,59443,59452,59460,59478,59493,63789,63866,63894,63976,63986,64016,64018,64021,64025,64034,64037,64042,65074,65093,65107,65112,65127,65132,65375,65510,65536],"gbChars":[0,36,38,45,50,81,89,95,96,100,103,104,105,109,126,133,148,172,175,179,208,306,307,308,309,310,311,312,313,341,428,443,544,545,558,741,742,749,750,805,819,820,7922,7924,7925,7927,7934,7943,7944,7945,7950,8062,8148,8149,8152,8164,8174,8236,8240,8262,8264,8374,8380,8381,8384,8388,8390,8392,8393,8394,8396,8401,8406,8416,8419,8424,8437,8439,8445,8482,8485,8496,8521,8603,8936,8946,9046,9050,9063,9066,9076,9092,9100,9108,9111,9113,9131,9162,9164,9218,9219,11329,11331,11334,11336,11346,11361,11363,11366,11370,11372,11375,11389,11682,11686,11687,11692,11694,11714,11716,11723,11725,11730,11736,11982,11989,12102,12336,12348,12350,12384,12393,12395,12397,12510,12553,12851,12962,12973,13738,13823,13919,13933,14080,14298,14585,14698,15583,15847,16318,16434,16438,16481,16729,17102,17122,17315,17320,17402,17418,17859,17909,17911,17915,17916,17936,17939,17961,18664,18703,18814,18962,19043,33469,33470,33471,33484,33485,33490,33497,33501,33505,33513,33520,33536,33550,37845,37921,37948,38029,38038,38064,38065,38066,38069,38075,38076,38078,39108,39109,39113,39114,39115,39116,39265,39394,189000]}')},function(e){e.exports=JSON.parse('[["0","\\u0000",127],["8141","갂갃갅갆갋",4,"갘갞갟갡갢갣갥",6,"갮갲갳갴"],["8161","갵갶갷갺갻갽갾갿걁",9,"걌걎",5,"걕"],["8181","걖걗걙걚걛걝",18,"걲걳걵걶걹걻",4,"겂겇겈겍겎겏겑겒겓겕",6,"겞겢",5,"겫겭겮겱",6,"겺겾겿곀곂곃곅곆곇곉곊곋곍",7,"곖곘",7,"곢곣곥곦곩곫곭곮곲곴곷",4,"곾곿괁괂괃괅괇",4,"괎괐괒괓"],["8241","괔괕괖괗괙괚괛괝괞괟괡",7,"괪괫괮",5],["8261","괶괷괹괺괻괽",6,"굆굈굊",5,"굑굒굓굕굖굗"],["8281","굙",7,"굢굤",7,"굮굯굱굲굷굸굹굺굾궀궃",4,"궊궋궍궎궏궑",10,"궞",5,"궥",17,"궸",7,"귂귃귅귆귇귉",6,"귒귔",7,"귝귞귟귡귢귣귥",18],["8341","귺귻귽귾긂",5,"긊긌긎",5,"긕",7],["8361","긝",18,"긲긳긵긶긹긻긼"],["8381","긽긾긿깂깄깇깈깉깋깏깑깒깓깕깗",4,"깞깢깣깤깦깧깪깫깭깮깯깱",6,"깺깾",5,"꺆",5,"꺍",46,"꺿껁껂껃껅",6,"껎껒",5,"껚껛껝",8],["8441","껦껧껩껪껬껮",5,"껵껶껷껹껺껻껽",8],["8461","꼆꼉꼊꼋꼌꼎꼏꼑",18],["8481","꼤",7,"꼮꼯꼱꼳꼵",6,"꼾꽀꽄꽅꽆꽇꽊",5,"꽑",10,"꽞",5,"꽦",18,"꽺",5,"꾁꾂꾃꾅꾆꾇꾉",6,"꾒꾓꾔꾖",5,"꾝",26,"꾺꾻꾽꾾"],["8541","꾿꿁",5,"꿊꿌꿏",4,"꿕",6,"꿝",4],["8561","꿢",5,"꿪",5,"꿲꿳꿵꿶꿷꿹",6,"뀂뀃"],["8581","뀅",6,"뀍뀎뀏뀑뀒뀓뀕",6,"뀞",9,"뀩",26,"끆끇끉끋끍끏끐끑끒끖끘끚끛끜끞",29,"끾끿낁낂낃낅",6,"낎낐낒",5,"낛낝낞낣낤"],["8641","낥낦낧낪낰낲낶낷낹낺낻낽",6,"냆냊",5,"냒"],["8661","냓냕냖냗냙",6,"냡냢냣냤냦",10],["8681","냱",22,"넊넍넎넏넑넔넕넖넗넚넞",4,"넦넧넩넪넫넭",6,"넶넺",5,"녂녃녅녆녇녉",6,"녒녓녖녗녙녚녛녝녞녟녡",22,"녺녻녽녾녿놁놃",4,"놊놌놎놏놐놑놕놖놗놙놚놛놝"],["8741","놞",9,"놩",15],["8761","놹",18,"뇍뇎뇏뇑뇒뇓뇕"],["8781","뇖",5,"뇞뇠",7,"뇪뇫뇭뇮뇯뇱",7,"뇺뇼뇾",5,"눆눇눉눊눍",6,"눖눘눚",5,"눡",18,"눵",6,"눽",26,"뉙뉚뉛뉝뉞뉟뉡",6,"뉪",4],["8841","뉯",4,"뉶",5,"뉽",6,"늆늇늈늊",4],["8861","늏늒늓늕늖늗늛",4,"늢늤늧늨늩늫늭늮늯늱늲늳늵늶늷"],["8881","늸",15,"닊닋닍닎닏닑닓",4,"닚닜닞닟닠닡닣닧닩닪닰닱닲닶닼닽닾댂댃댅댆댇댉",6,"댒댖",5,"댝",54,"덗덙덚덝덠덡덢덣"],["8941","덦덨덪덬덭덯덲덳덵덶덷덹",6,"뎂뎆",5,"뎍"],["8961","뎎뎏뎑뎒뎓뎕",10,"뎢",5,"뎩뎪뎫뎭"],["8981","뎮",21,"돆돇돉돊돍돏돑돒돓돖돘돚돜돞돟돡돢돣돥돦돧돩",18,"돽",18,"됑",6,"됙됚됛됝됞됟됡",6,"됪됬",7,"됵",15],["8a41","둅",10,"둒둓둕둖둗둙",6,"둢둤둦"],["8a61","둧",4,"둭",18,"뒁뒂"],["8a81","뒃",4,"뒉",19,"뒞",5,"뒥뒦뒧뒩뒪뒫뒭",7,"뒶뒸뒺",5,"듁듂듃듅듆듇듉",6,"듑듒듓듔듖",5,"듞듟듡듢듥듧",4,"듮듰듲",5,"듹",26,"딖딗딙딚딝"],["8b41","딞",5,"딦딫",4,"딲딳딵딶딷딹",6,"땂땆"],["8b61","땇땈땉땊땎땏땑땒땓땕",6,"땞땢",8],["8b81","땫",52,"떢떣떥떦떧떩떬떭떮떯떲떶",4,"떾떿뗁뗂뗃뗅",6,"뗎뗒",5,"뗙",18,"뗭",18],["8c41","똀",15,"똒똓똕똖똗똙",4],["8c61","똞",6,"똦",5,"똭",6,"똵",5],["8c81","똻",12,"뙉",26,"뙥뙦뙧뙩",50,"뚞뚟뚡뚢뚣뚥",5,"뚭뚮뚯뚰뚲",16],["8d41","뛃",16,"뛕",8],["8d61","뛞",17,"뛱뛲뛳뛵뛶뛷뛹뛺"],["8d81","뛻",4,"뜂뜃뜄뜆",33,"뜪뜫뜭뜮뜱",6,"뜺뜼",7,"띅띆띇띉띊띋띍",6,"띖",9,"띡띢띣띥띦띧띩",6,"띲띴띶",5,"띾띿랁랂랃랅",6,"랎랓랔랕랚랛랝랞"],["8e41","랟랡",6,"랪랮",5,"랶랷랹",8],["8e61","럂",4,"럈럊",19],["8e81","럞",13,"럮럯럱럲럳럵",6,"럾렂",4,"렊렋렍렎렏렑",6,"렚렜렞",5,"렦렧렩렪렫렭",6,"렶렺",5,"롁롂롃롅",11,"롒롔",7,"롞롟롡롢롣롥",6,"롮롰롲",5,"롹롺롻롽",7],["8f41","뢅",7,"뢎",17],["8f61","뢠",7,"뢩",6,"뢱뢲뢳뢵뢶뢷뢹",4],["8f81","뢾뢿룂룄룆",5,"룍룎룏룑룒룓룕",7,"룞룠룢",5,"룪룫룭룮룯룱",6,"룺룼룾",5,"뤅",18,"뤙",6,"뤡",26,"뤾뤿륁륂륃륅",6,"륍륎륐륒",5],["9041","륚륛륝륞륟륡",6,"륪륬륮",5,"륶륷륹륺륻륽"],["9061","륾",5,"릆릈릋릌릏",15],["9081","릟",12,"릮릯릱릲릳릵",6,"릾맀맂",5,"맊맋맍맓",4,"맚맜맟맠맢맦맧맩맪맫맭",6,"맶맻",4,"먂",5,"먉",11,"먖",33,"먺먻먽먾먿멁멃멄멅멆"],["9141","멇멊멌멏멐멑멒멖멗멙멚멛멝",6,"멦멪",5],["9161","멲멳멵멶멷멹",9,"몆몈몉몊몋몍",5],["9181","몓",20,"몪몭몮몯몱몳",4,"몺몼몾",5,"뫅뫆뫇뫉",14,"뫚",33,"뫽뫾뫿묁묂묃묅",7,"묎묐묒",5,"묙묚묛묝묞묟묡",6],["9241","묨묪묬",7,"묷묹묺묿",4,"뭆뭈뭊뭋뭌뭎뭑뭒"],["9261","뭓뭕뭖뭗뭙",7,"뭢뭤",7,"뭭",4],["9281","뭲",21,"뮉뮊뮋뮍뮎뮏뮑",18,"뮥뮦뮧뮩뮪뮫뮭",6,"뮵뮶뮸",7,"믁믂믃믅믆믇믉",6,"믑믒믔",35,"믺믻믽믾밁"],["9341","밃",4,"밊밎밐밒밓밙밚밠밡밢밣밦밨밪밫밬밮밯밲밳밵"],["9361","밶밷밹",6,"뱂뱆뱇뱈뱊뱋뱎뱏뱑",8],["9381","뱚뱛뱜뱞",37,"벆벇벉벊벍벏",4,"벖벘벛",4,"벢벣벥벦벩",6,"벲벶",5,"벾벿볁볂볃볅",7,"볎볒볓볔볖볗볙볚볛볝",22,"볷볹볺볻볽"],["9441","볾",5,"봆봈봊",5,"봑봒봓봕",8],["9461","봞",5,"봥",6,"봭",12],["9481","봺",5,"뵁",6,"뵊뵋뵍뵎뵏뵑",6,"뵚",9,"뵥뵦뵧뵩",22,"붂붃붅붆붋",4,"붒붔붖붗붘붛붝",6,"붥",10,"붱",6,"붹",24],["9541","뷒뷓뷖뷗뷙뷚뷛뷝",11,"뷪",5,"뷱"],["9561","뷲뷳뷵뷶뷷뷹",6,"븁븂븄븆",5,"븎븏븑븒븓"],["9581","븕",6,"븞븠",35,"빆빇빉빊빋빍빏",4,"빖빘빜빝빞빟빢빣빥빦빧빩빫",4,"빲빶",4,"빾빿뺁뺂뺃뺅",6,"뺎뺒",5,"뺚",13,"뺩",14],["9641","뺸",23,"뻒뻓"],["9661","뻕뻖뻙",6,"뻡뻢뻦",5,"뻭",8],["9681","뻶",10,"뼂",5,"뼊",13,"뼚뼞",33,"뽂뽃뽅뽆뽇뽉",6,"뽒뽓뽔뽖",44],["9741","뾃",16,"뾕",8],["9761","뾞",17,"뾱",7],["9781","뾹",11,"뿆",5,"뿎뿏뿑뿒뿓뿕",6,"뿝뿞뿠뿢",89,"쀽쀾쀿"],["9841","쁀",16,"쁒",5,"쁙쁚쁛"],["9861","쁝쁞쁟쁡",6,"쁪",15],["9881","쁺",21,"삒삓삕삖삗삙",6,"삢삤삦",5,"삮삱삲삷",4,"삾샂샃샄샆샇샊샋샍샎샏샑",6,"샚샞",5,"샦샧샩샪샫샭",6,"샶샸샺",5,"섁섂섃섅섆섇섉",6,"섑섒섓섔섖",5,"섡섢섥섨섩섪섫섮"],["9941","섲섳섴섵섷섺섻섽섾섿셁",6,"셊셎",5,"셖셗"],["9961","셙셚셛셝",6,"셦셪",5,"셱셲셳셵셶셷셹셺셻"],["9981","셼",8,"솆",5,"솏솑솒솓솕솗",4,"솞솠솢솣솤솦솧솪솫솭솮솯솱",11,"솾",5,"쇅쇆쇇쇉쇊쇋쇍",6,"쇕쇖쇙",6,"쇡쇢쇣쇥쇦쇧쇩",6,"쇲쇴",7,"쇾쇿숁숂숃숅",6,"숎숐숒",5,"숚숛숝숞숡숢숣"],["9a41","숤숥숦숧숪숬숮숰숳숵",16],["9a61","쉆쉇쉉",6,"쉒쉓쉕쉖쉗쉙",6,"쉡쉢쉣쉤쉦"],["9a81","쉧",4,"쉮쉯쉱쉲쉳쉵",6,"쉾슀슂",5,"슊",5,"슑",6,"슙슚슜슞",5,"슦슧슩슪슫슮",5,"슶슸슺",33,"싞싟싡싢싥",5,"싮싰싲싳싴싵싷싺싽싾싿쌁",6,"쌊쌋쌎쌏"],["9b41","쌐쌑쌒쌖쌗쌙쌚쌛쌝",6,"쌦쌧쌪",8],["9b61","쌳",17,"썆",7],["9b81","썎",25,"썪썫썭썮썯썱썳",4,"썺썻썾",5,"쎅쎆쎇쎉쎊쎋쎍",50,"쏁",22,"쏚"],["9c41","쏛쏝쏞쏡쏣",4,"쏪쏫쏬쏮",5,"쏶쏷쏹",5],["9c61","쏿",8,"쐉",6,"쐑",9],["9c81","쐛",8,"쐥",6,"쐭쐮쐯쐱쐲쐳쐵",6,"쐾",9,"쑉",26,"쑦쑧쑩쑪쑫쑭",6,"쑶쑷쑸쑺",5,"쒁",18,"쒕",6,"쒝",12],["9d41","쒪",13,"쒹쒺쒻쒽",8],["9d61","쓆",25],["9d81","쓠",8,"쓪",5,"쓲쓳쓵쓶쓷쓹쓻쓼쓽쓾씂",9,"씍씎씏씑씒씓씕",6,"씝",10,"씪씫씭씮씯씱",6,"씺씼씾",5,"앆앇앋앏앐앑앒앖앚앛앜앟앢앣앥앦앧앩",6,"앲앶",5,"앾앿얁얂얃얅얆얈얉얊얋얎얐얒얓얔"],["9e41","얖얙얚얛얝얞얟얡",7,"얪",9,"얶"],["9e61","얷얺얿",4,"엋엍엏엒엓엕엖엗엙",6,"엢엤엦엧"],["9e81","엨엩엪엫엯엱엲엳엵엸엹엺엻옂옃옄옉옊옋옍옎옏옑",6,"옚옝",6,"옦옧옩옪옫옯옱옲옶옸옺옼옽옾옿왂왃왅왆왇왉",6,"왒왖",5,"왞왟왡",10,"왭왮왰왲",5,"왺왻왽왾왿욁",6,"욊욌욎",5,"욖욗욙욚욛욝",6,"욦"],["9f41","욨욪",5,"욲욳욵욶욷욻",4,"웂웄웆",5,"웎"],["9f61","웏웑웒웓웕",6,"웞웟웢",5,"웪웫웭웮웯웱웲"],["9f81","웳",4,"웺웻웼웾",5,"윆윇윉윊윋윍",6,"윖윘윚",5,"윢윣윥윦윧윩",6,"윲윴윶윸윹윺윻윾윿읁읂읃읅",4,"읋읎읐읙읚읛읝읞읟읡",6,"읩읪읬",7,"읶읷읹읺읻읿잀잁잂잆잋잌잍잏잒잓잕잙잛",4,"잢잧",4,"잮잯잱잲잳잵잶잷"],["a041","잸잹잺잻잾쟂",5,"쟊쟋쟍쟏쟑",6,"쟙쟚쟛쟜"],["a061","쟞",5,"쟥쟦쟧쟩쟪쟫쟭",13],["a081","쟻",4,"젂젃젅젆젇젉젋",4,"젒젔젗",4,"젞젟젡젢젣젥",6,"젮젰젲",5,"젹젺젻젽젾젿졁",6,"졊졋졎",5,"졕",26,"졲졳졵졶졷졹졻",4,"좂좄좈좉좊좎",5,"좕",7,"좞좠좢좣좤"],["a141","좥좦좧좩",18,"좾좿죀죁"],["a161","죂죃죅죆죇죉죊죋죍",6,"죖죘죚",5,"죢죣죥"],["a181","죦",14,"죶",5,"죾죿줁줂줃줇",4,"줎　、。·‥…¨〃­―∥＼∼‘’“”〔〕〈",9,"±×÷≠≤≥∞∴°′″℃Å￠￡￥♂♀∠⊥⌒∂∇≡≒§※☆★○●◎◇◆□■△▲▽▼→←↑↓↔〓≪≫√∽∝∵∫∬∈∋⊆⊇⊂⊃∪∩∧∨￢"],["a241","줐줒",5,"줙",18],["a261","줭",6,"줵",18],["a281","쥈",7,"쥒쥓쥕쥖쥗쥙",6,"쥢쥤",7,"쥭쥮쥯⇒⇔∀∃´～ˇ˘˝˚˙¸˛¡¿ː∮∑∏¤℉‰◁◀▷▶♤♠♡♥♧♣⊙◈▣◐◑▒▤▥▨▧▦▩♨☏☎☜☞¶†‡↕↗↙↖↘♭♩♪♬㉿㈜№㏇™㏂㏘℡€®"],["a341","쥱쥲쥳쥵",6,"쥽",10,"즊즋즍즎즏"],["a361","즑",6,"즚즜즞",16],["a381","즯",16,"짂짃짅짆짉짋",4,"짒짔짗짘짛！",58,"￦］",32,"￣"],["a441","짞짟짡짣짥짦짨짩짪짫짮짲",5,"짺짻짽짾짿쨁쨂쨃쨄"],["a461","쨅쨆쨇쨊쨎",5,"쨕쨖쨗쨙",12],["a481","쨦쨧쨨쨪",28,"ㄱ",93],["a541","쩇",4,"쩎쩏쩑쩒쩓쩕",6,"쩞쩢",5,"쩩쩪"],["a561","쩫",17,"쩾",5,"쪅쪆"],["a581","쪇",16,"쪙",14,"ⅰ",9],["a5b0","Ⅰ",9],["a5c1","Α",16,"Σ",6],["a5e1","α",16,"σ",6],["a641","쪨",19,"쪾쪿쫁쫂쫃쫅"],["a661","쫆",5,"쫎쫐쫒쫔쫕쫖쫗쫚",5,"쫡",6],["a681","쫨쫩쫪쫫쫭",6,"쫵",18,"쬉쬊─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂┒┑┚┙┖┕┎┍┞┟┡┢┦┧┩┪┭┮┱┲┵┶┹┺┽┾╀╁╃",7],["a741","쬋",4,"쬑쬒쬓쬕쬖쬗쬙",6,"쬢",7],["a761","쬪",22,"쭂쭃쭄"],["a781","쭅쭆쭇쭊쭋쭍쭎쭏쭑",6,"쭚쭛쭜쭞",5,"쭥",7,"㎕㎖㎗ℓ㎘㏄㎣㎤㎥㎦㎙",9,"㏊㎍㎎㎏㏏㎈㎉㏈㎧㎨㎰",9,"㎀",4,"㎺",5,"㎐",4,"Ω㏀㏁㎊㎋㎌㏖㏅㎭㎮㎯㏛㎩㎪㎫㎬㏝㏐㏓㏃㏉㏜㏆"],["a841","쭭",10,"쭺",14],["a861","쮉",18,"쮝",6],["a881","쮤",19,"쮹",11,"ÆÐªĦ"],["a8a6","Ĳ"],["a8a8","ĿŁØŒºÞŦŊ"],["a8b1","㉠",27,"ⓐ",25,"①",14,"½⅓⅔¼¾⅛⅜⅝⅞"],["a941","쯅",14,"쯕",10],["a961","쯠쯡쯢쯣쯥쯦쯨쯪",18],["a981","쯽",14,"찎찏찑찒찓찕",6,"찞찟찠찣찤æđðħıĳĸŀłøœßþŧŋŉ㈀",27,"⒜",25,"⑴",14,"¹²³⁴ⁿ₁₂₃₄"],["aa41","찥찦찪찫찭찯찱",6,"찺찿",4,"챆챇챉챊챋챍챎"],["aa61","챏",4,"챖챚",5,"챡챢챣챥챧챩",6,"챱챲"],["aa81","챳챴챶",29,"ぁ",82],["ab41","첔첕첖첗첚첛첝첞첟첡",6,"첪첮",5,"첶첷첹"],["ab61","첺첻첽",6,"쳆쳈쳊",5,"쳑쳒쳓쳕",5],["ab81","쳛",8,"쳥",6,"쳭쳮쳯쳱",12,"ァ",85],["ac41","쳾쳿촀촂",5,"촊촋촍촎촏촑",6,"촚촜촞촟촠"],["ac61","촡촢촣촥촦촧촩촪촫촭",11,"촺",4],["ac81","촿",28,"쵝쵞쵟А",5,"ЁЖ",25],["acd1","а",5,"ёж",25],["ad41","쵡쵢쵣쵥",6,"쵮쵰쵲",5,"쵹",7],["ad61","춁",6,"춉",10,"춖춗춙춚춛춝춞춟"],["ad81","춠춡춢춣춦춨춪",5,"춱",18,"췅"],["ae41","췆",5,"췍췎췏췑",16],["ae61","췢",5,"췩췪췫췭췮췯췱",6,"췺췼췾",4],["ae81","츃츅츆츇츉츊츋츍",6,"츕츖츗츘츚",5,"츢츣츥츦츧츩츪츫"],["af41","츬츭츮츯츲츴츶",19],["af61","칊",13,"칚칛칝칞칢",5,"칪칬"],["af81","칮",5,"칶칷칹칺칻칽",6,"캆캈캊",5,"캒캓캕캖캗캙"],["b041","캚",5,"캢캦",5,"캮",12],["b061","캻",5,"컂",19],["b081","컖",13,"컦컧컩컪컭",6,"컶컺",5,"가각간갇갈갉갊감",7,"같",4,"갠갤갬갭갯갰갱갸갹갼걀걋걍걔걘걜거걱건걷걸걺검겁것겄겅겆겉겊겋게겐겔겜겝겟겠겡겨격겪견겯결겸겹겻겼경곁계곈곌곕곗고곡곤곧골곪곬곯곰곱곳공곶과곽관괄괆"],["b141","켂켃켅켆켇켉",6,"켒켔켖",5,"켝켞켟켡켢켣"],["b161","켥",6,"켮켲",5,"켹",11],["b181","콅",14,"콖콗콙콚콛콝",6,"콦콨콪콫콬괌괍괏광괘괜괠괩괬괭괴괵괸괼굄굅굇굉교굔굘굡굣구국군굳굴굵굶굻굼굽굿궁궂궈궉권궐궜궝궤궷귀귁귄귈귐귑귓규균귤그극근귿글긁금급긋긍긔기긱긴긷길긺김깁깃깅깆깊까깍깎깐깔깖깜깝깟깠깡깥깨깩깬깰깸"],["b241","콭콮콯콲콳콵콶콷콹",6,"쾁쾂쾃쾄쾆",5,"쾍"],["b261","쾎",18,"쾢",5,"쾩"],["b281","쾪",5,"쾱",18,"쿅",6,"깹깻깼깽꺄꺅꺌꺼꺽꺾껀껄껌껍껏껐껑께껙껜껨껫껭껴껸껼꼇꼈꼍꼐꼬꼭꼰꼲꼴꼼꼽꼿꽁꽂꽃꽈꽉꽐꽜꽝꽤꽥꽹꾀꾄꾈꾐꾑꾕꾜꾸꾹꾼꿀꿇꿈꿉꿋꿍꿎꿔꿜꿨꿩꿰꿱꿴꿸뀀뀁뀄뀌뀐뀔뀜뀝뀨끄끅끈끊끌끎끓끔끕끗끙"],["b341","쿌",19,"쿢쿣쿥쿦쿧쿩"],["b361","쿪",5,"쿲쿴쿶",5,"쿽쿾쿿퀁퀂퀃퀅",5],["b381","퀋",5,"퀒",5,"퀙",19,"끝끼끽낀낄낌낍낏낑나낙낚난낟날낡낢남납낫",4,"낱낳내낵낸낼냄냅냇냈냉냐냑냔냘냠냥너넉넋넌널넒넓넘넙넛넜넝넣네넥넨넬넴넵넷넸넹녀녁년녈념녑녔녕녘녜녠노녹논놀놂놈놉놋농높놓놔놘놜놨뇌뇐뇔뇜뇝"],["b441","퀮",5,"퀶퀷퀹퀺퀻퀽",6,"큆큈큊",5],["b461","큑큒큓큕큖큗큙",6,"큡",10,"큮큯"],["b481","큱큲큳큵",6,"큾큿킀킂",18,"뇟뇨뇩뇬뇰뇹뇻뇽누눅눈눋눌눔눕눗눙눠눴눼뉘뉜뉠뉨뉩뉴뉵뉼늄늅늉느늑는늘늙늚늠늡늣능늦늪늬늰늴니닉닌닐닒님닙닛닝닢다닥닦단닫",4,"닳담답닷",4,"닿대댁댄댈댐댑댓댔댕댜더덕덖던덛덜덞덟덤덥"],["b541","킕",14,"킦킧킩킪킫킭",5],["b561","킳킶킸킺",5,"탂탃탅탆탇탊",5,"탒탖",4],["b581","탛탞탟탡탢탣탥",6,"탮탲",5,"탹",11,"덧덩덫덮데덱덴델뎀뎁뎃뎄뎅뎌뎐뎔뎠뎡뎨뎬도독돈돋돌돎돐돔돕돗동돛돝돠돤돨돼됐되된될됨됩됫됴두둑둔둘둠둡둣둥둬뒀뒈뒝뒤뒨뒬뒵뒷뒹듀듄듈듐듕드득든듣들듦듬듭듯등듸디딕딘딛딜딤딥딧딨딩딪따딱딴딸"],["b641","턅",7,"턎",17],["b661","턠",15,"턲턳턵턶턷턹턻턼턽턾"],["b681","턿텂텆",5,"텎텏텑텒텓텕",6,"텞텠텢",5,"텩텪텫텭땀땁땃땄땅땋때땍땐땔땜땝땟땠땡떠떡떤떨떪떫떰떱떳떴떵떻떼떽뗀뗄뗌뗍뗏뗐뗑뗘뗬또똑똔똘똥똬똴뙈뙤뙨뚜뚝뚠뚤뚫뚬뚱뛔뛰뛴뛸뜀뜁뜅뜨뜩뜬뜯뜰뜸뜹뜻띄띈띌띔띕띠띤띨띰띱띳띵라락란랄람랍랏랐랑랒랖랗"],["b741","텮",13,"텽",6,"톅톆톇톉톊"],["b761","톋",20,"톢톣톥톦톧"],["b781","톩",6,"톲톴톶톷톸톹톻톽톾톿퇁",14,"래랙랜랠램랩랫랬랭랴략랸럇량러럭런럴럼럽럿렀렁렇레렉렌렐렘렙렛렝려력련렬렴렵렷렸령례롄롑롓로록론롤롬롭롯롱롸롼뢍뢨뢰뢴뢸룀룁룃룅료룐룔룝룟룡루룩룬룰룸룹룻룽뤄뤘뤠뤼뤽륀륄륌륏륑류륙륜률륨륩"],["b841","퇐",7,"퇙",17],["b861","퇫",8,"퇵퇶퇷퇹",13],["b881","툈툊",5,"툑",24,"륫륭르륵른를름릅릇릉릊릍릎리릭린릴림립릿링마막만많",4,"맘맙맛망맞맡맣매맥맨맬맴맵맷맸맹맺먀먁먈먕머먹먼멀멂멈멉멋멍멎멓메멕멘멜멤멥멧멨멩며멱면멸몃몄명몇몌모목몫몬몰몲몸몹못몽뫄뫈뫘뫙뫼"],["b941","툪툫툮툯툱툲툳툵",6,"툾퉀퉂",5,"퉉퉊퉋퉌"],["b961","퉍",14,"퉝",6,"퉥퉦퉧퉨"],["b981","퉩",22,"튂튃튅튆튇튉튊튋튌묀묄묍묏묑묘묜묠묩묫무묵묶문묻물묽묾뭄뭅뭇뭉뭍뭏뭐뭔뭘뭡뭣뭬뮈뮌뮐뮤뮨뮬뮴뮷므믄믈믐믓미믹민믿밀밂밈밉밋밌밍및밑바",4,"받",4,"밤밥밧방밭배백밴밸뱀뱁뱃뱄뱅뱉뱌뱍뱐뱝버벅번벋벌벎범법벗"],["ba41","튍튎튏튒튓튔튖",5,"튝튞튟튡튢튣튥",6,"튭"],["ba61","튮튯튰튲",5,"튺튻튽튾틁틃",4,"틊틌",5],["ba81","틒틓틕틖틗틙틚틛틝",6,"틦",9,"틲틳틵틶틷틹틺벙벚베벡벤벧벨벰벱벳벴벵벼벽변별볍볏볐병볕볘볜보복볶본볼봄봅봇봉봐봔봤봬뵀뵈뵉뵌뵐뵘뵙뵤뵨부북분붇불붉붊붐붑붓붕붙붚붜붤붰붸뷔뷕뷘뷜뷩뷰뷴뷸븀븃븅브븍븐블븜븝븟비빅빈빌빎빔빕빗빙빚빛빠빡빤"],["bb41","틻",4,"팂팄팆",5,"팏팑팒팓팕팗",4,"팞팢팣"],["bb61","팤팦팧팪팫팭팮팯팱",6,"팺팾",5,"퍆퍇퍈퍉"],["bb81","퍊",31,"빨빪빰빱빳빴빵빻빼빽뺀뺄뺌뺍뺏뺐뺑뺘뺙뺨뻐뻑뻔뻗뻘뻠뻣뻤뻥뻬뼁뼈뼉뼘뼙뼛뼜뼝뽀뽁뽄뽈뽐뽑뽕뾔뾰뿅뿌뿍뿐뿔뿜뿟뿡쀼쁑쁘쁜쁠쁨쁩삐삑삔삘삠삡삣삥사삭삯산삳살삵삶삼삽삿샀상샅새색샌샐샘샙샛샜생샤"],["bc41","퍪",17,"퍾퍿펁펂펃펅펆펇"],["bc61","펈펉펊펋펎펒",5,"펚펛펝펞펟펡",6,"펪펬펮"],["bc81","펯",4,"펵펶펷펹펺펻펽",6,"폆폇폊",5,"폑",5,"샥샨샬샴샵샷샹섀섄섈섐섕서",4,"섣설섦섧섬섭섯섰성섶세섹센셀셈셉셋셌셍셔셕션셜셤셥셧셨셩셰셴셸솅소속솎손솔솖솜솝솟송솥솨솩솬솰솽쇄쇈쇌쇔쇗쇘쇠쇤쇨쇰쇱쇳쇼쇽숀숄숌숍숏숑수숙순숟술숨숩숫숭"],["bd41","폗폙",7,"폢폤",7,"폮폯폱폲폳폵폶폷"],["bd61","폸폹폺폻폾퐀퐂",5,"퐉",13],["bd81","퐗",5,"퐞",25,"숯숱숲숴쉈쉐쉑쉔쉘쉠쉥쉬쉭쉰쉴쉼쉽쉿슁슈슉슐슘슛슝스슥슨슬슭슴습슷승시식신싣실싫심십싯싱싶싸싹싻싼쌀쌈쌉쌌쌍쌓쌔쌕쌘쌜쌤쌥쌨쌩썅써썩썬썰썲썸썹썼썽쎄쎈쎌쏀쏘쏙쏜쏟쏠쏢쏨쏩쏭쏴쏵쏸쐈쐐쐤쐬쐰"],["be41","퐸",7,"푁푂푃푅",14],["be61","푔",7,"푝푞푟푡푢푣푥",7,"푮푰푱푲"],["be81","푳",4,"푺푻푽푾풁풃",4,"풊풌풎",5,"풕",8,"쐴쐼쐽쑈쑤쑥쑨쑬쑴쑵쑹쒀쒔쒜쒸쒼쓩쓰쓱쓴쓸쓺쓿씀씁씌씐씔씜씨씩씬씰씸씹씻씽아악안앉않알앍앎앓암압앗았앙앝앞애액앤앨앰앱앳앴앵야약얀얄얇얌얍얏양얕얗얘얜얠얩어억언얹얻얼얽얾엄",6,"엌엎"],["bf41","풞",10,"풪",14],["bf61","풹",18,"퓍퓎퓏퓑퓒퓓퓕"],["bf81","퓖",5,"퓝퓞퓠",7,"퓩퓪퓫퓭퓮퓯퓱",6,"퓹퓺퓼에엑엔엘엠엡엣엥여역엮연열엶엷염",5,"옅옆옇예옌옐옘옙옛옜오옥온올옭옮옰옳옴옵옷옹옻와왁완왈왐왑왓왔왕왜왝왠왬왯왱외왹왼욀욈욉욋욍요욕욘욜욤욥욧용우욱운울욹욺움웁웃웅워웍원월웜웝웠웡웨"],["c041","퓾",5,"픅픆픇픉픊픋픍",6,"픖픘",5],["c061","픞",25],["c081","픸픹픺픻픾픿핁핂핃핅",6,"핎핐핒",5,"핚핛핝핞핟핡핢핣웩웬웰웸웹웽위윅윈윌윔윕윗윙유육윤율윰윱윳융윷으윽은을읊음읍읏응",7,"읜읠읨읫이익인일읽읾잃임입잇있잉잊잎자작잔잖잗잘잚잠잡잣잤장잦재잭잰잴잼잽잿쟀쟁쟈쟉쟌쟎쟐쟘쟝쟤쟨쟬저적전절젊"],["c141","핤핦핧핪핬핮",5,"핶핷핹핺핻핽",6,"햆햊햋"],["c161","햌햍햎햏햑",19,"햦햧"],["c181","햨",31,"점접젓정젖제젝젠젤젬젭젯젱져젼졀졈졉졌졍졔조족존졸졺좀좁좃종좆좇좋좌좍좔좝좟좡좨좼좽죄죈죌죔죕죗죙죠죡죤죵주죽준줄줅줆줌줍줏중줘줬줴쥐쥑쥔쥘쥠쥡쥣쥬쥰쥴쥼즈즉즌즐즘즙즛증지직진짇질짊짐집짓"],["c241","헊헋헍헎헏헑헓",4,"헚헜헞",5,"헦헧헩헪헫헭헮"],["c261","헯",4,"헶헸헺",5,"혂혃혅혆혇혉",6,"혒"],["c281","혖",5,"혝혞혟혡혢혣혥",7,"혮",9,"혺혻징짖짙짚짜짝짠짢짤짧짬짭짯짰짱째짹짼쨀쨈쨉쨋쨌쨍쨔쨘쨩쩌쩍쩐쩔쩜쩝쩟쩠쩡쩨쩽쪄쪘쪼쪽쫀쫄쫌쫍쫏쫑쫓쫘쫙쫠쫬쫴쬈쬐쬔쬘쬠쬡쭁쭈쭉쭌쭐쭘쭙쭝쭤쭸쭹쮜쮸쯔쯤쯧쯩찌찍찐찔찜찝찡찢찧차착찬찮찰참찹찻"],["c341","혽혾혿홁홂홃홄홆홇홊홌홎홏홐홒홓홖홗홙홚홛홝",4],["c361","홢",4,"홨홪",5,"홲홳홵",11],["c381","횁횂횄횆",5,"횎횏횑횒횓횕",7,"횞횠횢",5,"횩횪찼창찾채책챈챌챔챕챗챘챙챠챤챦챨챰챵처척천철첨첩첫첬청체첵첸첼쳄쳅쳇쳉쳐쳔쳤쳬쳰촁초촉촌촐촘촙촛총촤촨촬촹최쵠쵤쵬쵭쵯쵱쵸춈추축춘출춤춥춧충춰췄췌췐취췬췰췸췹췻췽츄츈츌츔츙츠측츤츨츰츱츳층"],["c441","횫횭횮횯횱",7,"횺횼",7,"훆훇훉훊훋"],["c461","훍훎훏훐훒훓훕훖훘훚",5,"훡훢훣훥훦훧훩",4],["c481","훮훯훱훲훳훴훶",5,"훾훿휁휂휃휅",11,"휒휓휔치칙친칟칠칡침칩칫칭카칵칸칼캄캅캇캉캐캑캔캘캠캡캣캤캥캬캭컁커컥컨컫컬컴컵컷컸컹케켁켄켈켐켑켓켕켜켠켤켬켭켯켰켱켸코콕콘콜콤콥콧콩콰콱콴콸쾀쾅쾌쾡쾨쾰쿄쿠쿡쿤쿨쿰쿱쿳쿵쿼퀀퀄퀑퀘퀭퀴퀵퀸퀼"],["c541","휕휖휗휚휛휝휞휟휡",6,"휪휬휮",5,"휶휷휹"],["c561","휺휻휽",6,"흅흆흈흊",5,"흒흓흕흚",4],["c581","흟흢흤흦흧흨흪흫흭흮흯흱흲흳흵",6,"흾흿힀힂",5,"힊힋큄큅큇큉큐큔큘큠크큭큰클큼큽킁키킥킨킬킴킵킷킹타탁탄탈탉탐탑탓탔탕태택탠탤탬탭탯탰탱탸턍터턱턴털턺텀텁텃텄텅테텍텐텔템텝텟텡텨텬텼톄톈토톡톤톨톰톱톳통톺톼퇀퇘퇴퇸툇툉툐투툭툰툴툼툽툿퉁퉈퉜"],["c641","힍힎힏힑",6,"힚힜힞",5],["c6a1","퉤튀튁튄튈튐튑튕튜튠튤튬튱트특튼튿틀틂틈틉틋틔틘틜틤틥티틱틴틸팀팁팃팅파팍팎판팔팖팜팝팟팠팡팥패팩팬팰팸팹팻팼팽퍄퍅퍼퍽펀펄펌펍펏펐펑페펙펜펠펨펩펫펭펴편펼폄폅폈평폐폘폡폣포폭폰폴폼폽폿퐁"],["c7a1","퐈퐝푀푄표푠푤푭푯푸푹푼푿풀풂품풉풋풍풔풩퓌퓐퓔퓜퓟퓨퓬퓰퓸퓻퓽프픈플픔픕픗피픽핀필핌핍핏핑하학한할핥함합핫항해핵핸핼햄햅햇했행햐향허헉헌헐헒험헙헛헝헤헥헨헬헴헵헷헹혀혁현혈혐협혓혔형혜혠"],["c8a1","혤혭호혹혼홀홅홈홉홋홍홑화확환활홧황홰홱홴횃횅회획횐횔횝횟횡효횬횰횹횻후훅훈훌훑훔훗훙훠훤훨훰훵훼훽휀휄휑휘휙휜휠휨휩휫휭휴휵휸휼흄흇흉흐흑흔흖흗흘흙흠흡흣흥흩희흰흴흼흽힁히힉힌힐힘힙힛힝"],["caa1","伽佳假價加可呵哥嘉嫁家暇架枷柯歌珂痂稼苛茄街袈訶賈跏軻迦駕刻却各恪慤殼珏脚覺角閣侃刊墾奸姦干幹懇揀杆柬桿澗癎看磵稈竿簡肝艮艱諫間乫喝曷渴碣竭葛褐蝎鞨勘坎堪嵌感憾戡敢柑橄減甘疳監瞰紺邯鑑鑒龕"],["cba1","匣岬甲胛鉀閘剛堈姜岡崗康强彊慷江畺疆糠絳綱羌腔舡薑襁講鋼降鱇介价個凱塏愷愾慨改槪漑疥皆盖箇芥蓋豈鎧開喀客坑更粳羹醵倨去居巨拒据據擧渠炬祛距踞車遽鉅鋸乾件健巾建愆楗腱虔蹇鍵騫乞傑杰桀儉劍劒檢"],["cca1","瞼鈐黔劫怯迲偈憩揭擊格檄激膈覡隔堅牽犬甄絹繭肩見譴遣鵑抉決潔結缺訣兼慊箝謙鉗鎌京俓倞傾儆勁勍卿坰境庚徑慶憬擎敬景暻更梗涇炅烱璟璥瓊痙硬磬竟競絅經耕耿脛莖警輕逕鏡頃頸驚鯨係啓堺契季屆悸戒桂械"],["cda1","棨溪界癸磎稽系繫繼計誡谿階鷄古叩告呱固姑孤尻庫拷攷故敲暠枯槁沽痼皐睾稿羔考股膏苦苽菰藁蠱袴誥賈辜錮雇顧高鼓哭斛曲梏穀谷鵠困坤崑昆梱棍滾琨袞鯤汨滑骨供公共功孔工恐恭拱控攻珙空蚣貢鞏串寡戈果瓜"],["cea1","科菓誇課跨過鍋顆廓槨藿郭串冠官寬慣棺款灌琯瓘管罐菅觀貫關館刮恝括适侊光匡壙廣曠洸炚狂珖筐胱鑛卦掛罫乖傀塊壞怪愧拐槐魁宏紘肱轟交僑咬喬嬌嶠巧攪敎校橋狡皎矯絞翹膠蕎蛟較轎郊餃驕鮫丘久九仇俱具勾"],["cfa1","區口句咎嘔坵垢寇嶇廐懼拘救枸柩構歐毆毬求溝灸狗玖球瞿矩究絿耉臼舅舊苟衢謳購軀逑邱鉤銶駒驅鳩鷗龜國局菊鞠鞫麴君窘群裙軍郡堀屈掘窟宮弓穹窮芎躬倦券勸卷圈拳捲權淃眷厥獗蕨蹶闕机櫃潰詭軌饋句晷歸貴"],["d0a1","鬼龜叫圭奎揆槻珪硅窺竅糾葵規赳逵閨勻均畇筠菌鈞龜橘克剋劇戟棘極隙僅劤勤懃斤根槿瑾筋芹菫覲謹近饉契今妗擒昑檎琴禁禽芩衾衿襟金錦伋及急扱汲級給亘兢矜肯企伎其冀嗜器圻基埼夔奇妓寄岐崎己幾忌技旗旣"],["d1a1","朞期杞棋棄機欺氣汽沂淇玘琦琪璂璣畸畿碁磯祁祇祈祺箕紀綺羈耆耭肌記譏豈起錡錤飢饑騎騏驥麒緊佶吉拮桔金喫儺喇奈娜懦懶拏拿癩",5,"那樂",4,"諾酪駱亂卵暖欄煖爛蘭難鸞捏捺南嵐枏楠湳濫男藍襤拉"],["d2a1","納臘蠟衲囊娘廊",4,"乃來內奈柰耐冷女年撚秊念恬拈捻寧寗努勞奴弩怒擄櫓爐瑙盧",5,"駑魯",10,"濃籠聾膿農惱牢磊腦賂雷尿壘",7,"嫩訥杻紐勒",5,"能菱陵尼泥匿溺多茶"],["d3a1","丹亶但單團壇彖斷旦檀段湍短端簞緞蛋袒鄲鍛撻澾獺疸達啖坍憺擔曇淡湛潭澹痰聃膽蕁覃談譚錟沓畓答踏遝唐堂塘幢戇撞棠當糖螳黨代垈坮大對岱帶待戴擡玳臺袋貸隊黛宅德悳倒刀到圖堵塗導屠島嶋度徒悼挑掉搗桃"],["d4a1","棹櫂淘渡滔濤燾盜睹禱稻萄覩賭跳蹈逃途道都鍍陶韜毒瀆牘犢獨督禿篤纛讀墩惇敦旽暾沌焞燉豚頓乭突仝冬凍動同憧東桐棟洞潼疼瞳童胴董銅兜斗杜枓痘竇荳讀豆逗頭屯臀芚遁遯鈍得嶝橙燈登等藤謄鄧騰喇懶拏癩羅"],["d5a1","蘿螺裸邏樂洛烙珞絡落諾酪駱丹亂卵欄欒瀾爛蘭鸞剌辣嵐擥攬欖濫籃纜藍襤覽拉臘蠟廊朗浪狼琅瑯螂郞來崍徠萊冷掠略亮倆兩凉梁樑粮粱糧良諒輛量侶儷勵呂廬慮戾旅櫚濾礪藜蠣閭驢驪麗黎力曆歷瀝礫轢靂憐戀攣漣"],["d6a1","煉璉練聯蓮輦連鍊冽列劣洌烈裂廉斂殮濂簾獵令伶囹寧岺嶺怜玲笭羚翎聆逞鈴零靈領齡例澧禮醴隷勞怒撈擄櫓潞瀘爐盧老蘆虜路輅露魯鷺鹵碌祿綠菉錄鹿麓論壟弄朧瀧瓏籠聾儡瀨牢磊賂賚賴雷了僚寮廖料燎療瞭聊蓼"],["d7a1","遼鬧龍壘婁屢樓淚漏瘻累縷蔞褸鏤陋劉旒柳榴流溜瀏琉瑠留瘤硫謬類六戮陸侖倫崙淪綸輪律慄栗率隆勒肋凜凌楞稜綾菱陵俚利厘吏唎履悧李梨浬犁狸理璃異痢籬罹羸莉裏裡里釐離鯉吝潾燐璘藺躪隣鱗麟林淋琳臨霖砬"],["d8a1","立笠粒摩瑪痲碼磨馬魔麻寞幕漠膜莫邈万卍娩巒彎慢挽晩曼滿漫灣瞞萬蔓蠻輓饅鰻唜抹末沫茉襪靺亡妄忘忙望網罔芒茫莽輞邙埋妹媒寐昧枚梅每煤罵買賣邁魅脈貊陌驀麥孟氓猛盲盟萌冪覓免冕勉棉沔眄眠綿緬面麵滅"],["d9a1","蔑冥名命明暝椧溟皿瞑茗蓂螟酩銘鳴袂侮冒募姆帽慕摸摹暮某模母毛牟牡瑁眸矛耗芼茅謀謨貌木沐牧目睦穆鶩歿沒夢朦蒙卯墓妙廟描昴杳渺猫竗苗錨務巫憮懋戊拇撫无楙武毋無珷畝繆舞茂蕪誣貿霧鵡墨默們刎吻問文"],["daa1","汶紊紋聞蚊門雯勿沕物味媚尾嵋彌微未梶楣渼湄眉米美薇謎迷靡黴岷悶愍憫敏旻旼民泯玟珉緡閔密蜜謐剝博拍搏撲朴樸泊珀璞箔粕縛膊舶薄迫雹駁伴半反叛拌搬攀斑槃泮潘班畔瘢盤盼磐磻礬絆般蟠返頒飯勃拔撥渤潑"],["dba1","發跋醱鉢髮魃倣傍坊妨尨幇彷房放方旁昉枋榜滂磅紡肪膀舫芳蒡蚌訪謗邦防龐倍俳北培徘拜排杯湃焙盃背胚裴裵褙賠輩配陪伯佰帛柏栢白百魄幡樊煩燔番磻繁蕃藩飜伐筏罰閥凡帆梵氾汎泛犯範范法琺僻劈壁擘檗璧癖"],["dca1","碧蘗闢霹便卞弁變辨辯邊別瞥鱉鼈丙倂兵屛幷昞昺柄棅炳甁病秉竝輧餠騈保堡報寶普步洑湺潽珤甫菩補褓譜輔伏僕匐卜宓復服福腹茯蔔複覆輹輻馥鰒本乶俸奉封峯峰捧棒烽熢琫縫蓬蜂逢鋒鳳不付俯傅剖副否咐埠夫婦"],["dda1","孚孵富府復扶敷斧浮溥父符簿缶腐腑膚艀芙莩訃負賦賻赴趺部釜阜附駙鳧北分吩噴墳奔奮忿憤扮昐汾焚盆粉糞紛芬賁雰不佛弗彿拂崩朋棚硼繃鵬丕備匕匪卑妃婢庇悲憊扉批斐枇榧比毖毗毘沸泌琵痺砒碑秕秘粃緋翡肥"],["dea1","脾臂菲蜚裨誹譬費鄙非飛鼻嚬嬪彬斌檳殯浜濱瀕牝玭貧賓頻憑氷聘騁乍事些仕伺似使俟僿史司唆嗣四士奢娑寫寺射巳師徙思捨斜斯柶査梭死沙泗渣瀉獅砂社祀祠私篩紗絲肆舍莎蓑蛇裟詐詞謝賜赦辭邪飼駟麝削數朔索"],["dfa1","傘刪山散汕珊産疝算蒜酸霰乷撒殺煞薩三參杉森渗芟蔘衫揷澁鈒颯上傷像償商喪嘗孀尙峠常床庠廂想桑橡湘爽牀狀相祥箱翔裳觴詳象賞霜塞璽賽嗇塞穡索色牲生甥省笙墅壻嶼序庶徐恕抒捿敍暑曙書栖棲犀瑞筮絮緖署"],["e0a1","胥舒薯西誓逝鋤黍鼠夕奭席惜昔晳析汐淅潟石碩蓆釋錫仙僊先善嬋宣扇敾旋渲煽琁瑄璇璿癬禪線繕羨腺膳船蘚蟬詵跣選銑鐥饍鮮卨屑楔泄洩渫舌薛褻設說雪齧剡暹殲纖蟾贍閃陝攝涉燮葉城姓宬性惺成星晟猩珹盛省筬"],["e1a1","聖聲腥誠醒世勢歲洗稅笹細說貰召嘯塑宵小少巢所掃搔昭梳沼消溯瀟炤燒甦疏疎瘙笑篠簫素紹蔬蕭蘇訴逍遡邵銷韶騷俗屬束涑粟續謖贖速孫巽損蓀遜飡率宋悚松淞訟誦送頌刷殺灑碎鎖衰釗修受嗽囚垂壽嫂守岫峀帥愁"],["e2a1","戍手授搜收數樹殊水洙漱燧狩獸琇璲瘦睡秀穗竪粹綏綬繡羞脩茱蒐蓚藪袖誰讐輸遂邃酬銖銹隋隧隨雖需須首髓鬚叔塾夙孰宿淑潚熟琡璹肅菽巡徇循恂旬栒楯橓殉洵淳珣盾瞬筍純脣舜荀蓴蕣詢諄醇錞順馴戌術述鉥崇崧"],["e3a1","嵩瑟膝蝨濕拾習褶襲丞乘僧勝升承昇繩蠅陞侍匙嘶始媤尸屎屍市弑恃施是時枾柴猜矢示翅蒔蓍視試詩諡豕豺埴寔式息拭植殖湜熄篒蝕識軾食飾伸侁信呻娠宸愼新晨燼申神紳腎臣莘薪藎蜃訊身辛辰迅失室實悉審尋心沁"],["e4a1","沈深瀋甚芯諶什十拾雙氏亞俄兒啞娥峨我牙芽莪蛾衙訝阿雅餓鴉鵝堊岳嶽幄惡愕握樂渥鄂鍔顎鰐齷安岸按晏案眼雁鞍顔鮟斡謁軋閼唵岩巖庵暗癌菴闇壓押狎鴨仰央怏昻殃秧鴦厓哀埃崖愛曖涯碍艾隘靄厄扼掖液縊腋額"],["e5a1","櫻罌鶯鸚也倻冶夜惹揶椰爺耶若野弱掠略約若葯蒻藥躍亮佯兩凉壤孃恙揚攘敭暘梁楊樣洋瀁煬痒瘍禳穰糧羊良襄諒讓釀陽量養圄御於漁瘀禦語馭魚齬億憶抑檍臆偃堰彦焉言諺孼蘖俺儼嚴奄掩淹嶪業円予余勵呂女如廬"],["e6a1","旅歟汝濾璵礖礪與艅茹輿轝閭餘驪麗黎亦力域役易曆歷疫繹譯轢逆驛嚥堧姸娟宴年延憐戀捐挻撚椽沇沿涎涓淵演漣烟然煙煉燃燕璉硏硯秊筵緣練縯聯衍軟輦蓮連鉛鍊鳶列劣咽悅涅烈熱裂說閱厭廉念捻染殮炎焰琰艶苒"],["e7a1","簾閻髥鹽曄獵燁葉令囹塋寧嶺嶸影怜映暎楹榮永泳渶潁濚瀛瀯煐營獰玲瑛瑩瓔盈穎纓羚聆英詠迎鈴鍈零霙靈領乂倪例刈叡曳汭濊猊睿穢芮藝蘂禮裔詣譽豫醴銳隸霓預五伍俉傲午吾吳嗚塢墺奧娛寤悟惡懊敖旿晤梧汚澳"],["e8a1","烏熬獒筽蜈誤鰲鼇屋沃獄玉鈺溫瑥瘟穩縕蘊兀壅擁瓮甕癰翁邕雍饔渦瓦窩窪臥蛙蝸訛婉完宛梡椀浣玩琓琬碗緩翫脘腕莞豌阮頑曰往旺枉汪王倭娃歪矮外嵬巍猥畏了僚僥凹堯夭妖姚寥寮尿嶢拗搖撓擾料曜樂橈燎燿瑤療"],["e9a1","窈窯繇繞耀腰蓼蟯要謠遙遼邀饒慾欲浴縟褥辱俑傭冗勇埇墉容庸慂榕涌湧溶熔瑢用甬聳茸蓉踊鎔鏞龍于佑偶優又友右宇寓尤愚憂旴牛玗瑀盂祐禑禹紆羽芋藕虞迂遇郵釪隅雨雩勖彧旭昱栯煜稶郁頊云暈橒殞澐熉耘芸蕓"],["eaa1","運隕雲韻蔚鬱亐熊雄元原員圓園垣媛嫄寃怨愿援沅洹湲源爰猿瑗苑袁轅遠阮院願鴛月越鉞位偉僞危圍委威尉慰暐渭爲瑋緯胃萎葦蔿蝟衛褘謂違韋魏乳侑儒兪劉唯喩孺宥幼幽庾悠惟愈愉揄攸有杻柔柚柳楡楢油洧流游溜"],["eba1","濡猶猷琉瑜由留癒硫紐維臾萸裕誘諛諭踰蹂遊逾遺酉釉鍮類六堉戮毓肉育陸倫允奫尹崙淪潤玧胤贇輪鈗閏律慄栗率聿戎瀜絨融隆垠恩慇殷誾銀隱乙吟淫蔭陰音飮揖泣邑凝應膺鷹依倚儀宜意懿擬椅毅疑矣義艤薏蟻衣誼"],["eca1","議醫二以伊利吏夷姨履已弛彛怡易李梨泥爾珥理異痍痢移罹而耳肄苡荑裏裡貽貳邇里離飴餌匿溺瀷益翊翌翼謚人仁刃印吝咽因姻寅引忍湮燐璘絪茵藺蚓認隣靭靷鱗麟一佚佾壹日溢逸鎰馹任壬妊姙恁林淋稔臨荏賃入卄"],["eda1","立笠粒仍剩孕芿仔刺咨姉姿子字孜恣慈滋炙煮玆瓷疵磁紫者自茨蔗藉諮資雌作勺嚼斫昨灼炸爵綽芍酌雀鵲孱棧殘潺盞岑暫潛箴簪蠶雜丈仗匠場墻壯奬將帳庄張掌暲杖樟檣欌漿牆狀獐璋章粧腸臟臧莊葬蔣薔藏裝贓醬長"],["eea1","障再哉在宰才材栽梓渽滓災縡裁財載齋齎爭箏諍錚佇低儲咀姐底抵杵楮樗沮渚狙猪疽箸紵苧菹著藷詛貯躇這邸雎齟勣吊嫡寂摘敵滴狄炙的積笛籍績翟荻謫賊赤跡蹟迪迹適鏑佃佺傳全典前剪塡塼奠專展廛悛戰栓殿氈澱"],["efa1","煎琠田甸畑癲筌箋箭篆纏詮輾轉鈿銓錢鐫電顚顫餞切截折浙癤竊節絶占岾店漸点粘霑鮎點接摺蝶丁井亭停偵呈姃定幀庭廷征情挺政整旌晶晸柾楨檉正汀淀淨渟湞瀞炡玎珽町睛碇禎程穽精綎艇訂諪貞鄭酊釘鉦鋌錠霆靖"],["f0a1","靜頂鼎制劑啼堤帝弟悌提梯濟祭第臍薺製諸蹄醍除際霽題齊俎兆凋助嘲弔彫措操早晁曺曹朝條棗槽漕潮照燥爪璪眺祖祚租稠窕粗糟組繰肇藻蚤詔調趙躁造遭釣阻雕鳥族簇足鏃存尊卒拙猝倧宗從悰慫棕淙琮種終綜縱腫"],["f1a1","踪踵鍾鐘佐坐左座挫罪主住侏做姝胄呪周嗾奏宙州廚晝朱柱株注洲湊澍炷珠疇籌紂紬綢舟蛛註誅走躊輳週酎酒鑄駐竹粥俊儁准埈寯峻晙樽浚準濬焌畯竣蠢逡遵雋駿茁中仲衆重卽櫛楫汁葺增憎曾拯烝甑症繒蒸證贈之只"],["f2a1","咫地址志持指摯支旨智枝枳止池沚漬知砥祉祗紙肢脂至芝芷蜘誌識贄趾遲直稙稷織職唇嗔塵振搢晉晋桭榛殄津溱珍瑨璡畛疹盡眞瞋秦縉縝臻蔯袗診賑軫辰進鎭陣陳震侄叱姪嫉帙桎瓆疾秩窒膣蛭質跌迭斟朕什執潗緝輯"],["f3a1","鏶集徵懲澄且侘借叉嗟嵯差次此磋箚茶蹉車遮捉搾着窄錯鑿齪撰澯燦璨瓚竄簒纂粲纘讚贊鑽餐饌刹察擦札紮僭參塹慘慙懺斬站讒讖倉倡創唱娼廠彰愴敞昌昶暢槍滄漲猖瘡窓脹艙菖蒼債埰寀寨彩採砦綵菜蔡采釵冊柵策"],["f4a1","責凄妻悽處倜刺剔尺慽戚拓擲斥滌瘠脊蹠陟隻仟千喘天川擅泉淺玔穿舛薦賤踐遷釧闡阡韆凸哲喆徹撤澈綴輟轍鐵僉尖沾添甛瞻簽籤詹諂堞妾帖捷牒疊睫諜貼輒廳晴淸聽菁請靑鯖切剃替涕滯締諦逮遞體初剿哨憔抄招梢"],["f5a1","椒楚樵炒焦硝礁礎秒稍肖艸苕草蕉貂超酢醋醮促囑燭矗蜀觸寸忖村邨叢塚寵悤憁摠總聰蔥銃撮催崔最墜抽推椎楸樞湫皺秋芻萩諏趨追鄒酋醜錐錘鎚雛騶鰍丑畜祝竺筑築縮蓄蹙蹴軸逐春椿瑃出朮黜充忠沖蟲衝衷悴膵萃"],["f6a1","贅取吹嘴娶就炊翠聚脆臭趣醉驟鷲側仄厠惻測層侈値嗤峙幟恥梔治淄熾痔痴癡稚穉緇緻置致蚩輜雉馳齒則勅飭親七柒漆侵寢枕沈浸琛砧針鍼蟄秤稱快他咤唾墮妥惰打拖朶楕舵陀馱駝倬卓啄坼度托拓擢晫柝濁濯琢琸託"],["f7a1","鐸呑嘆坦彈憚歎灘炭綻誕奪脫探眈耽貪塔搭榻宕帑湯糖蕩兌台太怠態殆汰泰笞胎苔跆邰颱宅擇澤撑攄兎吐土討慟桶洞痛筒統通堆槌腿褪退頹偸套妬投透鬪慝特闖坡婆巴把播擺杷波派爬琶破罷芭跛頗判坂板版瓣販辦鈑"],["f8a1","阪八叭捌佩唄悖敗沛浿牌狽稗覇貝彭澎烹膨愎便偏扁片篇編翩遍鞭騙貶坪平枰萍評吠嬖幣廢弊斃肺蔽閉陛佈包匍匏咆哺圃布怖抛抱捕暴泡浦疱砲胞脯苞葡蒲袍褒逋鋪飽鮑幅暴曝瀑爆輻俵剽彪慓杓標漂瓢票表豹飇飄驃"],["f9a1","品稟楓諷豊風馮彼披疲皮被避陂匹弼必泌珌畢疋筆苾馝乏逼下何厦夏廈昰河瑕荷蝦賀遐霞鰕壑學虐謔鶴寒恨悍旱汗漢澣瀚罕翰閑閒限韓割轄函含咸啣喊檻涵緘艦銜陷鹹合哈盒蛤閤闔陜亢伉姮嫦巷恒抗杭桁沆港缸肛航"],["faa1","行降項亥偕咳垓奚孩害懈楷海瀣蟹解該諧邂駭骸劾核倖幸杏荇行享向嚮珦鄕響餉饗香噓墟虛許憲櫶獻軒歇險驗奕爀赫革俔峴弦懸晛泫炫玄玹現眩睍絃絢縣舷衒見賢鉉顯孑穴血頁嫌俠協夾峽挾浹狹脅脇莢鋏頰亨兄刑型"],["fba1","形泂滎瀅灐炯熒珩瑩荊螢衡逈邢鎣馨兮彗惠慧暳蕙蹊醯鞋乎互呼壕壺好岵弧戶扈昊晧毫浩淏湖滸澔濠濩灝狐琥瑚瓠皓祜糊縞胡芦葫蒿虎號蝴護豪鎬頀顥惑或酷婚昏混渾琿魂忽惚笏哄弘汞泓洪烘紅虹訌鴻化和嬅樺火畵"],["fca1","禍禾花華話譁貨靴廓擴攫確碻穫丸喚奐宦幻患換歡晥桓渙煥環紈還驩鰥活滑猾豁闊凰幌徨恍惶愰慌晃晄榥況湟滉潢煌璜皇篁簧荒蝗遑隍黃匯回廻徊恢悔懷晦會檜淮澮灰獪繪膾茴蛔誨賄劃獲宖橫鐄哮嚆孝效斅曉梟涍淆"],["fda1","爻肴酵驍侯候厚后吼喉嗅帿後朽煦珝逅勛勳塤壎焄熏燻薰訓暈薨喧暄煊萱卉喙毁彙徽揮暉煇諱輝麾休携烋畦虧恤譎鷸兇凶匈洶胸黑昕欣炘痕吃屹紇訖欠欽歆吸恰洽翕興僖凞喜噫囍姬嬉希憙憘戱晞曦熙熹熺犧禧稀羲詰"]]')},function(e){e.exports=JSON.parse('[["8740","䏰䰲䘃䖦䕸𧉧䵷䖳𧲱䳢𧳅㮕䜶䝄䱇䱀𤊿𣘗𧍒𦺋𧃒䱗𪍑䝏䗚䲅𧱬䴇䪤䚡𦬣爥𥩔𡩣𣸆𣽡晍囻"],["8767","綕夝𨮹㷴霴𧯯寛𡵞媤㘥𩺰嫑宷峼杮薓𩥅瑡璝㡵𡵓𣚞𦀡㻬"],["87a1","𥣞㫵竼龗𤅡𨤍𣇪𠪊𣉞䌊蒄龖鐯䤰蘓墖靊鈘秐稲晠権袝瑌篅枂稬剏遆㓦珄𥶹瓆鿇垳䤯呌䄱𣚎堘穲𧭥讏䚮𦺈䆁𥶙箮𢒼鿈𢓁𢓉𢓌鿉蔄𣖻䂴鿊䓡𪷿拁灮鿋"],["8840","㇀",4,"𠄌㇅𠃑𠃍㇆㇇𠃋𡿨㇈𠃊㇉㇊㇋㇌𠄎㇍㇎ĀÁǍÀĒÉĚÈŌÓǑÒ࿿Ê̄Ế࿿Ê̌ỀÊāáǎàɑēéěèīíǐìōóǒòūúǔùǖǘǚ"],["88a1","ǜü࿿ê̄ế࿿ê̌ềêɡ⏚⏛"],["8940","𪎩𡅅"],["8943","攊"],["8946","丽滝鵎釟"],["894c","𧜵撑会伨侨兖兴农凤务动医华发变团声处备夲头学实実岚庆总斉柾栄桥济炼电纤纬纺织经统缆缷艺苏药视设询车轧轮"],["89a1","琑糼緍楆竉刧"],["89ab","醌碸酞肼"],["89b0","贋胶𠧧"],["89b5","肟黇䳍鷉鸌䰾𩷶𧀎鸊𪄳㗁"],["89c1","溚舾甙"],["89c5","䤑马骏龙禇𨑬𡷊𠗐𢫦两亁亀亇亿仫伷㑌侽㹈倃傈㑽㒓㒥円夅凛凼刅争剹劐匧㗇厩㕑厰㕓参吣㕭㕲㚁咓咣咴咹哐哯唘唣唨㖘唿㖥㖿嗗㗅"],["8a40","𧶄唥"],["8a43","𠱂𠴕𥄫喐𢳆㧬𠍁蹆𤶸𩓥䁓𨂾睺𢰸㨴䟕𨅝𦧲𤷪擝𠵼𠾴𠳕𡃴撍蹾𠺖𠰋𠽤𢲩𨉖𤓓"],["8a64","𠵆𩩍𨃩䟴𤺧𢳂骲㩧𩗴㿭㔆𥋇𩟔𧣈𢵄鵮頕"],["8a76","䏙𦂥撴哣𢵌𢯊𡁷㧻𡁯"],["8aa1","𦛚𦜖𧦠擪𥁒𠱃蹨𢆡𨭌𠜱"],["8aac","䠋𠆩㿺塳𢶍"],["8ab2","𤗈𠓼𦂗𠽌𠶖啹䂻䎺"],["8abb","䪴𢩦𡂝膪飵𠶜捹㧾𢝵跀嚡摼㹃"],["8ac9","𪘁𠸉𢫏𢳉"],["8ace","𡃈𣧂㦒㨆𨊛㕸𥹉𢃇噒𠼱𢲲𩜠㒼氽𤸻"],["8adf","𧕴𢺋𢈈𪙛𨳍𠹺𠰴𦠜羓𡃏𢠃𢤹㗻𥇣𠺌𠾍𠺪㾓𠼰𠵇𡅏𠹌"],["8af6","𠺫𠮩𠵈𡃀𡄽㿹𢚖搲𠾭"],["8b40","𣏴𧘹𢯎𠵾𠵿𢱑𢱕㨘𠺘𡃇𠼮𪘲𦭐𨳒𨶙𨳊閪哌苄喹"],["8b55","𩻃鰦骶𧝞𢷮煀腭胬尜𦕲脴㞗卟𨂽醶𠻺𠸏𠹷𠻻㗝𤷫㘉𠳖嚯𢞵𡃉𠸐𠹸𡁸𡅈𨈇𡑕𠹹𤹐𢶤婔𡀝𡀞𡃵𡃶垜𠸑"],["8ba1","𧚔𨋍𠾵𠹻𥅾㜃𠾶𡆀𥋘𪊽𤧚𡠺𤅷𨉼墙剨㘚𥜽箲孨䠀䬬鼧䧧鰟鮍𥭴𣄽嗻㗲嚉丨夂𡯁屮靑𠂆乛亻㔾尣彑忄㣺扌攵歺氵氺灬爫丬犭𤣩罒礻糹罓𦉪㓁"],["8bde","𦍋耂肀𦘒𦥑卝衤见𧢲讠贝钅镸长门𨸏韦页风飞饣𩠐鱼鸟黄歯龜丷𠂇阝户钢"],["8c40","倻淾𩱳龦㷉袏𤅎灷峵䬠𥇍㕙𥴰愢𨨲辧釶熑朙玺𣊁𪄇㲋𡦀䬐磤琂冮𨜏䀉橣𪊺䈣蘏𠩯稪𩥇𨫪靕灍匤𢁾鏴盙𨧣龧矝亣俰傼丯众龨吴綋墒壐𡶶庒庙忂𢜒斋"],["8ca1","𣏹椙橃𣱣泿"],["8ca7","爀𤔅玌㻛𤨓嬕璹讃𥲤𥚕窓篬糃繬苸薗龩袐龪躹龫迏蕟駠鈡龬𨶹𡐿䁱䊢娚"],["8cc9","顨杫䉶圽"],["8cce","藖𤥻芿𧄍䲁𦵴嵻𦬕𦾾龭龮宖龯曧繛湗秊㶈䓃𣉖𢞖䎚䔶"],["8ce6","峕𣬚諹屸㴒𣕑嵸龲煗䕘𤃬𡸣䱷㥸㑊𠆤𦱁諌侴𠈹妿腬顖𩣺弻"],["8d40","𠮟"],["8d42","𢇁𨥭䄂䚻𩁹㼇龳𪆵䃸㟖䛷𦱆䅼𨚲𧏿䕭㣔𥒚䕡䔛䶉䱻䵶䗪㿈𤬏㙡䓞䒽䇭崾嵈嵖㷼㠏嶤嶹㠠㠸幂庽弥徃㤈㤔㤿㥍惗愽峥㦉憷憹懏㦸戬抐拥挘㧸嚱"],["8da1","㨃揢揻搇摚㩋擀崕嘡龟㪗斆㪽旿晓㫲暒㬢朖㭂枤栀㭘桊梄㭲㭱㭻椉楃牜楤榟榅㮼槖㯝橥橴橱檂㯬檙㯲檫檵櫔櫶殁毁毪汵沪㳋洂洆洦涁㳯涤涱渕渘温溆𨧀溻滢滚齿滨滩漤漴㵆𣽁澁澾㵪㵵熷岙㶊瀬㶑灐灔灯灿炉𠌥䏁㗱𠻘"],["8e40","𣻗垾𦻓焾𥟠㙎榢𨯩孴穉𥣡𩓙穥穽𥦬窻窰竂竃燑𦒍䇊竚竝竪䇯咲𥰁笋筕笩𥌎𥳾箢筯莜𥮴𦱿篐萡箒箸𥴠㶭𥱥蒒篺簆簵𥳁籄粃𤢂粦晽𤕸糉糇糦籴糳糵糎"],["8ea1","繧䔝𦹄絝𦻖璍綉綫焵綳緒𤁗𦀩緤㴓緵𡟹緥𨍭縝𦄡𦅚繮纒䌫鑬縧罀罁罇礶𦋐駡羗𦍑羣𡙡𠁨䕜𣝦䔃𨌺翺𦒉者耈耝耨耯𪂇𦳃耻耼聡𢜔䦉𦘦𣷣𦛨朥肧𨩈脇脚墰𢛶汿𦒘𤾸擧𡒊舘𡡞橓𤩥𤪕䑺舩𠬍𦩒𣵾俹𡓽蓢荢𦬊𤦧𣔰𡝳𣷸芪椛芳䇛"],["8f40","蕋苐茚𠸖𡞴㛁𣅽𣕚艻苢茘𣺋𦶣𦬅𦮗𣗎㶿茝嗬莅䔋𦶥莬菁菓㑾𦻔橗蕚㒖𦹂𢻯葘𥯤葱㷓䓤檧葊𣲵祘蒨𦮖𦹷𦹃蓞萏莑䒠蒓蓤𥲑䉀𥳀䕃蔴嫲𦺙䔧蕳䔖枿蘖"],["8fa1","𨘥𨘻藁𧂈蘂𡖂𧃍䕫䕪蘨㙈𡢢号𧎚虾蝱𪃸蟮𢰧螱蟚蠏噡虬桖䘏衅衆𧗠𣶹𧗤衞袜䙛袴袵揁装睷𧜏覇覊覦覩覧覼𨨥觧𧤤𧪽誜瞓釾誐𧩙竩𧬺𣾏䜓𧬸煼謌謟𥐰𥕥謿譌譍誩𤩺讐讛誯𡛟䘕衏貛𧵔𧶏貫㜥𧵓賖𧶘𧶽贒贃𡤐賛灜贑𤳉㻐起"],["9040","趩𨀂𡀔𤦊㭼𨆼𧄌竧躭躶軃鋔輙輭𨍥𨐒辥錃𪊟𠩐辳䤪𨧞𨔽𣶻廸𣉢迹𪀔𨚼𨔁𢌥㦀𦻗逷𨔼𧪾遡𨕬𨘋邨𨜓郄𨛦邮都酧㫰醩釄粬𨤳𡺉鈎沟鉁鉢𥖹銹𨫆𣲛𨬌𥗛"],["90a1","𠴱錬鍫𨫡𨯫炏嫃𨫢𨫥䥥鉄𨯬𨰹𨯿鍳鑛躼閅閦鐦閠濶䊹𢙺𨛘𡉼𣸮䧟氜陻隖䅬隣𦻕懚隶磵𨫠隽双䦡𦲸𠉴𦐐𩂯𩃥𤫑𡤕𣌊霱虂霶䨏䔽䖅𤫩灵孁霛靜𩇕靗孊𩇫靟鐥僐𣂷𣂼鞉鞟鞱鞾韀韒韠𥑬韮琜𩐳響韵𩐝𧥺䫑頴頳顋顦㬎𧅵㵑𠘰𤅜"],["9140","𥜆飊颷飈飇䫿𦴧𡛓喰飡飦飬鍸餹𤨩䭲𩡗𩤅駵騌騻騐驘𥜥㛄𩂱𩯕髠髢𩬅髴䰎鬔鬭𨘀倴鬴𦦨㣃𣁽魐魀𩴾婅𡡣鮎𤉋鰂鯿鰌𩹨鷔𩾷𪆒𪆫𪃡𪄣𪇟鵾鶃𪄴鸎梈"],["91a1","鷄𢅛𪆓𪈠𡤻𪈳鴹𪂹𪊴麐麕麞麢䴴麪麯𤍤黁㭠㧥㴝伲㞾𨰫鼂鼈䮖鐤𦶢鼗鼖鼹嚟嚊齅馸𩂋韲葿齢齩竜龎爖䮾𤥵𤦻煷𤧸𤍈𤩑玞𨯚𡣺禟𨥾𨸶鍩鏳𨩄鋬鎁鏋𨥬𤒹爗㻫睲穃烐𤑳𤏸煾𡟯炣𡢾𣖙㻇𡢅𥐯𡟸㜢𡛻𡠹㛡𡝴𡣑𥽋㜣𡛀坛𤨥𡏾𡊨"],["9240","𡏆𡒶蔃𣚦蔃葕𤦔𧅥𣸱𥕜𣻻𧁒䓴𣛮𩦝𦼦柹㜳㰕㷧塬𡤢栐䁗𣜿𤃡𤂋𤄏𦰡哋嚞𦚱嚒𠿟𠮨𠸍鏆𨬓鎜仸儫㠙𤐶亼𠑥𠍿佋侊𥙑婨𠆫𠏋㦙𠌊𠐔㐵伩𠋀𨺳𠉵諚𠈌亘"],["92a1","働儍侢伃𤨎𣺊佂倮偬傁俌俥偘僼兙兛兝兞湶𣖕𣸹𣺿浲𡢄𣺉冨凃𠗠䓝𠒣𠒒𠒑赺𨪜𠜎剙劤𠡳勡鍮䙺熌𤎌𠰠𤦬𡃤槑𠸝瑹㻞璙琔瑖玘䮎𤪼𤂍叐㖄爏𤃉喴𠍅响𠯆圝鉝雴鍦埝垍坿㘾壋媙𨩆𡛺𡝯𡜐娬妸銏婾嫏娒𥥆𡧳𡡡𤊕㛵洅瑃娡𥺃"],["9340","媁𨯗𠐓鏠璌𡌃焅䥲鐈𨧻鎽㞠尞岞幞幈𡦖𡥼𣫮廍孏𡤃𡤄㜁𡢠㛝𡛾㛓脪𨩇𡶺𣑲𨦨弌弎𡤧𡞫婫𡜻孄蘔𧗽衠恾𢡠𢘫忛㺸𢖯𢖾𩂈𦽳懀𠀾𠁆𢘛憙憘恵𢲛𢴇𤛔𩅍"],["93a1","摱𤙥𢭪㨩𢬢𣑐𩣪𢹸挷𪑛撶挱揑𤧣𢵧护𢲡搻敫楲㯴𣂎𣊭𤦉𣊫唍𣋠𡣙𩐿曎𣊉𣆳㫠䆐𥖄𨬢𥖏𡛼𥕛𥐥磮𣄃𡠪𣈴㑤𣈏𣆂𤋉暎𦴤晫䮓昰𧡰𡷫晣𣋒𣋡昞𥡲㣑𣠺𣞼㮙𣞢𣏾瓐㮖枏𤘪梶栞㯄檾㡣𣟕𤒇樳橒櫉欅𡤒攑梘橌㯗橺歗𣿀𣲚鎠鋲𨯪𨫋"],["9440","銉𨀞𨧜鑧涥漋𤧬浧𣽿㶏渄𤀼娽渊塇洤硂焻𤌚𤉶烱牐犇犔𤞏𤜥兹𤪤𠗫瑺𣻸𣙟𤩊𤤗𥿡㼆㺱𤫟𨰣𣼵悧㻳瓌琼鎇琷䒟𦷪䕑疃㽣𤳙𤴆㽘畕癳𪗆㬙瑨𨫌𤦫𤦎㫻"],["94a1","㷍𤩎㻿𤧅𤣳釺圲鍂𨫣𡡤僟𥈡𥇧睸𣈲眎眏睻𤚗𣞁㩞𤣰琸璛㺿𤪺𤫇䃈𤪖𦆮錇𥖁砞碍碈磒珐祙𧝁𥛣䄎禛蒖禥樭𣻺稺秴䅮𡛦䄲鈵秱𠵌𤦌𠊙𣶺𡝮㖗啫㕰㚪𠇔𠰍竢婙𢛵𥪯𥪜娍𠉛磰娪𥯆竾䇹籝籭䈑𥮳𥺼𥺦糍𤧹𡞰粎籼粮檲緜縇緓罎𦉡"],["9540","𦅜𧭈綗𥺂䉪𦭵𠤖柖𠁎𣗏埄𦐒𦏸𤥢翝笧𠠬𥫩𥵃笌𥸎駦虅驣樜𣐿㧢𤧷𦖭騟𦖠蒀𧄧𦳑䓪脷䐂胆脉腂𦞴飃𦩂艢艥𦩑葓𦶧蘐𧈛媆䅿𡡀嬫𡢡嫤𡣘蚠蜨𣶏蠭𧐢娂"],["95a1","衮佅袇袿裦襥襍𥚃襔𧞅𧞄𨯵𨯙𨮜𨧹㺭蒣䛵䛏㟲訽訜𩑈彍鈫𤊄旔焩烄𡡅鵭貟賩𧷜妚矃姰䍮㛔踪躧𤰉輰轊䋴汘澻𢌡䢛潹溋𡟚鯩㚵𤤯邻邗啱䤆醻鐄𨩋䁢𨫼鐧𨰝𨰻蓥訫閙閧閗閖𨴴瑅㻂𤣿𤩂𤏪㻧𣈥随𨻧𨹦𨹥㻌𤧭𤩸𣿮琒瑫㻼靁𩂰"],["9640","桇䨝𩂓𥟟靝鍨𨦉𨰦𨬯𦎾銺嬑譩䤼珹𤈛鞛靱餸𠼦巁𨯅𤪲頟𩓚鋶𩗗釥䓀𨭐𤩧𨭤飜𨩅㼀鈪䤥萔餻饍𧬆㷽馛䭯馪驜𨭥𥣈檏騡嫾騯𩣱䮐𩥈馼䮽䮗鍽塲𡌂堢𤦸"],["96a1","𡓨硄𢜟𣶸棅㵽鑘㤧慐𢞁𢥫愇鱏鱓鱻鰵鰐魿鯏𩸭鮟𪇵𪃾鴡䲮𤄄鸘䲰鴌𪆴𪃭𪃳𩤯鶥蒽𦸒𦿟𦮂藼䔳𦶤𦺄𦷰萠藮𦸀𣟗𦁤秢𣖜𣙀䤭𤧞㵢鏛銾鍈𠊿碹鉷鑍俤㑀遤𥕝砽硔碶硋𡝗𣇉𤥁㚚佲濚濙瀞瀞吔𤆵垻壳垊鴖埗焴㒯𤆬燫𦱀𤾗嬨𡞵𨩉"],["9740","愌嫎娋䊼𤒈㜬䭻𨧼鎻鎸𡣖𠼝葲𦳀𡐓𤋺𢰦𤏁妔𣶷𦝁綨𦅛𦂤𤦹𤦋𨧺鋥珢㻩璴𨭣𡢟㻡𤪳櫘珳珻㻖𤨾𤪔𡟙𤩦𠎧𡐤𤧥瑈𤤖炥𤥶銄珦鍟𠓾錱𨫎𨨖鎆𨯧𥗕䤵𨪂煫"],["97a1","𤥃𠳿嚤𠘚𠯫𠲸唂秄𡟺緾𡛂𤩐𡡒䔮鐁㜊𨫀𤦭妰𡢿𡢃𧒄媡㛢𣵛㚰鉟婹𨪁𡡢鍴㳍𠪴䪖㦊僴㵩㵌𡎜煵䋻𨈘渏𩃤䓫浗𧹏灧沯㳖𣿭𣸭渂漌㵯𠏵畑㚼㓈䚀㻚䡱姄鉮䤾轁𨰜𦯀堒埈㛖𡑒烾𤍢𤩱𢿣𡊰𢎽梹楧𡎘𣓥𧯴𣛟𨪃𣟖𣏺𤲟樚𣚭𦲷萾䓟䓎"],["9840","𦴦𦵑𦲂𦿞漗𧄉茽𡜺菭𦲀𧁓𡟛妉媂𡞳婡婱𡤅𤇼㜭姯𡜼㛇熎鎐暚𤊥婮娫𤊓樫𣻹𧜶𤑛𤋊焝𤉙𨧡侰𦴨峂𤓎𧹍𤎽樌𤉖𡌄炦焳𤏩㶥泟勇𤩏繥姫崯㷳彜𤩝𡟟綤萦"],["98a1","咅𣫺𣌀𠈔坾𠣕𠘙㿥𡾞𪊶瀃𩅛嵰玏糓𨩙𩐠俈翧狍猐𧫴猸猹𥛶獁獈㺩𧬘遬燵𤣲珡臶㻊県㻑沢国琙琞琟㻢㻰㻴㻺瓓㼎㽓畂畭畲疍㽼痈痜㿀癍㿗癴㿜発𤽜熈嘣覀塩䀝睃䀹条䁅㗛瞘䁪䁯属瞾矋売砘点砜䂨砹硇硑硦葈𥔵礳栃礲䄃"],["9940","䄉禑禙辻稆込䅧窑䆲窼艹䇄竏竛䇏両筢筬筻簒簛䉠䉺类粜䊌粸䊔糭输烀𠳏総緔緐緽羮羴犟䎗耠耥笹耮耱联㷌垴炠肷胩䏭脌猪脎脒畠脔䐁㬹腖腙腚"],["99a1","䐓堺腼膄䐥膓䐭膥埯臁臤艔䒏芦艶苊苘苿䒰荗险榊萅烵葤惣蒈䔄蒾蓡蓸蔐蔸蕒䔻蕯蕰藠䕷虲蚒蚲蛯际螋䘆䘗袮裿褤襇覑𧥧訩訸誔誴豑賔賲贜䞘塟跃䟭仮踺嗘坔蹱嗵躰䠷軎転軤軭軲辷迁迊迌逳駄䢭飠鈓䤞鈨鉘鉫銱銮銿"],["9a40","鋣鋫鋳鋴鋽鍃鎄鎭䥅䥑麿鐗匁鐝鐭鐾䥪鑔鑹锭関䦧间阳䧥枠䨤靀䨵鞲韂噔䫤惨颹䬙飱塄餎餙冴餜餷饂饝饢䭰駅䮝騼鬏窃魩鮁鯝鯱鯴䱭鰠㝯𡯂鵉鰺"],["9aa1","黾噐鶓鶽鷀鷼银辶鹻麬麱麽黆铜黢黱黸竈齄𠂔𠊷𠎠椚铃妬𠓗塀铁㞹𠗕𠘕𠙶𡚺块煳𠫂𠫍𠮿呪吆𠯋咞𠯻𠰻𠱓𠱥𠱼惧𠲍噺𠲵𠳝𠳭𠵯𠶲𠷈楕鰯螥𠸄𠸎𠻗𠾐𠼭𠹳尠𠾼帋𡁜𡁏𡁶朞𡁻𡂈𡂖㙇𡂿𡃓𡄯𡄻卤蒭𡋣𡍵𡌶讁𡕷𡘙𡟃𡟇乸炻𡠭𡥪"],["9b40","𡨭𡩅𡰪𡱰𡲬𡻈拃𡻕𡼕熘桕𢁅槩㛈𢉼𢏗𢏺𢜪𢡱𢥏苽𢥧𢦓𢫕覥𢫨辠𢬎鞸𢬿顇骽𢱌"],["9b62","𢲈𢲷𥯨𢴈𢴒𢶷𢶕𢹂𢽴𢿌𣀳𣁦𣌟𣏞徱晈暿𧩹𣕧𣗳爁𤦺矗𣘚𣜖纇𠍆墵朎"],["9ba1","椘𣪧𧙗𥿢𣸑𣺹𧗾𢂚䣐䪸𤄙𨪚𤋮𤌍𤀻𤌴𤎖𤩅𠗊凒𠘑妟𡺨㮾𣳿𤐄𤓖垈𤙴㦛𤜯𨗨𩧉㝢𢇃譞𨭎駖𤠒𤣻𤨕爉𤫀𠱸奥𤺥𤾆𠝹軚𥀬劏圿煱𥊙𥐙𣽊𤪧喼𥑆𥑮𦭒釔㑳𥔿𧘲𥕞䜘𥕢𥕦𥟇𤤿𥡝偦㓻𣏌惞𥤃䝼𨥈𥪮𥮉𥰆𡶐垡煑澶𦄂𧰒遖𦆲𤾚譢𦐂𦑊"],["9c40","嵛𦯷輶𦒄𡤜諪𤧶𦒈𣿯𦔒䯀𦖿𦚵𢜛鑥𥟡憕娧晉侻嚹𤔡𦛼乪𤤴陖涏𦲽㘘襷𦞙𦡮𦐑𦡞營𦣇筂𩃀𠨑𦤦鄄𦤹穅鷰𦧺騦𦨭㙟𦑩𠀡禃𦨴𦭛崬𣔙菏𦮝䛐𦲤画补𦶮墶"],["9ca1","㜜𢖍𧁋𧇍㱔𧊀𧊅銁𢅺𧊋錰𧋦𤧐氹钟𧑐𠻸蠧裵𢤦𨑳𡞱溸𤨪𡠠㦤㚹尐秣䔿暶𩲭𩢤襃𧟌𧡘囖䃟𡘊㦡𣜯𨃨𡏅熭荦𧧝𩆨婧䲷𧂯𨦫𧧽𧨊𧬋𧵦𤅺筃祾𨀉澵𪋟樃𨌘厢𦸇鎿栶靝𨅯𨀣𦦵𡏭𣈯𨁈嶅𨰰𨂃圕頣𨥉嶫𤦈斾槕叒𤪥𣾁㰑朶𨂐𨃴𨄮𡾡𨅏"],["9d40","𨆉𨆯𨈚𨌆𨌯𨎊㗊𨑨𨚪䣺揦𨥖砈鉕𨦸䏲𨧧䏟𨧨𨭆𨯔姸𨰉輋𨿅𩃬筑𩄐𩄼㷷𩅞𤫊运犏嚋𩓧𩗩𩖰𩖸𩜲𩣑𩥉𩥪𩧃𩨨𩬎𩵚𩶛纟𩻸𩼣䲤镇𪊓熢𪋿䶑递𪗋䶜𠲜达嗁"],["9da1","辺𢒰边𤪓䔉繿潖檱仪㓤𨬬𧢝㜺躀𡟵𨀤𨭬𨮙𧨾𦚯㷫𧙕𣲷𥘵𥥖亚𥺁𦉘嚿𠹭踎孭𣺈𤲞揞拐𡟶𡡻攰嘭𥱊吚𥌑㷆𩶘䱽嘢嘞罉𥻘奵𣵀蝰东𠿪𠵉𣚺脗鵞贘瘻鱅癎瞹鍅吲腈苷嘥脲萘肽嗪祢噃吖𠺝㗎嘅嗱曱𨋢㘭甴嗰喺咗啲𠱁𠲖廐𥅈𠹶𢱢"],["9e40","𠺢麫絚嗞𡁵抝靭咔賍燶酶揼掹揾啩𢭃鱲𢺳冚㓟𠶧冧呍唞唓癦踭𦢊疱肶蠄螆裇膶萜𡃁䓬猄𤜆宐茋𦢓噻𢛴𧴯𤆣𧵳𦻐𧊶酰𡇙鈈𣳼𪚩𠺬𠻹牦𡲢䝎𤿂𧿹𠿫䃺"],["9ea1","鱝攟𢶠䣳𤟠𩵼𠿬𠸊恢𧖣𠿭"],["9ead","𦁈𡆇熣纎鵐业丄㕷嬍沲卧㚬㧜卽㚥𤘘墚𤭮舭呋垪𥪕𠥹"],["9ec5","㩒𢑥獴𩺬䴉鯭𣳾𩼰䱛𤾩𩖞𩿞葜𣶶𧊲𦞳𣜠挮紥𣻷𣸬㨪逈勌㹴㙺䗩𠒎癀嫰𠺶硺𧼮墧䂿噼鮋嵴癔𪐴麅䳡痹㟻愙𣃚𤏲"],["9ef5","噝𡊩垧𤥣𩸆刴𧂮㖭汊鵼"],["9f40","籖鬹埞𡝬屓擓𩓐𦌵𧅤蚭𠴨𦴢𤫢𠵱"],["9f4f","凾𡼏嶎霃𡷑麁遌笟鬂峑箣扨挵髿篏鬪籾鬮籂粆鰕篼鬉鼗鰛𤤾齚啳寃俽麘俲剠㸆勑坧偖妷帒韈鶫轜呩鞴饀鞺匬愰"],["9fa1","椬叚鰊鴂䰻陁榀傦畆𡝭駚剳"],["9fae","酙隁酜"],["9fb2","酑𨺗捿𦴣櫊嘑醎畺抅𠏼獏籰𥰡𣳽"],["9fc1","𤤙盖鮝个𠳔莾衂"],["9fc9","届槀僭坺刟巵从氱𠇲伹咜哚劚趂㗾弌㗳"],["9fdb","歒酼龥鮗頮颴骺麨麄煺笔"],["9fe7","毺蠘罸"],["9feb","嘠𪙊蹷齓"],["9ff0","跔蹏鸜踁抂𨍽踨蹵竓𤩷稾磘泪詧瘇"],["a040","𨩚鼦泎蟖痃𪊲硓咢贌狢獱謭猂瓱賫𤪻蘯徺袠䒷"],["a055","𡠻𦸅"],["a058","詾𢔛"],["a05b","惽癧髗鵄鍮鮏蟵"],["a063","蠏賷猬霡鮰㗖犲䰇籑饊𦅙慙䰄麖慽"],["a073","坟慯抦戹拎㩜懢厪𣏵捤栂㗒"],["a0a1","嵗𨯂迚𨸹"],["a0a6","僙𡵆礆匲阸𠼻䁥"],["a0ae","矾"],["a0b0","糂𥼚糚稭聦聣絍甅瓲覔舚朌聢𧒆聛瓰脃眤覉𦟌畓𦻑螩蟎臈螌詉貭譃眫瓸蓚㘵榲趦"],["a0d4","覩瑨涹蟁𤀑瓧㷛煶悤憜㳑煢恷"],["a0e2","罱𨬭牐惩䭾删㰘𣳇𥻗𧙖𥔱𡥄𡋾𩤃𦷜𧂭峁𦆭𨨏𣙷𠃮𦡆𤼎䕢嬟𦍌齐麦𦉫"],["a3c0","␀",31,"␡"],["c6a1","①",9,"⑴",9,"ⅰ",9,"丶丿亅亠冂冖冫勹匸卩厶夊宀巛⼳广廴彐彡攴无疒癶辵隶¨ˆヽヾゝゞ〃仝々〆〇ー［］✽ぁ",23],["c740","す",58,"ァアィイ"],["c7a1","ゥ",81,"А",5,"ЁЖ",4],["c840","Л",26,"ёж",25,"⇧↸↹㇏𠃌乚𠂊刂䒑"],["c8a1","龰冈龱𧘇"],["c8cd","￢￤＇＂㈱№℡゛゜⺀⺄⺆⺇⺈⺊⺌⺍⺕⺜⺝⺥⺧⺪⺬⺮⺶⺼⺾⻆⻊⻌⻍⻏⻖⻗⻞⻣"],["c8f5","ʃɐɛɔɵœøŋʊɪ"],["f9fe","￭"],["fa40","𠕇鋛𠗟𣿅蕌䊵珯况㙉𤥂𨧤鍄𡧛苮𣳈砼杄拟𤤳𨦪𠊠𦮳𡌅侫𢓭倈𦴩𧪄𣘀𤪱𢔓倩𠍾徤𠎀𠍇滛𠐟偽儁㑺儎顬㝃萖𤦤𠒇兠𣎴兪𠯿𢃼𠋥𢔰𠖎𣈳𡦃宂蝽𠖳𣲙冲冸"],["faa1","鴴凉减凑㳜凓𤪦决凢卂凭菍椾𣜭彻刋刦刼劵剗劔効勅簕蕂勠蘍𦬓包𨫞啉滙𣾀𠥔𣿬匳卄𠯢泋𡜦栛珕恊㺪㣌𡛨燝䒢卭却𨚫卾卿𡖖𡘓矦厓𨪛厠厫厮玧𥝲㽙玜叁叅汉义埾叙㪫𠮏叠𣿫𢶣叶𠱷吓灹唫晗浛呭𦭓𠵴啝咏咤䞦𡜍𠻝㶴𠵍"],["fb40","𨦼𢚘啇䳭启琗喆喩嘅𡣗𤀺䕒𤐵暳𡂴嘷曍𣊊暤暭噍噏磱囱鞇叾圀囯园𨭦㘣𡉏坆𤆥汮炋坂㚱𦱾埦𡐖堃𡑔𤍣堦𤯵塜墪㕡壠壜𡈼壻寿坃𪅐𤉸鏓㖡够梦㛃湙"],["fba1","𡘾娤啓𡚒蔅姉𠵎𦲁𦴪𡟜姙𡟻𡞲𦶦浱𡠨𡛕姹𦹅媫婣㛦𤦩婷㜈媖瑥嫓𦾡𢕔㶅𡤑㜲𡚸広勐孶斈孼𧨎䀄䡝𠈄寕慠𡨴𥧌𠖥寳宝䴐尅𡭄尓珎尔𡲥𦬨屉䣝岅峩峯嶋𡷹𡸷崐崘嵆𡺤岺巗苼㠭𤤁𢁉𢅳芇㠶㯂帮檊幵幺𤒼𠳓厦亷廐厨𡝱帉廴𨒂"],["fc40","廹廻㢠廼栾鐛弍𠇁弢㫞䢮𡌺强𦢈𢏐彘𢑱彣鞽𦹮彲鍀𨨶徧嶶㵟𥉐𡽪𧃸𢙨釖𠊞𨨩怱暅𡡷㥣㷇㘹垐𢞴祱㹀悞悤悳𤦂𤦏𧩓璤僡媠慤萤慂慈𦻒憁凴𠙖憇宪𣾷"],["fca1","𢡟懓𨮝𩥝懐㤲𢦀𢣁怣慜攞掋𠄘担𡝰拕𢸍捬𤧟㨗搸揸𡎎𡟼撐澊𢸶頔𤂌𥜝擡擥鑻㩦携㩗敍漖𤨨𤨣斅敭敟𣁾斵𤥀䬷旑䃘𡠩无旣忟𣐀昘𣇷𣇸晄𣆤𣆥晋𠹵晧𥇦晳晴𡸽𣈱𨗴𣇈𥌓矅𢣷馤朂𤎜𤨡㬫槺𣟂杞杧杢𤇍𩃭柗䓩栢湐鈼栁𣏦𦶠桝"],["fd40","𣑯槡樋𨫟楳棃𣗍椁椀㴲㨁𣘼㮀枬楡𨩊䋼椶榘㮡𠏉荣傐槹𣙙𢄪橅𣜃檝㯳枱櫈𩆜㰍欝𠤣惞欵歴𢟍溵𣫛𠎵𡥘㝀吡𣭚毡𣻼毜氷𢒋𤣱𦭑汚舦汹𣶼䓅𣶽𤆤𤤌𤤀"],["fda1","𣳉㛥㳫𠴲鮃𣇹𢒑羏样𦴥𦶡𦷫涖浜湼漄𤥿𤂅𦹲蔳𦽴凇沜渝萮𨬡港𣸯瑓𣾂秌湏媑𣁋濸㜍澝𣸰滺𡒗𤀽䕕鏰潄潜㵎潴𩅰㴻澟𤅄濓𤂑𤅕𤀹𣿰𣾴𤄿凟𤅖𤅗𤅀𦇝灋灾炧炁烌烕烖烟䄄㷨熴熖𤉷焫煅媈煊煮岜𤍥煏鍢𤋁焬𤑚𤨧𤨢熺𨯨炽爎"],["fe40","鑂爕夑鑃爤鍁𥘅爮牀𤥴梽牕牗㹕𣁄栍漽犂猪猫𤠣𨠫䣭𨠄猨献珏玪𠰺𦨮珉瑉𤇢𡛧𤨤昣㛅𤦷𤦍𤧻珷琕椃𤨦琹𠗃㻗瑜𢢭瑠𨺲瑇珤瑶莹瑬㜰瑴鏱樬璂䥓𤪌"],["fea1","𤅟𤩹𨮏孆𨰃𡢞瓈𡦈甎瓩甞𨻙𡩋寗𨺬鎅畍畊畧畮𤾂㼄𤴓疎瑝疞疴瘂瘬癑癏癯癶𦏵皐臯㟸𦤑𦤎皡皥皷盌𦾟葢𥂝𥅽𡸜眞眦着撯𥈠睘𣊬瞯𨥤𨥨𡛁矴砉𡍶𤨒棊碯磇磓隥礮𥗠磗礴碱𧘌辸袄𨬫𦂃𢘜禆褀椂禀𥡗禝𧬹礼禩渪𧄦㺨秆𩄍秔"]]')},function(e,t){},function(e,t){},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(7).Module,e.exports=function(e){var t;function n(e){this.file=e}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(n,e),n.aliasProperty("height","rows"),n.aliasProperty("width","cols"),t=["Bitmap","GrayScale","IndexedColor","RGBColor","CMYKColor","HSLColor","HSBColor","Multichannel","Duotone","LabColor","Gray16","RGB48","Lab48","CMYK64","DeepMultichannel","Duotone16"],n.prototype.sig=null,n.prototype.version=null,n.prototype.channels=null,n.prototype.rows=null,n.prototype.cols=null,n.prototype.depth=null,n.prototype.mode=null,n.prototype.parse=function(){var e;if(this.sig=this.file.readString(4),"8BPS"!==this.sig)throw new Error("Invalid file signature detected. Got: "+this.sig+". Expected 8BPS.");return this.version=this.file.readUShort(),this.file.seek(6,!0),this.channels=this.file.readUShort(),this.rows=this.height=this.file.readUInt(),this.cols=this.width=this.file.readUInt(),this.depth=this.file.readUShort(),this.mode=this.file.readUShort(),e=this.file.readUInt(),this.file.seek(e,!0)},n.prototype.modeName=function(){return t[this.mode]},n.prototype.export=function(){var e,t,n,r,i;for(e={},t=0,r=(i=["sig","version","channels","rows","cols","depth","mode"]).length;t<r;t++)e[n=i[t]]=this[n];return e},n}(t)}).call(this)},function(e,t,n){(function(){var t;t=n(70),e.exports=function(){function e(e){this.file=e,this.resources={},this.typeIndex={},this.length=null}return e.prototype.skip=function(){return this.length=this.file.readInt(),this.file.seek(this.length,!0)},e.prototype.parse=function(){var e,n,r,i;for(this.length=this.file.readInt(),e=this.length+this.file.tell();this.file.tell()<e;)(n=new t(this.file)).parse(),r=this.file.tell()+n.length,null!=(i=t.Section.factory(n))?(this.resources[i.id]=i,null!=i.name&&(this.typeIndex[i.name]=i.id),this.file.seek(r)):this.file.seek(r);return this.file.seek(e)},e.prototype.resource=function(e){return"string"==typeof e?this.byType(e):this.resources[e]},e.prototype.byType=function(e){return this.resources[this.typeIndex[e]]},e}()}).call(this)},function(e,t,n){(function(){var t;t=n(6),e.exports=function(){function e(e){this.file=e,this.id=null,this.type=null,this.length=0}return e.Section=n(71),e.prototype.parse=function(){var e;return this.type=this.file.readString(4),this.id=this.file.readShort(),e=t.pad2(this.file.readByte()+1)-1,this.name=this.file.readString(e),this.length=t.pad2(this.file.readInt())},e}()}).call(this)},function(e,t,n){(function(){var t,r=[].indexOf||function(e){for(var t=0,n=this.length;t<n;t++)if(t in this&&this[t]===e)return t;return-1};t=n(4),e.exports=function(){var e;function i(){}return e=[n(73),n(74),n(75),n(76),n(77),n(78),n(79),n(80)],i.factory=function(n){var i,o,a,s,u,c;for(o=0,s=e.length;o<s;o++){if((i=e[o]).prototype.id===n.id)return t.tap(new i(n),(function(e){return e.parse()}));if(u=n.id,r.call(function(){for(c=[],a=2e3;a<2998;a++)c.push(a);return c}.apply(this),u)>=0&&2e3===i.prototype.id)return t.tap(new i(n),(function(e){return e.parse()}))}return null},i}()}).call(this)},function(e,t){e.exports=function(e){return e.webpackPolyfill||(e.deprecate=function(){},e.paths=[],e.children||(e.children=[]),Object.defineProperty(e,"loaded",{enumerable:!0,get:function(){return e.l}}),Object.defineProperty(e,"id",{enumerable:!0,get:function(){return e.i}}),e.webpackPolyfill=1),e}},function(e,t,n){(function(){var t;t=n(3),e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=1065,e.prototype.name="layerComps",e.visibilityCaptured=function(e){return e.capturedInfo&parseInt("001",2)>0},e.positionCaptured=function(e){return e.positionCaptured&parseInt("010",2)>0},e.appearanceCaptured=function(e){return e.appearanceCaptured&parseInt("100",2)>0},e.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},e.prototype.names=function(){return this.data.list.map((function(e){return e["Nm  "]}))},e.prototype.export=function(){return this.data.list.map((function(e){return{id:e.compID,name:e["Nm  "],capturedInfo:e.capturedInfo}}))},e}()}).call(this)},function(e,t){(function(){e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file,this.linkArray=[]}return e.prototype.id=1026,e.prototype.name="LinkLayers",e.prototype.parse=function(){var e;for(e=this.file.tell()+this.resource.length;e>this.file.tell();)this.linkArray.push(this.file.readShort());return this.linkArray.reverse()},e}()}).call(this)},function(e,t){(function(){e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=1005,e.prototype.name="resolutionInfo",e.prototype.parse=function(){return this.h_res=this.file.readInt()/65536,this.h_res_unit=this.file.readShort(),this.width_unit=this.file.readShort(),this.v_res=this.file.readInt()/65536,this.v_res_unit=this.file.readShort(),this.height_unit=this.file.readShort(),this.resource.data=this},e.prototype.export=function(){var e,t,n,r,i;for(e={},t=0,r=(i=["h_res","h_res_unit","width_unit","v_res","v_res_unit","height_unit"]).length;t<r;t++)e[n=i[t]]=this[n];return e},e}()}).call(this)},function(e,t){(function(){e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=1037,e.prototype.name="globalLightAngle",e.prototype.parse=function(){return this.angle=this.file.readInt()},e}()}).call(this)},function(e,t){(function(){e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=1049,e.prototype.name="globalLightAngle",e.prototype.parse=function(){return this.altitude=this.file.readInt()},e}()}).call(this)},function(e,t,n){(function(){var t;t=n(3),e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=3e3,e.prototype.name="originPathInfo",e.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},e}()}).call(this)},function(e,t,n){(function(){var t;t=n(3),e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file}return e.prototype.id=1088,e.prototype.name="pathSelection",e.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},e}()}).call(this)},function(e,t,n){(function(){var t;t=n(24),e.exports=function(){function e(e){this.resource=e,this.file=this.resource.file,this.paths=[]}return e.prototype.id=2e3,e.prototype.name="path",e.prototype.parse=function(){var e,n,r,i;for(i=[],e=0,r=this.resource.length/26;0<=r?e<r:e>r;0<=r?++e:--e)(n=new t(this.file)).parse(),i.push(this.paths.push(n));return i},e.prototype.export=function(){return this.paths},e}()}).call(this)},function(e,t,n){(function(){var t,r,i,o,a,s,u={}.hasOwnProperty;o=n(7).Module,s=n(4),a=n(6),r=n(82),i=n(14),t={linkedLayer:n(27),unicodePath:n(125),textEngineData:n(126),filterMask:n(128)},e.exports=function(e){function o(e,t){this.file=e,this.header=t,this.layers=[],this.mergedAlpha=!1,this.globalMask=null,this.infoKeys=[],this.adjustments={}}return function(e,t){for(var n in t)u.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(o,e),o.includes(n(25)),o.prototype.skip=function(){return this.file.seek(this.file.readInt(),!0)},o.prototype.parse=function(){var e;if(e=1===this.header.version?this.file.readInt():this.file.readLongLong(),this.layerEnd=e+this.file.tell(),!(e<=0))return this.parseLayers(),this.parseGlobalMask(),this.layers.reverse(),this.parseAdditionalLayerInformation(),this.file.seek(this.layerEnd)},o.prototype.parseLayers=function(){var e,t,n,i,o,s,u,c;if(o=1===this.header.version?a.pad2(this.file.readInt()):a.pad2(this.file.readLongLong()),i=this.file.tell()+o,o>0){for((n=this.file.readShort())<0&&(n=Math.abs(n),this.mergedAlpha=!0),e=0,u=n;0<=u?e<u:e>u;0<=u?++e:--e)this.layers.push(new r(this.file,this.header).parse());for(t=0,s=(c=this.layers).length;t<s;t++)c[t].parseChannelImage()}return this.file.seek(i)},o.prototype.parseGlobalMask=function(){var e,t,n;if(!((e=this.file.readInt())<=0))return t=a.pad2(this.file.tell()+e),this.globalMask=s({}).tap((n=this,function(e){return e.overlayColorSpace=n.file.readShort(),e.colorComponents=[n.file.readShort()>>8,n.file.readShort()>>8,n.file.readShort()>>8,n.file.readShort()>>8],e.opacity=n.file.readShort()/16,e.kind=n.file.readByte()})),this.file.seek(t)},o.prototype.parseAdditionalLayerInformation=function(){var e,n,r,o,s,c,l;for(l=[];this.file.tell()<this.layerEnd;)if(this.file.seek(4,!0),n=this.file.readString(4),s=a.pad2(this.file.readInt()),this.file.tell(),!(s<=0)){for(c in r=!1,t)if(u.call(t,c)&&(o=t[c]).shouldParse(n)){e=new o(this,s),this.adjustments[c]=new i(e,this.file).now("skip").later("parse").get(),null==this[c]&&function(e){return function(t){return e[t]=function(){return e.adjustments[t]}}}(this)(c),this.infoKeys.push(n),r=!0;break}r?l.push(void 0):l.push(this.file.seek(s,!0))}return l},o}(o)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(7).Module,e.exports=function(e){function t(e,t){this.file=e,this.header=t,this.mask={},this.blendingRanges={},this.adjustments={},this.channelsInfo=[],this.blendMode={},this.groupLayer=null,this.infoKeys=[],Object.defineProperty(this,"name",{get:function(){return null!=this.adjustments.name?this.adjustments.name.data:this.legacyName}})}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.includes(n(83)),t.includes(n(84)),t.includes(n(86)),t.includes(n(88)),t.includes(n(89)),t.includes(n(25)),t.includes(n(112)),t.includes(n(113)),t.prototype.parse=function(){var e;return this.parsePositionAndChannels(),this.parseBlendModes(),e=this.file.readInt(),this.layerEnd=this.file.tell()+e,this.parseMaskData(),this.parseBlendingRanges(),this.parseLegacyLayerName(),this.parseLayerInfo(),this.file.seek(this.layerEnd),this},t.prototype.export=function(){return{name:this.name,top:this.top,right:this.right,bottom:this.bottom,left:this.left,width:this.width,height:this.height,opacity:this.opacity,visible:this.visible,clipped:this.clipped,mask:this.mask.export()}},t}(t)}).call(this)},function(e,t){(function(){e.exports={parsePositionAndChannels:function(){var e,t,n,r,i;for(this.top=this.file.readInt(),this.left=this.file.readInt(),this.bottom=this.file.readInt(),this.right=this.file.readInt(),this.channels=this.file.readShort(),this.rows=this.height=this.bottom-this.top,this.cols=this.width=this.right-this.left,i=[],t=0,r=this.channels;0<=r?t<r:t>r;0<=r?++t:--t)e=this.file.readShort(),n=1===this.header.version?this.file.readInt():this.file.readLongLong(),i.push(this.channelsInfo.push({id:e,length:n}));return i}}}).call(this)},function(e,t,n){(function(){var t;t=n(85),e.exports={parseBlendModes:function(){return this.blendMode=new t(this.file),this.blendMode.parse(),this.opacity=this.blendMode.opacity,this.visible=this.blendMode.visible,this.clipped=this.blendMode.clipped},hidden:function(){return!this.visible},blendingMode:function(){return this.blendMode.mode}}}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(7).Module,e.exports=function(e){var t;function n(e){this.file=e,this.blendKey=null,this.opacity=null,this.clipping=null,this.clipped=null,this.flags=null,this.mode=null,this.visible=null}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(n,e),n.aliasProperty("blendingMode","mode"),t={norm:"normal",dark:"darken",lite:"lighten",hue:"hue",sat:"saturation",colr:"color",lum:"luminosity",mul:"multiply",scrn:"screen",diss:"dissolve",over:"overlay",hLit:"hard_light",sLit:"soft_light",diff:"difference",smud:"exclusion",div:"color_dodge",idiv:"color_burn",lbrn:"linear_burn",lddg:"linear_dodge",vLit:"vivid_light",lLit:"linear_light",pLit:"pin_light",hMix:"hard_mix",pass:"passthru",dkCl:"darker_color",lgCl:"lighter_color",fsub:"subtract",fdiv:"divide"},n.prototype.parse=function(){return this.file.seek(4,!0),this.blendKey=this.file.readString(4).trim(),this.opacity=this.file.readByte(),this.clipping=this.file.readByte(),this.flags=this.file.readByte(),this.mode=t[this.blendKey],this.clipped=1===this.clipping,this.visible=!((2&this.flags)>0),this.file.seek(1,!0)},n.prototype.opacityPercentage=function(){return 100*this.opacity/255},n}(t)}).call(this)},function(e,t,n){(function(){var t;t=n(87),e.exports={parseMaskData:function(){return this.mask=new t(this.file).parse()}}}).call(this)},function(e,t){(function(){e.exports=function(){function e(e){this.file=e,this.top=0,this.right=0,this.bottom=0,this.left=0}return e.prototype.parse=function(){var e;return this.size=this.file.readInt(),0===this.size||(e=this.file.tell()+this.size,this.top=this.file.readInt(),this.left=this.file.readInt(),this.bottom=this.file.readInt(),this.right=this.file.readInt(),this.defaultColor=this.file.readByte(),this.flags=this.file.readByte(),20===this.size&&(this.padding=this.file.readShort()),this.size>=36&&(this.flags=this.file.readByte(),this.defaultColor=this.file.readByte(),this.top=this.file.readInt(),this.left=this.file.readInt(),this.bottom=this.file.readInt(),this.right=this.file.readInt()),this.width=this.right-this.left,this.height=this.bottom-this.top,this.relative=(1&this.flags)>0,this.disabled=(2&this.flags)>0,this.invert=(4&this.flags)>0,this.external=(8&this.flags)>0,this.file.seek(e)),this},e.prototype.export=function(){return 0===this.size?{}:{top:this.top,left:this.left,bottom:this.bottom,right:this.right,width:this.width,height:this.height,defaultColor:this.defaultColor,relative:this.relative,disabled:this.disabled,invert:this.invert,padding:this.padding,external:this.external}},e}()}).call(this)},function(e,t){(function(){e.exports={parseBlendingRanges:function(){var e,t,n,r,i;if(0!==(t=this.file.readInt())){for(this.blendingRanges.grey={source:{black:[this.file.readByte(),this.file.readByte()],white:[this.file.readByte(),this.file.readByte()]},dest:{black:[this.file.readByte(),this.file.readByte()],white:[this.file.readByte(),this.file.readByte()]}},n=(t-8)/8,this.blendingRanges.channels=[],i=[],e=0,r=n;0<=r?e<r:e>r;0<=r?++e:--e)i.push(this.blendingRanges.channels.push({source:{black:[this.file.readByte(),this.file.readByte()],white:[this.file.readByte(),this.file.readByte()]},dest:{black:[this.file.readByte(),this.file.readByte()],white:[this.file.readByte(),this.file.readByte()]}}));return i}}}}).call(this)},function(e,t,n){(function(){var t;t=n(6),e.exports={parseLegacyLayerName:function(){var e;return e=t.pad4(this.file.readByte()),this.legacyName=this.file.readString(e)}}}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"artb"===e},n.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},n.prototype.export=function(){return{coords:{left:this.data.artboardRect.Left,top:this.data.artboardRect["Top "],right:this.data.artboardRect.Rght,bottom:this.data.artboardRect.Btom}}},n}(r)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"clbl"===e},t.prototype.parse=function(){return this.enabled=this.file.readBoolean(),this.file.seek(3,!0)},t}(t)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"infx"===e},t.prototype.parse=function(){return this.enabled=this.file.readBoolean(),this.file.seek(3,!0)},t}(t)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"iOpa"===e},t.prototype.parse=function(){var e,t;return t=this.file.readByte(),e=Math.round(100*t/255),"Percent",this.data.opacity=e,this.data.unit="Percent"},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"GdFl"===e},n.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"lyid"===e},t.prototype.parse=function(){return this.id=this.file.readInt()},t}(t)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"lnsr"===e},t.prototype.parse=function(){return this.id=this.file.readString(4)},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(4),t=n(26),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n),this.transform={},this.faces=[],this.styles=[],this.lines=[],this.type=0,this.scalingFactor=0,this.characterCount=0,this.horzPlace=0,this.vertPlace=0,this.selectStart=0,this.selectEnd=0,this.color=null,this.antialias=null}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"tySh"===e},t.prototype.parse=function(){var e,t,n,i,o,a;for(this.file.seek(2,!0),this.parseTransformInfo(),this.file.seek(2,!0),e=0,i=this.file.readShort();0<=i?e<i:e>i;0<=i?++e:--e)this.faces.push(r({}).tap(function(e){return function(t){var n,r,i;for(t.mark=e.file.readShort(),t.fontType=e.file.readInt(),t.fontName=e.file.readString(),t.fontFamilyName=e.file.readString(),t.fontStyleName=e.file.readString(),t.script=e.file.readShort(),t.numberAxesVector=e.file.readInt(),t.vector=[],i=[],n=0,r=t.numberAxesVector;0<=r?n<r:n>r;0<=r?++n:--n)i.push(t.vector.push(e.file.readInt()));return i}}(this)));for(t=0,o=this.file.readShort();0<=o?t<o:t>o;0<=o?++t:--t)this.styles.push(r({}).tap(function(e){return function(t){return t.mark=e.file.readShort(),t.faceMark=e.file.readShort(),t.size=e.file.readInt(),t.tracking=e.file.readInt(),t.kerning=e.file.readInt(),t.leading=e.file.readInt(),t.baseShift=e.file.readInt(),t.autoKern=e.file.readBoolean(),e.file.seek(1,!0),t.rotate=e.file.readBoolean()}}(this)));for(this.type=this.file.readShort(),this.scalingFactor=this.file.readInt(),this.characterCount=this.file.readInt(),this.horzPlace=this.file.readInt(),this.vertPlace=this.file.readInt(),this.selectStart=this.file.readInt(),this.selectEnd=this.file.readInt(),n=0,a=this.file.readShort();0<=a?n<a:n>a;0<=a?++n:--n)this.lines.push(r({}).tap((function(e){return e.charCount=this.file.readInt(),e.orientation=this.file.readShort(),e.alignment=this.file.readShort(),e.actualChar=this.file.readShort(),e.style=this.file.readShort()})));return this.color=this.file.readSpaceColor(),this.antialias=this.file.readBoolean()},t}(t)}).call(this)},function(e,t,n){(function(t){var r=n(16),i=[function(e){return{match:c(/^<<$/,e),parse:function(){l({})}}},function(e){return{match:c(/^>>$/,e),parse:function(){f()}}},function(e){var t=/^\/(\w+) \[$/;return{match:c(t,e),parse:function(){a.push(e.match(t)[1]),l([])}}},function(e){return{match:c(/^\]$/,e),parse:function(){f()}}},function(e){var t=/^\/([A-Z0-9]+)$/i;return{match:c(t,e),parse:function(){a.push(e.match(t)[1])}}},function(e){var t=/^\/([A-Z0-9]+)\s((.|\r)*)$/i;return{match:c(t,e),parse:function(){var n,r,i=e.match(t);n=i[1],r=u(i[2]),s[n]=r}}},function(e){var t=/^\[(.*)\]$/;return{match:c(t,e),parse:function(){for(var n=e.match(t)[1].trim().split(" "),r=[],i=0,o=n.length;i<o;i++)r.push(u(n[i]));return r}}},function(e){return{match:c(/^(true|false)$/,e),parse:function(){return"true"===e}}},function(e){return{match:c(/^-?\d+$/,e),parse:function(){return Number(e)}}},function(e){return{match:c(/^(-?\d*)\.(\d+)$/,e),parse:function(){return Number(e)}}},function(e){var n=/^\(((.|\r)*)\)$/;return{match:c(n,e),parse:function(){for(var i=e.match(n)[1],o=[],a=0,s=i.length;a<s;a++)o.push(i.charCodeAt(a));return r.decode(new t(o),"utf-16")}}}],o=[],a=[],s=[];function u(e){for(var t in i){var n=new i[t](e);if(n.match)return n.parse()}return e}function c(e,t){return e.test(t)}function l(e){o.push(s),s=e}function f(){var e,t=o.pop();e=t,"[object Array]"===Object.prototype.toString.call(e)?t.push(s):t[a.pop()]=s,s=t}e.exports=function(e){var t;return o=a=s=[],t=function(e){return String.fromCharCode.apply(null,e)}(e),t.split("\n").map((function(e){u(e.replace(/^\t+/g,""))})),s.shift()}}).call(this,n(11).Buffer)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n),this.transparencyLocked=!1,this.compositeLocked=!1,this.positionLocked=!1,this.allLocked=!1}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"lspf"===e},t.prototype.parse=function(){var e;return e=this.file.readInt(),this.transparencyLocked=(1&e)>0||-2147483648===e,this.compositeLocked=(2&e)>0||-2147483648===e,this.positionLocked=(4&e)>0||-2147483648===e,this.allLocked=this.transparencyLocked&&this.compositeLocked&&this.positionLocked},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"shmd"===e},n.prototype.parse=function(){var e,t,n,r,i,o;for(o=[],t=0,i=this.file.readInt();0<=i?t<i:t>i;0<=i?++t:--t)this.file.seek(4,!0),n=this.file.readString(4),this.file.readByte(),this.file.seek(3,!0),r=this.file.readInt(),e=this.file.tell()+r,"cmls"===n&&this.parseLayerComps(),o.push(this.file.seek(e));return o},n.prototype.parseLayerComps=function(){return this.file.seek(4,!0),this.data.layerComp=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"luni"===e},t.prototype.parse=function(){var e;return e=this.file.tell(),this.data=this.file.readUnicodeString(),this.file.seek(e+this.length),this},t}(t)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n),this.isFolder=!1,this.isHidden=!1}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"lsdk"===e},t.prototype.parse=function(){switch(this.file.readInt()){case 1:case 2:return this.isFolder=!0;case 3:return this.isHidden=!0}},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"lfx2"===e||"lmfx"===e},n.prototype.parse=function(){return this.file.seek(8,!0),this.data=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){var t;function n(e,t){n.__super__.constructor.call(this,e,t),this.isFolder=!1,this.isHidden=!1,this.layerType=null,this.blendMode=null,this.subType=null}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"lsct"===e},t=["other","open folder","closed folder","bounding section divider"],n.prototype.parse=function(){var e;switch(e=this.file.readInt(),this.layerType=t[e],e){case 1:case 2:this.isFolder=!0;break;case 3:this.isHidden=!0}if(this.length>=12&&(this.file.seek(4,!0),this.blendMode=this.file.readString(4),this.length>=16))return this.subType=0===this.file.readInt()?"normal":"scene group"},n}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(e,t){n.__super__.constructor.call(this,e,t),this.r=this.g=this.b=0}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"SoCo"===e},n.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse(),this.r=Math.round(this.colorData()["Rd  "]),this.g=Math.round(this.colorData()["Grn "]),this.b=Math.round(this.colorData()["Bl  "])},n.prototype.colorData=function(){return this.data["Clr "]},n.prototype.color=function(){return[this.r,this.g,this.b]},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;t=n(1),r=n(24),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n),this.invert=null,this.notLink=null,this.disable=null,this.paths=[]}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"vmsk"===e||"vsms"===e},t.prototype.parse=function(){var e,t,n,i,o;for(this.file.seek(4,!0),o=this.file.readInt(),this.invert=(1&o)>0,this.notLink=(2&o)>0,this.disable=(4&o)>0,i=[],e=0,n=(this.length-10)/26;0<=n?e<n:e>n;0<=n?++e:--e)(t=new r(this.file)).parse(),i.push(this.paths.push(t));return i},t.prototype.export=function(){return{invert:this.invert,notLink:this.notLink,disable:this.disable,paths:this.paths.map((function(e){return e.export()}))}},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"vogk"===e},n.prototype.parse=function(){return this.file.seek(8,!0),this.data=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"vstk"===e},n.prototype.parse=function(){return this.file.seek(4,!0),this.data=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"vscg"===e},n.prototype.parse=function(){return this.file.seek(8,!0),this.data=new t(this.file).parse()},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i,o={}.hasOwnProperty;r=n(1),i=n(6),t=n(3),e.exports=function(e){function n(e,t){n.__super__.constructor.call(this,e,t),this.Trnf=[]}return function(e,t){for(var n in t)o.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"PlLd"===e},n.prototype.parse=function(){var e;return this.identifier=this.file.readString(),this.version=this.file.readInt(),e=i.pad2(this.file.readByte()),this.Idnt=this.file.readString(e),this.PgNm=this.file.parseInt(),this.totalPages=this.file.parseInt(),this.Annt=this.file.readInt(),this.Type=this.file.readInt(),this.parseTransformInfo(),this.warpValue=this.file.readInt(),this.file.seek(4,!0),this.warpData=new t(this.file).parse(),this},n.prototype.parseTransformInfo=function(){var e,t;for(8,t=[],e=0,8;e<8;++e)t.push(this.Trnf.push(this.file.readDouble()));return t},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(e,t){n.__super__.constructor.call(this,e,t)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"SoLd"===e},n.prototype.parse=function(){return this.identifier=this.file.readString(),this.version=this.file.readInt(),this.file.seek(4,!0),this.data=new t(this.file).parse(),this},n}(r)}).call(this)},function(e,t){(function(){e.exports={isFolder:function(){return null!=this.adjustments.sectionDivider?this.adjustments.sectionDivider.isFolder:null!=this.adjustments.nestedSectionDivider?this.adjustments.nestedSectionDivider.isFolder:"<Layer group>"===this.name},isFolderEnd:function(){return null!=this.adjustments.sectionDivider?this.adjustments.sectionDivider.isHidden:null!=this.adjustments.nestedSectionDivider?this.adjustments.nestedSectionDivider.isHidden:"</Layer group>"===this.name}}}).call(this)},function(e,t,n){(function(){var t,r;t=n(114),r=n(14),e.exports={parseChannelImage:function(){var e;return e=new t(this.file,this.header,this),this.image=new r(e,this.file).now("skip").later("parse").get()}}}).call(this)},function(e,t,n){(function(){var t,r,i,o={}.hasOwnProperty;i=n(4),t=n(28),r=n(29),e.exports=function(e){function t(e,n,r){this.layer=r,this._width=this.layer.width,this._height=this.layer.height,t.__super__.constructor.call(this,e,n),this.channelsInfo=this.layer.channelsInfo,this.hasMask=i.any(this.channelsInfo,(function(e){return e.id<-1})),this.opacity=this.layer.opacity/255}return function(e,t){for(var n in t)o.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.includes(r.LayerRAW),t.includes(r.LayerRLE),t.prototype.skip=function(){var e,t,n,r,i;for(i=[],t=0,n=(r=this.channelsInfo).length;t<n;t++)e=r[t],i.push(this.file.seek(e.length,!0));return i},t.prototype.width=function(){return this._width},t.prototype.height=function(){return this._height},t.prototype.channels=function(){return this.layer.channels},t.prototype.parse=function(){var e,t,n,r,i;for(this.chanPos=0,t=0,n=(r=this.channelsInfo).length;t<n;t++)(e=r[t]).length<=0?this.parseCompression():(this.chan=e,e.id<-1?(this._width=this.layer.mask.width,this._height=this.layer.mask.height):(this._width=this.layer.width,this._height=this.layer.height),this.length=this._width*this._height,i=this.file.tell(),this.parseImageData(),this.file.tell()!==i+this.chan.length&&this.file.seek(i+this.chan.length));return this._width=this.layer.width,this._height=this.layer.height,this.processImageData()},t.prototype.parseImageData=function(){switch(this.compression=this.parseCompression(),this.compression){case 0:return this.parseRaw();case 1:return this.parseRLE();case 2:case 3:return this.parseZip();default:return this.file.seek(this.endPos)}},t}(t)}).call(this)},function(e,t){(function(){e.exports={parseRaw:function(){return this.channelData.set(this.file.read(this.length))}}}).call(this)},function(e,t){(function(){e.exports={parseRLE:function(){return this.byteCounts=this.parseByteCounts(),this.parseChannelData()},parseByteCounts:function(){var e,t,n;for(n=[],e=0,t=this.channels()*this.height();0<=t?e<t:e>t;0<=t?++e:--e)1===this.header.version?n.push(this.file.readShort()):n.push(this.file.readInt());return n},parseChannelData:function(){var e,t,n;for(this.chanPos=0,this.lineIndex=0,n=[],e=0,t=this.channels();0<=t?e<t:e>t;0<=t?++e:--e)this.decodeRLEChannel(),n.push(this.lineIndex+=this.height());return n},decodeRLEChannel:function(){var e,t,n,r,i,o,a,s,u;for(s=[],r=i=0,a=this.height();0<=a?i<a:i>a;r=0<=a?++i:--i)e=this.byteCounts[this.lineIndex+r],n=this.file.tell()+e,s.push(function(){var e;for(e=[];this.file.tell()<n;)(o=this.file.read(1)[0])<128?(o+=1,t=this.file.read(o),this.channelData.set(t,this.chanPos),e.push(this.chanPos+=o)):o>128?(o^=255,o+=2,u=this.file.read(1)[0],this.channelData.fill(u,this.chanPos,this.chanPos+o),e.push(this.chanPos+=o)):e.push(void 0);return e}.call(this));return s}}}).call(this)},function(e,t){(function(){e.exports={parseByteCounts:function(){var e,t,n;for(n=[],e=0,t=this.height();0<=t?e<t:e>t;0<=t?++e:--e)1===this.header.version?n.push(this.file.readShort()):n.push(this.file.readInt());return n},parseChannelData:function(){return this.lineIndex=0,this.decodeRLEChannel()}}}).call(this)},function(e,t){(function(){e.exports={parseRaw:function(){var e,t,n,r;for(e=t=n=this.chanPos,r=this.chanPos+this.chan.length-2;n<=r?t<r:t>r;e=n<=r?++t:--t)this.channelData[e]=this.file.readByte();return this.chanPos+=this.chan.length-2}}}).call(this)},function(e,t,n){(function(){e.exports={Greyscale:n(120),RGB:n(121),CMYK:n(122)}}).call(this)},function(e,t){(function(){e.exports={setGreyscaleChannels:function(){if(this.channelsInfo=[{id:0}],2===this.channels())return this.channelsInfo.push({id:-1})},combineGreyscaleChannel:function(){var e,t,n,r,i,o;for(o=[],n=r=0,i=this.numPixels;0<=i?r<i:r>i;n=0<=i?++r:--r)t=this.channelData[n],e=2===this.channels()?this.channelData[this.channelLength+n]:255,o.push(this.pixelData.set([t,t,t,e],4*n));return o}}}).call(this)},function(e,t){(function(){e.exports={setRgbChannels:function(){if(this.channelsInfo=[{id:0},{id:1},{id:2}],4===this.channels())return this.channelsInfo.push({id:-1})},combineRgbChannel:function(){var e,t,n,r,i,o,a,s,u,c,l,f,h;for(f=this.channelsInfo.map((function(e){return e.id})).filter((function(e){return e>=-1})),i=a=0,l=this.numPixels;0<=l?a<l:a>l;i=0<=l?++a:--a){for(c=r=t=0,e=255,o=s=0,u=f.length;s<u;o=++s)switch(n=f[o],h=this.channelData[i+this.channelLength*o],n){case-1:e=h;break;case 0:c=h;break;case 1:r=h;break;case 2:t=h}this.pixelData.set([c,r,t,e],4*i)}return this.readMaskData(f)},readMaskData:function(e){var t,n,r,i,o,a,s;if(this.hasMask){for(r=this.layer.mask.width*this.layer.mask.height,i=this.channelLength*e.length,a=[],t=n=0,o=r;0<=o?n<o:n>o;t=0<=o?++n:--n)s=this.channelData[t+i],a.push(this.maskData.set([0,0,0,s],4*t));return a}}}}).call(this)},function(e,t,n){(function(){var t;t=n(23),e.exports={setCmykChannels:function(){if(this.channelsInfo=[{id:0},{id:1},{id:2},{id:3}],5===this.channels())return this.channelsInfo.push({id:-1})},combineCmykChannel:function(){var e,n,r,i,o,a,s,u,c,l,f,h,p,d,v,g,y,m;for(o=this.channelsInfo.map((function(e){return e.id})).filter((function(e){return e>=-1})),s=c=0,v=this.numPixels;0<=v?c<v:c>v;s=0<=v?++c:--c){for(r=p=m=l=0,e=255,u=f=0,h=o.length;f<h;u=++f)switch(i=o[u],y=this.channelData[s+this.channelLength*u],i){case-1:e=y;break;case 0:r=y;break;case 1:p=y;break;case 2:m=y;break;case 3:l=y}d=(g=t.cmykToRgb(255-r,255-p,255-m,255-l))[0],a=g[1],n=g[2],this.pixelData.set([d,a,n,e],4*s)}return this.readMaskData(o)}}}).call(this)},function(e,t,n){(function(){e.exports={PNG:n(124)}}).call(this)},function(e,t,n){(function(){n(15),e.exports={toBase64:function(){var e,t,n,r,i,o,a,s,u;for((e=document.createElement("canvas")).width=this.width(),e.height=this.height(),s=(r=(t=e.getContext("2d")).getImageData(0,0,this.width(),this.height())).data,n=i=0,o=(u=this.pixelData).length;i<o;n=++i)a=u[n],s[n]=a;return t.putImageData(r,0,0),e.toDataURL("image/png")},toPng:function(){var e,t;return e=this.toBase64(),(t=new Image).width=this.width(),t.height=this.height(),t.src=e,t},saveAsPng:function(){throw"Not available in the browser. Use toPng() instead."}}}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(1),t=n(3),e.exports=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.shouldParse=function(e){return"pths"===e},n.prototype.parse=function(){return this.file.seek(4),this.data=new t(this.file).parse(),this},n}(r)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;t=n(1),r=n(127),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n),this.textEngineData=null}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"Txt2"===e},t.prototype.parse=function(){var e;return e=this.file.read(this.length),this.textEngineData=r(e)},t.prototype.export=function(){return{textEngineData:this.textEngineData}},t}(t)}).call(this)},function(e,t,n){(function(t){(function(){var r,i,o,a,s,u,c,l,f;s=n(16),u=0,c="",l=function(e){return c=o(e),a(c).parse()},o=function(e){return String.fromCharCode.apply(null,e)},i=function(e,t){return e.test(t)},r=[a=function(e){return{type:"hashStart",match:i(/^<<$/,e),parse:function(){var e,t,n,r,i;for(n={};u<c.length;)if(t="",i="","property"===(e=f(c.substring(u)).parser).type)t=e.parse(),"multiLineArrayStart"===(r=f(c.substring(u)).parser).type||"hashStart"===r.type?i=r.parse(c.substring(u)):r&&(i=r.parse()),n[t]=i;else if("hashEnd"===e.type)break;return n}}},function(e){return{type:"hashEnd",match:i(/^>>(\x00)*$/,e)}},function(e){return{type:"multiLineArrayStart",match:i(/^\[$/,e),parse:function(){var e,t,n;for(e=[];u<c.length&&(n="","multiLineArrayEnd"!==(t=f(c.substring(u)).parser).type);)"multiLineArrayStart"===t.type||"hashStart"===t.type?n=t.parse(c.substring(u)):t&&(n=t.parse()),e.push(n);return e}}},function(e){return{type:"multiLineArrayEnd",match:i(/^\]$/,e)}},function(e){var t;return{type:"property",match:i(t=/^\/([a-zA-Z0-9]+)$/i,e),parse:function(){return e.match(t)[1]}}},function(e){return{type:"unknownTag",match:i(/^\([a-zA-Z0-9]*\)$/,e),parse:function(){return e}}},function(e){return{type:"boolean",match:i(/^(true|false)$/,e),parse:function(){return"true"===e}}},function(e){return{type:"number",match:i(/^-?\d+$/,e),parse:function(){return Number(e)}}},function(e){return{type:"numberWithDecimal",match:i(/^(-?\d*)\.(\d+)$/,e),parse:function(){return Number(e)}}},function(e){var n;return{name:"string",match:i(n=/^\((\xfe\xff([^\)]|\\\))*)\)$/,e),parse:function(){var r,i,o,a;for(r=[],i=0,o=(a=e.match(n)[1]).length;i<o;)r.push(a.charCodeAt(i)),i++;return s.decode(new t(r),"utf-16")}}}],f=function(e){var t,n,i,o,a;return t=/[ \n\t]+/,a=/\(\xfe\xff/,o=/[^\\]\)/,i=0,(n=function(){var s,c,l,f,h,p,d,v;if(d=e.substring(i),v="",(p=a.exec(d))&&0===p.index)(c=o.exec(d)).index>0&&(l=c.index+c[0].length,v=d.substring(0,l),i+=l);else if(f=t.exec(d)){if(v=d.substring(0,f.index),i=i+f.index+f[0].length,""===v)return n()}else v=d.substring(i),u+=d.length;for(s in u+=i,r)if((h=new r[s](v)).match)return{parser:h,token:v}})()},e.exports=l}).call(this)}).call(this,n(11).Buffer)},function(e,t,n){(function(){var t,r={}.hasOwnProperty;t=n(1),e.exports=function(e){function t(e,n){t.__super__.constructor.call(this,e,n)}return function(e,t){for(var n in t)r.call(t,n)&&(e[n]=t[n]);function i(){this.constructor=e}i.prototype=t.prototype,e.prototype=new i,e.__super__=t.prototype}(t,e),t.shouldParse=function(e){return"FMsk"===e},t.prototype.parse=function(){return this.color=this.file.readSpaceColor(),this.opacity=this.file.readShort()},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i,o,a={}.hasOwnProperty;o=n(4),i=n(18),t=n(133),r=n(134),e.exports=function(e){function n(e){this.psd=e,n.__super__.constructor.call(this,n.layerForPsd(this.psd)),this.buildHeirarchy()}return function(e,t){for(var n in t)a.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(n,e),n.layerForPsd=function(e){var t,n,r,o;for(n={},t=0,r=(o=i.PROPERTIES).length;t<r;t++)n[o[t]]=null;return n.top=0,n.left=0,n.right=e.header.width,n.bottom=e.header.height,n},n.prototype.type="root",n.prototype.documentDimensions=function(){return[this.width,this.height]},n.prototype.depth=function(){return 0},n.prototype.opacity=function(){return 255},n.prototype.fillOpacity=function(){return 255},n.prototype.export=function(){var e,t;return{children:this._children.map((function(e){return e.export()})),document:{width:this.width,height:this.height,resources:{layerComps:(null!=(e=this.psd.resources.resource("layerComps"))?e.export():void 0)||[],resolutionInfo:(null!=(t=this.psd.resources.resource("resolutionInfo"))?t.export():void 0)||[],guides:[],slices:[]}}}},n.prototype.buildHeirarchy=function(){var e,n,i,a,s,u,c;for(e=this,u=[],n=0,a=(c=this.psd.layers).length;n<a;n++)(i=c[n]).isFolder()?(u.push(e),e=new t(i,o.last(u))):i.isFolderEnd()?((s=u.pop()).children().push(e),e=s):e.children().push(new r(i,e));return this.updateDimensions()},n}(i)}).call(this)},function(e,t,n){(function(){var t;t=n(4),e.exports={root:function(){return this.isRoot()?this:this.parent.root()},isRoot:function(){return 0===this.depth()},children:function(){return this._children},ancestors:function(){return null==this.parent||this.parent.isRoot()?[]:this.parent.ancestors().concat([this.parent])},hasChildren:function(){return this._children.length>0},childless:function(){return!this.hasChildren()},siblings:function(){return null==this.parent?[]:this.parent.children()},nextSibling:function(){var e;return null==this.parent?null:(e=this.siblings().indexOf(this),this.siblings()[e+1])},prevSibling:function(){var e;return null==this.parent?null:(e=this.siblings().indexOf(this),this.siblings()[e-1])},hasSiblings:function(){return this.siblings().length>1},onlyChild:function(){return!this.hasSiblings()},descendants:function(){return t.flatten(this._children.map((function(e){return e.subtree()})))},subtree:function(){return[this].concat(this.descendants())},depth:function(){return this.ancestors().length+1},path:function(e){var t;return null==e&&(e=!1),t=this.ancestors().map((function(e){return e.name})).concat([this.name]),e?t:t.join("/")}}}).call(this)},function(e,t,n){(function(){var t;t=n(4),e.exports={childrenAtPath:function(e,n){var r,i;return null==n&&(n={}),Array.isArray(e)||(e=e.split("/").filter((function(e){return e.length>0}))),e=t.clone(e),i=e.shift(),r=this.children().filter((function(e){return n.caseSensitive?e.name===i:e.name.toLowerCase()===i.toLowerCase()})),0===e.length?r:t.flatten(r.map((function(r){return r.childrenAtPath(t.clone(e),n)})))}}}).call(this)},function(e,t){(function(){e.exports={toPng:function(){return this.layer.image.toPng()},saveAsPng:function(e){return this.layer.image.saveAsPng(e)}}}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(4),t=n(18),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.prototype.type="group",t.prototype.passthruBlending=function(){return"passthru"===this.get("blendingMode")},t.prototype.isEmpty=function(){var e;if(!function(){var t,n,r,i;for(i=[],t=0,n=(r=this._children).length;t<n;t++)e=r[t],i.push(e.isEmpty());return i}.call(this))return!1},t.prototype.export=function(){return r.merge(t.__super__.export.call(this),{type:"group",children:this._children.map((function(e){return e.export()}))})},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i={}.hasOwnProperty;r=n(4),t=n(18),e.exports=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return function(e,t){for(var n in t)i.call(t,n)&&(e[n]=t[n]);function r(){this.constructor=e}r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype}(t,e),t.prototype.type="layer",t.prototype.isEmpty=function(){return 0===this.width||0===this.height},t.prototype.export=function(){var e;return r.merge(t.__super__.export.call(this),{type:"layer",mask:this.layer.mask.export(),text:null!=(e=this.get("typeTool"))?e.export():void 0,image:{}})},t}(t)}).call(this)},function(e,t,n){(function(){var t;t=n(15),e.exports={extended:function(e){return this.fromURL=function(n){return new t.Promise((function(t,r){var i;return(i=new XMLHttpRequest).open("GET",n,!0),i.responseType="arraybuffer",i.onload=function(){var n,o;n=new Uint8Array(i.response||i.mozResponseArrayBuffer);try{return(o=new e(n)).parse(),t(o)}catch(e){return r(e)}},i.send(null)}))},this.fromEvent=function(n){return new t.Promise((function(t,r){var i,o;return i=n.dataTransfer.files[0],(o=new FileReader).onload=function(n){var i;try{return(i=new e(new Uint8Array(n.target.result))).parse(),t(i)}catch(e){return r(e)}},o.onerror=r,o.readAsArrayBuffer(i)}))},this.fromDroppedFile=function(n){return new t.Promise((function(t,r){var i;return(i=new FileReader).onload=function(n){var i;try{return(i=new e(new Uint8Array(n.target.result))).parse(),t(i)}catch(e){return r(e)}},i.onerror=r,i.readAsArrayBuffer(n)}))}}}}).call(this)},function(e,t,n){var r={injectType:"linkTag",insert:"head"};n(137)(n(138),r)},function(e,t,n){"use strict";var r,i=(r={},function(e){if(void 0===r[e]){var t=document.querySelector(e);if(window.HTMLIFrameElement&&t instanceof window.HTMLIFrameElement)try{t=t.contentDocument.head}catch(e){t=null}r[e]=t}return r[e]});e.exports=function(e,t){if((t=t||{}).attributes="object"==typeof t.attributes?t.attributes:{},void 0===t.attributes.nonce){var r=n.nc;r&&(t.attributes.nonce=r)}var o=document.createElement("link");if(o.rel="stylesheet",o.href=e,Object.keys(t.attributes).forEach((function(e){o.setAttribute(e,t.attributes[e])})),"function"==typeof t.insert)t.insert(o);else{var a=i(t.insert||"head");if(!a)throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");a.appendChild(o)}return function(e){"string"==typeof e?o.href=e:o.parentNode.removeChild(o)}}},function(e,t,n){e.exports=n.p+"_統合.css"}]);